# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetProjectIssueLabelEventsResult',
    'AwaitableGetProjectIssueLabelEventsResult',
    'get_project_issue_label_events',
    'get_project_issue_label_events_output',
]

@pulumi.output_type
class GetProjectIssueLabelEventsResult:
    """
    A collection of values returned by getProjectIssueLabelEvents.
    """
    def __init__(__self__, events=None, id=None, issue_iid=None, pages_returned=None, project=None):
        if events and not isinstance(events, list):
            raise TypeError("Expected argument 'events' to be a list")
        pulumi.set(__self__, "events", events)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if issue_iid and not isinstance(issue_iid, int):
            raise TypeError("Expected argument 'issue_iid' to be a int")
        pulumi.set(__self__, "issue_iid", issue_iid)
        if pages_returned and not isinstance(pages_returned, int):
            raise TypeError("Expected argument 'pages_returned' to be a int")
        pulumi.set(__self__, "pages_returned", pages_returned)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)

    @_builtins.property
    @pulumi.getter
    def events(self) -> Sequence['outputs.GetProjectIssueLabelEventsEventResult']:
        """
        List of label events for the issue.
        """
        return pulumi.get(self, "events")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="issueIid")
    def issue_iid(self) -> _builtins.int:
        """
        The internal ID of the issue.
        """
        return pulumi.get(self, "issue_iid")

    @_builtins.property
    @pulumi.getter(name="pagesReturned")
    def pages_returned(self) -> Optional[_builtins.int]:
        """
        Number of pages to return. Default is 1.
        """
        return pulumi.get(self, "pages_returned")

    @_builtins.property
    @pulumi.getter
    def project(self) -> _builtins.str:
        """
        The ID or full path of the project.
        """
        return pulumi.get(self, "project")


class AwaitableGetProjectIssueLabelEventsResult(GetProjectIssueLabelEventsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectIssueLabelEventsResult(
            events=self.events,
            id=self.id,
            issue_iid=self.issue_iid,
            pages_returned=self.pages_returned,
            project=self.project)


def get_project_issue_label_events(issue_iid: Optional[_builtins.int] = None,
                                   pages_returned: Optional[_builtins.int] = None,
                                   project: Optional[_builtins.str] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectIssueLabelEventsResult:
    """
    The `get_project_issue_label_events` data source retrieves label events for a specific GitLab project issue.

    **Upstream API**: [GitLab Resource Label Events API docs](https://docs.gitlab.com/api/resource_label_events/)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    example = gitlab.get_project_issue_label_events(project="my-group/my-project",
        issue_iid=42)
    ```


    :param _builtins.int issue_iid: The internal ID of the issue.
    :param _builtins.int pages_returned: Number of pages to return. Default is 1.
    :param _builtins.str project: The ID or full path of the project.
    """
    __args__ = dict()
    __args__['issueIid'] = issue_iid
    __args__['pagesReturned'] = pages_returned
    __args__['project'] = project
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getProjectIssueLabelEvents:getProjectIssueLabelEvents', __args__, opts=opts, typ=GetProjectIssueLabelEventsResult).value

    return AwaitableGetProjectIssueLabelEventsResult(
        events=pulumi.get(__ret__, 'events'),
        id=pulumi.get(__ret__, 'id'),
        issue_iid=pulumi.get(__ret__, 'issue_iid'),
        pages_returned=pulumi.get(__ret__, 'pages_returned'),
        project=pulumi.get(__ret__, 'project'))
def get_project_issue_label_events_output(issue_iid: Optional[pulumi.Input[_builtins.int]] = None,
                                          pages_returned: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                                          project: Optional[pulumi.Input[_builtins.str]] = None,
                                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProjectIssueLabelEventsResult]:
    """
    The `get_project_issue_label_events` data source retrieves label events for a specific GitLab project issue.

    **Upstream API**: [GitLab Resource Label Events API docs](https://docs.gitlab.com/api/resource_label_events/)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    example = gitlab.get_project_issue_label_events(project="my-group/my-project",
        issue_iid=42)
    ```


    :param _builtins.int issue_iid: The internal ID of the issue.
    :param _builtins.int pages_returned: Number of pages to return. Default is 1.
    :param _builtins.str project: The ID or full path of the project.
    """
    __args__ = dict()
    __args__['issueIid'] = issue_iid
    __args__['pagesReturned'] = pages_returned
    __args__['project'] = project
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getProjectIssueLabelEvents:getProjectIssueLabelEvents', __args__, opts=opts, typ=GetProjectIssueLabelEventsResult)
    return __ret__.apply(lambda __response__: GetProjectIssueLabelEventsResult(
        events=pulumi.get(__response__, 'events'),
        id=pulumi.get(__response__, 'id'),
        issue_iid=pulumi.get(__response__, 'issue_iid'),
        pages_returned=pulumi.get(__response__, 'pages_returned'),
        project=pulumi.get(__response__, 'project')))
