# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ApplicationSettingsArgs', 'ApplicationSettings']

@pulumi.input_type
class ApplicationSettingsArgs:
    def __init__(__self__, *,
                 abuse_notification_email: Optional[pulumi.Input[_builtins.str]] = None,
                 admin_mode: Optional[pulumi.Input[_builtins.bool]] = None,
                 after_sign_out_path: Optional[pulumi.Input[_builtins.str]] = None,
                 after_sign_up_text: Optional[pulumi.Input[_builtins.str]] = None,
                 akismet_api_key: Optional[pulumi.Input[_builtins.str]] = None,
                 akismet_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_account_deletion: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_group_owners_to_manage_ldap: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_local_requests_from_system_hooks: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_local_requests_from_web_hooks_and_services: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_project_creation_for_guest_and_below: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_runner_registration_token: Optional[pulumi.Input[_builtins.bool]] = None,
                 archive_builds_in_human_readable: Optional[pulumi.Input[_builtins.str]] = None,
                 asciidoc_max_includes: Optional[pulumi.Input[_builtins.int]] = None,
                 asset_proxy_allowlists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 asset_proxy_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 asset_proxy_secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 asset_proxy_url: Optional[pulumi.Input[_builtins.str]] = None,
                 authorized_keys_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 auto_ban_user_on_excessive_projects_download: Optional[pulumi.Input[_builtins.bool]] = None,
                 auto_devops_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 auto_devops_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 automatic_purchased_storage_allocation: Optional[pulumi.Input[_builtins.bool]] = None,
                 bulk_import_concurrent_pipeline_batch_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 bulk_import_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 bulk_import_max_download_file_size: Optional[pulumi.Input[_builtins.int]] = None,
                 can_create_group: Optional[pulumi.Input[_builtins.bool]] = None,
                 check_namespace_plan: Optional[pulumi.Input[_builtins.bool]] = None,
                 ci_max_includes: Optional[pulumi.Input[_builtins.int]] = None,
                 ci_max_total_yaml_size_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 commit_email_hostname: Optional[pulumi.Input[_builtins.str]] = None,
                 concurrent_bitbucket_import_jobs_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 concurrent_bitbucket_server_import_jobs_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 concurrent_github_import_jobs_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 container_expiration_policies_enable_historic_entries: Optional[pulumi.Input[_builtins.bool]] = None,
                 container_registry_cleanup_tags_service_max_list_size: Optional[pulumi.Input[_builtins.int]] = None,
                 container_registry_delete_tags_service_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 container_registry_expiration_policies_caching: Optional[pulumi.Input[_builtins.bool]] = None,
                 container_registry_expiration_policies_worker_capacity: Optional[pulumi.Input[_builtins.int]] = None,
                 container_registry_token_expire_delay: Optional[pulumi.Input[_builtins.int]] = None,
                 deactivate_dormant_users: Optional[pulumi.Input[_builtins.bool]] = None,
                 deactivate_dormant_users_period: Optional[pulumi.Input[_builtins.int]] = None,
                 decompress_archive_file_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 default_artifacts_expire_in: Optional[pulumi.Input[_builtins.str]] = None,
                 default_branch_name: Optional[pulumi.Input[_builtins.str]] = None,
                 default_branch_protection: Optional[pulumi.Input[_builtins.int]] = None,
                 default_branch_protection_defaults: Optional[pulumi.Input['ApplicationSettingsDefaultBranchProtectionDefaultsArgs']] = None,
                 default_ci_config_path: Optional[pulumi.Input[_builtins.str]] = None,
                 default_group_visibility: Optional[pulumi.Input[_builtins.str]] = None,
                 default_preferred_language: Optional[pulumi.Input[_builtins.str]] = None,
                 default_project_creation: Optional[pulumi.Input[_builtins.int]] = None,
                 default_project_visibility: Optional[pulumi.Input[_builtins.str]] = None,
                 default_projects_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 default_snippet_visibility: Optional[pulumi.Input[_builtins.str]] = None,
                 default_syntax_highlighting_theme: Optional[pulumi.Input[_builtins.int]] = None,
                 delete_inactive_projects: Optional[pulumi.Input[_builtins.bool]] = None,
                 delete_unconfirmed_users: Optional[pulumi.Input[_builtins.bool]] = None,
                 deletion_adjourned_period: Optional[pulumi.Input[_builtins.int]] = None,
                 diagramsnet_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 diagramsnet_url: Optional[pulumi.Input[_builtins.str]] = None,
                 diff_max_files: Optional[pulumi.Input[_builtins.int]] = None,
                 diff_max_lines: Optional[pulumi.Input[_builtins.int]] = None,
                 diff_max_patch_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 disable_admin_oauth_scopes: Optional[pulumi.Input[_builtins.bool]] = None,
                 disable_feed_token: Optional[pulumi.Input[_builtins.bool]] = None,
                 disable_personal_access_tokens: Optional[pulumi.Input[_builtins.bool]] = None,
                 disabled_oauth_sign_in_sources: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dns_rebinding_protection_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 domain_allowlists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 domain_denylist_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 domain_denylists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 downstream_pipeline_trigger_limit_per_project_user_sha: Optional[pulumi.Input[_builtins.int]] = None,
                 dsa_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
                 duo_features_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 ecdsa_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
                 ecdsa_sk_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
                 ed25519_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
                 ed25519_sk_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
                 eks_access_key_id: Optional[pulumi.Input[_builtins.str]] = None,
                 eks_account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 eks_integration_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 eks_secret_access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 elasticsearch_aws: Optional[pulumi.Input[_builtins.bool]] = None,
                 elasticsearch_aws_access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 elasticsearch_aws_region: Optional[pulumi.Input[_builtins.str]] = None,
                 elasticsearch_aws_secret_access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 elasticsearch_indexed_field_length_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 elasticsearch_indexed_file_size_limit_kb: Optional[pulumi.Input[_builtins.int]] = None,
                 elasticsearch_indexing: Optional[pulumi.Input[_builtins.bool]] = None,
                 elasticsearch_limit_indexing: Optional[pulumi.Input[_builtins.bool]] = None,
                 elasticsearch_max_bulk_concurrency: Optional[pulumi.Input[_builtins.int]] = None,
                 elasticsearch_max_bulk_size_mb: Optional[pulumi.Input[_builtins.int]] = None,
                 elasticsearch_max_code_indexing_concurrency: Optional[pulumi.Input[_builtins.int]] = None,
                 elasticsearch_namespace_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 elasticsearch_password: Optional[pulumi.Input[_builtins.str]] = None,
                 elasticsearch_project_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 elasticsearch_requeue_workers: Optional[pulumi.Input[_builtins.bool]] = None,
                 elasticsearch_search: Optional[pulumi.Input[_builtins.bool]] = None,
                 elasticsearch_urls: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 elasticsearch_username: Optional[pulumi.Input[_builtins.str]] = None,
                 elasticsearch_worker_number_of_shards: Optional[pulumi.Input[_builtins.int]] = None,
                 email_additional_text: Optional[pulumi.Input[_builtins.str]] = None,
                 email_author_in_body: Optional[pulumi.Input[_builtins.bool]] = None,
                 email_confirmation_setting: Optional[pulumi.Input[_builtins.str]] = None,
                 enable_artifact_external_redirect_warning_page: Optional[pulumi.Input[_builtins.bool]] = None,
                 enabled_git_access_protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 enforce_namespace_storage_limit: Optional[pulumi.Input[_builtins.bool]] = None,
                 enforce_terms: Optional[pulumi.Input[_builtins.bool]] = None,
                 external_auth_client_cert: Optional[pulumi.Input[_builtins.str]] = None,
                 external_auth_client_key: Optional[pulumi.Input[_builtins.str]] = None,
                 external_auth_client_key_pass: Optional[pulumi.Input[_builtins.str]] = None,
                 external_authorization_service_default_label: Optional[pulumi.Input[_builtins.str]] = None,
                 external_authorization_service_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 external_authorization_service_timeout: Optional[pulumi.Input[_builtins.float]] = None,
                 external_authorization_service_url: Optional[pulumi.Input[_builtins.str]] = None,
                 external_pipeline_validation_service_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 external_pipeline_validation_service_token: Optional[pulumi.Input[_builtins.str]] = None,
                 external_pipeline_validation_service_url: Optional[pulumi.Input[_builtins.str]] = None,
                 failed_login_attempts_unlock_period_in_minutes: Optional[pulumi.Input[_builtins.int]] = None,
                 file_template_project_id: Optional[pulumi.Input[_builtins.int]] = None,
                 first_day_of_week: Optional[pulumi.Input[_builtins.int]] = None,
                 geo_node_allowed_ips: Optional[pulumi.Input[_builtins.str]] = None,
                 geo_status_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 git_rate_limit_users_alertlists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 git_rate_limit_users_allowlists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 git_two_factor_session_expiry: Optional[pulumi.Input[_builtins.int]] = None,
                 gitaly_timeout_default: Optional[pulumi.Input[_builtins.int]] = None,
                 gitaly_timeout_fast: Optional[pulumi.Input[_builtins.int]] = None,
                 gitaly_timeout_medium: Optional[pulumi.Input[_builtins.int]] = None,
                 gitlab_shell_operation_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 gitpod_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 gitpod_url: Optional[pulumi.Input[_builtins.str]] = None,
                 globally_allowed_ips: Optional[pulumi.Input[_builtins.str]] = None,
                 grafana_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 grafana_url: Optional[pulumi.Input[_builtins.str]] = None,
                 gravatar_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 group_owners_can_manage_default_branch_protection: Optional[pulumi.Input[_builtins.bool]] = None,
                 help_page_hide_commercial_content: Optional[pulumi.Input[_builtins.bool]] = None,
                 help_page_support_url: Optional[pulumi.Input[_builtins.str]] = None,
                 help_page_text: Optional[pulumi.Input[_builtins.str]] = None,
                 help_text: Optional[pulumi.Input[_builtins.str]] = None,
                 hide_third_party_offers: Optional[pulumi.Input[_builtins.bool]] = None,
                 home_page_url: Optional[pulumi.Input[_builtins.str]] = None,
                 housekeeping_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 housekeeping_optimize_repository_period: Optional[pulumi.Input[_builtins.int]] = None,
                 html_emails_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 import_sources: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 in_product_marketing_emails_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 inactive_projects_delete_after_months: Optional[pulumi.Input[_builtins.int]] = None,
                 inactive_projects_min_size_mb: Optional[pulumi.Input[_builtins.int]] = None,
                 inactive_projects_send_warning_email_after_months: Optional[pulumi.Input[_builtins.int]] = None,
                 include_optional_metrics_in_service_ping: Optional[pulumi.Input[_builtins.bool]] = None,
                 invisible_captcha_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 issues_create_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 jira_connect_application_key: Optional[pulumi.Input[_builtins.str]] = None,
                 jira_connect_proxy_url: Optional[pulumi.Input[_builtins.str]] = None,
                 jira_connect_public_key_storage_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 keep_latest_artifact: Optional[pulumi.Input[_builtins.bool]] = None,
                 local_markdown_version: Optional[pulumi.Input[_builtins.int]] = None,
                 lock_duo_features_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 lock_memberships_to_ldap: Optional[pulumi.Input[_builtins.bool]] = None,
                 mailgun_events_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 mailgun_signing_key: Optional[pulumi.Input[_builtins.str]] = None,
                 maintenance_mode: Optional[pulumi.Input[_builtins.bool]] = None,
                 maintenance_mode_message: Optional[pulumi.Input[_builtins.str]] = None,
                 maven_package_requests_forwarding: Optional[pulumi.Input[_builtins.bool]] = None,
                 max_artifacts_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_attachment_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_decompressed_archive_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_export_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_import_remote_file_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_import_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_login_attempts: Optional[pulumi.Input[_builtins.int]] = None,
                 max_number_of_repository_downloads: Optional[pulumi.Input[_builtins.int]] = None,
                 max_number_of_repository_downloads_within_time_period: Optional[pulumi.Input[_builtins.int]] = None,
                 max_pages_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_personal_access_token_lifetime: Optional[pulumi.Input[_builtins.int]] = None,
                 max_ssh_key_lifetime: Optional[pulumi.Input[_builtins.int]] = None,
                 max_terraform_state_size_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 metrics_method_call_threshold: Optional[pulumi.Input[_builtins.int]] = None,
                 minimum_password_length: Optional[pulumi.Input[_builtins.int]] = None,
                 mirror_available: Optional[pulumi.Input[_builtins.bool]] = None,
                 mirror_capacity_threshold: Optional[pulumi.Input[_builtins.int]] = None,
                 mirror_max_capacity: Optional[pulumi.Input[_builtins.int]] = None,
                 mirror_max_delay: Optional[pulumi.Input[_builtins.int]] = None,
                 npm_package_requests_forwarding: Optional[pulumi.Input[_builtins.bool]] = None,
                 nuget_skip_metadata_url_validation: Optional[pulumi.Input[_builtins.bool]] = None,
                 outbound_local_requests_whitelists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 package_metadata_purl_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 package_registry_allow_anyone_to_pull_option: Optional[pulumi.Input[_builtins.bool]] = None,
                 package_registry_cleanup_policies_worker_capacity: Optional[pulumi.Input[_builtins.int]] = None,
                 pages_domain_verification_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 password_authentication_enabled_for_git: Optional[pulumi.Input[_builtins.bool]] = None,
                 password_authentication_enabled_for_web: Optional[pulumi.Input[_builtins.bool]] = None,
                 password_lowercase_required: Optional[pulumi.Input[_builtins.bool]] = None,
                 password_number_required: Optional[pulumi.Input[_builtins.bool]] = None,
                 password_symbol_required: Optional[pulumi.Input[_builtins.bool]] = None,
                 password_uppercase_required: Optional[pulumi.Input[_builtins.bool]] = None,
                 performance_bar_allowed_group_path: Optional[pulumi.Input[_builtins.str]] = None,
                 personal_access_token_prefix: Optional[pulumi.Input[_builtins.str]] = None,
                 pipeline_limit_per_project_user_sha: Optional[pulumi.Input[_builtins.int]] = None,
                 plantuml_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 plantuml_url: Optional[pulumi.Input[_builtins.str]] = None,
                 polling_interval_multiplier: Optional[pulumi.Input[_builtins.float]] = None,
                 project_export_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 project_jobs_api_rate_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 projects_api_rate_limit_unauthenticated: Optional[pulumi.Input[_builtins.int]] = None,
                 prometheus_metrics_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 protected_ci_variables: Optional[pulumi.Input[_builtins.bool]] = None,
                 push_event_activities_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 push_event_hooks_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 pypi_package_requests_forwarding: Optional[pulumi.Input[_builtins.bool]] = None,
                 rate_limiting_response_text: Optional[pulumi.Input[_builtins.str]] = None,
                 raw_blob_request_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 recaptcha_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 recaptcha_private_key: Optional[pulumi.Input[_builtins.str]] = None,
                 recaptcha_site_key: Optional[pulumi.Input[_builtins.str]] = None,
                 receive_max_input_size: Optional[pulumi.Input[_builtins.int]] = None,
                 receptive_cluster_agents_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 remember_me_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 repository_checks_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 repository_size_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 repository_storages_weighted: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.int]]]] = None,
                 require_admin_approval_after_user_signup: Optional[pulumi.Input[_builtins.bool]] = None,
                 require_admin_two_factor_authentication: Optional[pulumi.Input[_builtins.bool]] = None,
                 require_personal_access_token_expiry: Optional[pulumi.Input[_builtins.bool]] = None,
                 require_two_factor_authentication: Optional[pulumi.Input[_builtins.bool]] = None,
                 restricted_visibility_levels: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 rsa_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
                 search_rate_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 search_rate_limit_unauthenticated: Optional[pulumi.Input[_builtins.int]] = None,
                 security_approval_policies_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 security_policy_global_group_approvers_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 security_txt_content: Optional[pulumi.Input[_builtins.str]] = None,
                 send_user_confirmation_email: Optional[pulumi.Input[_builtins.bool]] = None,
                 service_access_tokens_expiration_enforced: Optional[pulumi.Input[_builtins.bool]] = None,
                 session_expire_delay: Optional[pulumi.Input[_builtins.int]] = None,
                 shared_runners_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 shared_runners_minutes: Optional[pulumi.Input[_builtins.int]] = None,
                 shared_runners_text: Optional[pulumi.Input[_builtins.str]] = None,
                 sidekiq_job_limiter_compression_threshold_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 sidekiq_job_limiter_limit_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 sidekiq_job_limiter_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 sign_in_text: Optional[pulumi.Input[_builtins.str]] = None,
                 signup_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 silent_admin_exports_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 silent_mode_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 slack_app_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 slack_app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 slack_app_secret: Optional[pulumi.Input[_builtins.str]] = None,
                 slack_app_signing_secret: Optional[pulumi.Input[_builtins.str]] = None,
                 slack_app_verification_token: Optional[pulumi.Input[_builtins.str]] = None,
                 snippet_size_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 snowplow_app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 snowplow_collector_hostname: Optional[pulumi.Input[_builtins.str]] = None,
                 snowplow_cookie_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 snowplow_database_collector_hostname: Optional[pulumi.Input[_builtins.str]] = None,
                 snowplow_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 sourcegraph_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 sourcegraph_public_only: Optional[pulumi.Input[_builtins.bool]] = None,
                 sourcegraph_url: Optional[pulumi.Input[_builtins.str]] = None,
                 spam_check_api_key: Optional[pulumi.Input[_builtins.str]] = None,
                 spam_check_endpoint_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 spam_check_endpoint_url: Optional[pulumi.Input[_builtins.str]] = None,
                 static_objects_external_storage_auth_token: Optional[pulumi.Input[_builtins.str]] = None,
                 static_objects_external_storage_url: Optional[pulumi.Input[_builtins.str]] = None,
                 suggest_pipeline_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 terminal_max_session_time: Optional[pulumi.Input[_builtins.int]] = None,
                 terms: Optional[pulumi.Input[_builtins.str]] = None,
                 throttle_authenticated_api_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 throttle_authenticated_api_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_authenticated_api_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_authenticated_packages_api_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 throttle_authenticated_packages_api_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_authenticated_packages_api_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_authenticated_web_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 throttle_authenticated_web_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_authenticated_web_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_unauthenticated_api_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 throttle_unauthenticated_api_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_unauthenticated_api_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_unauthenticated_packages_api_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 throttle_unauthenticated_packages_api_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_unauthenticated_packages_api_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_unauthenticated_web_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 throttle_unauthenticated_web_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_unauthenticated_web_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
                 time_tracking_limit_to_hours: Optional[pulumi.Input[_builtins.bool]] = None,
                 two_factor_grace_period: Optional[pulumi.Input[_builtins.int]] = None,
                 unconfirmed_users_delete_after_days: Optional[pulumi.Input[_builtins.int]] = None,
                 unique_ips_limit_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 unique_ips_limit_per_user: Optional[pulumi.Input[_builtins.int]] = None,
                 unique_ips_limit_time_window: Optional[pulumi.Input[_builtins.int]] = None,
                 update_runner_versions_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 usage_ping_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 use_clickhouse_for_analytics: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_deactivation_emails_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_default_external: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_default_internal_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 user_defaults_to_private_profile: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_oauth_applications: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_show_add_ssh_key_message: Optional[pulumi.Input[_builtins.bool]] = None,
                 valid_runner_registrars: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 version_check_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 web_ide_clientside_preview_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 whats_new_variant: Optional[pulumi.Input[_builtins.str]] = None,
                 wiki_page_max_content_bytes: Optional[pulumi.Input[_builtins.int]] = None):
        """
        The set of arguments for constructing a ApplicationSettings resource.
        :param pulumi.Input[_builtins.str] abuse_notification_email: If set, abuse reports are sent to this address. Abuse reports are always available in the Admin Area.
        :param pulumi.Input[_builtins.bool] admin_mode: Require administrators to enable Admin Mode by re-authenticating for administrative tasks.
        :param pulumi.Input[_builtins.str] after_sign_out_path: Where to redirect users after logout.
        :param pulumi.Input[_builtins.str] after_sign_up_text: Text shown to the user after signing up.
        :param pulumi.Input[_builtins.str] akismet_api_key: API key for Akismet spam protection.
        :param pulumi.Input[_builtins.bool] akismet_enabled: (If enabled, requires: akismet*api*key) Enable or disable Akismet spam protection.
        :param pulumi.Input[_builtins.bool] allow_account_deletion: Set to true to allow users to delete their accounts. Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] allow_group_owners_to_manage_ldap: Set to true to allow group owners to manage LDAP.
        :param pulumi.Input[_builtins.bool] allow_local_requests_from_system_hooks: Allow requests to the local network from system hooks.
        :param pulumi.Input[_builtins.bool] allow_local_requests_from_web_hooks_and_services: Allow requests to the local network from web hooks and services.
        :param pulumi.Input[_builtins.bool] allow_project_creation_for_guest_and_below: Indicates whether users assigned up to the Guest role can create groups and personal projects.
        :param pulumi.Input[_builtins.bool] allow_runner_registration_token: Allow using a registration token to create a runner.
        :param pulumi.Input[_builtins.str] archive_builds_in_human_readable: Set the duration for which the jobs are considered as old and expired. After that time passes, the jobs are archived and no longer able to be retried. Make it empty to never expire jobs. It has to be no less than 1 day, for example: 15 days, 1 month, 2 years.
        :param pulumi.Input[_builtins.int] asciidoc_max_includes: Maximum limit of AsciiDoc include directives being processed in any one document. Maximum: 64.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] asset_proxy_allowlists: Assets that match these domains are not proxied. Wildcards allowed. Your GitLab installation URL is automatically allowlisted. GitLab restart is required to apply changes.
        :param pulumi.Input[_builtins.bool] asset_proxy_enabled: (If enabled, requires: asset*proxy*url) Enable proxying of assets. GitLab restart is required to apply changes.
        :param pulumi.Input[_builtins.str] asset_proxy_secret_key: Shared secret with the asset proxy server. GitLab restart is required to apply changes.
        :param pulumi.Input[_builtins.str] asset_proxy_url: URL of the asset proxy server. GitLab restart is required to apply changes.
        :param pulumi.Input[_builtins.bool] authorized_keys_enabled: By default, we write to the authorized_keys file to support Git over SSH without additional configuration. GitLab can be optimized to authenticate SSH keys via the database file. Only disable this if you have configured your OpenSSH server to use the AuthorizedKeysCommand.
        :param pulumi.Input[_builtins.bool] auto_ban_user_on_excessive_projects_download: When enabled, users will get automatically banned from the application when they download more than the maximum number of unique projects in the time period specified by max*number*of*repository*downloads and max*number*of*repository*downloads*within*time_period respectively. Self-managed, Ultimate only.
        :param pulumi.Input[_builtins.str] auto_devops_domain: Specify a domain to use by default for every project’s Auto Review Apps and Auto Deploy stages.
        :param pulumi.Input[_builtins.bool] auto_devops_enabled: Enable Auto DevOps for projects by default. It automatically builds, tests, and deploys applications based on a predefined CI/CD configuration.
        :param pulumi.Input[_builtins.bool] automatic_purchased_storage_allocation: Enabling this permits automatic allocation of purchased storage in a namespace.
        :param pulumi.Input[_builtins.int] bulk_import_concurrent_pipeline_batch_limit: Maximum simultaneous Direct Transfer batches to process.
        :param pulumi.Input[_builtins.bool] bulk_import_enabled: Enable migrating GitLab groups by direct transfer.
        :param pulumi.Input[_builtins.int] bulk_import_max_download_file_size: Maximum download file size when importing from source GitLab instances by direct transfer.
        :param pulumi.Input[_builtins.bool] can_create_group: Indicates whether users can create top-level groups.
        :param pulumi.Input[_builtins.bool] check_namespace_plan: Enabling this makes only licensed EE features available to projects if the project namespace’s plan includes the feature or if the project is public.
        :param pulumi.Input[_builtins.int] ci_max_includes: The maximum number of includes per pipeline.
        :param pulumi.Input[_builtins.int] ci_max_total_yaml_size_bytes: The maximum amount of memory, in bytes, that can be allocated for the pipeline configuration, with all included YAML configuration files.
        :param pulumi.Input[_builtins.str] commit_email_hostname: Custom hostname (for private commit emails).
        :param pulumi.Input[_builtins.int] concurrent_bitbucket_import_jobs_limit: Maximum number of simultaneous import jobs for the Bitbucket Cloud importer.
        :param pulumi.Input[_builtins.int] concurrent_bitbucket_server_import_jobs_limit: Maximum number of simultaneous import jobs for the Bitbucket Server importer.
        :param pulumi.Input[_builtins.int] concurrent_github_import_jobs_limit: Maximum number of simultaneous import jobs for the GitHub importer.
        :param pulumi.Input[_builtins.bool] container_expiration_policies_enable_historic_entries: Enable cleanup policies for all projects.
        :param pulumi.Input[_builtins.int] container_registry_cleanup_tags_service_max_list_size: The maximum number of tags that can be deleted in a single execution of cleanup policies.
        :param pulumi.Input[_builtins.int] container_registry_delete_tags_service_timeout: The maximum time, in seconds, that the cleanup process can take to delete a batch of tags for cleanup policies.
        :param pulumi.Input[_builtins.bool] container_registry_expiration_policies_caching: Caching during the execution of cleanup policies.
        :param pulumi.Input[_builtins.int] container_registry_expiration_policies_worker_capacity: Number of workers for cleanup policies.
        :param pulumi.Input[_builtins.int] container_registry_token_expire_delay: Container Registry token duration in minutes.
        :param pulumi.Input[_builtins.bool] deactivate_dormant_users: Enable automatic deactivation of dormant users.
        :param pulumi.Input[_builtins.int] deactivate_dormant_users_period: Length of time (in days) after which a user is considered dormant.
        :param pulumi.Input[_builtins.int] decompress_archive_file_timeout: Default timeout for decompressing archived files, in seconds. Set to 0 to disable timeouts.
        :param pulumi.Input[_builtins.str] default_artifacts_expire_in: Set the default expiration time for each job’s artifacts.
        :param pulumi.Input[_builtins.str] default_branch_name: Instance-level custom initial branch name
        :param pulumi.Input[_builtins.int] default_branch_protection: Determine if developers can push to the default branch. Can take: 0 (not protected, both users with the Developer role or Maintainer role can push new commits and force push), 1 (partially protected, users with the Developer role or Maintainer role can push new commits, but cannot force push) or 2 (fully protected, users with the Developer or Maintainer role cannot push new commits, but users with the Developer or Maintainer role can; no one can force push) as a parameter. Default is 2. Use `default_branch_protection_defaults` instead. To be removed in 19.0.
        :param pulumi.Input['ApplicationSettingsDefaultBranchProtectionDefaultsArgs'] default_branch_protection_defaults: The default*branch*protection*defaults attribute describes the default branch protection defaults. All parameters are optional.
        :param pulumi.Input[_builtins.str] default_ci_config_path: Default CI/CD configuration file and path for new projects (.gitlab-ci.yml if not set).
        :param pulumi.Input[_builtins.str] default_group_visibility: What visibility level new groups receive. Can take private, internal and public as a parameter.
        :param pulumi.Input[_builtins.str] default_preferred_language: Default preferred language for users who are not logged in.
        :param pulumi.Input[_builtins.int] default_project_creation: Default project creation protection. Can take: 0 (No one), 1 (Maintainers) or 2 (Developers + Maintainers).
        :param pulumi.Input[_builtins.str] default_project_visibility: What visibility level new projects receive. Can take private, internal and public as a parameter.
        :param pulumi.Input[_builtins.int] default_projects_limit: Project limit per user.
        :param pulumi.Input[_builtins.str] default_snippet_visibility: What visibility level new snippets receive. Can take private, internal and public as a parameter.
        :param pulumi.Input[_builtins.int] default_syntax_highlighting_theme: Default syntax highlighting theme for users who are new or not signed in. See IDs of available themes (https://gitlab.com/gitlab-org/gitlab/blob/master/lib/gitlab/themes.rb#L16)
        :param pulumi.Input[_builtins.bool] delete_inactive_projects: Enable inactive project deletion feature.
        :param pulumi.Input[_builtins.bool] delete_unconfirmed_users: Specifies whether users who have not confirmed their email should be deleted. When set to true, unconfirmed users are deleted after unconfirmed*users*delete*after*days days. Self-managed, Premium and Ultimate only.
        :param pulumi.Input[_builtins.int] deletion_adjourned_period: The number of days to wait before deleting a project or group that is marked for deletion. Value must be between 1 and 90.
        :param pulumi.Input[_builtins.bool] diagramsnet_enabled: (If enabled, requires diagramsnet_url) Enable Diagrams.net integration.
        :param pulumi.Input[_builtins.str] diagramsnet_url: The Diagrams.net instance URL for integration.
        :param pulumi.Input[_builtins.int] diff_max_files: Maximum files in a diff.
        :param pulumi.Input[_builtins.int] diff_max_lines: Maximum lines in a diff.
        :param pulumi.Input[_builtins.int] diff_max_patch_bytes: Maximum diff patch size, in bytes.
        :param pulumi.Input[_builtins.bool] disable_admin_oauth_scopes: Stops administrators from connecting their GitLab accounts to non-trusted OAuth 2.0 applications that have the api, read*api, read*repository, write*repository, read*registry, write_registry, or sudo scopes.
        :param pulumi.Input[_builtins.bool] disable_feed_token: Disable display of RSS/Atom and calendar feed tokens.
        :param pulumi.Input[_builtins.bool] disable_personal_access_tokens: Disable personal access tokens. Self-managed, Premium and Ultimate only. There is no method available to enable a personal access token that’s been disabled through the API. This is a known issue.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] disabled_oauth_sign_in_sources: Disabled OAuth sign-in sources.
        :param pulumi.Input[_builtins.bool] dns_rebinding_protection_enabled: Enforce DNS rebinding attack protection.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] domain_allowlists: Force people to use only corporate emails for sign-up. Null means there is no restriction.
        :param pulumi.Input[_builtins.bool] domain_denylist_enabled: (If enabled, requires: domain_denylist) Allows blocking sign-ups from emails from specific domains.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] domain_denylists: Users with email addresses that match these domains cannot sign up. Wildcards allowed. Use separate lines for multiple entries. Ex: domain.com, *.domain.com.
        :param pulumi.Input[_builtins.int] downstream_pipeline_trigger_limit_per_project_user_sha: Maximum downstream pipeline trigger rate.
        :param pulumi.Input[_builtins.int] dsa_key_restriction: The minimum allowed bit length of an uploaded DSA key. 0 means no restriction. -1 disables DSA keys.
        :param pulumi.Input[_builtins.bool] duo_features_enabled: Indicates whether GitLab Duo features are enabled for this instance. Self-managed, Premium and Ultimate only.
        :param pulumi.Input[_builtins.int] ecdsa_key_restriction: The minimum allowed curve size (in bits) of an uploaded ECDSA key. 0 means no restriction. -1 disables ECDSA keys.
        :param pulumi.Input[_builtins.int] ecdsa_sk_key_restriction: The minimum allowed curve size (in bits) of an uploaded ECDSA*SK key. 0 means no restriction. -1 disables ECDSA*SK keys.
        :param pulumi.Input[_builtins.int] ed25519_key_restriction: The minimum allowed curve size (in bits) of an uploaded ED25519 key. 0 means no restriction. -1 disables ED25519 keys.
        :param pulumi.Input[_builtins.int] ed25519_sk_key_restriction: The minimum allowed curve size (in bits) of an uploaded ED25519*SK key. 0 means no restriction. -1 disables ED25519*SK keys.
        :param pulumi.Input[_builtins.str] eks_access_key_id: AWS IAM access key ID.
        :param pulumi.Input[_builtins.str] eks_account_id: Amazon account ID.
        :param pulumi.Input[_builtins.bool] eks_integration_enabled: Enable integration with Amazon EKS.
        :param pulumi.Input[_builtins.str] eks_secret_access_key: AWS IAM secret access key.
        :param pulumi.Input[_builtins.bool] elasticsearch_aws: Enable the use of AWS hosted Elasticsearch.
        :param pulumi.Input[_builtins.str] elasticsearch_aws_access_key: AWS IAM access key.
        :param pulumi.Input[_builtins.str] elasticsearch_aws_region: The AWS region the Elasticsearch domain is configured.
        :param pulumi.Input[_builtins.str] elasticsearch_aws_secret_access_key: AWS IAM secret access key.
        :param pulumi.Input[_builtins.int] elasticsearch_indexed_field_length_limit: Maximum size of text fields to index by Elasticsearch. 0 value means no limit. This does not apply to repository and wiki indexing.
        :param pulumi.Input[_builtins.int] elasticsearch_indexed_file_size_limit_kb: Maximum size of repository and wiki files that are indexed by Elasticsearch.
        :param pulumi.Input[_builtins.bool] elasticsearch_indexing: Enable Elasticsearch indexing.
        :param pulumi.Input[_builtins.bool] elasticsearch_limit_indexing: Limit Elasticsearch to index certain namespaces and projects.
        :param pulumi.Input[_builtins.int] elasticsearch_max_bulk_concurrency: Maximum concurrency of Elasticsearch bulk requests per indexing operation. This only applies to repository indexing operations.
        :param pulumi.Input[_builtins.int] elasticsearch_max_bulk_size_mb: Maximum size of Elasticsearch bulk indexing requests in MB. This only applies to repository indexing operations.
        :param pulumi.Input[_builtins.int] elasticsearch_max_code_indexing_concurrency: Maximum concurrency of Elasticsearch code indexing background jobs. This only applies to repository indexing operations. Premium and Ultimate only.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] elasticsearch_namespace_ids: The namespaces to index via Elasticsearch if elasticsearch*limit*indexing is enabled.
        :param pulumi.Input[_builtins.str] elasticsearch_password: The password of your Elasticsearch instance.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] elasticsearch_project_ids: The projects to index via Elasticsearch if elasticsearch*limit*indexing is enabled.
        :param pulumi.Input[_builtins.bool] elasticsearch_requeue_workers: Enable automatic requeuing of indexing workers. This improves non-code indexing throughput by enqueuing Sidekiq jobs until all documents are processed. Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] elasticsearch_search: Enable Elasticsearch search.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] elasticsearch_urls: The URL to use for connecting to Elasticsearch. Use a comma-separated list to support cluster (for example, http://localhost:9200, http://localhost:9201).
        :param pulumi.Input[_builtins.str] elasticsearch_username: The username of your Elasticsearch instance.
        :param pulumi.Input[_builtins.int] elasticsearch_worker_number_of_shards: Number of indexing worker shards. This improves non-code indexing throughput by enqueuing more parallel Sidekiq jobs. Premium and Ultimate only.
        :param pulumi.Input[_builtins.str] email_additional_text: Additional text added to the bottom of every email for legal/auditing/compliance reasons.
        :param pulumi.Input[_builtins.bool] email_author_in_body: Some email servers do not support overriding the email sender name. Enable this option to include the name of the author of the issue, merge request or comment in the email body instead.
        :param pulumi.Input[_builtins.str] email_confirmation_setting: Specifies whether users must confirm their email before sign in. Possible values are off, soft, and hard.
        :param pulumi.Input[_builtins.bool] enable_artifact_external_redirect_warning_page: Show the external redirect page that warns you about user-generated content in GitLab Pages.
        :param pulumi.Input[_builtins.str] enabled_git_access_protocol: Enabled protocols for Git access. Allowed values are: ssh, http, and nil to allow both protocols.
        :param pulumi.Input[_builtins.bool] enforce_namespace_storage_limit: Enabling this permits enforcement of namespace storage limits.
        :param pulumi.Input[_builtins.bool] enforce_terms: (If enabled, requires: terms) Enforce application ToS to all users.
        :param pulumi.Input[_builtins.str] external_auth_client_cert: (If enabled, requires: external*auth*client_key) The certificate to use to authenticate with the external authorization service.
        :param pulumi.Input[_builtins.str] external_auth_client_key: Private key for the certificate when authentication is required for the external authorization service, this is encrypted when stored.
        :param pulumi.Input[_builtins.str] external_auth_client_key_pass: Passphrase to use for the private key when authenticating with the external service this is encrypted when stored.
        :param pulumi.Input[_builtins.str] external_authorization_service_default_label: The default classification label to use when requesting authorization and no classification label has been specified on the project.
        :param pulumi.Input[_builtins.bool] external_authorization_service_enabled: (If enabled, requires: external*authorization*service*default*label, external*authorization*service*timeout and external*authorization*service*url) Enable using an external authorization service for accessing projects.
        :param pulumi.Input[_builtins.float] external_authorization_service_timeout: The timeout after which an authorization request is aborted, in seconds. When a request times out, access is denied to the user. (min: 0.001, max: 10, step: 0.001).
        :param pulumi.Input[_builtins.str] external_authorization_service_url: URL to which authorization requests are directed.
        :param pulumi.Input[_builtins.int] external_pipeline_validation_service_timeout: How long to wait for a response from the pipeline validation service. Assumes OK if it times out.
        :param pulumi.Input[_builtins.str] external_pipeline_validation_service_token: Optional. Token to include as the X-Gitlab-Token header in requests to the URL in external*pipeline*validation*service*url.
        :param pulumi.Input[_builtins.str] external_pipeline_validation_service_url: URL to use for pipeline validation requests.
        :param pulumi.Input[_builtins.int] failed_login_attempts_unlock_period_in_minutes: Time period in minutes after which the user is unlocked when maximum number of failed sign-in attempts reached.
        :param pulumi.Input[_builtins.int] file_template_project_id: The ID of a project to load custom file templates from.
        :param pulumi.Input[_builtins.int] first_day_of_week: Start day of the week for calendar views and date pickers. Valid values are 0 for Sunday, 1 for Monday, and 6 for Saturday.
        :param pulumi.Input[_builtins.str] geo_node_allowed_ips: Comma-separated list of IPs and CIDRs of allowed secondary nodes. For example, 1.1.1.1, 2.2.2.0/24.
        :param pulumi.Input[_builtins.int] geo_status_timeout: The amount of seconds after which a request to get a secondary node status times out.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] git_rate_limit_users_alertlists: List of user IDs that are emailed when the Git abuse rate limit is exceeded. Maximum: 100 user IDs. Self-managed, Ultimate only.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] git_rate_limit_users_allowlists: List of usernames excluded from Git anti-abuse rate limits. Maximum: 100 usernames. Self-managed, Ultimate only.
        :param pulumi.Input[_builtins.int] git_two_factor_session_expiry: Maximum duration (in minutes) of a session for Git operations when 2FA is enabled.
        :param pulumi.Input[_builtins.int] gitaly_timeout_default: Default Gitaly timeout, in seconds. This timeout is not enforced for Git fetch/push operations or Sidekiq jobs. Set to 0 to disable timeouts.
        :param pulumi.Input[_builtins.int] gitaly_timeout_fast: Gitaly fast operation timeout, in seconds. Some Gitaly operations are expected to be fast. If they exceed this threshold, there may be a problem with a storage shard and ‘failing fast’ can help maintain the stability of the GitLab instance. Set to 0 to disable timeouts.
        :param pulumi.Input[_builtins.int] gitaly_timeout_medium: Medium Gitaly timeout, in seconds. This should be a value between the Fast and the Default timeout. Set to 0 to disable timeouts.
        :param pulumi.Input[_builtins.int] gitlab_shell_operation_limit: Maximum number of Git operations per minute a user can perform.
        :param pulumi.Input[_builtins.bool] gitpod_enabled: Enable Gitpod integration.
        :param pulumi.Input[_builtins.str] gitpod_url: The Gitpod instance URL for integration.
        :param pulumi.Input[_builtins.str] globally_allowed_ips: Comma-separated list of IP addresses and CIDRs always allowed for inbound traffic. For example, 1.1.1.1, 2.2.2.0/24.
        :param pulumi.Input[_builtins.bool] grafana_enabled: Enable Grafana.
        :param pulumi.Input[_builtins.str] grafana_url: Grafana URL.
        :param pulumi.Input[_builtins.bool] gravatar_enabled: Enable Gravatar.
        :param pulumi.Input[_builtins.bool] group_owners_can_manage_default_branch_protection: Prevent overrides of default branch protection.
        :param pulumi.Input[_builtins.bool] help_page_hide_commercial_content: Hide marketing-related entries from help.
        :param pulumi.Input[_builtins.str] help_page_support_url: Alternate support URL for help page and help dropdown.
        :param pulumi.Input[_builtins.str] help_page_text: Custom text displayed on the help page.
        :param pulumi.Input[_builtins.str] help_text: GitLab server administrator information.
        :param pulumi.Input[_builtins.bool] hide_third_party_offers: Do not display offers from third parties in GitLab.
        :param pulumi.Input[_builtins.str] home_page_url: Redirect to this URL when not logged in.
        :param pulumi.Input[_builtins.bool] housekeeping_enabled: Enable or disable Git housekeeping. If enabled, requires housekeeping*optimize*repository_period.
        :param pulumi.Input[_builtins.int] housekeeping_optimize_repository_period: Number of Git pushes after which an incremental git-repack is run.
        :param pulumi.Input[_builtins.bool] html_emails_enabled: Enable HTML emails.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] import_sources: Sources to allow project import from. Valid values are: `github`, `bitbucket`, `bitbucket_server`, `fogbugz`, `git`, `Project`, `gitea`, `manifest`
        :param pulumi.Input[_builtins.bool] in_product_marketing_emails_enabled: Enable in-product marketing emails.
        :param pulumi.Input[_builtins.int] inactive_projects_delete_after_months: If delete*inactive*projects is true, the time (in months) to wait before deleting inactive projects.
        :param pulumi.Input[_builtins.int] inactive_projects_min_size_mb: If delete*inactive*projects is true, the minimum repository size for projects to be checked for inactivity.
        :param pulumi.Input[_builtins.int] inactive_projects_send_warning_email_after_months: If delete*inactive*projects is true, sets the time (in months) to wait before emailing maintainers that the project is scheduled be deleted because it is inactive.
        :param pulumi.Input[_builtins.bool] include_optional_metrics_in_service_ping: Whether or not optional metrics are enabled in Service Ping.
        :param pulumi.Input[_builtins.bool] invisible_captcha_enabled: Enable Invisible CAPTCHA spam detection during sign-up.
        :param pulumi.Input[_builtins.int] issues_create_limit: Max number of issue creation requests per minute per user.
        :param pulumi.Input[_builtins.str] jira_connect_application_key: ID of the OAuth application used to authenticate with the GitLab for Jira Cloud app.
        :param pulumi.Input[_builtins.str] jira_connect_proxy_url: URL of the GitLab instance used as a proxy for the GitLab for Jira Cloud app.
        :param pulumi.Input[_builtins.bool] jira_connect_public_key_storage_enabled: Enable public key storage for the GitLab for Jira Cloud app.
        :param pulumi.Input[_builtins.bool] keep_latest_artifact: Prevent the deletion of the artifacts from the most recent successful jobs, regardless of the expiry time.
        :param pulumi.Input[_builtins.int] local_markdown_version: Increase this value when any cached Markdown should be invalidated.
        :param pulumi.Input[_builtins.bool] lock_duo_features_enabled: Indicates whether the GitLab Duo features enabled setting is enforced for all subgroups. Self-managed, Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] lock_memberships_to_ldap: Set to true to lock all memberships to LDAP. Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] mailgun_events_enabled: Enable Mailgun event receiver.
        :param pulumi.Input[_builtins.str] mailgun_signing_key: The Mailgun HTTP webhook signing key for receiving events from webhook.
        :param pulumi.Input[_builtins.bool] maintenance_mode: When instance is in maintenance mode, non-administrative users can sign in with read-only access and make read-only API requests.
        :param pulumi.Input[_builtins.str] maintenance_mode_message: Message displayed when instance is in maintenance mode.
        :param pulumi.Input[_builtins.bool] maven_package_requests_forwarding: Use repo.maven.apache.org as a default remote repository when the package is not found in the GitLab Package Registry for Maven. Premium and Ultimate only.
        :param pulumi.Input[_builtins.int] max_artifacts_size: Maximum artifacts size in MB.
        :param pulumi.Input[_builtins.int] max_attachment_size: Limit attachment size in MB.
        :param pulumi.Input[_builtins.int] max_decompressed_archive_size: Maximum decompressed archive size in bytes.
        :param pulumi.Input[_builtins.int] max_export_size: Maximum export size in MB. 0 for unlimited.
        :param pulumi.Input[_builtins.int] max_import_remote_file_size: Maximum remote file size for imports from external object storages.
        :param pulumi.Input[_builtins.int] max_import_size: Maximum import size in MB. 0 for unlimited.
        :param pulumi.Input[_builtins.int] max_login_attempts: Maximum number of sign-in attempts before locking out the user.
        :param pulumi.Input[_builtins.int] max_number_of_repository_downloads: Maximum number of unique repositories a user can download in the specified time period before they are banned. Maximum: 10,000 repositories.
        :param pulumi.Input[_builtins.int] max_number_of_repository_downloads_within_time_period: Reporting time period (in seconds). Maximum: 864000 seconds (10 days).
        :param pulumi.Input[_builtins.int] max_pages_size: Maximum size of pages repositories in MB.
        :param pulumi.Input[_builtins.int] max_personal_access_token_lifetime: Maximum allowable lifetime for access tokens in days.
        :param pulumi.Input[_builtins.int] max_ssh_key_lifetime: Maximum allowable lifetime for SSH keys in days.
        :param pulumi.Input[_builtins.int] metrics_method_call_threshold: A method call is only tracked when it takes longer than the given amount of milliseconds.
        :param pulumi.Input[_builtins.int] minimum_password_length: Indicates whether passwords require a minimum length. Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] mirror_available: Allow repository mirroring to configured by project Maintainers. If disabled, only Administrators can configure repository mirroring.
        :param pulumi.Input[_builtins.int] mirror_capacity_threshold: Minimum capacity to be available before scheduling more mirrors preemptively.
        :param pulumi.Input[_builtins.int] mirror_max_capacity: Maximum number of mirrors that can be synchronizing at the same time.
        :param pulumi.Input[_builtins.int] mirror_max_delay: Maximum time (in minutes) between updates that a mirror can have when scheduled to synchronize.
        :param pulumi.Input[_builtins.bool] npm_package_requests_forwarding: Use npmjs.org as a default remote repository when the package is not found in the GitLab Package Registry for npm.
        :param pulumi.Input[_builtins.bool] nuget_skip_metadata_url_validation: Indicates whether to skip metadata URL validation for the NuGet package.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] outbound_local_requests_whitelists: Define a list of trusted domains or IP addresses to which local requests are allowed when local requests for hooks and services are disabled.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] package_metadata_purl_types: List of package registry metadata to sync. See the list of the available values (https://gitlab.com/gitlab-org/gitlab/-/blob/ace16c20d5da7c4928dd03fb139692638b557fe3/app/models/concerns/enums/package_metadata.rb#L5). Self-managed, Ultimate only.
        :param pulumi.Input[_builtins.bool] package_registry_allow_anyone_to_pull_option: Enable to allow anyone to pull from Package Registry visible and changeable.
        :param pulumi.Input[_builtins.int] package_registry_cleanup_policies_worker_capacity: Number of workers assigned to the packages cleanup policies.
        :param pulumi.Input[_builtins.bool] pages_domain_verification_enabled: Require users to prove ownership of custom domains. Domain verification is an essential security measure for public GitLab sites. Users are required to demonstrate they control a domain before it is enabled.
        :param pulumi.Input[_builtins.bool] password_authentication_enabled_for_git: Enable authentication for Git over HTTP(S) via a GitLab account password.
        :param pulumi.Input[_builtins.bool] password_authentication_enabled_for_web: Enable authentication for the web interface via a GitLab account password.
        :param pulumi.Input[_builtins.bool] password_lowercase_required: Indicates whether passwords require at least one lowercase letter.
        :param pulumi.Input[_builtins.bool] password_number_required: Indicates whether passwords require at least one number.
        :param pulumi.Input[_builtins.bool] password_symbol_required: Indicates whether passwords require at least one symbol character.
        :param pulumi.Input[_builtins.bool] password_uppercase_required: Indicates whether passwords require at least one uppercase letter.
        :param pulumi.Input[_builtins.str] performance_bar_allowed_group_path: Path of the group that is allowed to toggle the performance bar.
        :param pulumi.Input[_builtins.str] personal_access_token_prefix: Prefix for all generated personal access tokens.
        :param pulumi.Input[_builtins.int] pipeline_limit_per_project_user_sha: Maximum number of pipeline creation requests per minute per user and commit.
        :param pulumi.Input[_builtins.bool] plantuml_enabled: (If enabled, requires: plantuml_url) Enable PlantUML integration.
        :param pulumi.Input[_builtins.str] plantuml_url: The PlantUML instance URL for integration.
        :param pulumi.Input[_builtins.float] polling_interval_multiplier: Interval multiplier used by endpoints that perform polling. Set to 0 to disable polling.
        :param pulumi.Input[_builtins.bool] project_export_enabled: Enable project export.
        :param pulumi.Input[_builtins.int] project_jobs_api_rate_limit: Maximum authenticated requests to /project/:id/jobs per minute.
        :param pulumi.Input[_builtins.int] projects_api_rate_limit_unauthenticated: Max number of requests per 10 minutes per IP address for unauthenticated requests to the list all projects API. To disable throttling set to 0.
        :param pulumi.Input[_builtins.bool] prometheus_metrics_enabled: Enable Prometheus metrics.
        :param pulumi.Input[_builtins.bool] protected_ci_variables: CI/CD variables are protected by default.
        :param pulumi.Input[_builtins.int] push_event_activities_limit: Number of changes (branches or tags) in a single push to determine whether individual push events or bulk push events are created. Bulk push events are created if it surpasses that value.
        :param pulumi.Input[_builtins.int] push_event_hooks_limit: Number of changes (branches or tags) in a single push to determine whether webhooks and services fire or not. Webhooks and services aren’t submitted if it surpasses that value.
        :param pulumi.Input[_builtins.bool] pypi_package_requests_forwarding: Use pypi.org as a default remote repository when the package is not found in the GitLab Package Registry for PyPI.
        :param pulumi.Input[_builtins.str] rate_limiting_response_text: When rate limiting is enabled via the throttle_* settings, send this plain text response when a rate limit is exceeded. ‘Retry later’ is sent if this is blank.
        :param pulumi.Input[_builtins.int] raw_blob_request_limit: Max number of requests per minute for each raw path. To disable throttling set to 0.
        :param pulumi.Input[_builtins.bool] recaptcha_enabled: (If enabled, requires: recaptcha*private*key and recaptcha*site*key) Enable reCAPTCHA.
        :param pulumi.Input[_builtins.str] recaptcha_private_key: Private key for reCAPTCHA.
        :param pulumi.Input[_builtins.str] recaptcha_site_key: Site key for reCAPTCHA.
        :param pulumi.Input[_builtins.int] receive_max_input_size: Maximum push size (MB).
        :param pulumi.Input[_builtins.bool] receptive_cluster_agents_enabled: Enable receptive mode for GitLab Agents for Kubernetes.
        :param pulumi.Input[_builtins.bool] remember_me_enabled: Enable Remember me setting.
        :param pulumi.Input[_builtins.bool] repository_checks_enabled: GitLab periodically runs git fsck in all project and wiki repositories to look for silent disk corruption issues.
        :param pulumi.Input[_builtins.int] repository_size_limit: Size limit per repository (MB).
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.int]]] repository_storages_weighted: Hash of names taken from gitlab.yml to weights. New projects are created in one of these stores, chosen by a weighted random selection.
        :param pulumi.Input[_builtins.bool] require_admin_approval_after_user_signup: When enabled, any user that signs up for an account using the registration form is placed under a Pending approval state and has to be explicitly approved by an administrator.
        :param pulumi.Input[_builtins.bool] require_admin_two_factor_authentication: Allow administrators to require 2FA for all administrators on the instance.
        :param pulumi.Input[_builtins.bool] require_personal_access_token_expiry: When enabled, users must set an expiration date when creating a group or project access token, or a personal access token owned by a non-service account.
        :param pulumi.Input[_builtins.bool] require_two_factor_authentication: (If enabled, requires: two*factor*grace_period) Require all users to set up Two-factor authentication.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] restricted_visibility_levels: Selected levels cannot be used by non-Administrator users for groups, projects or snippets. Can take private, internal and public as a parameter. Null means there is no restriction.
        :param pulumi.Input[_builtins.int] rsa_key_restriction: The minimum allowed bit length of an uploaded RSA key. 0 means no restriction. -1 disables RSA keys.
        :param pulumi.Input[_builtins.int] search_rate_limit: Max number of requests per minute for performing a search while authenticated. To disable throttling set to 0.
        :param pulumi.Input[_builtins.int] search_rate_limit_unauthenticated: Max number of requests per minute for performing a search while unauthenticated. To disable throttling set to 0.
        :param pulumi.Input[_builtins.int] security_approval_policies_limit: Maximum number of active merge request approval policies per security policy project. Maximum: 20
        :param pulumi.Input[_builtins.bool] security_policy_global_group_approvers_enabled: Whether to look up merge request approval policy approval groups globally or within project hierarchies.
        :param pulumi.Input[_builtins.str] security_txt_content: Public security contact information.
        :param pulumi.Input[_builtins.bool] send_user_confirmation_email: Send confirmation email on sign-up.
        :param pulumi.Input[_builtins.bool] service_access_tokens_expiration_enforced: Flag to indicate if token expiry date can be optional for service account users
        :param pulumi.Input[_builtins.int] session_expire_delay: Session duration in minutes. GitLab restart is required to apply changes.
        :param pulumi.Input[_builtins.bool] shared_runners_enabled: (If enabled, requires: shared*runners*text and shared*runners*minutes) Enable shared runners for new projects.
        :param pulumi.Input[_builtins.int] shared_runners_minutes: Set the maximum number of CI/CD minutes that a group can use on shared runners per month.
        :param pulumi.Input[_builtins.str] shared_runners_text: Shared runners text.
        :param pulumi.Input[_builtins.int] sidekiq_job_limiter_compression_threshold_bytes: The threshold in bytes at which Sidekiq jobs are compressed before being stored in Redis.
        :param pulumi.Input[_builtins.int] sidekiq_job_limiter_limit_bytes: The threshold in bytes at which Sidekiq jobs are rejected. 0 means do not reject any job.
        :param pulumi.Input[_builtins.str] sidekiq_job_limiter_mode: track or compress. Sets the behavior for Sidekiq job size limits.
        :param pulumi.Input[_builtins.str] sign_in_text: Text on the login page.
        :param pulumi.Input[_builtins.bool] signup_enabled: Enable registration.
        :param pulumi.Input[_builtins.bool] silent_admin_exports_enabled: Enable Silent admin exports.
        :param pulumi.Input[_builtins.bool] silent_mode_enabled: Enable Silent mode.
        :param pulumi.Input[_builtins.bool] slack_app_enabled: (If enabled, requires: slack*app*id, slack*app*secret and slack*app*secret) Enable Slack app.
        :param pulumi.Input[_builtins.str] slack_app_id: The app ID of the Slack-app.
        :param pulumi.Input[_builtins.str] slack_app_secret: The app secret of the Slack-app.
        :param pulumi.Input[_builtins.str] slack_app_signing_secret: The signing secret of the Slack-app.
        :param pulumi.Input[_builtins.str] slack_app_verification_token: The verification token of the Slack-app.
        :param pulumi.Input[_builtins.int] snippet_size_limit: Max snippet content size in bytes.
        :param pulumi.Input[_builtins.str] snowplow_app_id: The Snowplow site name / application ID. (for example, gitlab)
        :param pulumi.Input[_builtins.str] snowplow_collector_hostname: The Snowplow collector hostname. (for example, snowplow.trx.gitlab.net)
        :param pulumi.Input[_builtins.str] snowplow_cookie_domain: The Snowplow cookie domain. (for example, .gitlab.com)
        :param pulumi.Input[_builtins.str] snowplow_database_collector_hostname: The Snowplow collector for database events hostname. (for example, db-snowplow.trx.gitlab.net)
        :param pulumi.Input[_builtins.bool] snowplow_enabled: Enable snowplow tracking.
        :param pulumi.Input[_builtins.bool] sourcegraph_enabled: Enables Sourcegraph integration. If enabled, requires sourcegraph_url.
        :param pulumi.Input[_builtins.bool] sourcegraph_public_only: Blocks Sourcegraph from being loaded on private and internal projects.
        :param pulumi.Input[_builtins.str] sourcegraph_url: The Sourcegraph instance URL for integration.
        :param pulumi.Input[_builtins.str] spam_check_api_key: API key used by GitLab for accessing the Spam Check service endpoint.
        :param pulumi.Input[_builtins.bool] spam_check_endpoint_enabled: Enables spam checking using external Spam Check API endpoint.
        :param pulumi.Input[_builtins.str] spam_check_endpoint_url: URL of the external Spamcheck service endpoint. Valid URI schemes are grpc or tls. Specifying tls forces communication to be encrypted.
        :param pulumi.Input[_builtins.str] static_objects_external_storage_auth_token: Authentication token for the external storage linked in static*objects*external*storage*url.
        :param pulumi.Input[_builtins.str] static_objects_external_storage_url: URL to an external storage for repository static objects.
        :param pulumi.Input[_builtins.bool] suggest_pipeline_enabled: Enable pipeline suggestion banner.
        :param pulumi.Input[_builtins.int] terminal_max_session_time: Maximum time for web terminal websocket connection (in seconds). Set to 0 for unlimited time.
        :param pulumi.Input[_builtins.str] terms: (Required by: enforce_terms) Markdown content for the ToS.
        :param pulumi.Input[_builtins.bool] throttle_authenticated_api_enabled: (If enabled, requires: throttle*authenticated*api*period*in*seconds and throttle*authenticated*api*requests*per*period) Enable authenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        :param pulumi.Input[_builtins.int] throttle_authenticated_api_period_in_seconds: Rate limit period (in seconds).
        :param pulumi.Input[_builtins.int] throttle_authenticated_api_requests_per_period: Maximum requests per period per user.
        :param pulumi.Input[_builtins.bool] throttle_authenticated_packages_api_enabled: (If enabled, requires: throttle*authenticated*packages*api*period*in*seconds and throttle*authenticated*packages*api*requests*per*period) Enable authenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots). View Package Registry rate limits for more details.
        :param pulumi.Input[_builtins.int] throttle_authenticated_packages_api_period_in_seconds: Rate limit period (in seconds). View Package Registry rate limits for more details.
        :param pulumi.Input[_builtins.int] throttle_authenticated_packages_api_requests_per_period: Maximum requests per period per user. View Package Registry rate limits for more details.
        :param pulumi.Input[_builtins.bool] throttle_authenticated_web_enabled: (If enabled, requires: throttle*authenticated*web*period*in*seconds and throttle*authenticated*web*requests*per*period) Enable authenticated web request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        :param pulumi.Input[_builtins.int] throttle_authenticated_web_period_in_seconds: Rate limit period (in seconds).
        :param pulumi.Input[_builtins.int] throttle_authenticated_web_requests_per_period: Maximum requests per period per user.
        :param pulumi.Input[_builtins.bool] throttle_unauthenticated_api_enabled: (If enabled, requires: throttle*unauthenticated*api*period*in*seconds and throttle*unauthenticated*api*requests*per*period) Enable unauthenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        :param pulumi.Input[_builtins.int] throttle_unauthenticated_api_period_in_seconds: Rate limit period in seconds.
        :param pulumi.Input[_builtins.int] throttle_unauthenticated_api_requests_per_period: Max requests per period per IP.
        :param pulumi.Input[_builtins.bool] throttle_unauthenticated_packages_api_enabled: (If enabled, requires: throttle*unauthenticated*packages*api*period*in*seconds and throttle*unauthenticated*packages*api*requests*per*period) Enable authenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots). View Package Registry rate limits for more details.
        :param pulumi.Input[_builtins.int] throttle_unauthenticated_packages_api_period_in_seconds: Rate limit period (in seconds). View Package Registry rate limits for more details.
        :param pulumi.Input[_builtins.int] throttle_unauthenticated_packages_api_requests_per_period: Maximum requests per period per user. View Package Registry rate limits for more details.
        :param pulumi.Input[_builtins.bool] throttle_unauthenticated_web_enabled: (If enabled, requires: throttle*unauthenticated*web*period*in*seconds and throttle*unauthenticated*web*requests*per*period) Enable unauthenticated web request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        :param pulumi.Input[_builtins.int] throttle_unauthenticated_web_period_in_seconds: Rate limit period in seconds.
        :param pulumi.Input[_builtins.int] throttle_unauthenticated_web_requests_per_period: Max requests per period per IP.
        :param pulumi.Input[_builtins.bool] time_tracking_limit_to_hours: Limit display of time tracking units to hours.
        :param pulumi.Input[_builtins.int] two_factor_grace_period: Amount of time (in hours) that users are allowed to skip forced configuration of two-factor authentication.
        :param pulumi.Input[_builtins.int] unconfirmed_users_delete_after_days: Specifies how many days after sign-up to delete users who have not confirmed their email. Only applicable if delete*unconfirmed*users is set to true. Must be 1 or greater. Self-managed, Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] unique_ips_limit_enabled: (If enabled, requires: unique*ips*limit*per*user and unique*ips*limit*time*window) Limit sign in from multiple IPs.
        :param pulumi.Input[_builtins.int] unique_ips_limit_per_user: Maximum number of IPs per user.
        :param pulumi.Input[_builtins.int] unique_ips_limit_time_window: How many seconds an IP is counted towards the limit.
        :param pulumi.Input[_builtins.bool] update_runner_versions_enabled: Fetch GitLab Runner release version data from GitLab.com.
        :param pulumi.Input[_builtins.bool] usage_ping_enabled: Every week GitLab reports license usage back to GitLab, Inc.
        :param pulumi.Input[_builtins.bool] use_clickhouse_for_analytics: Enables ClickHouse as a data source for analytics reports. ClickHouse must be configured for this setting to take effect. Available on Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] user_deactivation_emails_enabled: Send an email to users upon account deactivation.
        :param pulumi.Input[_builtins.bool] user_default_external: Newly registered users are external by default.
        :param pulumi.Input[_builtins.str] user_default_internal_regex: Specify an email address regex pattern to identify default internal users.
        :param pulumi.Input[_builtins.bool] user_defaults_to_private_profile: Newly created users have private profile by default.
        :param pulumi.Input[_builtins.bool] user_oauth_applications: Allow users to register any application to use GitLab as an OAuth provider.
        :param pulumi.Input[_builtins.bool] user_show_add_ssh_key_message: When set to false disable the You won't be able to pull or push project code via SSH warning shown to users with no uploaded SSH key.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] valid_runner_registrars: List of types which are allowed to register a GitLab Runner. Can be [], ['group'], ['project'] or ['group', 'project'].
        :param pulumi.Input[_builtins.bool] version_check_enabled: Let GitLab inform you when an update is available.
        :param pulumi.Input[_builtins.bool] web_ide_clientside_preview_enabled: Live Preview (allow live previews of JavaScript projects in the Web IDE using CodeSandbox Live Preview).
        :param pulumi.Input[_builtins.str] whats_new_variant: What's new variant, possible values: all*tiers, current*tier, and disabled.
        :param pulumi.Input[_builtins.int] wiki_page_max_content_bytes: Maximum wiki page content size in bytes. The minimum value is 1024 bytes.
        """
        if abuse_notification_email is not None:
            pulumi.set(__self__, "abuse_notification_email", abuse_notification_email)
        if admin_mode is not None:
            pulumi.set(__self__, "admin_mode", admin_mode)
        if after_sign_out_path is not None:
            pulumi.set(__self__, "after_sign_out_path", after_sign_out_path)
        if after_sign_up_text is not None:
            pulumi.set(__self__, "after_sign_up_text", after_sign_up_text)
        if akismet_api_key is not None:
            pulumi.set(__self__, "akismet_api_key", akismet_api_key)
        if akismet_enabled is not None:
            pulumi.set(__self__, "akismet_enabled", akismet_enabled)
        if allow_account_deletion is not None:
            pulumi.set(__self__, "allow_account_deletion", allow_account_deletion)
        if allow_group_owners_to_manage_ldap is not None:
            pulumi.set(__self__, "allow_group_owners_to_manage_ldap", allow_group_owners_to_manage_ldap)
        if allow_local_requests_from_system_hooks is not None:
            pulumi.set(__self__, "allow_local_requests_from_system_hooks", allow_local_requests_from_system_hooks)
        if allow_local_requests_from_web_hooks_and_services is not None:
            pulumi.set(__self__, "allow_local_requests_from_web_hooks_and_services", allow_local_requests_from_web_hooks_and_services)
        if allow_project_creation_for_guest_and_below is not None:
            pulumi.set(__self__, "allow_project_creation_for_guest_and_below", allow_project_creation_for_guest_and_below)
        if allow_runner_registration_token is not None:
            pulumi.set(__self__, "allow_runner_registration_token", allow_runner_registration_token)
        if archive_builds_in_human_readable is not None:
            pulumi.set(__self__, "archive_builds_in_human_readable", archive_builds_in_human_readable)
        if asciidoc_max_includes is not None:
            pulumi.set(__self__, "asciidoc_max_includes", asciidoc_max_includes)
        if asset_proxy_allowlists is not None:
            pulumi.set(__self__, "asset_proxy_allowlists", asset_proxy_allowlists)
        if asset_proxy_enabled is not None:
            pulumi.set(__self__, "asset_proxy_enabled", asset_proxy_enabled)
        if asset_proxy_secret_key is not None:
            pulumi.set(__self__, "asset_proxy_secret_key", asset_proxy_secret_key)
        if asset_proxy_url is not None:
            pulumi.set(__self__, "asset_proxy_url", asset_proxy_url)
        if authorized_keys_enabled is not None:
            pulumi.set(__self__, "authorized_keys_enabled", authorized_keys_enabled)
        if auto_ban_user_on_excessive_projects_download is not None:
            pulumi.set(__self__, "auto_ban_user_on_excessive_projects_download", auto_ban_user_on_excessive_projects_download)
        if auto_devops_domain is not None:
            pulumi.set(__self__, "auto_devops_domain", auto_devops_domain)
        if auto_devops_enabled is not None:
            pulumi.set(__self__, "auto_devops_enabled", auto_devops_enabled)
        if automatic_purchased_storage_allocation is not None:
            pulumi.set(__self__, "automatic_purchased_storage_allocation", automatic_purchased_storage_allocation)
        if bulk_import_concurrent_pipeline_batch_limit is not None:
            pulumi.set(__self__, "bulk_import_concurrent_pipeline_batch_limit", bulk_import_concurrent_pipeline_batch_limit)
        if bulk_import_enabled is not None:
            pulumi.set(__self__, "bulk_import_enabled", bulk_import_enabled)
        if bulk_import_max_download_file_size is not None:
            pulumi.set(__self__, "bulk_import_max_download_file_size", bulk_import_max_download_file_size)
        if can_create_group is not None:
            pulumi.set(__self__, "can_create_group", can_create_group)
        if check_namespace_plan is not None:
            pulumi.set(__self__, "check_namespace_plan", check_namespace_plan)
        if ci_max_includes is not None:
            pulumi.set(__self__, "ci_max_includes", ci_max_includes)
        if ci_max_total_yaml_size_bytes is not None:
            pulumi.set(__self__, "ci_max_total_yaml_size_bytes", ci_max_total_yaml_size_bytes)
        if commit_email_hostname is not None:
            pulumi.set(__self__, "commit_email_hostname", commit_email_hostname)
        if concurrent_bitbucket_import_jobs_limit is not None:
            pulumi.set(__self__, "concurrent_bitbucket_import_jobs_limit", concurrent_bitbucket_import_jobs_limit)
        if concurrent_bitbucket_server_import_jobs_limit is not None:
            pulumi.set(__self__, "concurrent_bitbucket_server_import_jobs_limit", concurrent_bitbucket_server_import_jobs_limit)
        if concurrent_github_import_jobs_limit is not None:
            pulumi.set(__self__, "concurrent_github_import_jobs_limit", concurrent_github_import_jobs_limit)
        if container_expiration_policies_enable_historic_entries is not None:
            pulumi.set(__self__, "container_expiration_policies_enable_historic_entries", container_expiration_policies_enable_historic_entries)
        if container_registry_cleanup_tags_service_max_list_size is not None:
            pulumi.set(__self__, "container_registry_cleanup_tags_service_max_list_size", container_registry_cleanup_tags_service_max_list_size)
        if container_registry_delete_tags_service_timeout is not None:
            pulumi.set(__self__, "container_registry_delete_tags_service_timeout", container_registry_delete_tags_service_timeout)
        if container_registry_expiration_policies_caching is not None:
            pulumi.set(__self__, "container_registry_expiration_policies_caching", container_registry_expiration_policies_caching)
        if container_registry_expiration_policies_worker_capacity is not None:
            pulumi.set(__self__, "container_registry_expiration_policies_worker_capacity", container_registry_expiration_policies_worker_capacity)
        if container_registry_token_expire_delay is not None:
            pulumi.set(__self__, "container_registry_token_expire_delay", container_registry_token_expire_delay)
        if deactivate_dormant_users is not None:
            pulumi.set(__self__, "deactivate_dormant_users", deactivate_dormant_users)
        if deactivate_dormant_users_period is not None:
            pulumi.set(__self__, "deactivate_dormant_users_period", deactivate_dormant_users_period)
        if decompress_archive_file_timeout is not None:
            pulumi.set(__self__, "decompress_archive_file_timeout", decompress_archive_file_timeout)
        if default_artifacts_expire_in is not None:
            pulumi.set(__self__, "default_artifacts_expire_in", default_artifacts_expire_in)
        if default_branch_name is not None:
            pulumi.set(__self__, "default_branch_name", default_branch_name)
        if default_branch_protection is not None:
            warnings.warn("""Use `default_branch_protection_defaults` instead. To be removed in 19.0.""", DeprecationWarning)
            pulumi.log.warn("""default_branch_protection is deprecated: Use `default_branch_protection_defaults` instead. To be removed in 19.0.""")
        if default_branch_protection is not None:
            pulumi.set(__self__, "default_branch_protection", default_branch_protection)
        if default_branch_protection_defaults is not None:
            pulumi.set(__self__, "default_branch_protection_defaults", default_branch_protection_defaults)
        if default_ci_config_path is not None:
            pulumi.set(__self__, "default_ci_config_path", default_ci_config_path)
        if default_group_visibility is not None:
            pulumi.set(__self__, "default_group_visibility", default_group_visibility)
        if default_preferred_language is not None:
            pulumi.set(__self__, "default_preferred_language", default_preferred_language)
        if default_project_creation is not None:
            pulumi.set(__self__, "default_project_creation", default_project_creation)
        if default_project_visibility is not None:
            pulumi.set(__self__, "default_project_visibility", default_project_visibility)
        if default_projects_limit is not None:
            pulumi.set(__self__, "default_projects_limit", default_projects_limit)
        if default_snippet_visibility is not None:
            pulumi.set(__self__, "default_snippet_visibility", default_snippet_visibility)
        if default_syntax_highlighting_theme is not None:
            pulumi.set(__self__, "default_syntax_highlighting_theme", default_syntax_highlighting_theme)
        if delete_inactive_projects is not None:
            pulumi.set(__self__, "delete_inactive_projects", delete_inactive_projects)
        if delete_unconfirmed_users is not None:
            pulumi.set(__self__, "delete_unconfirmed_users", delete_unconfirmed_users)
        if deletion_adjourned_period is not None:
            pulumi.set(__self__, "deletion_adjourned_period", deletion_adjourned_period)
        if diagramsnet_enabled is not None:
            pulumi.set(__self__, "diagramsnet_enabled", diagramsnet_enabled)
        if diagramsnet_url is not None:
            pulumi.set(__self__, "diagramsnet_url", diagramsnet_url)
        if diff_max_files is not None:
            pulumi.set(__self__, "diff_max_files", diff_max_files)
        if diff_max_lines is not None:
            pulumi.set(__self__, "diff_max_lines", diff_max_lines)
        if diff_max_patch_bytes is not None:
            pulumi.set(__self__, "diff_max_patch_bytes", diff_max_patch_bytes)
        if disable_admin_oauth_scopes is not None:
            pulumi.set(__self__, "disable_admin_oauth_scopes", disable_admin_oauth_scopes)
        if disable_feed_token is not None:
            pulumi.set(__self__, "disable_feed_token", disable_feed_token)
        if disable_personal_access_tokens is not None:
            pulumi.set(__self__, "disable_personal_access_tokens", disable_personal_access_tokens)
        if disabled_oauth_sign_in_sources is not None:
            pulumi.set(__self__, "disabled_oauth_sign_in_sources", disabled_oauth_sign_in_sources)
        if dns_rebinding_protection_enabled is not None:
            pulumi.set(__self__, "dns_rebinding_protection_enabled", dns_rebinding_protection_enabled)
        if domain_allowlists is not None:
            pulumi.set(__self__, "domain_allowlists", domain_allowlists)
        if domain_denylist_enabled is not None:
            pulumi.set(__self__, "domain_denylist_enabled", domain_denylist_enabled)
        if domain_denylists is not None:
            pulumi.set(__self__, "domain_denylists", domain_denylists)
        if downstream_pipeline_trigger_limit_per_project_user_sha is not None:
            pulumi.set(__self__, "downstream_pipeline_trigger_limit_per_project_user_sha", downstream_pipeline_trigger_limit_per_project_user_sha)
        if dsa_key_restriction is not None:
            pulumi.set(__self__, "dsa_key_restriction", dsa_key_restriction)
        if duo_features_enabled is not None:
            pulumi.set(__self__, "duo_features_enabled", duo_features_enabled)
        if ecdsa_key_restriction is not None:
            pulumi.set(__self__, "ecdsa_key_restriction", ecdsa_key_restriction)
        if ecdsa_sk_key_restriction is not None:
            pulumi.set(__self__, "ecdsa_sk_key_restriction", ecdsa_sk_key_restriction)
        if ed25519_key_restriction is not None:
            pulumi.set(__self__, "ed25519_key_restriction", ed25519_key_restriction)
        if ed25519_sk_key_restriction is not None:
            pulumi.set(__self__, "ed25519_sk_key_restriction", ed25519_sk_key_restriction)
        if eks_access_key_id is not None:
            pulumi.set(__self__, "eks_access_key_id", eks_access_key_id)
        if eks_account_id is not None:
            pulumi.set(__self__, "eks_account_id", eks_account_id)
        if eks_integration_enabled is not None:
            pulumi.set(__self__, "eks_integration_enabled", eks_integration_enabled)
        if eks_secret_access_key is not None:
            pulumi.set(__self__, "eks_secret_access_key", eks_secret_access_key)
        if elasticsearch_aws is not None:
            pulumi.set(__self__, "elasticsearch_aws", elasticsearch_aws)
        if elasticsearch_aws_access_key is not None:
            pulumi.set(__self__, "elasticsearch_aws_access_key", elasticsearch_aws_access_key)
        if elasticsearch_aws_region is not None:
            pulumi.set(__self__, "elasticsearch_aws_region", elasticsearch_aws_region)
        if elasticsearch_aws_secret_access_key is not None:
            pulumi.set(__self__, "elasticsearch_aws_secret_access_key", elasticsearch_aws_secret_access_key)
        if elasticsearch_indexed_field_length_limit is not None:
            pulumi.set(__self__, "elasticsearch_indexed_field_length_limit", elasticsearch_indexed_field_length_limit)
        if elasticsearch_indexed_file_size_limit_kb is not None:
            pulumi.set(__self__, "elasticsearch_indexed_file_size_limit_kb", elasticsearch_indexed_file_size_limit_kb)
        if elasticsearch_indexing is not None:
            pulumi.set(__self__, "elasticsearch_indexing", elasticsearch_indexing)
        if elasticsearch_limit_indexing is not None:
            pulumi.set(__self__, "elasticsearch_limit_indexing", elasticsearch_limit_indexing)
        if elasticsearch_max_bulk_concurrency is not None:
            pulumi.set(__self__, "elasticsearch_max_bulk_concurrency", elasticsearch_max_bulk_concurrency)
        if elasticsearch_max_bulk_size_mb is not None:
            pulumi.set(__self__, "elasticsearch_max_bulk_size_mb", elasticsearch_max_bulk_size_mb)
        if elasticsearch_max_code_indexing_concurrency is not None:
            pulumi.set(__self__, "elasticsearch_max_code_indexing_concurrency", elasticsearch_max_code_indexing_concurrency)
        if elasticsearch_namespace_ids is not None:
            pulumi.set(__self__, "elasticsearch_namespace_ids", elasticsearch_namespace_ids)
        if elasticsearch_password is not None:
            pulumi.set(__self__, "elasticsearch_password", elasticsearch_password)
        if elasticsearch_project_ids is not None:
            pulumi.set(__self__, "elasticsearch_project_ids", elasticsearch_project_ids)
        if elasticsearch_requeue_workers is not None:
            pulumi.set(__self__, "elasticsearch_requeue_workers", elasticsearch_requeue_workers)
        if elasticsearch_search is not None:
            pulumi.set(__self__, "elasticsearch_search", elasticsearch_search)
        if elasticsearch_urls is not None:
            pulumi.set(__self__, "elasticsearch_urls", elasticsearch_urls)
        if elasticsearch_username is not None:
            pulumi.set(__self__, "elasticsearch_username", elasticsearch_username)
        if elasticsearch_worker_number_of_shards is not None:
            pulumi.set(__self__, "elasticsearch_worker_number_of_shards", elasticsearch_worker_number_of_shards)
        if email_additional_text is not None:
            pulumi.set(__self__, "email_additional_text", email_additional_text)
        if email_author_in_body is not None:
            pulumi.set(__self__, "email_author_in_body", email_author_in_body)
        if email_confirmation_setting is not None:
            pulumi.set(__self__, "email_confirmation_setting", email_confirmation_setting)
        if enable_artifact_external_redirect_warning_page is not None:
            pulumi.set(__self__, "enable_artifact_external_redirect_warning_page", enable_artifact_external_redirect_warning_page)
        if enabled_git_access_protocol is not None:
            pulumi.set(__self__, "enabled_git_access_protocol", enabled_git_access_protocol)
        if enforce_namespace_storage_limit is not None:
            pulumi.set(__self__, "enforce_namespace_storage_limit", enforce_namespace_storage_limit)
        if enforce_terms is not None:
            pulumi.set(__self__, "enforce_terms", enforce_terms)
        if external_auth_client_cert is not None:
            pulumi.set(__self__, "external_auth_client_cert", external_auth_client_cert)
        if external_auth_client_key is not None:
            pulumi.set(__self__, "external_auth_client_key", external_auth_client_key)
        if external_auth_client_key_pass is not None:
            pulumi.set(__self__, "external_auth_client_key_pass", external_auth_client_key_pass)
        if external_authorization_service_default_label is not None:
            pulumi.set(__self__, "external_authorization_service_default_label", external_authorization_service_default_label)
        if external_authorization_service_enabled is not None:
            pulumi.set(__self__, "external_authorization_service_enabled", external_authorization_service_enabled)
        if external_authorization_service_timeout is not None:
            pulumi.set(__self__, "external_authorization_service_timeout", external_authorization_service_timeout)
        if external_authorization_service_url is not None:
            pulumi.set(__self__, "external_authorization_service_url", external_authorization_service_url)
        if external_pipeline_validation_service_timeout is not None:
            pulumi.set(__self__, "external_pipeline_validation_service_timeout", external_pipeline_validation_service_timeout)
        if external_pipeline_validation_service_token is not None:
            pulumi.set(__self__, "external_pipeline_validation_service_token", external_pipeline_validation_service_token)
        if external_pipeline_validation_service_url is not None:
            pulumi.set(__self__, "external_pipeline_validation_service_url", external_pipeline_validation_service_url)
        if failed_login_attempts_unlock_period_in_minutes is not None:
            pulumi.set(__self__, "failed_login_attempts_unlock_period_in_minutes", failed_login_attempts_unlock_period_in_minutes)
        if file_template_project_id is not None:
            pulumi.set(__self__, "file_template_project_id", file_template_project_id)
        if first_day_of_week is not None:
            pulumi.set(__self__, "first_day_of_week", first_day_of_week)
        if geo_node_allowed_ips is not None:
            pulumi.set(__self__, "geo_node_allowed_ips", geo_node_allowed_ips)
        if geo_status_timeout is not None:
            pulumi.set(__self__, "geo_status_timeout", geo_status_timeout)
        if git_rate_limit_users_alertlists is not None:
            pulumi.set(__self__, "git_rate_limit_users_alertlists", git_rate_limit_users_alertlists)
        if git_rate_limit_users_allowlists is not None:
            pulumi.set(__self__, "git_rate_limit_users_allowlists", git_rate_limit_users_allowlists)
        if git_two_factor_session_expiry is not None:
            pulumi.set(__self__, "git_two_factor_session_expiry", git_two_factor_session_expiry)
        if gitaly_timeout_default is not None:
            pulumi.set(__self__, "gitaly_timeout_default", gitaly_timeout_default)
        if gitaly_timeout_fast is not None:
            pulumi.set(__self__, "gitaly_timeout_fast", gitaly_timeout_fast)
        if gitaly_timeout_medium is not None:
            pulumi.set(__self__, "gitaly_timeout_medium", gitaly_timeout_medium)
        if gitlab_shell_operation_limit is not None:
            pulumi.set(__self__, "gitlab_shell_operation_limit", gitlab_shell_operation_limit)
        if gitpod_enabled is not None:
            pulumi.set(__self__, "gitpod_enabled", gitpod_enabled)
        if gitpod_url is not None:
            pulumi.set(__self__, "gitpod_url", gitpod_url)
        if globally_allowed_ips is not None:
            pulumi.set(__self__, "globally_allowed_ips", globally_allowed_ips)
        if grafana_enabled is not None:
            pulumi.set(__self__, "grafana_enabled", grafana_enabled)
        if grafana_url is not None:
            pulumi.set(__self__, "grafana_url", grafana_url)
        if gravatar_enabled is not None:
            pulumi.set(__self__, "gravatar_enabled", gravatar_enabled)
        if group_owners_can_manage_default_branch_protection is not None:
            pulumi.set(__self__, "group_owners_can_manage_default_branch_protection", group_owners_can_manage_default_branch_protection)
        if help_page_hide_commercial_content is not None:
            pulumi.set(__self__, "help_page_hide_commercial_content", help_page_hide_commercial_content)
        if help_page_support_url is not None:
            pulumi.set(__self__, "help_page_support_url", help_page_support_url)
        if help_page_text is not None:
            pulumi.set(__self__, "help_page_text", help_page_text)
        if help_text is not None:
            pulumi.set(__self__, "help_text", help_text)
        if hide_third_party_offers is not None:
            pulumi.set(__self__, "hide_third_party_offers", hide_third_party_offers)
        if home_page_url is not None:
            pulumi.set(__self__, "home_page_url", home_page_url)
        if housekeeping_enabled is not None:
            pulumi.set(__self__, "housekeeping_enabled", housekeeping_enabled)
        if housekeeping_optimize_repository_period is not None:
            pulumi.set(__self__, "housekeeping_optimize_repository_period", housekeeping_optimize_repository_period)
        if html_emails_enabled is not None:
            pulumi.set(__self__, "html_emails_enabled", html_emails_enabled)
        if import_sources is not None:
            pulumi.set(__self__, "import_sources", import_sources)
        if in_product_marketing_emails_enabled is not None:
            pulumi.set(__self__, "in_product_marketing_emails_enabled", in_product_marketing_emails_enabled)
        if inactive_projects_delete_after_months is not None:
            pulumi.set(__self__, "inactive_projects_delete_after_months", inactive_projects_delete_after_months)
        if inactive_projects_min_size_mb is not None:
            pulumi.set(__self__, "inactive_projects_min_size_mb", inactive_projects_min_size_mb)
        if inactive_projects_send_warning_email_after_months is not None:
            pulumi.set(__self__, "inactive_projects_send_warning_email_after_months", inactive_projects_send_warning_email_after_months)
        if include_optional_metrics_in_service_ping is not None:
            pulumi.set(__self__, "include_optional_metrics_in_service_ping", include_optional_metrics_in_service_ping)
        if invisible_captcha_enabled is not None:
            pulumi.set(__self__, "invisible_captcha_enabled", invisible_captcha_enabled)
        if issues_create_limit is not None:
            pulumi.set(__self__, "issues_create_limit", issues_create_limit)
        if jira_connect_application_key is not None:
            pulumi.set(__self__, "jira_connect_application_key", jira_connect_application_key)
        if jira_connect_proxy_url is not None:
            pulumi.set(__self__, "jira_connect_proxy_url", jira_connect_proxy_url)
        if jira_connect_public_key_storage_enabled is not None:
            pulumi.set(__self__, "jira_connect_public_key_storage_enabled", jira_connect_public_key_storage_enabled)
        if keep_latest_artifact is not None:
            pulumi.set(__self__, "keep_latest_artifact", keep_latest_artifact)
        if local_markdown_version is not None:
            pulumi.set(__self__, "local_markdown_version", local_markdown_version)
        if lock_duo_features_enabled is not None:
            pulumi.set(__self__, "lock_duo_features_enabled", lock_duo_features_enabled)
        if lock_memberships_to_ldap is not None:
            pulumi.set(__self__, "lock_memberships_to_ldap", lock_memberships_to_ldap)
        if mailgun_events_enabled is not None:
            pulumi.set(__self__, "mailgun_events_enabled", mailgun_events_enabled)
        if mailgun_signing_key is not None:
            pulumi.set(__self__, "mailgun_signing_key", mailgun_signing_key)
        if maintenance_mode is not None:
            pulumi.set(__self__, "maintenance_mode", maintenance_mode)
        if maintenance_mode_message is not None:
            pulumi.set(__self__, "maintenance_mode_message", maintenance_mode_message)
        if maven_package_requests_forwarding is not None:
            pulumi.set(__self__, "maven_package_requests_forwarding", maven_package_requests_forwarding)
        if max_artifacts_size is not None:
            pulumi.set(__self__, "max_artifacts_size", max_artifacts_size)
        if max_attachment_size is not None:
            pulumi.set(__self__, "max_attachment_size", max_attachment_size)
        if max_decompressed_archive_size is not None:
            pulumi.set(__self__, "max_decompressed_archive_size", max_decompressed_archive_size)
        if max_export_size is not None:
            pulumi.set(__self__, "max_export_size", max_export_size)
        if max_import_remote_file_size is not None:
            pulumi.set(__self__, "max_import_remote_file_size", max_import_remote_file_size)
        if max_import_size is not None:
            pulumi.set(__self__, "max_import_size", max_import_size)
        if max_login_attempts is not None:
            pulumi.set(__self__, "max_login_attempts", max_login_attempts)
        if max_number_of_repository_downloads is not None:
            pulumi.set(__self__, "max_number_of_repository_downloads", max_number_of_repository_downloads)
        if max_number_of_repository_downloads_within_time_period is not None:
            pulumi.set(__self__, "max_number_of_repository_downloads_within_time_period", max_number_of_repository_downloads_within_time_period)
        if max_pages_size is not None:
            pulumi.set(__self__, "max_pages_size", max_pages_size)
        if max_personal_access_token_lifetime is not None:
            pulumi.set(__self__, "max_personal_access_token_lifetime", max_personal_access_token_lifetime)
        if max_ssh_key_lifetime is not None:
            pulumi.set(__self__, "max_ssh_key_lifetime", max_ssh_key_lifetime)
        if max_terraform_state_size_bytes is not None:
            pulumi.set(__self__, "max_terraform_state_size_bytes", max_terraform_state_size_bytes)
        if metrics_method_call_threshold is not None:
            pulumi.set(__self__, "metrics_method_call_threshold", metrics_method_call_threshold)
        if minimum_password_length is not None:
            pulumi.set(__self__, "minimum_password_length", minimum_password_length)
        if mirror_available is not None:
            pulumi.set(__self__, "mirror_available", mirror_available)
        if mirror_capacity_threshold is not None:
            pulumi.set(__self__, "mirror_capacity_threshold", mirror_capacity_threshold)
        if mirror_max_capacity is not None:
            pulumi.set(__self__, "mirror_max_capacity", mirror_max_capacity)
        if mirror_max_delay is not None:
            pulumi.set(__self__, "mirror_max_delay", mirror_max_delay)
        if npm_package_requests_forwarding is not None:
            pulumi.set(__self__, "npm_package_requests_forwarding", npm_package_requests_forwarding)
        if nuget_skip_metadata_url_validation is not None:
            pulumi.set(__self__, "nuget_skip_metadata_url_validation", nuget_skip_metadata_url_validation)
        if outbound_local_requests_whitelists is not None:
            pulumi.set(__self__, "outbound_local_requests_whitelists", outbound_local_requests_whitelists)
        if package_metadata_purl_types is not None:
            pulumi.set(__self__, "package_metadata_purl_types", package_metadata_purl_types)
        if package_registry_allow_anyone_to_pull_option is not None:
            pulumi.set(__self__, "package_registry_allow_anyone_to_pull_option", package_registry_allow_anyone_to_pull_option)
        if package_registry_cleanup_policies_worker_capacity is not None:
            pulumi.set(__self__, "package_registry_cleanup_policies_worker_capacity", package_registry_cleanup_policies_worker_capacity)
        if pages_domain_verification_enabled is not None:
            pulumi.set(__self__, "pages_domain_verification_enabled", pages_domain_verification_enabled)
        if password_authentication_enabled_for_git is not None:
            pulumi.set(__self__, "password_authentication_enabled_for_git", password_authentication_enabled_for_git)
        if password_authentication_enabled_for_web is not None:
            pulumi.set(__self__, "password_authentication_enabled_for_web", password_authentication_enabled_for_web)
        if password_lowercase_required is not None:
            pulumi.set(__self__, "password_lowercase_required", password_lowercase_required)
        if password_number_required is not None:
            pulumi.set(__self__, "password_number_required", password_number_required)
        if password_symbol_required is not None:
            pulumi.set(__self__, "password_symbol_required", password_symbol_required)
        if password_uppercase_required is not None:
            pulumi.set(__self__, "password_uppercase_required", password_uppercase_required)
        if performance_bar_allowed_group_path is not None:
            pulumi.set(__self__, "performance_bar_allowed_group_path", performance_bar_allowed_group_path)
        if personal_access_token_prefix is not None:
            pulumi.set(__self__, "personal_access_token_prefix", personal_access_token_prefix)
        if pipeline_limit_per_project_user_sha is not None:
            pulumi.set(__self__, "pipeline_limit_per_project_user_sha", pipeline_limit_per_project_user_sha)
        if plantuml_enabled is not None:
            pulumi.set(__self__, "plantuml_enabled", plantuml_enabled)
        if plantuml_url is not None:
            pulumi.set(__self__, "plantuml_url", plantuml_url)
        if polling_interval_multiplier is not None:
            pulumi.set(__self__, "polling_interval_multiplier", polling_interval_multiplier)
        if project_export_enabled is not None:
            pulumi.set(__self__, "project_export_enabled", project_export_enabled)
        if project_jobs_api_rate_limit is not None:
            pulumi.set(__self__, "project_jobs_api_rate_limit", project_jobs_api_rate_limit)
        if projects_api_rate_limit_unauthenticated is not None:
            pulumi.set(__self__, "projects_api_rate_limit_unauthenticated", projects_api_rate_limit_unauthenticated)
        if prometheus_metrics_enabled is not None:
            pulumi.set(__self__, "prometheus_metrics_enabled", prometheus_metrics_enabled)
        if protected_ci_variables is not None:
            pulumi.set(__self__, "protected_ci_variables", protected_ci_variables)
        if push_event_activities_limit is not None:
            pulumi.set(__self__, "push_event_activities_limit", push_event_activities_limit)
        if push_event_hooks_limit is not None:
            pulumi.set(__self__, "push_event_hooks_limit", push_event_hooks_limit)
        if pypi_package_requests_forwarding is not None:
            pulumi.set(__self__, "pypi_package_requests_forwarding", pypi_package_requests_forwarding)
        if rate_limiting_response_text is not None:
            pulumi.set(__self__, "rate_limiting_response_text", rate_limiting_response_text)
        if raw_blob_request_limit is not None:
            pulumi.set(__self__, "raw_blob_request_limit", raw_blob_request_limit)
        if recaptcha_enabled is not None:
            pulumi.set(__self__, "recaptcha_enabled", recaptcha_enabled)
        if recaptcha_private_key is not None:
            pulumi.set(__self__, "recaptcha_private_key", recaptcha_private_key)
        if recaptcha_site_key is not None:
            pulumi.set(__self__, "recaptcha_site_key", recaptcha_site_key)
        if receive_max_input_size is not None:
            pulumi.set(__self__, "receive_max_input_size", receive_max_input_size)
        if receptive_cluster_agents_enabled is not None:
            pulumi.set(__self__, "receptive_cluster_agents_enabled", receptive_cluster_agents_enabled)
        if remember_me_enabled is not None:
            pulumi.set(__self__, "remember_me_enabled", remember_me_enabled)
        if repository_checks_enabled is not None:
            pulumi.set(__self__, "repository_checks_enabled", repository_checks_enabled)
        if repository_size_limit is not None:
            pulumi.set(__self__, "repository_size_limit", repository_size_limit)
        if repository_storages_weighted is not None:
            pulumi.set(__self__, "repository_storages_weighted", repository_storages_weighted)
        if require_admin_approval_after_user_signup is not None:
            pulumi.set(__self__, "require_admin_approval_after_user_signup", require_admin_approval_after_user_signup)
        if require_admin_two_factor_authentication is not None:
            pulumi.set(__self__, "require_admin_two_factor_authentication", require_admin_two_factor_authentication)
        if require_personal_access_token_expiry is not None:
            pulumi.set(__self__, "require_personal_access_token_expiry", require_personal_access_token_expiry)
        if require_two_factor_authentication is not None:
            pulumi.set(__self__, "require_two_factor_authentication", require_two_factor_authentication)
        if restricted_visibility_levels is not None:
            pulumi.set(__self__, "restricted_visibility_levels", restricted_visibility_levels)
        if rsa_key_restriction is not None:
            pulumi.set(__self__, "rsa_key_restriction", rsa_key_restriction)
        if search_rate_limit is not None:
            pulumi.set(__self__, "search_rate_limit", search_rate_limit)
        if search_rate_limit_unauthenticated is not None:
            pulumi.set(__self__, "search_rate_limit_unauthenticated", search_rate_limit_unauthenticated)
        if security_approval_policies_limit is not None:
            pulumi.set(__self__, "security_approval_policies_limit", security_approval_policies_limit)
        if security_policy_global_group_approvers_enabled is not None:
            pulumi.set(__self__, "security_policy_global_group_approvers_enabled", security_policy_global_group_approvers_enabled)
        if security_txt_content is not None:
            pulumi.set(__self__, "security_txt_content", security_txt_content)
        if send_user_confirmation_email is not None:
            pulumi.set(__self__, "send_user_confirmation_email", send_user_confirmation_email)
        if service_access_tokens_expiration_enforced is not None:
            pulumi.set(__self__, "service_access_tokens_expiration_enforced", service_access_tokens_expiration_enforced)
        if session_expire_delay is not None:
            pulumi.set(__self__, "session_expire_delay", session_expire_delay)
        if shared_runners_enabled is not None:
            pulumi.set(__self__, "shared_runners_enabled", shared_runners_enabled)
        if shared_runners_minutes is not None:
            pulumi.set(__self__, "shared_runners_minutes", shared_runners_minutes)
        if shared_runners_text is not None:
            pulumi.set(__self__, "shared_runners_text", shared_runners_text)
        if sidekiq_job_limiter_compression_threshold_bytes is not None:
            pulumi.set(__self__, "sidekiq_job_limiter_compression_threshold_bytes", sidekiq_job_limiter_compression_threshold_bytes)
        if sidekiq_job_limiter_limit_bytes is not None:
            pulumi.set(__self__, "sidekiq_job_limiter_limit_bytes", sidekiq_job_limiter_limit_bytes)
        if sidekiq_job_limiter_mode is not None:
            pulumi.set(__self__, "sidekiq_job_limiter_mode", sidekiq_job_limiter_mode)
        if sign_in_text is not None:
            pulumi.set(__self__, "sign_in_text", sign_in_text)
        if signup_enabled is not None:
            pulumi.set(__self__, "signup_enabled", signup_enabled)
        if silent_admin_exports_enabled is not None:
            pulumi.set(__self__, "silent_admin_exports_enabled", silent_admin_exports_enabled)
        if silent_mode_enabled is not None:
            pulumi.set(__self__, "silent_mode_enabled", silent_mode_enabled)
        if slack_app_enabled is not None:
            pulumi.set(__self__, "slack_app_enabled", slack_app_enabled)
        if slack_app_id is not None:
            pulumi.set(__self__, "slack_app_id", slack_app_id)
        if slack_app_secret is not None:
            pulumi.set(__self__, "slack_app_secret", slack_app_secret)
        if slack_app_signing_secret is not None:
            pulumi.set(__self__, "slack_app_signing_secret", slack_app_signing_secret)
        if slack_app_verification_token is not None:
            pulumi.set(__self__, "slack_app_verification_token", slack_app_verification_token)
        if snippet_size_limit is not None:
            pulumi.set(__self__, "snippet_size_limit", snippet_size_limit)
        if snowplow_app_id is not None:
            pulumi.set(__self__, "snowplow_app_id", snowplow_app_id)
        if snowplow_collector_hostname is not None:
            pulumi.set(__self__, "snowplow_collector_hostname", snowplow_collector_hostname)
        if snowplow_cookie_domain is not None:
            pulumi.set(__self__, "snowplow_cookie_domain", snowplow_cookie_domain)
        if snowplow_database_collector_hostname is not None:
            pulumi.set(__self__, "snowplow_database_collector_hostname", snowplow_database_collector_hostname)
        if snowplow_enabled is not None:
            pulumi.set(__self__, "snowplow_enabled", snowplow_enabled)
        if sourcegraph_enabled is not None:
            pulumi.set(__self__, "sourcegraph_enabled", sourcegraph_enabled)
        if sourcegraph_public_only is not None:
            pulumi.set(__self__, "sourcegraph_public_only", sourcegraph_public_only)
        if sourcegraph_url is not None:
            pulumi.set(__self__, "sourcegraph_url", sourcegraph_url)
        if spam_check_api_key is not None:
            pulumi.set(__self__, "spam_check_api_key", spam_check_api_key)
        if spam_check_endpoint_enabled is not None:
            pulumi.set(__self__, "spam_check_endpoint_enabled", spam_check_endpoint_enabled)
        if spam_check_endpoint_url is not None:
            pulumi.set(__self__, "spam_check_endpoint_url", spam_check_endpoint_url)
        if static_objects_external_storage_auth_token is not None:
            pulumi.set(__self__, "static_objects_external_storage_auth_token", static_objects_external_storage_auth_token)
        if static_objects_external_storage_url is not None:
            pulumi.set(__self__, "static_objects_external_storage_url", static_objects_external_storage_url)
        if suggest_pipeline_enabled is not None:
            pulumi.set(__self__, "suggest_pipeline_enabled", suggest_pipeline_enabled)
        if terminal_max_session_time is not None:
            pulumi.set(__self__, "terminal_max_session_time", terminal_max_session_time)
        if terms is not None:
            pulumi.set(__self__, "terms", terms)
        if throttle_authenticated_api_enabled is not None:
            pulumi.set(__self__, "throttle_authenticated_api_enabled", throttle_authenticated_api_enabled)
        if throttle_authenticated_api_period_in_seconds is not None:
            pulumi.set(__self__, "throttle_authenticated_api_period_in_seconds", throttle_authenticated_api_period_in_seconds)
        if throttle_authenticated_api_requests_per_period is not None:
            pulumi.set(__self__, "throttle_authenticated_api_requests_per_period", throttle_authenticated_api_requests_per_period)
        if throttle_authenticated_packages_api_enabled is not None:
            pulumi.set(__self__, "throttle_authenticated_packages_api_enabled", throttle_authenticated_packages_api_enabled)
        if throttle_authenticated_packages_api_period_in_seconds is not None:
            pulumi.set(__self__, "throttle_authenticated_packages_api_period_in_seconds", throttle_authenticated_packages_api_period_in_seconds)
        if throttle_authenticated_packages_api_requests_per_period is not None:
            pulumi.set(__self__, "throttle_authenticated_packages_api_requests_per_period", throttle_authenticated_packages_api_requests_per_period)
        if throttle_authenticated_web_enabled is not None:
            pulumi.set(__self__, "throttle_authenticated_web_enabled", throttle_authenticated_web_enabled)
        if throttle_authenticated_web_period_in_seconds is not None:
            pulumi.set(__self__, "throttle_authenticated_web_period_in_seconds", throttle_authenticated_web_period_in_seconds)
        if throttle_authenticated_web_requests_per_period is not None:
            pulumi.set(__self__, "throttle_authenticated_web_requests_per_period", throttle_authenticated_web_requests_per_period)
        if throttle_unauthenticated_api_enabled is not None:
            pulumi.set(__self__, "throttle_unauthenticated_api_enabled", throttle_unauthenticated_api_enabled)
        if throttle_unauthenticated_api_period_in_seconds is not None:
            pulumi.set(__self__, "throttle_unauthenticated_api_period_in_seconds", throttle_unauthenticated_api_period_in_seconds)
        if throttle_unauthenticated_api_requests_per_period is not None:
            pulumi.set(__self__, "throttle_unauthenticated_api_requests_per_period", throttle_unauthenticated_api_requests_per_period)
        if throttle_unauthenticated_packages_api_enabled is not None:
            pulumi.set(__self__, "throttle_unauthenticated_packages_api_enabled", throttle_unauthenticated_packages_api_enabled)
        if throttle_unauthenticated_packages_api_period_in_seconds is not None:
            pulumi.set(__self__, "throttle_unauthenticated_packages_api_period_in_seconds", throttle_unauthenticated_packages_api_period_in_seconds)
        if throttle_unauthenticated_packages_api_requests_per_period is not None:
            pulumi.set(__self__, "throttle_unauthenticated_packages_api_requests_per_period", throttle_unauthenticated_packages_api_requests_per_period)
        if throttle_unauthenticated_web_enabled is not None:
            pulumi.set(__self__, "throttle_unauthenticated_web_enabled", throttle_unauthenticated_web_enabled)
        if throttle_unauthenticated_web_period_in_seconds is not None:
            pulumi.set(__self__, "throttle_unauthenticated_web_period_in_seconds", throttle_unauthenticated_web_period_in_seconds)
        if throttle_unauthenticated_web_requests_per_period is not None:
            pulumi.set(__self__, "throttle_unauthenticated_web_requests_per_period", throttle_unauthenticated_web_requests_per_period)
        if time_tracking_limit_to_hours is not None:
            pulumi.set(__self__, "time_tracking_limit_to_hours", time_tracking_limit_to_hours)
        if two_factor_grace_period is not None:
            pulumi.set(__self__, "two_factor_grace_period", two_factor_grace_period)
        if unconfirmed_users_delete_after_days is not None:
            pulumi.set(__self__, "unconfirmed_users_delete_after_days", unconfirmed_users_delete_after_days)
        if unique_ips_limit_enabled is not None:
            pulumi.set(__self__, "unique_ips_limit_enabled", unique_ips_limit_enabled)
        if unique_ips_limit_per_user is not None:
            pulumi.set(__self__, "unique_ips_limit_per_user", unique_ips_limit_per_user)
        if unique_ips_limit_time_window is not None:
            pulumi.set(__self__, "unique_ips_limit_time_window", unique_ips_limit_time_window)
        if update_runner_versions_enabled is not None:
            pulumi.set(__self__, "update_runner_versions_enabled", update_runner_versions_enabled)
        if usage_ping_enabled is not None:
            pulumi.set(__self__, "usage_ping_enabled", usage_ping_enabled)
        if use_clickhouse_for_analytics is not None:
            pulumi.set(__self__, "use_clickhouse_for_analytics", use_clickhouse_for_analytics)
        if user_deactivation_emails_enabled is not None:
            pulumi.set(__self__, "user_deactivation_emails_enabled", user_deactivation_emails_enabled)
        if user_default_external is not None:
            pulumi.set(__self__, "user_default_external", user_default_external)
        if user_default_internal_regex is not None:
            pulumi.set(__self__, "user_default_internal_regex", user_default_internal_regex)
        if user_defaults_to_private_profile is not None:
            pulumi.set(__self__, "user_defaults_to_private_profile", user_defaults_to_private_profile)
        if user_oauth_applications is not None:
            pulumi.set(__self__, "user_oauth_applications", user_oauth_applications)
        if user_show_add_ssh_key_message is not None:
            pulumi.set(__self__, "user_show_add_ssh_key_message", user_show_add_ssh_key_message)
        if valid_runner_registrars is not None:
            pulumi.set(__self__, "valid_runner_registrars", valid_runner_registrars)
        if version_check_enabled is not None:
            pulumi.set(__self__, "version_check_enabled", version_check_enabled)
        if web_ide_clientside_preview_enabled is not None:
            pulumi.set(__self__, "web_ide_clientside_preview_enabled", web_ide_clientside_preview_enabled)
        if whats_new_variant is not None:
            pulumi.set(__self__, "whats_new_variant", whats_new_variant)
        if wiki_page_max_content_bytes is not None:
            pulumi.set(__self__, "wiki_page_max_content_bytes", wiki_page_max_content_bytes)

    @_builtins.property
    @pulumi.getter(name="abuseNotificationEmail")
    def abuse_notification_email(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        If set, abuse reports are sent to this address. Abuse reports are always available in the Admin Area.
        """
        return pulumi.get(self, "abuse_notification_email")

    @abuse_notification_email.setter
    def abuse_notification_email(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "abuse_notification_email", value)

    @_builtins.property
    @pulumi.getter(name="adminMode")
    def admin_mode(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Require administrators to enable Admin Mode by re-authenticating for administrative tasks.
        """
        return pulumi.get(self, "admin_mode")

    @admin_mode.setter
    def admin_mode(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "admin_mode", value)

    @_builtins.property
    @pulumi.getter(name="afterSignOutPath")
    def after_sign_out_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Where to redirect users after logout.
        """
        return pulumi.get(self, "after_sign_out_path")

    @after_sign_out_path.setter
    def after_sign_out_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "after_sign_out_path", value)

    @_builtins.property
    @pulumi.getter(name="afterSignUpText")
    def after_sign_up_text(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Text shown to the user after signing up.
        """
        return pulumi.get(self, "after_sign_up_text")

    @after_sign_up_text.setter
    def after_sign_up_text(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "after_sign_up_text", value)

    @_builtins.property
    @pulumi.getter(name="akismetApiKey")
    def akismet_api_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        API key for Akismet spam protection.
        """
        return pulumi.get(self, "akismet_api_key")

    @akismet_api_key.setter
    def akismet_api_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "akismet_api_key", value)

    @_builtins.property
    @pulumi.getter(name="akismetEnabled")
    def akismet_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: akismet*api*key) Enable or disable Akismet spam protection.
        """
        return pulumi.get(self, "akismet_enabled")

    @akismet_enabled.setter
    def akismet_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "akismet_enabled", value)

    @_builtins.property
    @pulumi.getter(name="allowAccountDeletion")
    def allow_account_deletion(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to true to allow users to delete their accounts. Premium and Ultimate only.
        """
        return pulumi.get(self, "allow_account_deletion")

    @allow_account_deletion.setter
    def allow_account_deletion(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_account_deletion", value)

    @_builtins.property
    @pulumi.getter(name="allowGroupOwnersToManageLdap")
    def allow_group_owners_to_manage_ldap(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to true to allow group owners to manage LDAP.
        """
        return pulumi.get(self, "allow_group_owners_to_manage_ldap")

    @allow_group_owners_to_manage_ldap.setter
    def allow_group_owners_to_manage_ldap(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_group_owners_to_manage_ldap", value)

    @_builtins.property
    @pulumi.getter(name="allowLocalRequestsFromSystemHooks")
    def allow_local_requests_from_system_hooks(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow requests to the local network from system hooks.
        """
        return pulumi.get(self, "allow_local_requests_from_system_hooks")

    @allow_local_requests_from_system_hooks.setter
    def allow_local_requests_from_system_hooks(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_local_requests_from_system_hooks", value)

    @_builtins.property
    @pulumi.getter(name="allowLocalRequestsFromWebHooksAndServices")
    def allow_local_requests_from_web_hooks_and_services(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow requests to the local network from web hooks and services.
        """
        return pulumi.get(self, "allow_local_requests_from_web_hooks_and_services")

    @allow_local_requests_from_web_hooks_and_services.setter
    def allow_local_requests_from_web_hooks_and_services(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_local_requests_from_web_hooks_and_services", value)

    @_builtins.property
    @pulumi.getter(name="allowProjectCreationForGuestAndBelow")
    def allow_project_creation_for_guest_and_below(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether users assigned up to the Guest role can create groups and personal projects.
        """
        return pulumi.get(self, "allow_project_creation_for_guest_and_below")

    @allow_project_creation_for_guest_and_below.setter
    def allow_project_creation_for_guest_and_below(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_project_creation_for_guest_and_below", value)

    @_builtins.property
    @pulumi.getter(name="allowRunnerRegistrationToken")
    def allow_runner_registration_token(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow using a registration token to create a runner.
        """
        return pulumi.get(self, "allow_runner_registration_token")

    @allow_runner_registration_token.setter
    def allow_runner_registration_token(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_runner_registration_token", value)

    @_builtins.property
    @pulumi.getter(name="archiveBuildsInHumanReadable")
    def archive_builds_in_human_readable(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Set the duration for which the jobs are considered as old and expired. After that time passes, the jobs are archived and no longer able to be retried. Make it empty to never expire jobs. It has to be no less than 1 day, for example: 15 days, 1 month, 2 years.
        """
        return pulumi.get(self, "archive_builds_in_human_readable")

    @archive_builds_in_human_readable.setter
    def archive_builds_in_human_readable(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "archive_builds_in_human_readable", value)

    @_builtins.property
    @pulumi.getter(name="asciidocMaxIncludes")
    def asciidoc_max_includes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum limit of AsciiDoc include directives being processed in any one document. Maximum: 64.
        """
        return pulumi.get(self, "asciidoc_max_includes")

    @asciidoc_max_includes.setter
    def asciidoc_max_includes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "asciidoc_max_includes", value)

    @_builtins.property
    @pulumi.getter(name="assetProxyAllowlists")
    def asset_proxy_allowlists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Assets that match these domains are not proxied. Wildcards allowed. Your GitLab installation URL is automatically allowlisted. GitLab restart is required to apply changes.
        """
        return pulumi.get(self, "asset_proxy_allowlists")

    @asset_proxy_allowlists.setter
    def asset_proxy_allowlists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "asset_proxy_allowlists", value)

    @_builtins.property
    @pulumi.getter(name="assetProxyEnabled")
    def asset_proxy_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: asset*proxy*url) Enable proxying of assets. GitLab restart is required to apply changes.
        """
        return pulumi.get(self, "asset_proxy_enabled")

    @asset_proxy_enabled.setter
    def asset_proxy_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "asset_proxy_enabled", value)

    @_builtins.property
    @pulumi.getter(name="assetProxySecretKey")
    def asset_proxy_secret_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Shared secret with the asset proxy server. GitLab restart is required to apply changes.
        """
        return pulumi.get(self, "asset_proxy_secret_key")

    @asset_proxy_secret_key.setter
    def asset_proxy_secret_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "asset_proxy_secret_key", value)

    @_builtins.property
    @pulumi.getter(name="assetProxyUrl")
    def asset_proxy_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        URL of the asset proxy server. GitLab restart is required to apply changes.
        """
        return pulumi.get(self, "asset_proxy_url")

    @asset_proxy_url.setter
    def asset_proxy_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "asset_proxy_url", value)

    @_builtins.property
    @pulumi.getter(name="authorizedKeysEnabled")
    def authorized_keys_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        By default, we write to the authorized_keys file to support Git over SSH without additional configuration. GitLab can be optimized to authenticate SSH keys via the database file. Only disable this if you have configured your OpenSSH server to use the AuthorizedKeysCommand.
        """
        return pulumi.get(self, "authorized_keys_enabled")

    @authorized_keys_enabled.setter
    def authorized_keys_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "authorized_keys_enabled", value)

    @_builtins.property
    @pulumi.getter(name="autoBanUserOnExcessiveProjectsDownload")
    def auto_ban_user_on_excessive_projects_download(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When enabled, users will get automatically banned from the application when they download more than the maximum number of unique projects in the time period specified by max*number*of*repository*downloads and max*number*of*repository*downloads*within*time_period respectively. Self-managed, Ultimate only.
        """
        return pulumi.get(self, "auto_ban_user_on_excessive_projects_download")

    @auto_ban_user_on_excessive_projects_download.setter
    def auto_ban_user_on_excessive_projects_download(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "auto_ban_user_on_excessive_projects_download", value)

    @_builtins.property
    @pulumi.getter(name="autoDevopsDomain")
    def auto_devops_domain(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specify a domain to use by default for every project’s Auto Review Apps and Auto Deploy stages.
        """
        return pulumi.get(self, "auto_devops_domain")

    @auto_devops_domain.setter
    def auto_devops_domain(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "auto_devops_domain", value)

    @_builtins.property
    @pulumi.getter(name="autoDevopsEnabled")
    def auto_devops_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable Auto DevOps for projects by default. It automatically builds, tests, and deploys applications based on a predefined CI/CD configuration.
        """
        return pulumi.get(self, "auto_devops_enabled")

    @auto_devops_enabled.setter
    def auto_devops_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "auto_devops_enabled", value)

    @_builtins.property
    @pulumi.getter(name="automaticPurchasedStorageAllocation")
    def automatic_purchased_storage_allocation(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enabling this permits automatic allocation of purchased storage in a namespace.
        """
        return pulumi.get(self, "automatic_purchased_storage_allocation")

    @automatic_purchased_storage_allocation.setter
    def automatic_purchased_storage_allocation(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "automatic_purchased_storage_allocation", value)

    @_builtins.property
    @pulumi.getter(name="bulkImportConcurrentPipelineBatchLimit")
    def bulk_import_concurrent_pipeline_batch_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum simultaneous Direct Transfer batches to process.
        """
        return pulumi.get(self, "bulk_import_concurrent_pipeline_batch_limit")

    @bulk_import_concurrent_pipeline_batch_limit.setter
    def bulk_import_concurrent_pipeline_batch_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "bulk_import_concurrent_pipeline_batch_limit", value)

    @_builtins.property
    @pulumi.getter(name="bulkImportEnabled")
    def bulk_import_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable migrating GitLab groups by direct transfer.
        """
        return pulumi.get(self, "bulk_import_enabled")

    @bulk_import_enabled.setter
    def bulk_import_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "bulk_import_enabled", value)

    @_builtins.property
    @pulumi.getter(name="bulkImportMaxDownloadFileSize")
    def bulk_import_max_download_file_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum download file size when importing from source GitLab instances by direct transfer.
        """
        return pulumi.get(self, "bulk_import_max_download_file_size")

    @bulk_import_max_download_file_size.setter
    def bulk_import_max_download_file_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "bulk_import_max_download_file_size", value)

    @_builtins.property
    @pulumi.getter(name="canCreateGroup")
    def can_create_group(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether users can create top-level groups.
        """
        return pulumi.get(self, "can_create_group")

    @can_create_group.setter
    def can_create_group(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "can_create_group", value)

    @_builtins.property
    @pulumi.getter(name="checkNamespacePlan")
    def check_namespace_plan(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enabling this makes only licensed EE features available to projects if the project namespace’s plan includes the feature or if the project is public.
        """
        return pulumi.get(self, "check_namespace_plan")

    @check_namespace_plan.setter
    def check_namespace_plan(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "check_namespace_plan", value)

    @_builtins.property
    @pulumi.getter(name="ciMaxIncludes")
    def ci_max_includes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum number of includes per pipeline.
        """
        return pulumi.get(self, "ci_max_includes")

    @ci_max_includes.setter
    def ci_max_includes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "ci_max_includes", value)

    @_builtins.property
    @pulumi.getter(name="ciMaxTotalYamlSizeBytes")
    def ci_max_total_yaml_size_bytes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum amount of memory, in bytes, that can be allocated for the pipeline configuration, with all included YAML configuration files.
        """
        return pulumi.get(self, "ci_max_total_yaml_size_bytes")

    @ci_max_total_yaml_size_bytes.setter
    def ci_max_total_yaml_size_bytes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "ci_max_total_yaml_size_bytes", value)

    @_builtins.property
    @pulumi.getter(name="commitEmailHostname")
    def commit_email_hostname(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Custom hostname (for private commit emails).
        """
        return pulumi.get(self, "commit_email_hostname")

    @commit_email_hostname.setter
    def commit_email_hostname(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "commit_email_hostname", value)

    @_builtins.property
    @pulumi.getter(name="concurrentBitbucketImportJobsLimit")
    def concurrent_bitbucket_import_jobs_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum number of simultaneous import jobs for the Bitbucket Cloud importer.
        """
        return pulumi.get(self, "concurrent_bitbucket_import_jobs_limit")

    @concurrent_bitbucket_import_jobs_limit.setter
    def concurrent_bitbucket_import_jobs_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "concurrent_bitbucket_import_jobs_limit", value)

    @_builtins.property
    @pulumi.getter(name="concurrentBitbucketServerImportJobsLimit")
    def concurrent_bitbucket_server_import_jobs_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum number of simultaneous import jobs for the Bitbucket Server importer.
        """
        return pulumi.get(self, "concurrent_bitbucket_server_import_jobs_limit")

    @concurrent_bitbucket_server_import_jobs_limit.setter
    def concurrent_bitbucket_server_import_jobs_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "concurrent_bitbucket_server_import_jobs_limit", value)

    @_builtins.property
    @pulumi.getter(name="concurrentGithubImportJobsLimit")
    def concurrent_github_import_jobs_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum number of simultaneous import jobs for the GitHub importer.
        """
        return pulumi.get(self, "concurrent_github_import_jobs_limit")

    @concurrent_github_import_jobs_limit.setter
    def concurrent_github_import_jobs_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "concurrent_github_import_jobs_limit", value)

    @_builtins.property
    @pulumi.getter(name="containerExpirationPoliciesEnableHistoricEntries")
    def container_expiration_policies_enable_historic_entries(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable cleanup policies for all projects.
        """
        return pulumi.get(self, "container_expiration_policies_enable_historic_entries")

    @container_expiration_policies_enable_historic_entries.setter
    def container_expiration_policies_enable_historic_entries(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "container_expiration_policies_enable_historic_entries", value)

    @_builtins.property
    @pulumi.getter(name="containerRegistryCleanupTagsServiceMaxListSize")
    def container_registry_cleanup_tags_service_max_list_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum number of tags that can be deleted in a single execution of cleanup policies.
        """
        return pulumi.get(self, "container_registry_cleanup_tags_service_max_list_size")

    @container_registry_cleanup_tags_service_max_list_size.setter
    def container_registry_cleanup_tags_service_max_list_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "container_registry_cleanup_tags_service_max_list_size", value)

    @_builtins.property
    @pulumi.getter(name="containerRegistryDeleteTagsServiceTimeout")
    def container_registry_delete_tags_service_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum time, in seconds, that the cleanup process can take to delete a batch of tags for cleanup policies.
        """
        return pulumi.get(self, "container_registry_delete_tags_service_timeout")

    @container_registry_delete_tags_service_timeout.setter
    def container_registry_delete_tags_service_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "container_registry_delete_tags_service_timeout", value)

    @_builtins.property
    @pulumi.getter(name="containerRegistryExpirationPoliciesCaching")
    def container_registry_expiration_policies_caching(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Caching during the execution of cleanup policies.
        """
        return pulumi.get(self, "container_registry_expiration_policies_caching")

    @container_registry_expiration_policies_caching.setter
    def container_registry_expiration_policies_caching(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "container_registry_expiration_policies_caching", value)

    @_builtins.property
    @pulumi.getter(name="containerRegistryExpirationPoliciesWorkerCapacity")
    def container_registry_expiration_policies_worker_capacity(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Number of workers for cleanup policies.
        """
        return pulumi.get(self, "container_registry_expiration_policies_worker_capacity")

    @container_registry_expiration_policies_worker_capacity.setter
    def container_registry_expiration_policies_worker_capacity(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "container_registry_expiration_policies_worker_capacity", value)

    @_builtins.property
    @pulumi.getter(name="containerRegistryTokenExpireDelay")
    def container_registry_token_expire_delay(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Container Registry token duration in minutes.
        """
        return pulumi.get(self, "container_registry_token_expire_delay")

    @container_registry_token_expire_delay.setter
    def container_registry_token_expire_delay(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "container_registry_token_expire_delay", value)

    @_builtins.property
    @pulumi.getter(name="deactivateDormantUsers")
    def deactivate_dormant_users(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable automatic deactivation of dormant users.
        """
        return pulumi.get(self, "deactivate_dormant_users")

    @deactivate_dormant_users.setter
    def deactivate_dormant_users(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "deactivate_dormant_users", value)

    @_builtins.property
    @pulumi.getter(name="deactivateDormantUsersPeriod")
    def deactivate_dormant_users_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Length of time (in days) after which a user is considered dormant.
        """
        return pulumi.get(self, "deactivate_dormant_users_period")

    @deactivate_dormant_users_period.setter
    def deactivate_dormant_users_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "deactivate_dormant_users_period", value)

    @_builtins.property
    @pulumi.getter(name="decompressArchiveFileTimeout")
    def decompress_archive_file_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Default timeout for decompressing archived files, in seconds. Set to 0 to disable timeouts.
        """
        return pulumi.get(self, "decompress_archive_file_timeout")

    @decompress_archive_file_timeout.setter
    def decompress_archive_file_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "decompress_archive_file_timeout", value)

    @_builtins.property
    @pulumi.getter(name="defaultArtifactsExpireIn")
    def default_artifacts_expire_in(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Set the default expiration time for each job’s artifacts.
        """
        return pulumi.get(self, "default_artifacts_expire_in")

    @default_artifacts_expire_in.setter
    def default_artifacts_expire_in(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_artifacts_expire_in", value)

    @_builtins.property
    @pulumi.getter(name="defaultBranchName")
    def default_branch_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Instance-level custom initial branch name
        """
        return pulumi.get(self, "default_branch_name")

    @default_branch_name.setter
    def default_branch_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_branch_name", value)

    @_builtins.property
    @pulumi.getter(name="defaultBranchProtection")
    @_utilities.deprecated("""Use `default_branch_protection_defaults` instead. To be removed in 19.0.""")
    def default_branch_protection(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Determine if developers can push to the default branch. Can take: 0 (not protected, both users with the Developer role or Maintainer role can push new commits and force push), 1 (partially protected, users with the Developer role or Maintainer role can push new commits, but cannot force push) or 2 (fully protected, users with the Developer or Maintainer role cannot push new commits, but users with the Developer or Maintainer role can; no one can force push) as a parameter. Default is 2. Use `default_branch_protection_defaults` instead. To be removed in 19.0.
        """
        return pulumi.get(self, "default_branch_protection")

    @default_branch_protection.setter
    def default_branch_protection(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "default_branch_protection", value)

    @_builtins.property
    @pulumi.getter(name="defaultBranchProtectionDefaults")
    def default_branch_protection_defaults(self) -> Optional[pulumi.Input['ApplicationSettingsDefaultBranchProtectionDefaultsArgs']]:
        """
        The default*branch*protection*defaults attribute describes the default branch protection defaults. All parameters are optional.
        """
        return pulumi.get(self, "default_branch_protection_defaults")

    @default_branch_protection_defaults.setter
    def default_branch_protection_defaults(self, value: Optional[pulumi.Input['ApplicationSettingsDefaultBranchProtectionDefaultsArgs']]):
        pulumi.set(self, "default_branch_protection_defaults", value)

    @_builtins.property
    @pulumi.getter(name="defaultCiConfigPath")
    def default_ci_config_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Default CI/CD configuration file and path for new projects (.gitlab-ci.yml if not set).
        """
        return pulumi.get(self, "default_ci_config_path")

    @default_ci_config_path.setter
    def default_ci_config_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_ci_config_path", value)

    @_builtins.property
    @pulumi.getter(name="defaultGroupVisibility")
    def default_group_visibility(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        What visibility level new groups receive. Can take private, internal and public as a parameter.
        """
        return pulumi.get(self, "default_group_visibility")

    @default_group_visibility.setter
    def default_group_visibility(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_group_visibility", value)

    @_builtins.property
    @pulumi.getter(name="defaultPreferredLanguage")
    def default_preferred_language(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Default preferred language for users who are not logged in.
        """
        return pulumi.get(self, "default_preferred_language")

    @default_preferred_language.setter
    def default_preferred_language(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_preferred_language", value)

    @_builtins.property
    @pulumi.getter(name="defaultProjectCreation")
    def default_project_creation(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Default project creation protection. Can take: 0 (No one), 1 (Maintainers) or 2 (Developers + Maintainers).
        """
        return pulumi.get(self, "default_project_creation")

    @default_project_creation.setter
    def default_project_creation(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "default_project_creation", value)

    @_builtins.property
    @pulumi.getter(name="defaultProjectVisibility")
    def default_project_visibility(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        What visibility level new projects receive. Can take private, internal and public as a parameter.
        """
        return pulumi.get(self, "default_project_visibility")

    @default_project_visibility.setter
    def default_project_visibility(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_project_visibility", value)

    @_builtins.property
    @pulumi.getter(name="defaultProjectsLimit")
    def default_projects_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Project limit per user.
        """
        return pulumi.get(self, "default_projects_limit")

    @default_projects_limit.setter
    def default_projects_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "default_projects_limit", value)

    @_builtins.property
    @pulumi.getter(name="defaultSnippetVisibility")
    def default_snippet_visibility(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        What visibility level new snippets receive. Can take private, internal and public as a parameter.
        """
        return pulumi.get(self, "default_snippet_visibility")

    @default_snippet_visibility.setter
    def default_snippet_visibility(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_snippet_visibility", value)

    @_builtins.property
    @pulumi.getter(name="defaultSyntaxHighlightingTheme")
    def default_syntax_highlighting_theme(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Default syntax highlighting theme for users who are new or not signed in. See IDs of available themes (https://gitlab.com/gitlab-org/gitlab/blob/master/lib/gitlab/themes.rb#L16)
        """
        return pulumi.get(self, "default_syntax_highlighting_theme")

    @default_syntax_highlighting_theme.setter
    def default_syntax_highlighting_theme(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "default_syntax_highlighting_theme", value)

    @_builtins.property
    @pulumi.getter(name="deleteInactiveProjects")
    def delete_inactive_projects(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable inactive project deletion feature.
        """
        return pulumi.get(self, "delete_inactive_projects")

    @delete_inactive_projects.setter
    def delete_inactive_projects(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "delete_inactive_projects", value)

    @_builtins.property
    @pulumi.getter(name="deleteUnconfirmedUsers")
    def delete_unconfirmed_users(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Specifies whether users who have not confirmed their email should be deleted. When set to true, unconfirmed users are deleted after unconfirmed*users*delete*after*days days. Self-managed, Premium and Ultimate only.
        """
        return pulumi.get(self, "delete_unconfirmed_users")

    @delete_unconfirmed_users.setter
    def delete_unconfirmed_users(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "delete_unconfirmed_users", value)

    @_builtins.property
    @pulumi.getter(name="deletionAdjournedPeriod")
    def deletion_adjourned_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of days to wait before deleting a project or group that is marked for deletion. Value must be between 1 and 90.
        """
        return pulumi.get(self, "deletion_adjourned_period")

    @deletion_adjourned_period.setter
    def deletion_adjourned_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "deletion_adjourned_period", value)

    @_builtins.property
    @pulumi.getter(name="diagramsnetEnabled")
    def diagramsnet_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires diagramsnet_url) Enable Diagrams.net integration.
        """
        return pulumi.get(self, "diagramsnet_enabled")

    @diagramsnet_enabled.setter
    def diagramsnet_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "diagramsnet_enabled", value)

    @_builtins.property
    @pulumi.getter(name="diagramsnetUrl")
    def diagramsnet_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Diagrams.net instance URL for integration.
        """
        return pulumi.get(self, "diagramsnet_url")

    @diagramsnet_url.setter
    def diagramsnet_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "diagramsnet_url", value)

    @_builtins.property
    @pulumi.getter(name="diffMaxFiles")
    def diff_max_files(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum files in a diff.
        """
        return pulumi.get(self, "diff_max_files")

    @diff_max_files.setter
    def diff_max_files(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "diff_max_files", value)

    @_builtins.property
    @pulumi.getter(name="diffMaxLines")
    def diff_max_lines(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum lines in a diff.
        """
        return pulumi.get(self, "diff_max_lines")

    @diff_max_lines.setter
    def diff_max_lines(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "diff_max_lines", value)

    @_builtins.property
    @pulumi.getter(name="diffMaxPatchBytes")
    def diff_max_patch_bytes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum diff patch size, in bytes.
        """
        return pulumi.get(self, "diff_max_patch_bytes")

    @diff_max_patch_bytes.setter
    def diff_max_patch_bytes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "diff_max_patch_bytes", value)

    @_builtins.property
    @pulumi.getter(name="disableAdminOauthScopes")
    def disable_admin_oauth_scopes(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Stops administrators from connecting their GitLab accounts to non-trusted OAuth 2.0 applications that have the api, read*api, read*repository, write*repository, read*registry, write_registry, or sudo scopes.
        """
        return pulumi.get(self, "disable_admin_oauth_scopes")

    @disable_admin_oauth_scopes.setter
    def disable_admin_oauth_scopes(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disable_admin_oauth_scopes", value)

    @_builtins.property
    @pulumi.getter(name="disableFeedToken")
    def disable_feed_token(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Disable display of RSS/Atom and calendar feed tokens.
        """
        return pulumi.get(self, "disable_feed_token")

    @disable_feed_token.setter
    def disable_feed_token(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disable_feed_token", value)

    @_builtins.property
    @pulumi.getter(name="disablePersonalAccessTokens")
    def disable_personal_access_tokens(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Disable personal access tokens. Self-managed, Premium and Ultimate only. There is no method available to enable a personal access token that’s been disabled through the API. This is a known issue.
        """
        return pulumi.get(self, "disable_personal_access_tokens")

    @disable_personal_access_tokens.setter
    def disable_personal_access_tokens(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disable_personal_access_tokens", value)

    @_builtins.property
    @pulumi.getter(name="disabledOauthSignInSources")
    def disabled_oauth_sign_in_sources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Disabled OAuth sign-in sources.
        """
        return pulumi.get(self, "disabled_oauth_sign_in_sources")

    @disabled_oauth_sign_in_sources.setter
    def disabled_oauth_sign_in_sources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "disabled_oauth_sign_in_sources", value)

    @_builtins.property
    @pulumi.getter(name="dnsRebindingProtectionEnabled")
    def dns_rebinding_protection_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enforce DNS rebinding attack protection.
        """
        return pulumi.get(self, "dns_rebinding_protection_enabled")

    @dns_rebinding_protection_enabled.setter
    def dns_rebinding_protection_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "dns_rebinding_protection_enabled", value)

    @_builtins.property
    @pulumi.getter(name="domainAllowlists")
    def domain_allowlists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Force people to use only corporate emails for sign-up. Null means there is no restriction.
        """
        return pulumi.get(self, "domain_allowlists")

    @domain_allowlists.setter
    def domain_allowlists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "domain_allowlists", value)

    @_builtins.property
    @pulumi.getter(name="domainDenylistEnabled")
    def domain_denylist_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: domain_denylist) Allows blocking sign-ups from emails from specific domains.
        """
        return pulumi.get(self, "domain_denylist_enabled")

    @domain_denylist_enabled.setter
    def domain_denylist_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "domain_denylist_enabled", value)

    @_builtins.property
    @pulumi.getter(name="domainDenylists")
    def domain_denylists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Users with email addresses that match these domains cannot sign up. Wildcards allowed. Use separate lines for multiple entries. Ex: domain.com, *.domain.com.
        """
        return pulumi.get(self, "domain_denylists")

    @domain_denylists.setter
    def domain_denylists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "domain_denylists", value)

    @_builtins.property
    @pulumi.getter(name="downstreamPipelineTriggerLimitPerProjectUserSha")
    def downstream_pipeline_trigger_limit_per_project_user_sha(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum downstream pipeline trigger rate.
        """
        return pulumi.get(self, "downstream_pipeline_trigger_limit_per_project_user_sha")

    @downstream_pipeline_trigger_limit_per_project_user_sha.setter
    def downstream_pipeline_trigger_limit_per_project_user_sha(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "downstream_pipeline_trigger_limit_per_project_user_sha", value)

    @_builtins.property
    @pulumi.getter(name="dsaKeyRestriction")
    def dsa_key_restriction(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The minimum allowed bit length of an uploaded DSA key. 0 means no restriction. -1 disables DSA keys.
        """
        return pulumi.get(self, "dsa_key_restriction")

    @dsa_key_restriction.setter
    def dsa_key_restriction(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "dsa_key_restriction", value)

    @_builtins.property
    @pulumi.getter(name="duoFeaturesEnabled")
    def duo_features_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether GitLab Duo features are enabled for this instance. Self-managed, Premium and Ultimate only.
        """
        return pulumi.get(self, "duo_features_enabled")

    @duo_features_enabled.setter
    def duo_features_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "duo_features_enabled", value)

    @_builtins.property
    @pulumi.getter(name="ecdsaKeyRestriction")
    def ecdsa_key_restriction(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The minimum allowed curve size (in bits) of an uploaded ECDSA key. 0 means no restriction. -1 disables ECDSA keys.
        """
        return pulumi.get(self, "ecdsa_key_restriction")

    @ecdsa_key_restriction.setter
    def ecdsa_key_restriction(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "ecdsa_key_restriction", value)

    @_builtins.property
    @pulumi.getter(name="ecdsaSkKeyRestriction")
    def ecdsa_sk_key_restriction(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The minimum allowed curve size (in bits) of an uploaded ECDSA*SK key. 0 means no restriction. -1 disables ECDSA*SK keys.
        """
        return pulumi.get(self, "ecdsa_sk_key_restriction")

    @ecdsa_sk_key_restriction.setter
    def ecdsa_sk_key_restriction(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "ecdsa_sk_key_restriction", value)

    @_builtins.property
    @pulumi.getter(name="ed25519KeyRestriction")
    def ed25519_key_restriction(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The minimum allowed curve size (in bits) of an uploaded ED25519 key. 0 means no restriction. -1 disables ED25519 keys.
        """
        return pulumi.get(self, "ed25519_key_restriction")

    @ed25519_key_restriction.setter
    def ed25519_key_restriction(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "ed25519_key_restriction", value)

    @_builtins.property
    @pulumi.getter(name="ed25519SkKeyRestriction")
    def ed25519_sk_key_restriction(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The minimum allowed curve size (in bits) of an uploaded ED25519*SK key. 0 means no restriction. -1 disables ED25519*SK keys.
        """
        return pulumi.get(self, "ed25519_sk_key_restriction")

    @ed25519_sk_key_restriction.setter
    def ed25519_sk_key_restriction(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "ed25519_sk_key_restriction", value)

    @_builtins.property
    @pulumi.getter(name="eksAccessKeyId")
    def eks_access_key_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        AWS IAM access key ID.
        """
        return pulumi.get(self, "eks_access_key_id")

    @eks_access_key_id.setter
    def eks_access_key_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "eks_access_key_id", value)

    @_builtins.property
    @pulumi.getter(name="eksAccountId")
    def eks_account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Amazon account ID.
        """
        return pulumi.get(self, "eks_account_id")

    @eks_account_id.setter
    def eks_account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "eks_account_id", value)

    @_builtins.property
    @pulumi.getter(name="eksIntegrationEnabled")
    def eks_integration_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable integration with Amazon EKS.
        """
        return pulumi.get(self, "eks_integration_enabled")

    @eks_integration_enabled.setter
    def eks_integration_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "eks_integration_enabled", value)

    @_builtins.property
    @pulumi.getter(name="eksSecretAccessKey")
    def eks_secret_access_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        AWS IAM secret access key.
        """
        return pulumi.get(self, "eks_secret_access_key")

    @eks_secret_access_key.setter
    def eks_secret_access_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "eks_secret_access_key", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchAws")
    def elasticsearch_aws(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable the use of AWS hosted Elasticsearch.
        """
        return pulumi.get(self, "elasticsearch_aws")

    @elasticsearch_aws.setter
    def elasticsearch_aws(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "elasticsearch_aws", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchAwsAccessKey")
    def elasticsearch_aws_access_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        AWS IAM access key.
        """
        return pulumi.get(self, "elasticsearch_aws_access_key")

    @elasticsearch_aws_access_key.setter
    def elasticsearch_aws_access_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "elasticsearch_aws_access_key", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchAwsRegion")
    def elasticsearch_aws_region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The AWS region the Elasticsearch domain is configured.
        """
        return pulumi.get(self, "elasticsearch_aws_region")

    @elasticsearch_aws_region.setter
    def elasticsearch_aws_region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "elasticsearch_aws_region", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchAwsSecretAccessKey")
    def elasticsearch_aws_secret_access_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        AWS IAM secret access key.
        """
        return pulumi.get(self, "elasticsearch_aws_secret_access_key")

    @elasticsearch_aws_secret_access_key.setter
    def elasticsearch_aws_secret_access_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "elasticsearch_aws_secret_access_key", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchIndexedFieldLengthLimit")
    def elasticsearch_indexed_field_length_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum size of text fields to index by Elasticsearch. 0 value means no limit. This does not apply to repository and wiki indexing.
        """
        return pulumi.get(self, "elasticsearch_indexed_field_length_limit")

    @elasticsearch_indexed_field_length_limit.setter
    def elasticsearch_indexed_field_length_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "elasticsearch_indexed_field_length_limit", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchIndexedFileSizeLimitKb")
    def elasticsearch_indexed_file_size_limit_kb(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum size of repository and wiki files that are indexed by Elasticsearch.
        """
        return pulumi.get(self, "elasticsearch_indexed_file_size_limit_kb")

    @elasticsearch_indexed_file_size_limit_kb.setter
    def elasticsearch_indexed_file_size_limit_kb(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "elasticsearch_indexed_file_size_limit_kb", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchIndexing")
    def elasticsearch_indexing(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable Elasticsearch indexing.
        """
        return pulumi.get(self, "elasticsearch_indexing")

    @elasticsearch_indexing.setter
    def elasticsearch_indexing(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "elasticsearch_indexing", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchLimitIndexing")
    def elasticsearch_limit_indexing(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Limit Elasticsearch to index certain namespaces and projects.
        """
        return pulumi.get(self, "elasticsearch_limit_indexing")

    @elasticsearch_limit_indexing.setter
    def elasticsearch_limit_indexing(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "elasticsearch_limit_indexing", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchMaxBulkConcurrency")
    def elasticsearch_max_bulk_concurrency(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum concurrency of Elasticsearch bulk requests per indexing operation. This only applies to repository indexing operations.
        """
        return pulumi.get(self, "elasticsearch_max_bulk_concurrency")

    @elasticsearch_max_bulk_concurrency.setter
    def elasticsearch_max_bulk_concurrency(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "elasticsearch_max_bulk_concurrency", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchMaxBulkSizeMb")
    def elasticsearch_max_bulk_size_mb(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum size of Elasticsearch bulk indexing requests in MB. This only applies to repository indexing operations.
        """
        return pulumi.get(self, "elasticsearch_max_bulk_size_mb")

    @elasticsearch_max_bulk_size_mb.setter
    def elasticsearch_max_bulk_size_mb(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "elasticsearch_max_bulk_size_mb", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchMaxCodeIndexingConcurrency")
    def elasticsearch_max_code_indexing_concurrency(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum concurrency of Elasticsearch code indexing background jobs. This only applies to repository indexing operations. Premium and Ultimate only.
        """
        return pulumi.get(self, "elasticsearch_max_code_indexing_concurrency")

    @elasticsearch_max_code_indexing_concurrency.setter
    def elasticsearch_max_code_indexing_concurrency(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "elasticsearch_max_code_indexing_concurrency", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchNamespaceIds")
    def elasticsearch_namespace_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]:
        """
        The namespaces to index via Elasticsearch if elasticsearch*limit*indexing is enabled.
        """
        return pulumi.get(self, "elasticsearch_namespace_ids")

    @elasticsearch_namespace_ids.setter
    def elasticsearch_namespace_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]):
        pulumi.set(self, "elasticsearch_namespace_ids", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchPassword")
    def elasticsearch_password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The password of your Elasticsearch instance.
        """
        return pulumi.get(self, "elasticsearch_password")

    @elasticsearch_password.setter
    def elasticsearch_password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "elasticsearch_password", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchProjectIds")
    def elasticsearch_project_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]:
        """
        The projects to index via Elasticsearch if elasticsearch*limit*indexing is enabled.
        """
        return pulumi.get(self, "elasticsearch_project_ids")

    @elasticsearch_project_ids.setter
    def elasticsearch_project_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]):
        pulumi.set(self, "elasticsearch_project_ids", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchRequeueWorkers")
    def elasticsearch_requeue_workers(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable automatic requeuing of indexing workers. This improves non-code indexing throughput by enqueuing Sidekiq jobs until all documents are processed. Premium and Ultimate only.
        """
        return pulumi.get(self, "elasticsearch_requeue_workers")

    @elasticsearch_requeue_workers.setter
    def elasticsearch_requeue_workers(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "elasticsearch_requeue_workers", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchSearch")
    def elasticsearch_search(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable Elasticsearch search.
        """
        return pulumi.get(self, "elasticsearch_search")

    @elasticsearch_search.setter
    def elasticsearch_search(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "elasticsearch_search", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchUrls")
    def elasticsearch_urls(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The URL to use for connecting to Elasticsearch. Use a comma-separated list to support cluster (for example, http://localhost:9200, http://localhost:9201).
        """
        return pulumi.get(self, "elasticsearch_urls")

    @elasticsearch_urls.setter
    def elasticsearch_urls(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "elasticsearch_urls", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchUsername")
    def elasticsearch_username(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The username of your Elasticsearch instance.
        """
        return pulumi.get(self, "elasticsearch_username")

    @elasticsearch_username.setter
    def elasticsearch_username(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "elasticsearch_username", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchWorkerNumberOfShards")
    def elasticsearch_worker_number_of_shards(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Number of indexing worker shards. This improves non-code indexing throughput by enqueuing more parallel Sidekiq jobs. Premium and Ultimate only.
        """
        return pulumi.get(self, "elasticsearch_worker_number_of_shards")

    @elasticsearch_worker_number_of_shards.setter
    def elasticsearch_worker_number_of_shards(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "elasticsearch_worker_number_of_shards", value)

    @_builtins.property
    @pulumi.getter(name="emailAdditionalText")
    def email_additional_text(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Additional text added to the bottom of every email for legal/auditing/compliance reasons.
        """
        return pulumi.get(self, "email_additional_text")

    @email_additional_text.setter
    def email_additional_text(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "email_additional_text", value)

    @_builtins.property
    @pulumi.getter(name="emailAuthorInBody")
    def email_author_in_body(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Some email servers do not support overriding the email sender name. Enable this option to include the name of the author of the issue, merge request or comment in the email body instead.
        """
        return pulumi.get(self, "email_author_in_body")

    @email_author_in_body.setter
    def email_author_in_body(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "email_author_in_body", value)

    @_builtins.property
    @pulumi.getter(name="emailConfirmationSetting")
    def email_confirmation_setting(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies whether users must confirm their email before sign in. Possible values are off, soft, and hard.
        """
        return pulumi.get(self, "email_confirmation_setting")

    @email_confirmation_setting.setter
    def email_confirmation_setting(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "email_confirmation_setting", value)

    @_builtins.property
    @pulumi.getter(name="enableArtifactExternalRedirectWarningPage")
    def enable_artifact_external_redirect_warning_page(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Show the external redirect page that warns you about user-generated content in GitLab Pages.
        """
        return pulumi.get(self, "enable_artifact_external_redirect_warning_page")

    @enable_artifact_external_redirect_warning_page.setter
    def enable_artifact_external_redirect_warning_page(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enable_artifact_external_redirect_warning_page", value)

    @_builtins.property
    @pulumi.getter(name="enabledGitAccessProtocol")
    def enabled_git_access_protocol(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Enabled protocols for Git access. Allowed values are: ssh, http, and nil to allow both protocols.
        """
        return pulumi.get(self, "enabled_git_access_protocol")

    @enabled_git_access_protocol.setter
    def enabled_git_access_protocol(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "enabled_git_access_protocol", value)

    @_builtins.property
    @pulumi.getter(name="enforceNamespaceStorageLimit")
    def enforce_namespace_storage_limit(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enabling this permits enforcement of namespace storage limits.
        """
        return pulumi.get(self, "enforce_namespace_storage_limit")

    @enforce_namespace_storage_limit.setter
    def enforce_namespace_storage_limit(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enforce_namespace_storage_limit", value)

    @_builtins.property
    @pulumi.getter(name="enforceTerms")
    def enforce_terms(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: terms) Enforce application ToS to all users.
        """
        return pulumi.get(self, "enforce_terms")

    @enforce_terms.setter
    def enforce_terms(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enforce_terms", value)

    @_builtins.property
    @pulumi.getter(name="externalAuthClientCert")
    def external_auth_client_cert(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (If enabled, requires: external*auth*client_key) The certificate to use to authenticate with the external authorization service.
        """
        return pulumi.get(self, "external_auth_client_cert")

    @external_auth_client_cert.setter
    def external_auth_client_cert(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "external_auth_client_cert", value)

    @_builtins.property
    @pulumi.getter(name="externalAuthClientKey")
    def external_auth_client_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Private key for the certificate when authentication is required for the external authorization service, this is encrypted when stored.
        """
        return pulumi.get(self, "external_auth_client_key")

    @external_auth_client_key.setter
    def external_auth_client_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "external_auth_client_key", value)

    @_builtins.property
    @pulumi.getter(name="externalAuthClientKeyPass")
    def external_auth_client_key_pass(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Passphrase to use for the private key when authenticating with the external service this is encrypted when stored.
        """
        return pulumi.get(self, "external_auth_client_key_pass")

    @external_auth_client_key_pass.setter
    def external_auth_client_key_pass(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "external_auth_client_key_pass", value)

    @_builtins.property
    @pulumi.getter(name="externalAuthorizationServiceDefaultLabel")
    def external_authorization_service_default_label(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The default classification label to use when requesting authorization and no classification label has been specified on the project.
        """
        return pulumi.get(self, "external_authorization_service_default_label")

    @external_authorization_service_default_label.setter
    def external_authorization_service_default_label(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "external_authorization_service_default_label", value)

    @_builtins.property
    @pulumi.getter(name="externalAuthorizationServiceEnabled")
    def external_authorization_service_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: external*authorization*service*default*label, external*authorization*service*timeout and external*authorization*service*url) Enable using an external authorization service for accessing projects.
        """
        return pulumi.get(self, "external_authorization_service_enabled")

    @external_authorization_service_enabled.setter
    def external_authorization_service_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "external_authorization_service_enabled", value)

    @_builtins.property
    @pulumi.getter(name="externalAuthorizationServiceTimeout")
    def external_authorization_service_timeout(self) -> Optional[pulumi.Input[_builtins.float]]:
        """
        The timeout after which an authorization request is aborted, in seconds. When a request times out, access is denied to the user. (min: 0.001, max: 10, step: 0.001).
        """
        return pulumi.get(self, "external_authorization_service_timeout")

    @external_authorization_service_timeout.setter
    def external_authorization_service_timeout(self, value: Optional[pulumi.Input[_builtins.float]]):
        pulumi.set(self, "external_authorization_service_timeout", value)

    @_builtins.property
    @pulumi.getter(name="externalAuthorizationServiceUrl")
    def external_authorization_service_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        URL to which authorization requests are directed.
        """
        return pulumi.get(self, "external_authorization_service_url")

    @external_authorization_service_url.setter
    def external_authorization_service_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "external_authorization_service_url", value)

    @_builtins.property
    @pulumi.getter(name="externalPipelineValidationServiceTimeout")
    def external_pipeline_validation_service_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        How long to wait for a response from the pipeline validation service. Assumes OK if it times out.
        """
        return pulumi.get(self, "external_pipeline_validation_service_timeout")

    @external_pipeline_validation_service_timeout.setter
    def external_pipeline_validation_service_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "external_pipeline_validation_service_timeout", value)

    @_builtins.property
    @pulumi.getter(name="externalPipelineValidationServiceToken")
    def external_pipeline_validation_service_token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Optional. Token to include as the X-Gitlab-Token header in requests to the URL in external*pipeline*validation*service*url.
        """
        return pulumi.get(self, "external_pipeline_validation_service_token")

    @external_pipeline_validation_service_token.setter
    def external_pipeline_validation_service_token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "external_pipeline_validation_service_token", value)

    @_builtins.property
    @pulumi.getter(name="externalPipelineValidationServiceUrl")
    def external_pipeline_validation_service_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        URL to use for pipeline validation requests.
        """
        return pulumi.get(self, "external_pipeline_validation_service_url")

    @external_pipeline_validation_service_url.setter
    def external_pipeline_validation_service_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "external_pipeline_validation_service_url", value)

    @_builtins.property
    @pulumi.getter(name="failedLoginAttemptsUnlockPeriodInMinutes")
    def failed_login_attempts_unlock_period_in_minutes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Time period in minutes after which the user is unlocked when maximum number of failed sign-in attempts reached.
        """
        return pulumi.get(self, "failed_login_attempts_unlock_period_in_minutes")

    @failed_login_attempts_unlock_period_in_minutes.setter
    def failed_login_attempts_unlock_period_in_minutes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "failed_login_attempts_unlock_period_in_minutes", value)

    @_builtins.property
    @pulumi.getter(name="fileTemplateProjectId")
    def file_template_project_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The ID of a project to load custom file templates from.
        """
        return pulumi.get(self, "file_template_project_id")

    @file_template_project_id.setter
    def file_template_project_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "file_template_project_id", value)

    @_builtins.property
    @pulumi.getter(name="firstDayOfWeek")
    def first_day_of_week(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Start day of the week for calendar views and date pickers. Valid values are 0 for Sunday, 1 for Monday, and 6 for Saturday.
        """
        return pulumi.get(self, "first_day_of_week")

    @first_day_of_week.setter
    def first_day_of_week(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "first_day_of_week", value)

    @_builtins.property
    @pulumi.getter(name="geoNodeAllowedIps")
    def geo_node_allowed_ips(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Comma-separated list of IPs and CIDRs of allowed secondary nodes. For example, 1.1.1.1, 2.2.2.0/24.
        """
        return pulumi.get(self, "geo_node_allowed_ips")

    @geo_node_allowed_ips.setter
    def geo_node_allowed_ips(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "geo_node_allowed_ips", value)

    @_builtins.property
    @pulumi.getter(name="geoStatusTimeout")
    def geo_status_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The amount of seconds after which a request to get a secondary node status times out.
        """
        return pulumi.get(self, "geo_status_timeout")

    @geo_status_timeout.setter
    def geo_status_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "geo_status_timeout", value)

    @_builtins.property
    @pulumi.getter(name="gitRateLimitUsersAlertlists")
    def git_rate_limit_users_alertlists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]:
        """
        List of user IDs that are emailed when the Git abuse rate limit is exceeded. Maximum: 100 user IDs. Self-managed, Ultimate only.
        """
        return pulumi.get(self, "git_rate_limit_users_alertlists")

    @git_rate_limit_users_alertlists.setter
    def git_rate_limit_users_alertlists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]):
        pulumi.set(self, "git_rate_limit_users_alertlists", value)

    @_builtins.property
    @pulumi.getter(name="gitRateLimitUsersAllowlists")
    def git_rate_limit_users_allowlists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of usernames excluded from Git anti-abuse rate limits. Maximum: 100 usernames. Self-managed, Ultimate only.
        """
        return pulumi.get(self, "git_rate_limit_users_allowlists")

    @git_rate_limit_users_allowlists.setter
    def git_rate_limit_users_allowlists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "git_rate_limit_users_allowlists", value)

    @_builtins.property
    @pulumi.getter(name="gitTwoFactorSessionExpiry")
    def git_two_factor_session_expiry(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum duration (in minutes) of a session for Git operations when 2FA is enabled.
        """
        return pulumi.get(self, "git_two_factor_session_expiry")

    @git_two_factor_session_expiry.setter
    def git_two_factor_session_expiry(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "git_two_factor_session_expiry", value)

    @_builtins.property
    @pulumi.getter(name="gitalyTimeoutDefault")
    def gitaly_timeout_default(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Default Gitaly timeout, in seconds. This timeout is not enforced for Git fetch/push operations or Sidekiq jobs. Set to 0 to disable timeouts.
        """
        return pulumi.get(self, "gitaly_timeout_default")

    @gitaly_timeout_default.setter
    def gitaly_timeout_default(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "gitaly_timeout_default", value)

    @_builtins.property
    @pulumi.getter(name="gitalyTimeoutFast")
    def gitaly_timeout_fast(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Gitaly fast operation timeout, in seconds. Some Gitaly operations are expected to be fast. If they exceed this threshold, there may be a problem with a storage shard and ‘failing fast’ can help maintain the stability of the GitLab instance. Set to 0 to disable timeouts.
        """
        return pulumi.get(self, "gitaly_timeout_fast")

    @gitaly_timeout_fast.setter
    def gitaly_timeout_fast(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "gitaly_timeout_fast", value)

    @_builtins.property
    @pulumi.getter(name="gitalyTimeoutMedium")
    def gitaly_timeout_medium(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Medium Gitaly timeout, in seconds. This should be a value between the Fast and the Default timeout. Set to 0 to disable timeouts.
        """
        return pulumi.get(self, "gitaly_timeout_medium")

    @gitaly_timeout_medium.setter
    def gitaly_timeout_medium(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "gitaly_timeout_medium", value)

    @_builtins.property
    @pulumi.getter(name="gitlabShellOperationLimit")
    def gitlab_shell_operation_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum number of Git operations per minute a user can perform.
        """
        return pulumi.get(self, "gitlab_shell_operation_limit")

    @gitlab_shell_operation_limit.setter
    def gitlab_shell_operation_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "gitlab_shell_operation_limit", value)

    @_builtins.property
    @pulumi.getter(name="gitpodEnabled")
    def gitpod_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable Gitpod integration.
        """
        return pulumi.get(self, "gitpod_enabled")

    @gitpod_enabled.setter
    def gitpod_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "gitpod_enabled", value)

    @_builtins.property
    @pulumi.getter(name="gitpodUrl")
    def gitpod_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Gitpod instance URL for integration.
        """
        return pulumi.get(self, "gitpod_url")

    @gitpod_url.setter
    def gitpod_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "gitpod_url", value)

    @_builtins.property
    @pulumi.getter(name="globallyAllowedIps")
    def globally_allowed_ips(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Comma-separated list of IP addresses and CIDRs always allowed for inbound traffic. For example, 1.1.1.1, 2.2.2.0/24.
        """
        return pulumi.get(self, "globally_allowed_ips")

    @globally_allowed_ips.setter
    def globally_allowed_ips(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "globally_allowed_ips", value)

    @_builtins.property
    @pulumi.getter(name="grafanaEnabled")
    def grafana_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable Grafana.
        """
        return pulumi.get(self, "grafana_enabled")

    @grafana_enabled.setter
    def grafana_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "grafana_enabled", value)

    @_builtins.property
    @pulumi.getter(name="grafanaUrl")
    def grafana_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Grafana URL.
        """
        return pulumi.get(self, "grafana_url")

    @grafana_url.setter
    def grafana_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "grafana_url", value)

    @_builtins.property
    @pulumi.getter(name="gravatarEnabled")
    def gravatar_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable Gravatar.
        """
        return pulumi.get(self, "gravatar_enabled")

    @gravatar_enabled.setter
    def gravatar_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "gravatar_enabled", value)

    @_builtins.property
    @pulumi.getter(name="groupOwnersCanManageDefaultBranchProtection")
    def group_owners_can_manage_default_branch_protection(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Prevent overrides of default branch protection.
        """
        return pulumi.get(self, "group_owners_can_manage_default_branch_protection")

    @group_owners_can_manage_default_branch_protection.setter
    def group_owners_can_manage_default_branch_protection(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "group_owners_can_manage_default_branch_protection", value)

    @_builtins.property
    @pulumi.getter(name="helpPageHideCommercialContent")
    def help_page_hide_commercial_content(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Hide marketing-related entries from help.
        """
        return pulumi.get(self, "help_page_hide_commercial_content")

    @help_page_hide_commercial_content.setter
    def help_page_hide_commercial_content(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "help_page_hide_commercial_content", value)

    @_builtins.property
    @pulumi.getter(name="helpPageSupportUrl")
    def help_page_support_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Alternate support URL for help page and help dropdown.
        """
        return pulumi.get(self, "help_page_support_url")

    @help_page_support_url.setter
    def help_page_support_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "help_page_support_url", value)

    @_builtins.property
    @pulumi.getter(name="helpPageText")
    def help_page_text(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Custom text displayed on the help page.
        """
        return pulumi.get(self, "help_page_text")

    @help_page_text.setter
    def help_page_text(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "help_page_text", value)

    @_builtins.property
    @pulumi.getter(name="helpText")
    def help_text(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        GitLab server administrator information.
        """
        return pulumi.get(self, "help_text")

    @help_text.setter
    def help_text(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "help_text", value)

    @_builtins.property
    @pulumi.getter(name="hideThirdPartyOffers")
    def hide_third_party_offers(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Do not display offers from third parties in GitLab.
        """
        return pulumi.get(self, "hide_third_party_offers")

    @hide_third_party_offers.setter
    def hide_third_party_offers(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "hide_third_party_offers", value)

    @_builtins.property
    @pulumi.getter(name="homePageUrl")
    def home_page_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Redirect to this URL when not logged in.
        """
        return pulumi.get(self, "home_page_url")

    @home_page_url.setter
    def home_page_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "home_page_url", value)

    @_builtins.property
    @pulumi.getter(name="housekeepingEnabled")
    def housekeeping_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable or disable Git housekeeping. If enabled, requires housekeeping*optimize*repository_period.
        """
        return pulumi.get(self, "housekeeping_enabled")

    @housekeeping_enabled.setter
    def housekeeping_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "housekeeping_enabled", value)

    @_builtins.property
    @pulumi.getter(name="housekeepingOptimizeRepositoryPeriod")
    def housekeeping_optimize_repository_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Number of Git pushes after which an incremental git-repack is run.
        """
        return pulumi.get(self, "housekeeping_optimize_repository_period")

    @housekeeping_optimize_repository_period.setter
    def housekeeping_optimize_repository_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "housekeeping_optimize_repository_period", value)

    @_builtins.property
    @pulumi.getter(name="htmlEmailsEnabled")
    def html_emails_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable HTML emails.
        """
        return pulumi.get(self, "html_emails_enabled")

    @html_emails_enabled.setter
    def html_emails_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "html_emails_enabled", value)

    @_builtins.property
    @pulumi.getter(name="importSources")
    def import_sources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Sources to allow project import from. Valid values are: `github`, `bitbucket`, `bitbucket_server`, `fogbugz`, `git`, `Project`, `gitea`, `manifest`
        """
        return pulumi.get(self, "import_sources")

    @import_sources.setter
    def import_sources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "import_sources", value)

    @_builtins.property
    @pulumi.getter(name="inProductMarketingEmailsEnabled")
    def in_product_marketing_emails_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable in-product marketing emails.
        """
        return pulumi.get(self, "in_product_marketing_emails_enabled")

    @in_product_marketing_emails_enabled.setter
    def in_product_marketing_emails_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "in_product_marketing_emails_enabled", value)

    @_builtins.property
    @pulumi.getter(name="inactiveProjectsDeleteAfterMonths")
    def inactive_projects_delete_after_months(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        If delete*inactive*projects is true, the time (in months) to wait before deleting inactive projects.
        """
        return pulumi.get(self, "inactive_projects_delete_after_months")

    @inactive_projects_delete_after_months.setter
    def inactive_projects_delete_after_months(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "inactive_projects_delete_after_months", value)

    @_builtins.property
    @pulumi.getter(name="inactiveProjectsMinSizeMb")
    def inactive_projects_min_size_mb(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        If delete*inactive*projects is true, the minimum repository size for projects to be checked for inactivity.
        """
        return pulumi.get(self, "inactive_projects_min_size_mb")

    @inactive_projects_min_size_mb.setter
    def inactive_projects_min_size_mb(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "inactive_projects_min_size_mb", value)

    @_builtins.property
    @pulumi.getter(name="inactiveProjectsSendWarningEmailAfterMonths")
    def inactive_projects_send_warning_email_after_months(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        If delete*inactive*projects is true, sets the time (in months) to wait before emailing maintainers that the project is scheduled be deleted because it is inactive.
        """
        return pulumi.get(self, "inactive_projects_send_warning_email_after_months")

    @inactive_projects_send_warning_email_after_months.setter
    def inactive_projects_send_warning_email_after_months(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "inactive_projects_send_warning_email_after_months", value)

    @_builtins.property
    @pulumi.getter(name="includeOptionalMetricsInServicePing")
    def include_optional_metrics_in_service_ping(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether or not optional metrics are enabled in Service Ping.
        """
        return pulumi.get(self, "include_optional_metrics_in_service_ping")

    @include_optional_metrics_in_service_ping.setter
    def include_optional_metrics_in_service_ping(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "include_optional_metrics_in_service_ping", value)

    @_builtins.property
    @pulumi.getter(name="invisibleCaptchaEnabled")
    def invisible_captcha_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable Invisible CAPTCHA spam detection during sign-up.
        """
        return pulumi.get(self, "invisible_captcha_enabled")

    @invisible_captcha_enabled.setter
    def invisible_captcha_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "invisible_captcha_enabled", value)

    @_builtins.property
    @pulumi.getter(name="issuesCreateLimit")
    def issues_create_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Max number of issue creation requests per minute per user.
        """
        return pulumi.get(self, "issues_create_limit")

    @issues_create_limit.setter
    def issues_create_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "issues_create_limit", value)

    @_builtins.property
    @pulumi.getter(name="jiraConnectApplicationKey")
    def jira_connect_application_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the OAuth application used to authenticate with the GitLab for Jira Cloud app.
        """
        return pulumi.get(self, "jira_connect_application_key")

    @jira_connect_application_key.setter
    def jira_connect_application_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "jira_connect_application_key", value)

    @_builtins.property
    @pulumi.getter(name="jiraConnectProxyUrl")
    def jira_connect_proxy_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        URL of the GitLab instance used as a proxy for the GitLab for Jira Cloud app.
        """
        return pulumi.get(self, "jira_connect_proxy_url")

    @jira_connect_proxy_url.setter
    def jira_connect_proxy_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "jira_connect_proxy_url", value)

    @_builtins.property
    @pulumi.getter(name="jiraConnectPublicKeyStorageEnabled")
    def jira_connect_public_key_storage_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable public key storage for the GitLab for Jira Cloud app.
        """
        return pulumi.get(self, "jira_connect_public_key_storage_enabled")

    @jira_connect_public_key_storage_enabled.setter
    def jira_connect_public_key_storage_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "jira_connect_public_key_storage_enabled", value)

    @_builtins.property
    @pulumi.getter(name="keepLatestArtifact")
    def keep_latest_artifact(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Prevent the deletion of the artifacts from the most recent successful jobs, regardless of the expiry time.
        """
        return pulumi.get(self, "keep_latest_artifact")

    @keep_latest_artifact.setter
    def keep_latest_artifact(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "keep_latest_artifact", value)

    @_builtins.property
    @pulumi.getter(name="localMarkdownVersion")
    def local_markdown_version(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Increase this value when any cached Markdown should be invalidated.
        """
        return pulumi.get(self, "local_markdown_version")

    @local_markdown_version.setter
    def local_markdown_version(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "local_markdown_version", value)

    @_builtins.property
    @pulumi.getter(name="lockDuoFeaturesEnabled")
    def lock_duo_features_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the GitLab Duo features enabled setting is enforced for all subgroups. Self-managed, Premium and Ultimate only.
        """
        return pulumi.get(self, "lock_duo_features_enabled")

    @lock_duo_features_enabled.setter
    def lock_duo_features_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "lock_duo_features_enabled", value)

    @_builtins.property
    @pulumi.getter(name="lockMembershipsToLdap")
    def lock_memberships_to_ldap(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to true to lock all memberships to LDAP. Premium and Ultimate only.
        """
        return pulumi.get(self, "lock_memberships_to_ldap")

    @lock_memberships_to_ldap.setter
    def lock_memberships_to_ldap(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "lock_memberships_to_ldap", value)

    @_builtins.property
    @pulumi.getter(name="mailgunEventsEnabled")
    def mailgun_events_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable Mailgun event receiver.
        """
        return pulumi.get(self, "mailgun_events_enabled")

    @mailgun_events_enabled.setter
    def mailgun_events_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "mailgun_events_enabled", value)

    @_builtins.property
    @pulumi.getter(name="mailgunSigningKey")
    def mailgun_signing_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Mailgun HTTP webhook signing key for receiving events from webhook.
        """
        return pulumi.get(self, "mailgun_signing_key")

    @mailgun_signing_key.setter
    def mailgun_signing_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mailgun_signing_key", value)

    @_builtins.property
    @pulumi.getter(name="maintenanceMode")
    def maintenance_mode(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When instance is in maintenance mode, non-administrative users can sign in with read-only access and make read-only API requests.
        """
        return pulumi.get(self, "maintenance_mode")

    @maintenance_mode.setter
    def maintenance_mode(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "maintenance_mode", value)

    @_builtins.property
    @pulumi.getter(name="maintenanceModeMessage")
    def maintenance_mode_message(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Message displayed when instance is in maintenance mode.
        """
        return pulumi.get(self, "maintenance_mode_message")

    @maintenance_mode_message.setter
    def maintenance_mode_message(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "maintenance_mode_message", value)

    @_builtins.property
    @pulumi.getter(name="mavenPackageRequestsForwarding")
    def maven_package_requests_forwarding(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Use repo.maven.apache.org as a default remote repository when the package is not found in the GitLab Package Registry for Maven. Premium and Ultimate only.
        """
        return pulumi.get(self, "maven_package_requests_forwarding")

    @maven_package_requests_forwarding.setter
    def maven_package_requests_forwarding(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "maven_package_requests_forwarding", value)

    @_builtins.property
    @pulumi.getter(name="maxArtifactsSize")
    def max_artifacts_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum artifacts size in MB.
        """
        return pulumi.get(self, "max_artifacts_size")

    @max_artifacts_size.setter
    def max_artifacts_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_artifacts_size", value)

    @_builtins.property
    @pulumi.getter(name="maxAttachmentSize")
    def max_attachment_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Limit attachment size in MB.
        """
        return pulumi.get(self, "max_attachment_size")

    @max_attachment_size.setter
    def max_attachment_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_attachment_size", value)

    @_builtins.property
    @pulumi.getter(name="maxDecompressedArchiveSize")
    def max_decompressed_archive_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum decompressed archive size in bytes.
        """
        return pulumi.get(self, "max_decompressed_archive_size")

    @max_decompressed_archive_size.setter
    def max_decompressed_archive_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_decompressed_archive_size", value)

    @_builtins.property
    @pulumi.getter(name="maxExportSize")
    def max_export_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum export size in MB. 0 for unlimited.
        """
        return pulumi.get(self, "max_export_size")

    @max_export_size.setter
    def max_export_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_export_size", value)

    @_builtins.property
    @pulumi.getter(name="maxImportRemoteFileSize")
    def max_import_remote_file_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum remote file size for imports from external object storages.
        """
        return pulumi.get(self, "max_import_remote_file_size")

    @max_import_remote_file_size.setter
    def max_import_remote_file_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_import_remote_file_size", value)

    @_builtins.property
    @pulumi.getter(name="maxImportSize")
    def max_import_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum import size in MB. 0 for unlimited.
        """
        return pulumi.get(self, "max_import_size")

    @max_import_size.setter
    def max_import_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_import_size", value)

    @_builtins.property
    @pulumi.getter(name="maxLoginAttempts")
    def max_login_attempts(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum number of sign-in attempts before locking out the user.
        """
        return pulumi.get(self, "max_login_attempts")

    @max_login_attempts.setter
    def max_login_attempts(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_login_attempts", value)

    @_builtins.property
    @pulumi.getter(name="maxNumberOfRepositoryDownloads")
    def max_number_of_repository_downloads(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum number of unique repositories a user can download in the specified time period before they are banned. Maximum: 10,000 repositories.
        """
        return pulumi.get(self, "max_number_of_repository_downloads")

    @max_number_of_repository_downloads.setter
    def max_number_of_repository_downloads(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_number_of_repository_downloads", value)

    @_builtins.property
    @pulumi.getter(name="maxNumberOfRepositoryDownloadsWithinTimePeriod")
    def max_number_of_repository_downloads_within_time_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Reporting time period (in seconds). Maximum: 864000 seconds (10 days).
        """
        return pulumi.get(self, "max_number_of_repository_downloads_within_time_period")

    @max_number_of_repository_downloads_within_time_period.setter
    def max_number_of_repository_downloads_within_time_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_number_of_repository_downloads_within_time_period", value)

    @_builtins.property
    @pulumi.getter(name="maxPagesSize")
    def max_pages_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum size of pages repositories in MB.
        """
        return pulumi.get(self, "max_pages_size")

    @max_pages_size.setter
    def max_pages_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_pages_size", value)

    @_builtins.property
    @pulumi.getter(name="maxPersonalAccessTokenLifetime")
    def max_personal_access_token_lifetime(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum allowable lifetime for access tokens in days.
        """
        return pulumi.get(self, "max_personal_access_token_lifetime")

    @max_personal_access_token_lifetime.setter
    def max_personal_access_token_lifetime(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_personal_access_token_lifetime", value)

    @_builtins.property
    @pulumi.getter(name="maxSshKeyLifetime")
    def max_ssh_key_lifetime(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum allowable lifetime for SSH keys in days.
        """
        return pulumi.get(self, "max_ssh_key_lifetime")

    @max_ssh_key_lifetime.setter
    def max_ssh_key_lifetime(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_ssh_key_lifetime", value)

    @_builtins.property
    @pulumi.getter(name="maxTerraformStateSizeBytes")
    def max_terraform_state_size_bytes(self) -> Optional[pulumi.Input[_builtins.int]]:
        return pulumi.get(self, "max_terraform_state_size_bytes")

    @max_terraform_state_size_bytes.setter
    def max_terraform_state_size_bytes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_terraform_state_size_bytes", value)

    @_builtins.property
    @pulumi.getter(name="metricsMethodCallThreshold")
    def metrics_method_call_threshold(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        A method call is only tracked when it takes longer than the given amount of milliseconds.
        """
        return pulumi.get(self, "metrics_method_call_threshold")

    @metrics_method_call_threshold.setter
    def metrics_method_call_threshold(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "metrics_method_call_threshold", value)

    @_builtins.property
    @pulumi.getter(name="minimumPasswordLength")
    def minimum_password_length(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Indicates whether passwords require a minimum length. Premium and Ultimate only.
        """
        return pulumi.get(self, "minimum_password_length")

    @minimum_password_length.setter
    def minimum_password_length(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "minimum_password_length", value)

    @_builtins.property
    @pulumi.getter(name="mirrorAvailable")
    def mirror_available(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow repository mirroring to configured by project Maintainers. If disabled, only Administrators can configure repository mirroring.
        """
        return pulumi.get(self, "mirror_available")

    @mirror_available.setter
    def mirror_available(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "mirror_available", value)

    @_builtins.property
    @pulumi.getter(name="mirrorCapacityThreshold")
    def mirror_capacity_threshold(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Minimum capacity to be available before scheduling more mirrors preemptively.
        """
        return pulumi.get(self, "mirror_capacity_threshold")

    @mirror_capacity_threshold.setter
    def mirror_capacity_threshold(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "mirror_capacity_threshold", value)

    @_builtins.property
    @pulumi.getter(name="mirrorMaxCapacity")
    def mirror_max_capacity(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum number of mirrors that can be synchronizing at the same time.
        """
        return pulumi.get(self, "mirror_max_capacity")

    @mirror_max_capacity.setter
    def mirror_max_capacity(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "mirror_max_capacity", value)

    @_builtins.property
    @pulumi.getter(name="mirrorMaxDelay")
    def mirror_max_delay(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum time (in minutes) between updates that a mirror can have when scheduled to synchronize.
        """
        return pulumi.get(self, "mirror_max_delay")

    @mirror_max_delay.setter
    def mirror_max_delay(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "mirror_max_delay", value)

    @_builtins.property
    @pulumi.getter(name="npmPackageRequestsForwarding")
    def npm_package_requests_forwarding(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Use npmjs.org as a default remote repository when the package is not found in the GitLab Package Registry for npm.
        """
        return pulumi.get(self, "npm_package_requests_forwarding")

    @npm_package_requests_forwarding.setter
    def npm_package_requests_forwarding(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "npm_package_requests_forwarding", value)

    @_builtins.property
    @pulumi.getter(name="nugetSkipMetadataUrlValidation")
    def nuget_skip_metadata_url_validation(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether to skip metadata URL validation for the NuGet package.
        """
        return pulumi.get(self, "nuget_skip_metadata_url_validation")

    @nuget_skip_metadata_url_validation.setter
    def nuget_skip_metadata_url_validation(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "nuget_skip_metadata_url_validation", value)

    @_builtins.property
    @pulumi.getter(name="outboundLocalRequestsWhitelists")
    def outbound_local_requests_whitelists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Define a list of trusted domains or IP addresses to which local requests are allowed when local requests for hooks and services are disabled.
        """
        return pulumi.get(self, "outbound_local_requests_whitelists")

    @outbound_local_requests_whitelists.setter
    def outbound_local_requests_whitelists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "outbound_local_requests_whitelists", value)

    @_builtins.property
    @pulumi.getter(name="packageMetadataPurlTypes")
    def package_metadata_purl_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]:
        """
        List of package registry metadata to sync. See the list of the available values (https://gitlab.com/gitlab-org/gitlab/-/blob/ace16c20d5da7c4928dd03fb139692638b557fe3/app/models/concerns/enums/package_metadata.rb#L5). Self-managed, Ultimate only.
        """
        return pulumi.get(self, "package_metadata_purl_types")

    @package_metadata_purl_types.setter
    def package_metadata_purl_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]):
        pulumi.set(self, "package_metadata_purl_types", value)

    @_builtins.property
    @pulumi.getter(name="packageRegistryAllowAnyoneToPullOption")
    def package_registry_allow_anyone_to_pull_option(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable to allow anyone to pull from Package Registry visible and changeable.
        """
        return pulumi.get(self, "package_registry_allow_anyone_to_pull_option")

    @package_registry_allow_anyone_to_pull_option.setter
    def package_registry_allow_anyone_to_pull_option(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "package_registry_allow_anyone_to_pull_option", value)

    @_builtins.property
    @pulumi.getter(name="packageRegistryCleanupPoliciesWorkerCapacity")
    def package_registry_cleanup_policies_worker_capacity(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Number of workers assigned to the packages cleanup policies.
        """
        return pulumi.get(self, "package_registry_cleanup_policies_worker_capacity")

    @package_registry_cleanup_policies_worker_capacity.setter
    def package_registry_cleanup_policies_worker_capacity(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "package_registry_cleanup_policies_worker_capacity", value)

    @_builtins.property
    @pulumi.getter(name="pagesDomainVerificationEnabled")
    def pages_domain_verification_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Require users to prove ownership of custom domains. Domain verification is an essential security measure for public GitLab sites. Users are required to demonstrate they control a domain before it is enabled.
        """
        return pulumi.get(self, "pages_domain_verification_enabled")

    @pages_domain_verification_enabled.setter
    def pages_domain_verification_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "pages_domain_verification_enabled", value)

    @_builtins.property
    @pulumi.getter(name="passwordAuthenticationEnabledForGit")
    def password_authentication_enabled_for_git(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable authentication for Git over HTTP(S) via a GitLab account password.
        """
        return pulumi.get(self, "password_authentication_enabled_for_git")

    @password_authentication_enabled_for_git.setter
    def password_authentication_enabled_for_git(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "password_authentication_enabled_for_git", value)

    @_builtins.property
    @pulumi.getter(name="passwordAuthenticationEnabledForWeb")
    def password_authentication_enabled_for_web(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable authentication for the web interface via a GitLab account password.
        """
        return pulumi.get(self, "password_authentication_enabled_for_web")

    @password_authentication_enabled_for_web.setter
    def password_authentication_enabled_for_web(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "password_authentication_enabled_for_web", value)

    @_builtins.property
    @pulumi.getter(name="passwordLowercaseRequired")
    def password_lowercase_required(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether passwords require at least one lowercase letter.
        """
        return pulumi.get(self, "password_lowercase_required")

    @password_lowercase_required.setter
    def password_lowercase_required(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "password_lowercase_required", value)

    @_builtins.property
    @pulumi.getter(name="passwordNumberRequired")
    def password_number_required(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether passwords require at least one number.
        """
        return pulumi.get(self, "password_number_required")

    @password_number_required.setter
    def password_number_required(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "password_number_required", value)

    @_builtins.property
    @pulumi.getter(name="passwordSymbolRequired")
    def password_symbol_required(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether passwords require at least one symbol character.
        """
        return pulumi.get(self, "password_symbol_required")

    @password_symbol_required.setter
    def password_symbol_required(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "password_symbol_required", value)

    @_builtins.property
    @pulumi.getter(name="passwordUppercaseRequired")
    def password_uppercase_required(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether passwords require at least one uppercase letter.
        """
        return pulumi.get(self, "password_uppercase_required")

    @password_uppercase_required.setter
    def password_uppercase_required(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "password_uppercase_required", value)

    @_builtins.property
    @pulumi.getter(name="performanceBarAllowedGroupPath")
    def performance_bar_allowed_group_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Path of the group that is allowed to toggle the performance bar.
        """
        return pulumi.get(self, "performance_bar_allowed_group_path")

    @performance_bar_allowed_group_path.setter
    def performance_bar_allowed_group_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "performance_bar_allowed_group_path", value)

    @_builtins.property
    @pulumi.getter(name="personalAccessTokenPrefix")
    def personal_access_token_prefix(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Prefix for all generated personal access tokens.
        """
        return pulumi.get(self, "personal_access_token_prefix")

    @personal_access_token_prefix.setter
    def personal_access_token_prefix(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "personal_access_token_prefix", value)

    @_builtins.property
    @pulumi.getter(name="pipelineLimitPerProjectUserSha")
    def pipeline_limit_per_project_user_sha(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum number of pipeline creation requests per minute per user and commit.
        """
        return pulumi.get(self, "pipeline_limit_per_project_user_sha")

    @pipeline_limit_per_project_user_sha.setter
    def pipeline_limit_per_project_user_sha(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "pipeline_limit_per_project_user_sha", value)

    @_builtins.property
    @pulumi.getter(name="plantumlEnabled")
    def plantuml_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: plantuml_url) Enable PlantUML integration.
        """
        return pulumi.get(self, "plantuml_enabled")

    @plantuml_enabled.setter
    def plantuml_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "plantuml_enabled", value)

    @_builtins.property
    @pulumi.getter(name="plantumlUrl")
    def plantuml_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The PlantUML instance URL for integration.
        """
        return pulumi.get(self, "plantuml_url")

    @plantuml_url.setter
    def plantuml_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "plantuml_url", value)

    @_builtins.property
    @pulumi.getter(name="pollingIntervalMultiplier")
    def polling_interval_multiplier(self) -> Optional[pulumi.Input[_builtins.float]]:
        """
        Interval multiplier used by endpoints that perform polling. Set to 0 to disable polling.
        """
        return pulumi.get(self, "polling_interval_multiplier")

    @polling_interval_multiplier.setter
    def polling_interval_multiplier(self, value: Optional[pulumi.Input[_builtins.float]]):
        pulumi.set(self, "polling_interval_multiplier", value)

    @_builtins.property
    @pulumi.getter(name="projectExportEnabled")
    def project_export_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable project export.
        """
        return pulumi.get(self, "project_export_enabled")

    @project_export_enabled.setter
    def project_export_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "project_export_enabled", value)

    @_builtins.property
    @pulumi.getter(name="projectJobsApiRateLimit")
    def project_jobs_api_rate_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum authenticated requests to /project/:id/jobs per minute.
        """
        return pulumi.get(self, "project_jobs_api_rate_limit")

    @project_jobs_api_rate_limit.setter
    def project_jobs_api_rate_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "project_jobs_api_rate_limit", value)

    @_builtins.property
    @pulumi.getter(name="projectsApiRateLimitUnauthenticated")
    def projects_api_rate_limit_unauthenticated(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Max number of requests per 10 minutes per IP address for unauthenticated requests to the list all projects API. To disable throttling set to 0.
        """
        return pulumi.get(self, "projects_api_rate_limit_unauthenticated")

    @projects_api_rate_limit_unauthenticated.setter
    def projects_api_rate_limit_unauthenticated(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "projects_api_rate_limit_unauthenticated", value)

    @_builtins.property
    @pulumi.getter(name="prometheusMetricsEnabled")
    def prometheus_metrics_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable Prometheus metrics.
        """
        return pulumi.get(self, "prometheus_metrics_enabled")

    @prometheus_metrics_enabled.setter
    def prometheus_metrics_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "prometheus_metrics_enabled", value)

    @_builtins.property
    @pulumi.getter(name="protectedCiVariables")
    def protected_ci_variables(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        CI/CD variables are protected by default.
        """
        return pulumi.get(self, "protected_ci_variables")

    @protected_ci_variables.setter
    def protected_ci_variables(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "protected_ci_variables", value)

    @_builtins.property
    @pulumi.getter(name="pushEventActivitiesLimit")
    def push_event_activities_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Number of changes (branches or tags) in a single push to determine whether individual push events or bulk push events are created. Bulk push events are created if it surpasses that value.
        """
        return pulumi.get(self, "push_event_activities_limit")

    @push_event_activities_limit.setter
    def push_event_activities_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "push_event_activities_limit", value)

    @_builtins.property
    @pulumi.getter(name="pushEventHooksLimit")
    def push_event_hooks_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Number of changes (branches or tags) in a single push to determine whether webhooks and services fire or not. Webhooks and services aren’t submitted if it surpasses that value.
        """
        return pulumi.get(self, "push_event_hooks_limit")

    @push_event_hooks_limit.setter
    def push_event_hooks_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "push_event_hooks_limit", value)

    @_builtins.property
    @pulumi.getter(name="pypiPackageRequestsForwarding")
    def pypi_package_requests_forwarding(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Use pypi.org as a default remote repository when the package is not found in the GitLab Package Registry for PyPI.
        """
        return pulumi.get(self, "pypi_package_requests_forwarding")

    @pypi_package_requests_forwarding.setter
    def pypi_package_requests_forwarding(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "pypi_package_requests_forwarding", value)

    @_builtins.property
    @pulumi.getter(name="rateLimitingResponseText")
    def rate_limiting_response_text(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        When rate limiting is enabled via the throttle_* settings, send this plain text response when a rate limit is exceeded. ‘Retry later’ is sent if this is blank.
        """
        return pulumi.get(self, "rate_limiting_response_text")

    @rate_limiting_response_text.setter
    def rate_limiting_response_text(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "rate_limiting_response_text", value)

    @_builtins.property
    @pulumi.getter(name="rawBlobRequestLimit")
    def raw_blob_request_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Max number of requests per minute for each raw path. To disable throttling set to 0.
        """
        return pulumi.get(self, "raw_blob_request_limit")

    @raw_blob_request_limit.setter
    def raw_blob_request_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "raw_blob_request_limit", value)

    @_builtins.property
    @pulumi.getter(name="recaptchaEnabled")
    def recaptcha_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: recaptcha*private*key and recaptcha*site*key) Enable reCAPTCHA.
        """
        return pulumi.get(self, "recaptcha_enabled")

    @recaptcha_enabled.setter
    def recaptcha_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "recaptcha_enabled", value)

    @_builtins.property
    @pulumi.getter(name="recaptchaPrivateKey")
    def recaptcha_private_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Private key for reCAPTCHA.
        """
        return pulumi.get(self, "recaptcha_private_key")

    @recaptcha_private_key.setter
    def recaptcha_private_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "recaptcha_private_key", value)

    @_builtins.property
    @pulumi.getter(name="recaptchaSiteKey")
    def recaptcha_site_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Site key for reCAPTCHA.
        """
        return pulumi.get(self, "recaptcha_site_key")

    @recaptcha_site_key.setter
    def recaptcha_site_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "recaptcha_site_key", value)

    @_builtins.property
    @pulumi.getter(name="receiveMaxInputSize")
    def receive_max_input_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum push size (MB).
        """
        return pulumi.get(self, "receive_max_input_size")

    @receive_max_input_size.setter
    def receive_max_input_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "receive_max_input_size", value)

    @_builtins.property
    @pulumi.getter(name="receptiveClusterAgentsEnabled")
    def receptive_cluster_agents_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable receptive mode for GitLab Agents for Kubernetes.
        """
        return pulumi.get(self, "receptive_cluster_agents_enabled")

    @receptive_cluster_agents_enabled.setter
    def receptive_cluster_agents_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "receptive_cluster_agents_enabled", value)

    @_builtins.property
    @pulumi.getter(name="rememberMeEnabled")
    def remember_me_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable Remember me setting.
        """
        return pulumi.get(self, "remember_me_enabled")

    @remember_me_enabled.setter
    def remember_me_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "remember_me_enabled", value)

    @_builtins.property
    @pulumi.getter(name="repositoryChecksEnabled")
    def repository_checks_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        GitLab periodically runs git fsck in all project and wiki repositories to look for silent disk corruption issues.
        """
        return pulumi.get(self, "repository_checks_enabled")

    @repository_checks_enabled.setter
    def repository_checks_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "repository_checks_enabled", value)

    @_builtins.property
    @pulumi.getter(name="repositorySizeLimit")
    def repository_size_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Size limit per repository (MB).
        """
        return pulumi.get(self, "repository_size_limit")

    @repository_size_limit.setter
    def repository_size_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "repository_size_limit", value)

    @_builtins.property
    @pulumi.getter(name="repositoryStoragesWeighted")
    def repository_storages_weighted(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.int]]]]:
        """
        Hash of names taken from gitlab.yml to weights. New projects are created in one of these stores, chosen by a weighted random selection.
        """
        return pulumi.get(self, "repository_storages_weighted")

    @repository_storages_weighted.setter
    def repository_storages_weighted(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.int]]]]):
        pulumi.set(self, "repository_storages_weighted", value)

    @_builtins.property
    @pulumi.getter(name="requireAdminApprovalAfterUserSignup")
    def require_admin_approval_after_user_signup(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When enabled, any user that signs up for an account using the registration form is placed under a Pending approval state and has to be explicitly approved by an administrator.
        """
        return pulumi.get(self, "require_admin_approval_after_user_signup")

    @require_admin_approval_after_user_signup.setter
    def require_admin_approval_after_user_signup(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "require_admin_approval_after_user_signup", value)

    @_builtins.property
    @pulumi.getter(name="requireAdminTwoFactorAuthentication")
    def require_admin_two_factor_authentication(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow administrators to require 2FA for all administrators on the instance.
        """
        return pulumi.get(self, "require_admin_two_factor_authentication")

    @require_admin_two_factor_authentication.setter
    def require_admin_two_factor_authentication(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "require_admin_two_factor_authentication", value)

    @_builtins.property
    @pulumi.getter(name="requirePersonalAccessTokenExpiry")
    def require_personal_access_token_expiry(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When enabled, users must set an expiration date when creating a group or project access token, or a personal access token owned by a non-service account.
        """
        return pulumi.get(self, "require_personal_access_token_expiry")

    @require_personal_access_token_expiry.setter
    def require_personal_access_token_expiry(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "require_personal_access_token_expiry", value)

    @_builtins.property
    @pulumi.getter(name="requireTwoFactorAuthentication")
    def require_two_factor_authentication(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: two*factor*grace_period) Require all users to set up Two-factor authentication.
        """
        return pulumi.get(self, "require_two_factor_authentication")

    @require_two_factor_authentication.setter
    def require_two_factor_authentication(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "require_two_factor_authentication", value)

    @_builtins.property
    @pulumi.getter(name="restrictedVisibilityLevels")
    def restricted_visibility_levels(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Selected levels cannot be used by non-Administrator users for groups, projects or snippets. Can take private, internal and public as a parameter. Null means there is no restriction.
        """
        return pulumi.get(self, "restricted_visibility_levels")

    @restricted_visibility_levels.setter
    def restricted_visibility_levels(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "restricted_visibility_levels", value)

    @_builtins.property
    @pulumi.getter(name="rsaKeyRestriction")
    def rsa_key_restriction(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The minimum allowed bit length of an uploaded RSA key. 0 means no restriction. -1 disables RSA keys.
        """
        return pulumi.get(self, "rsa_key_restriction")

    @rsa_key_restriction.setter
    def rsa_key_restriction(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "rsa_key_restriction", value)

    @_builtins.property
    @pulumi.getter(name="searchRateLimit")
    def search_rate_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Max number of requests per minute for performing a search while authenticated. To disable throttling set to 0.
        """
        return pulumi.get(self, "search_rate_limit")

    @search_rate_limit.setter
    def search_rate_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "search_rate_limit", value)

    @_builtins.property
    @pulumi.getter(name="searchRateLimitUnauthenticated")
    def search_rate_limit_unauthenticated(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Max number of requests per minute for performing a search while unauthenticated. To disable throttling set to 0.
        """
        return pulumi.get(self, "search_rate_limit_unauthenticated")

    @search_rate_limit_unauthenticated.setter
    def search_rate_limit_unauthenticated(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "search_rate_limit_unauthenticated", value)

    @_builtins.property
    @pulumi.getter(name="securityApprovalPoliciesLimit")
    def security_approval_policies_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum number of active merge request approval policies per security policy project. Maximum: 20
        """
        return pulumi.get(self, "security_approval_policies_limit")

    @security_approval_policies_limit.setter
    def security_approval_policies_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "security_approval_policies_limit", value)

    @_builtins.property
    @pulumi.getter(name="securityPolicyGlobalGroupApproversEnabled")
    def security_policy_global_group_approvers_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to look up merge request approval policy approval groups globally or within project hierarchies.
        """
        return pulumi.get(self, "security_policy_global_group_approvers_enabled")

    @security_policy_global_group_approvers_enabled.setter
    def security_policy_global_group_approvers_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "security_policy_global_group_approvers_enabled", value)

    @_builtins.property
    @pulumi.getter(name="securityTxtContent")
    def security_txt_content(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Public security contact information.
        """
        return pulumi.get(self, "security_txt_content")

    @security_txt_content.setter
    def security_txt_content(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "security_txt_content", value)

    @_builtins.property
    @pulumi.getter(name="sendUserConfirmationEmail")
    def send_user_confirmation_email(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Send confirmation email on sign-up.
        """
        return pulumi.get(self, "send_user_confirmation_email")

    @send_user_confirmation_email.setter
    def send_user_confirmation_email(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "send_user_confirmation_email", value)

    @_builtins.property
    @pulumi.getter(name="serviceAccessTokensExpirationEnforced")
    def service_access_tokens_expiration_enforced(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Flag to indicate if token expiry date can be optional for service account users
        """
        return pulumi.get(self, "service_access_tokens_expiration_enforced")

    @service_access_tokens_expiration_enforced.setter
    def service_access_tokens_expiration_enforced(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "service_access_tokens_expiration_enforced", value)

    @_builtins.property
    @pulumi.getter(name="sessionExpireDelay")
    def session_expire_delay(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Session duration in minutes. GitLab restart is required to apply changes.
        """
        return pulumi.get(self, "session_expire_delay")

    @session_expire_delay.setter
    def session_expire_delay(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "session_expire_delay", value)

    @_builtins.property
    @pulumi.getter(name="sharedRunnersEnabled")
    def shared_runners_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: shared*runners*text and shared*runners*minutes) Enable shared runners for new projects.
        """
        return pulumi.get(self, "shared_runners_enabled")

    @shared_runners_enabled.setter
    def shared_runners_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "shared_runners_enabled", value)

    @_builtins.property
    @pulumi.getter(name="sharedRunnersMinutes")
    def shared_runners_minutes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Set the maximum number of CI/CD minutes that a group can use on shared runners per month.
        """
        return pulumi.get(self, "shared_runners_minutes")

    @shared_runners_minutes.setter
    def shared_runners_minutes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "shared_runners_minutes", value)

    @_builtins.property
    @pulumi.getter(name="sharedRunnersText")
    def shared_runners_text(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Shared runners text.
        """
        return pulumi.get(self, "shared_runners_text")

    @shared_runners_text.setter
    def shared_runners_text(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "shared_runners_text", value)

    @_builtins.property
    @pulumi.getter(name="sidekiqJobLimiterCompressionThresholdBytes")
    def sidekiq_job_limiter_compression_threshold_bytes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The threshold in bytes at which Sidekiq jobs are compressed before being stored in Redis.
        """
        return pulumi.get(self, "sidekiq_job_limiter_compression_threshold_bytes")

    @sidekiq_job_limiter_compression_threshold_bytes.setter
    def sidekiq_job_limiter_compression_threshold_bytes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "sidekiq_job_limiter_compression_threshold_bytes", value)

    @_builtins.property
    @pulumi.getter(name="sidekiqJobLimiterLimitBytes")
    def sidekiq_job_limiter_limit_bytes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The threshold in bytes at which Sidekiq jobs are rejected. 0 means do not reject any job.
        """
        return pulumi.get(self, "sidekiq_job_limiter_limit_bytes")

    @sidekiq_job_limiter_limit_bytes.setter
    def sidekiq_job_limiter_limit_bytes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "sidekiq_job_limiter_limit_bytes", value)

    @_builtins.property
    @pulumi.getter(name="sidekiqJobLimiterMode")
    def sidekiq_job_limiter_mode(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        track or compress. Sets the behavior for Sidekiq job size limits.
        """
        return pulumi.get(self, "sidekiq_job_limiter_mode")

    @sidekiq_job_limiter_mode.setter
    def sidekiq_job_limiter_mode(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sidekiq_job_limiter_mode", value)

    @_builtins.property
    @pulumi.getter(name="signInText")
    def sign_in_text(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Text on the login page.
        """
        return pulumi.get(self, "sign_in_text")

    @sign_in_text.setter
    def sign_in_text(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sign_in_text", value)

    @_builtins.property
    @pulumi.getter(name="signupEnabled")
    def signup_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable registration.
        """
        return pulumi.get(self, "signup_enabled")

    @signup_enabled.setter
    def signup_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "signup_enabled", value)

    @_builtins.property
    @pulumi.getter(name="silentAdminExportsEnabled")
    def silent_admin_exports_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable Silent admin exports.
        """
        return pulumi.get(self, "silent_admin_exports_enabled")

    @silent_admin_exports_enabled.setter
    def silent_admin_exports_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "silent_admin_exports_enabled", value)

    @_builtins.property
    @pulumi.getter(name="silentModeEnabled")
    def silent_mode_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable Silent mode.
        """
        return pulumi.get(self, "silent_mode_enabled")

    @silent_mode_enabled.setter
    def silent_mode_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "silent_mode_enabled", value)

    @_builtins.property
    @pulumi.getter(name="slackAppEnabled")
    def slack_app_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: slack*app*id, slack*app*secret and slack*app*secret) Enable Slack app.
        """
        return pulumi.get(self, "slack_app_enabled")

    @slack_app_enabled.setter
    def slack_app_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "slack_app_enabled", value)

    @_builtins.property
    @pulumi.getter(name="slackAppId")
    def slack_app_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The app ID of the Slack-app.
        """
        return pulumi.get(self, "slack_app_id")

    @slack_app_id.setter
    def slack_app_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "slack_app_id", value)

    @_builtins.property
    @pulumi.getter(name="slackAppSecret")
    def slack_app_secret(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The app secret of the Slack-app.
        """
        return pulumi.get(self, "slack_app_secret")

    @slack_app_secret.setter
    def slack_app_secret(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "slack_app_secret", value)

    @_builtins.property
    @pulumi.getter(name="slackAppSigningSecret")
    def slack_app_signing_secret(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The signing secret of the Slack-app.
        """
        return pulumi.get(self, "slack_app_signing_secret")

    @slack_app_signing_secret.setter
    def slack_app_signing_secret(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "slack_app_signing_secret", value)

    @_builtins.property
    @pulumi.getter(name="slackAppVerificationToken")
    def slack_app_verification_token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The verification token of the Slack-app.
        """
        return pulumi.get(self, "slack_app_verification_token")

    @slack_app_verification_token.setter
    def slack_app_verification_token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "slack_app_verification_token", value)

    @_builtins.property
    @pulumi.getter(name="snippetSizeLimit")
    def snippet_size_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Max snippet content size in bytes.
        """
        return pulumi.get(self, "snippet_size_limit")

    @snippet_size_limit.setter
    def snippet_size_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "snippet_size_limit", value)

    @_builtins.property
    @pulumi.getter(name="snowplowAppId")
    def snowplow_app_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Snowplow site name / application ID. (for example, gitlab)
        """
        return pulumi.get(self, "snowplow_app_id")

    @snowplow_app_id.setter
    def snowplow_app_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "snowplow_app_id", value)

    @_builtins.property
    @pulumi.getter(name="snowplowCollectorHostname")
    def snowplow_collector_hostname(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Snowplow collector hostname. (for example, snowplow.trx.gitlab.net)
        """
        return pulumi.get(self, "snowplow_collector_hostname")

    @snowplow_collector_hostname.setter
    def snowplow_collector_hostname(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "snowplow_collector_hostname", value)

    @_builtins.property
    @pulumi.getter(name="snowplowCookieDomain")
    def snowplow_cookie_domain(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Snowplow cookie domain. (for example, .gitlab.com)
        """
        return pulumi.get(self, "snowplow_cookie_domain")

    @snowplow_cookie_domain.setter
    def snowplow_cookie_domain(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "snowplow_cookie_domain", value)

    @_builtins.property
    @pulumi.getter(name="snowplowDatabaseCollectorHostname")
    def snowplow_database_collector_hostname(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Snowplow collector for database events hostname. (for example, db-snowplow.trx.gitlab.net)
        """
        return pulumi.get(self, "snowplow_database_collector_hostname")

    @snowplow_database_collector_hostname.setter
    def snowplow_database_collector_hostname(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "snowplow_database_collector_hostname", value)

    @_builtins.property
    @pulumi.getter(name="snowplowEnabled")
    def snowplow_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable snowplow tracking.
        """
        return pulumi.get(self, "snowplow_enabled")

    @snowplow_enabled.setter
    def snowplow_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "snowplow_enabled", value)

    @_builtins.property
    @pulumi.getter(name="sourcegraphEnabled")
    def sourcegraph_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enables Sourcegraph integration. If enabled, requires sourcegraph_url.
        """
        return pulumi.get(self, "sourcegraph_enabled")

    @sourcegraph_enabled.setter
    def sourcegraph_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "sourcegraph_enabled", value)

    @_builtins.property
    @pulumi.getter(name="sourcegraphPublicOnly")
    def sourcegraph_public_only(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Blocks Sourcegraph from being loaded on private and internal projects.
        """
        return pulumi.get(self, "sourcegraph_public_only")

    @sourcegraph_public_only.setter
    def sourcegraph_public_only(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "sourcegraph_public_only", value)

    @_builtins.property
    @pulumi.getter(name="sourcegraphUrl")
    def sourcegraph_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Sourcegraph instance URL for integration.
        """
        return pulumi.get(self, "sourcegraph_url")

    @sourcegraph_url.setter
    def sourcegraph_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sourcegraph_url", value)

    @_builtins.property
    @pulumi.getter(name="spamCheckApiKey")
    def spam_check_api_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        API key used by GitLab for accessing the Spam Check service endpoint.
        """
        return pulumi.get(self, "spam_check_api_key")

    @spam_check_api_key.setter
    def spam_check_api_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "spam_check_api_key", value)

    @_builtins.property
    @pulumi.getter(name="spamCheckEndpointEnabled")
    def spam_check_endpoint_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enables spam checking using external Spam Check API endpoint.
        """
        return pulumi.get(self, "spam_check_endpoint_enabled")

    @spam_check_endpoint_enabled.setter
    def spam_check_endpoint_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "spam_check_endpoint_enabled", value)

    @_builtins.property
    @pulumi.getter(name="spamCheckEndpointUrl")
    def spam_check_endpoint_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        URL of the external Spamcheck service endpoint. Valid URI schemes are grpc or tls. Specifying tls forces communication to be encrypted.
        """
        return pulumi.get(self, "spam_check_endpoint_url")

    @spam_check_endpoint_url.setter
    def spam_check_endpoint_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "spam_check_endpoint_url", value)

    @_builtins.property
    @pulumi.getter(name="staticObjectsExternalStorageAuthToken")
    def static_objects_external_storage_auth_token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Authentication token for the external storage linked in static*objects*external*storage*url.
        """
        return pulumi.get(self, "static_objects_external_storage_auth_token")

    @static_objects_external_storage_auth_token.setter
    def static_objects_external_storage_auth_token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "static_objects_external_storage_auth_token", value)

    @_builtins.property
    @pulumi.getter(name="staticObjectsExternalStorageUrl")
    def static_objects_external_storage_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        URL to an external storage for repository static objects.
        """
        return pulumi.get(self, "static_objects_external_storage_url")

    @static_objects_external_storage_url.setter
    def static_objects_external_storage_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "static_objects_external_storage_url", value)

    @_builtins.property
    @pulumi.getter(name="suggestPipelineEnabled")
    def suggest_pipeline_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable pipeline suggestion banner.
        """
        return pulumi.get(self, "suggest_pipeline_enabled")

    @suggest_pipeline_enabled.setter
    def suggest_pipeline_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "suggest_pipeline_enabled", value)

    @_builtins.property
    @pulumi.getter(name="terminalMaxSessionTime")
    def terminal_max_session_time(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum time for web terminal websocket connection (in seconds). Set to 0 for unlimited time.
        """
        return pulumi.get(self, "terminal_max_session_time")

    @terminal_max_session_time.setter
    def terminal_max_session_time(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "terminal_max_session_time", value)

    @_builtins.property
    @pulumi.getter
    def terms(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Required by: enforce_terms) Markdown content for the ToS.
        """
        return pulumi.get(self, "terms")

    @terms.setter
    def terms(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "terms", value)

    @_builtins.property
    @pulumi.getter(name="throttleAuthenticatedApiEnabled")
    def throttle_authenticated_api_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: throttle*authenticated*api*period*in*seconds and throttle*authenticated*api*requests*per*period) Enable authenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        """
        return pulumi.get(self, "throttle_authenticated_api_enabled")

    @throttle_authenticated_api_enabled.setter
    def throttle_authenticated_api_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "throttle_authenticated_api_enabled", value)

    @_builtins.property
    @pulumi.getter(name="throttleAuthenticatedApiPeriodInSeconds")
    def throttle_authenticated_api_period_in_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Rate limit period (in seconds).
        """
        return pulumi.get(self, "throttle_authenticated_api_period_in_seconds")

    @throttle_authenticated_api_period_in_seconds.setter
    def throttle_authenticated_api_period_in_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "throttle_authenticated_api_period_in_seconds", value)

    @_builtins.property
    @pulumi.getter(name="throttleAuthenticatedApiRequestsPerPeriod")
    def throttle_authenticated_api_requests_per_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum requests per period per user.
        """
        return pulumi.get(self, "throttle_authenticated_api_requests_per_period")

    @throttle_authenticated_api_requests_per_period.setter
    def throttle_authenticated_api_requests_per_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "throttle_authenticated_api_requests_per_period", value)

    @_builtins.property
    @pulumi.getter(name="throttleAuthenticatedPackagesApiEnabled")
    def throttle_authenticated_packages_api_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: throttle*authenticated*packages*api*period*in*seconds and throttle*authenticated*packages*api*requests*per*period) Enable authenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots). View Package Registry rate limits for more details.
        """
        return pulumi.get(self, "throttle_authenticated_packages_api_enabled")

    @throttle_authenticated_packages_api_enabled.setter
    def throttle_authenticated_packages_api_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "throttle_authenticated_packages_api_enabled", value)

    @_builtins.property
    @pulumi.getter(name="throttleAuthenticatedPackagesApiPeriodInSeconds")
    def throttle_authenticated_packages_api_period_in_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Rate limit period (in seconds). View Package Registry rate limits for more details.
        """
        return pulumi.get(self, "throttle_authenticated_packages_api_period_in_seconds")

    @throttle_authenticated_packages_api_period_in_seconds.setter
    def throttle_authenticated_packages_api_period_in_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "throttle_authenticated_packages_api_period_in_seconds", value)

    @_builtins.property
    @pulumi.getter(name="throttleAuthenticatedPackagesApiRequestsPerPeriod")
    def throttle_authenticated_packages_api_requests_per_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum requests per period per user. View Package Registry rate limits for more details.
        """
        return pulumi.get(self, "throttle_authenticated_packages_api_requests_per_period")

    @throttle_authenticated_packages_api_requests_per_period.setter
    def throttle_authenticated_packages_api_requests_per_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "throttle_authenticated_packages_api_requests_per_period", value)

    @_builtins.property
    @pulumi.getter(name="throttleAuthenticatedWebEnabled")
    def throttle_authenticated_web_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: throttle*authenticated*web*period*in*seconds and throttle*authenticated*web*requests*per*period) Enable authenticated web request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        """
        return pulumi.get(self, "throttle_authenticated_web_enabled")

    @throttle_authenticated_web_enabled.setter
    def throttle_authenticated_web_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "throttle_authenticated_web_enabled", value)

    @_builtins.property
    @pulumi.getter(name="throttleAuthenticatedWebPeriodInSeconds")
    def throttle_authenticated_web_period_in_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Rate limit period (in seconds).
        """
        return pulumi.get(self, "throttle_authenticated_web_period_in_seconds")

    @throttle_authenticated_web_period_in_seconds.setter
    def throttle_authenticated_web_period_in_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "throttle_authenticated_web_period_in_seconds", value)

    @_builtins.property
    @pulumi.getter(name="throttleAuthenticatedWebRequestsPerPeriod")
    def throttle_authenticated_web_requests_per_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum requests per period per user.
        """
        return pulumi.get(self, "throttle_authenticated_web_requests_per_period")

    @throttle_authenticated_web_requests_per_period.setter
    def throttle_authenticated_web_requests_per_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "throttle_authenticated_web_requests_per_period", value)

    @_builtins.property
    @pulumi.getter(name="throttleUnauthenticatedApiEnabled")
    def throttle_unauthenticated_api_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: throttle*unauthenticated*api*period*in*seconds and throttle*unauthenticated*api*requests*per*period) Enable unauthenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        """
        return pulumi.get(self, "throttle_unauthenticated_api_enabled")

    @throttle_unauthenticated_api_enabled.setter
    def throttle_unauthenticated_api_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "throttle_unauthenticated_api_enabled", value)

    @_builtins.property
    @pulumi.getter(name="throttleUnauthenticatedApiPeriodInSeconds")
    def throttle_unauthenticated_api_period_in_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Rate limit period in seconds.
        """
        return pulumi.get(self, "throttle_unauthenticated_api_period_in_seconds")

    @throttle_unauthenticated_api_period_in_seconds.setter
    def throttle_unauthenticated_api_period_in_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "throttle_unauthenticated_api_period_in_seconds", value)

    @_builtins.property
    @pulumi.getter(name="throttleUnauthenticatedApiRequestsPerPeriod")
    def throttle_unauthenticated_api_requests_per_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Max requests per period per IP.
        """
        return pulumi.get(self, "throttle_unauthenticated_api_requests_per_period")

    @throttle_unauthenticated_api_requests_per_period.setter
    def throttle_unauthenticated_api_requests_per_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "throttle_unauthenticated_api_requests_per_period", value)

    @_builtins.property
    @pulumi.getter(name="throttleUnauthenticatedPackagesApiEnabled")
    def throttle_unauthenticated_packages_api_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: throttle*unauthenticated*packages*api*period*in*seconds and throttle*unauthenticated*packages*api*requests*per*period) Enable authenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots). View Package Registry rate limits for more details.
        """
        return pulumi.get(self, "throttle_unauthenticated_packages_api_enabled")

    @throttle_unauthenticated_packages_api_enabled.setter
    def throttle_unauthenticated_packages_api_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "throttle_unauthenticated_packages_api_enabled", value)

    @_builtins.property
    @pulumi.getter(name="throttleUnauthenticatedPackagesApiPeriodInSeconds")
    def throttle_unauthenticated_packages_api_period_in_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Rate limit period (in seconds). View Package Registry rate limits for more details.
        """
        return pulumi.get(self, "throttle_unauthenticated_packages_api_period_in_seconds")

    @throttle_unauthenticated_packages_api_period_in_seconds.setter
    def throttle_unauthenticated_packages_api_period_in_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "throttle_unauthenticated_packages_api_period_in_seconds", value)

    @_builtins.property
    @pulumi.getter(name="throttleUnauthenticatedPackagesApiRequestsPerPeriod")
    def throttle_unauthenticated_packages_api_requests_per_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum requests per period per user. View Package Registry rate limits for more details.
        """
        return pulumi.get(self, "throttle_unauthenticated_packages_api_requests_per_period")

    @throttle_unauthenticated_packages_api_requests_per_period.setter
    def throttle_unauthenticated_packages_api_requests_per_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "throttle_unauthenticated_packages_api_requests_per_period", value)

    @_builtins.property
    @pulumi.getter(name="throttleUnauthenticatedWebEnabled")
    def throttle_unauthenticated_web_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: throttle*unauthenticated*web*period*in*seconds and throttle*unauthenticated*web*requests*per*period) Enable unauthenticated web request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        """
        return pulumi.get(self, "throttle_unauthenticated_web_enabled")

    @throttle_unauthenticated_web_enabled.setter
    def throttle_unauthenticated_web_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "throttle_unauthenticated_web_enabled", value)

    @_builtins.property
    @pulumi.getter(name="throttleUnauthenticatedWebPeriodInSeconds")
    def throttle_unauthenticated_web_period_in_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Rate limit period in seconds.
        """
        return pulumi.get(self, "throttle_unauthenticated_web_period_in_seconds")

    @throttle_unauthenticated_web_period_in_seconds.setter
    def throttle_unauthenticated_web_period_in_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "throttle_unauthenticated_web_period_in_seconds", value)

    @_builtins.property
    @pulumi.getter(name="throttleUnauthenticatedWebRequestsPerPeriod")
    def throttle_unauthenticated_web_requests_per_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Max requests per period per IP.
        """
        return pulumi.get(self, "throttle_unauthenticated_web_requests_per_period")

    @throttle_unauthenticated_web_requests_per_period.setter
    def throttle_unauthenticated_web_requests_per_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "throttle_unauthenticated_web_requests_per_period", value)

    @_builtins.property
    @pulumi.getter(name="timeTrackingLimitToHours")
    def time_tracking_limit_to_hours(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Limit display of time tracking units to hours.
        """
        return pulumi.get(self, "time_tracking_limit_to_hours")

    @time_tracking_limit_to_hours.setter
    def time_tracking_limit_to_hours(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "time_tracking_limit_to_hours", value)

    @_builtins.property
    @pulumi.getter(name="twoFactorGracePeriod")
    def two_factor_grace_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Amount of time (in hours) that users are allowed to skip forced configuration of two-factor authentication.
        """
        return pulumi.get(self, "two_factor_grace_period")

    @two_factor_grace_period.setter
    def two_factor_grace_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "two_factor_grace_period", value)

    @_builtins.property
    @pulumi.getter(name="unconfirmedUsersDeleteAfterDays")
    def unconfirmed_users_delete_after_days(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies how many days after sign-up to delete users who have not confirmed their email. Only applicable if delete*unconfirmed*users is set to true. Must be 1 or greater. Self-managed, Premium and Ultimate only.
        """
        return pulumi.get(self, "unconfirmed_users_delete_after_days")

    @unconfirmed_users_delete_after_days.setter
    def unconfirmed_users_delete_after_days(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "unconfirmed_users_delete_after_days", value)

    @_builtins.property
    @pulumi.getter(name="uniqueIpsLimitEnabled")
    def unique_ips_limit_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: unique*ips*limit*per*user and unique*ips*limit*time*window) Limit sign in from multiple IPs.
        """
        return pulumi.get(self, "unique_ips_limit_enabled")

    @unique_ips_limit_enabled.setter
    def unique_ips_limit_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "unique_ips_limit_enabled", value)

    @_builtins.property
    @pulumi.getter(name="uniqueIpsLimitPerUser")
    def unique_ips_limit_per_user(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum number of IPs per user.
        """
        return pulumi.get(self, "unique_ips_limit_per_user")

    @unique_ips_limit_per_user.setter
    def unique_ips_limit_per_user(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "unique_ips_limit_per_user", value)

    @_builtins.property
    @pulumi.getter(name="uniqueIpsLimitTimeWindow")
    def unique_ips_limit_time_window(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        How many seconds an IP is counted towards the limit.
        """
        return pulumi.get(self, "unique_ips_limit_time_window")

    @unique_ips_limit_time_window.setter
    def unique_ips_limit_time_window(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "unique_ips_limit_time_window", value)

    @_builtins.property
    @pulumi.getter(name="updateRunnerVersionsEnabled")
    def update_runner_versions_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Fetch GitLab Runner release version data from GitLab.com.
        """
        return pulumi.get(self, "update_runner_versions_enabled")

    @update_runner_versions_enabled.setter
    def update_runner_versions_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "update_runner_versions_enabled", value)

    @_builtins.property
    @pulumi.getter(name="usagePingEnabled")
    def usage_ping_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Every week GitLab reports license usage back to GitLab, Inc.
        """
        return pulumi.get(self, "usage_ping_enabled")

    @usage_ping_enabled.setter
    def usage_ping_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "usage_ping_enabled", value)

    @_builtins.property
    @pulumi.getter(name="useClickhouseForAnalytics")
    def use_clickhouse_for_analytics(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enables ClickHouse as a data source for analytics reports. ClickHouse must be configured for this setting to take effect. Available on Premium and Ultimate only.
        """
        return pulumi.get(self, "use_clickhouse_for_analytics")

    @use_clickhouse_for_analytics.setter
    def use_clickhouse_for_analytics(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "use_clickhouse_for_analytics", value)

    @_builtins.property
    @pulumi.getter(name="userDeactivationEmailsEnabled")
    def user_deactivation_emails_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Send an email to users upon account deactivation.
        """
        return pulumi.get(self, "user_deactivation_emails_enabled")

    @user_deactivation_emails_enabled.setter
    def user_deactivation_emails_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "user_deactivation_emails_enabled", value)

    @_builtins.property
    @pulumi.getter(name="userDefaultExternal")
    def user_default_external(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Newly registered users are external by default.
        """
        return pulumi.get(self, "user_default_external")

    @user_default_external.setter
    def user_default_external(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "user_default_external", value)

    @_builtins.property
    @pulumi.getter(name="userDefaultInternalRegex")
    def user_default_internal_regex(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specify an email address regex pattern to identify default internal users.
        """
        return pulumi.get(self, "user_default_internal_regex")

    @user_default_internal_regex.setter
    def user_default_internal_regex(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_default_internal_regex", value)

    @_builtins.property
    @pulumi.getter(name="userDefaultsToPrivateProfile")
    def user_defaults_to_private_profile(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Newly created users have private profile by default.
        """
        return pulumi.get(self, "user_defaults_to_private_profile")

    @user_defaults_to_private_profile.setter
    def user_defaults_to_private_profile(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "user_defaults_to_private_profile", value)

    @_builtins.property
    @pulumi.getter(name="userOauthApplications")
    def user_oauth_applications(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow users to register any application to use GitLab as an OAuth provider.
        """
        return pulumi.get(self, "user_oauth_applications")

    @user_oauth_applications.setter
    def user_oauth_applications(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "user_oauth_applications", value)

    @_builtins.property
    @pulumi.getter(name="userShowAddSshKeyMessage")
    def user_show_add_ssh_key_message(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When set to false disable the You won't be able to pull or push project code via SSH warning shown to users with no uploaded SSH key.
        """
        return pulumi.get(self, "user_show_add_ssh_key_message")

    @user_show_add_ssh_key_message.setter
    def user_show_add_ssh_key_message(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "user_show_add_ssh_key_message", value)

    @_builtins.property
    @pulumi.getter(name="validRunnerRegistrars")
    def valid_runner_registrars(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of types which are allowed to register a GitLab Runner. Can be [], ['group'], ['project'] or ['group', 'project'].
        """
        return pulumi.get(self, "valid_runner_registrars")

    @valid_runner_registrars.setter
    def valid_runner_registrars(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "valid_runner_registrars", value)

    @_builtins.property
    @pulumi.getter(name="versionCheckEnabled")
    def version_check_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Let GitLab inform you when an update is available.
        """
        return pulumi.get(self, "version_check_enabled")

    @version_check_enabled.setter
    def version_check_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "version_check_enabled", value)

    @_builtins.property
    @pulumi.getter(name="webIdeClientsidePreviewEnabled")
    def web_ide_clientside_preview_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Live Preview (allow live previews of JavaScript projects in the Web IDE using CodeSandbox Live Preview).
        """
        return pulumi.get(self, "web_ide_clientside_preview_enabled")

    @web_ide_clientside_preview_enabled.setter
    def web_ide_clientside_preview_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "web_ide_clientside_preview_enabled", value)

    @_builtins.property
    @pulumi.getter(name="whatsNewVariant")
    def whats_new_variant(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        What's new variant, possible values: all*tiers, current*tier, and disabled.
        """
        return pulumi.get(self, "whats_new_variant")

    @whats_new_variant.setter
    def whats_new_variant(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "whats_new_variant", value)

    @_builtins.property
    @pulumi.getter(name="wikiPageMaxContentBytes")
    def wiki_page_max_content_bytes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum wiki page content size in bytes. The minimum value is 1024 bytes.
        """
        return pulumi.get(self, "wiki_page_max_content_bytes")

    @wiki_page_max_content_bytes.setter
    def wiki_page_max_content_bytes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "wiki_page_max_content_bytes", value)


@pulumi.input_type
class _ApplicationSettingsState:
    def __init__(__self__, *,
                 abuse_notification_email: Optional[pulumi.Input[_builtins.str]] = None,
                 admin_mode: Optional[pulumi.Input[_builtins.bool]] = None,
                 after_sign_out_path: Optional[pulumi.Input[_builtins.str]] = None,
                 after_sign_up_text: Optional[pulumi.Input[_builtins.str]] = None,
                 akismet_api_key: Optional[pulumi.Input[_builtins.str]] = None,
                 akismet_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_account_deletion: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_group_owners_to_manage_ldap: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_local_requests_from_system_hooks: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_local_requests_from_web_hooks_and_services: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_project_creation_for_guest_and_below: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_runner_registration_token: Optional[pulumi.Input[_builtins.bool]] = None,
                 archive_builds_in_human_readable: Optional[pulumi.Input[_builtins.str]] = None,
                 asciidoc_max_includes: Optional[pulumi.Input[_builtins.int]] = None,
                 asset_proxy_allowlists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 asset_proxy_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 asset_proxy_secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 asset_proxy_url: Optional[pulumi.Input[_builtins.str]] = None,
                 authorized_keys_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 auto_ban_user_on_excessive_projects_download: Optional[pulumi.Input[_builtins.bool]] = None,
                 auto_devops_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 auto_devops_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 automatic_purchased_storage_allocation: Optional[pulumi.Input[_builtins.bool]] = None,
                 bulk_import_concurrent_pipeline_batch_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 bulk_import_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 bulk_import_max_download_file_size: Optional[pulumi.Input[_builtins.int]] = None,
                 can_create_group: Optional[pulumi.Input[_builtins.bool]] = None,
                 check_namespace_plan: Optional[pulumi.Input[_builtins.bool]] = None,
                 ci_max_includes: Optional[pulumi.Input[_builtins.int]] = None,
                 ci_max_total_yaml_size_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 commit_email_hostname: Optional[pulumi.Input[_builtins.str]] = None,
                 concurrent_bitbucket_import_jobs_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 concurrent_bitbucket_server_import_jobs_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 concurrent_github_import_jobs_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 container_expiration_policies_enable_historic_entries: Optional[pulumi.Input[_builtins.bool]] = None,
                 container_registry_cleanup_tags_service_max_list_size: Optional[pulumi.Input[_builtins.int]] = None,
                 container_registry_delete_tags_service_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 container_registry_expiration_policies_caching: Optional[pulumi.Input[_builtins.bool]] = None,
                 container_registry_expiration_policies_worker_capacity: Optional[pulumi.Input[_builtins.int]] = None,
                 container_registry_token_expire_delay: Optional[pulumi.Input[_builtins.int]] = None,
                 deactivate_dormant_users: Optional[pulumi.Input[_builtins.bool]] = None,
                 deactivate_dormant_users_period: Optional[pulumi.Input[_builtins.int]] = None,
                 decompress_archive_file_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 default_artifacts_expire_in: Optional[pulumi.Input[_builtins.str]] = None,
                 default_branch_name: Optional[pulumi.Input[_builtins.str]] = None,
                 default_branch_protection: Optional[pulumi.Input[_builtins.int]] = None,
                 default_branch_protection_defaults: Optional[pulumi.Input['ApplicationSettingsDefaultBranchProtectionDefaultsArgs']] = None,
                 default_ci_config_path: Optional[pulumi.Input[_builtins.str]] = None,
                 default_group_visibility: Optional[pulumi.Input[_builtins.str]] = None,
                 default_preferred_language: Optional[pulumi.Input[_builtins.str]] = None,
                 default_project_creation: Optional[pulumi.Input[_builtins.int]] = None,
                 default_project_visibility: Optional[pulumi.Input[_builtins.str]] = None,
                 default_projects_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 default_snippet_visibility: Optional[pulumi.Input[_builtins.str]] = None,
                 default_syntax_highlighting_theme: Optional[pulumi.Input[_builtins.int]] = None,
                 delete_inactive_projects: Optional[pulumi.Input[_builtins.bool]] = None,
                 delete_unconfirmed_users: Optional[pulumi.Input[_builtins.bool]] = None,
                 deletion_adjourned_period: Optional[pulumi.Input[_builtins.int]] = None,
                 diagramsnet_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 diagramsnet_url: Optional[pulumi.Input[_builtins.str]] = None,
                 diff_max_files: Optional[pulumi.Input[_builtins.int]] = None,
                 diff_max_lines: Optional[pulumi.Input[_builtins.int]] = None,
                 diff_max_patch_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 disable_admin_oauth_scopes: Optional[pulumi.Input[_builtins.bool]] = None,
                 disable_feed_token: Optional[pulumi.Input[_builtins.bool]] = None,
                 disable_personal_access_tokens: Optional[pulumi.Input[_builtins.bool]] = None,
                 disabled_oauth_sign_in_sources: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dns_rebinding_protection_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 domain_allowlists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 domain_denylist_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 domain_denylists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 downstream_pipeline_trigger_limit_per_project_user_sha: Optional[pulumi.Input[_builtins.int]] = None,
                 dsa_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
                 duo_features_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 ecdsa_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
                 ecdsa_sk_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
                 ed25519_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
                 ed25519_sk_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
                 eks_access_key_id: Optional[pulumi.Input[_builtins.str]] = None,
                 eks_account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 eks_integration_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 eks_secret_access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 elasticsearch_aws: Optional[pulumi.Input[_builtins.bool]] = None,
                 elasticsearch_aws_access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 elasticsearch_aws_region: Optional[pulumi.Input[_builtins.str]] = None,
                 elasticsearch_aws_secret_access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 elasticsearch_indexed_field_length_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 elasticsearch_indexed_file_size_limit_kb: Optional[pulumi.Input[_builtins.int]] = None,
                 elasticsearch_indexing: Optional[pulumi.Input[_builtins.bool]] = None,
                 elasticsearch_limit_indexing: Optional[pulumi.Input[_builtins.bool]] = None,
                 elasticsearch_max_bulk_concurrency: Optional[pulumi.Input[_builtins.int]] = None,
                 elasticsearch_max_bulk_size_mb: Optional[pulumi.Input[_builtins.int]] = None,
                 elasticsearch_max_code_indexing_concurrency: Optional[pulumi.Input[_builtins.int]] = None,
                 elasticsearch_namespace_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 elasticsearch_password: Optional[pulumi.Input[_builtins.str]] = None,
                 elasticsearch_project_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 elasticsearch_requeue_workers: Optional[pulumi.Input[_builtins.bool]] = None,
                 elasticsearch_search: Optional[pulumi.Input[_builtins.bool]] = None,
                 elasticsearch_urls: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 elasticsearch_username: Optional[pulumi.Input[_builtins.str]] = None,
                 elasticsearch_worker_number_of_shards: Optional[pulumi.Input[_builtins.int]] = None,
                 email_additional_text: Optional[pulumi.Input[_builtins.str]] = None,
                 email_author_in_body: Optional[pulumi.Input[_builtins.bool]] = None,
                 email_confirmation_setting: Optional[pulumi.Input[_builtins.str]] = None,
                 enable_artifact_external_redirect_warning_page: Optional[pulumi.Input[_builtins.bool]] = None,
                 enabled_git_access_protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 enforce_namespace_storage_limit: Optional[pulumi.Input[_builtins.bool]] = None,
                 enforce_terms: Optional[pulumi.Input[_builtins.bool]] = None,
                 external_auth_client_cert: Optional[pulumi.Input[_builtins.str]] = None,
                 external_auth_client_key: Optional[pulumi.Input[_builtins.str]] = None,
                 external_auth_client_key_pass: Optional[pulumi.Input[_builtins.str]] = None,
                 external_authorization_service_default_label: Optional[pulumi.Input[_builtins.str]] = None,
                 external_authorization_service_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 external_authorization_service_timeout: Optional[pulumi.Input[_builtins.float]] = None,
                 external_authorization_service_url: Optional[pulumi.Input[_builtins.str]] = None,
                 external_pipeline_validation_service_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 external_pipeline_validation_service_token: Optional[pulumi.Input[_builtins.str]] = None,
                 external_pipeline_validation_service_url: Optional[pulumi.Input[_builtins.str]] = None,
                 failed_login_attempts_unlock_period_in_minutes: Optional[pulumi.Input[_builtins.int]] = None,
                 file_template_project_id: Optional[pulumi.Input[_builtins.int]] = None,
                 first_day_of_week: Optional[pulumi.Input[_builtins.int]] = None,
                 geo_node_allowed_ips: Optional[pulumi.Input[_builtins.str]] = None,
                 geo_status_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 git_rate_limit_users_alertlists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 git_rate_limit_users_allowlists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 git_two_factor_session_expiry: Optional[pulumi.Input[_builtins.int]] = None,
                 gitaly_timeout_default: Optional[pulumi.Input[_builtins.int]] = None,
                 gitaly_timeout_fast: Optional[pulumi.Input[_builtins.int]] = None,
                 gitaly_timeout_medium: Optional[pulumi.Input[_builtins.int]] = None,
                 gitlab_dedicated_instance: Optional[pulumi.Input[_builtins.bool]] = None,
                 gitlab_environment_toolkit_instance: Optional[pulumi.Input[_builtins.bool]] = None,
                 gitlab_shell_operation_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 gitpod_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 gitpod_url: Optional[pulumi.Input[_builtins.str]] = None,
                 globally_allowed_ips: Optional[pulumi.Input[_builtins.str]] = None,
                 grafana_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 grafana_url: Optional[pulumi.Input[_builtins.str]] = None,
                 gravatar_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 group_owners_can_manage_default_branch_protection: Optional[pulumi.Input[_builtins.bool]] = None,
                 help_page_hide_commercial_content: Optional[pulumi.Input[_builtins.bool]] = None,
                 help_page_support_url: Optional[pulumi.Input[_builtins.str]] = None,
                 help_page_text: Optional[pulumi.Input[_builtins.str]] = None,
                 help_text: Optional[pulumi.Input[_builtins.str]] = None,
                 hide_third_party_offers: Optional[pulumi.Input[_builtins.bool]] = None,
                 home_page_url: Optional[pulumi.Input[_builtins.str]] = None,
                 housekeeping_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 housekeeping_optimize_repository_period: Optional[pulumi.Input[_builtins.int]] = None,
                 html_emails_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 import_sources: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 in_product_marketing_emails_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 inactive_projects_delete_after_months: Optional[pulumi.Input[_builtins.int]] = None,
                 inactive_projects_min_size_mb: Optional[pulumi.Input[_builtins.int]] = None,
                 inactive_projects_send_warning_email_after_months: Optional[pulumi.Input[_builtins.int]] = None,
                 include_optional_metrics_in_service_ping: Optional[pulumi.Input[_builtins.bool]] = None,
                 invisible_captcha_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 issues_create_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 jira_connect_application_key: Optional[pulumi.Input[_builtins.str]] = None,
                 jira_connect_proxy_url: Optional[pulumi.Input[_builtins.str]] = None,
                 jira_connect_public_key_storage_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 keep_latest_artifact: Optional[pulumi.Input[_builtins.bool]] = None,
                 local_markdown_version: Optional[pulumi.Input[_builtins.int]] = None,
                 lock_duo_features_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 lock_memberships_to_ldap: Optional[pulumi.Input[_builtins.bool]] = None,
                 mailgun_events_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 mailgun_signing_key: Optional[pulumi.Input[_builtins.str]] = None,
                 maintenance_mode: Optional[pulumi.Input[_builtins.bool]] = None,
                 maintenance_mode_message: Optional[pulumi.Input[_builtins.str]] = None,
                 maven_package_requests_forwarding: Optional[pulumi.Input[_builtins.bool]] = None,
                 max_artifacts_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_attachment_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_decompressed_archive_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_export_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_import_remote_file_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_import_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_login_attempts: Optional[pulumi.Input[_builtins.int]] = None,
                 max_number_of_repository_downloads: Optional[pulumi.Input[_builtins.int]] = None,
                 max_number_of_repository_downloads_within_time_period: Optional[pulumi.Input[_builtins.int]] = None,
                 max_pages_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_personal_access_token_lifetime: Optional[pulumi.Input[_builtins.int]] = None,
                 max_ssh_key_lifetime: Optional[pulumi.Input[_builtins.int]] = None,
                 max_terraform_state_size_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 metrics_method_call_threshold: Optional[pulumi.Input[_builtins.int]] = None,
                 minimum_password_length: Optional[pulumi.Input[_builtins.int]] = None,
                 mirror_available: Optional[pulumi.Input[_builtins.bool]] = None,
                 mirror_capacity_threshold: Optional[pulumi.Input[_builtins.int]] = None,
                 mirror_max_capacity: Optional[pulumi.Input[_builtins.int]] = None,
                 mirror_max_delay: Optional[pulumi.Input[_builtins.int]] = None,
                 npm_package_requests_forwarding: Optional[pulumi.Input[_builtins.bool]] = None,
                 nuget_skip_metadata_url_validation: Optional[pulumi.Input[_builtins.bool]] = None,
                 outbound_local_requests_whitelists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 package_metadata_purl_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 package_registry_allow_anyone_to_pull_option: Optional[pulumi.Input[_builtins.bool]] = None,
                 package_registry_cleanup_policies_worker_capacity: Optional[pulumi.Input[_builtins.int]] = None,
                 pages_domain_verification_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 password_authentication_enabled_for_git: Optional[pulumi.Input[_builtins.bool]] = None,
                 password_authentication_enabled_for_web: Optional[pulumi.Input[_builtins.bool]] = None,
                 password_lowercase_required: Optional[pulumi.Input[_builtins.bool]] = None,
                 password_number_required: Optional[pulumi.Input[_builtins.bool]] = None,
                 password_symbol_required: Optional[pulumi.Input[_builtins.bool]] = None,
                 password_uppercase_required: Optional[pulumi.Input[_builtins.bool]] = None,
                 performance_bar_allowed_group_path: Optional[pulumi.Input[_builtins.str]] = None,
                 personal_access_token_prefix: Optional[pulumi.Input[_builtins.str]] = None,
                 pipeline_limit_per_project_user_sha: Optional[pulumi.Input[_builtins.int]] = None,
                 plantuml_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 plantuml_url: Optional[pulumi.Input[_builtins.str]] = None,
                 polling_interval_multiplier: Optional[pulumi.Input[_builtins.float]] = None,
                 project_export_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 project_jobs_api_rate_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 projects_api_rate_limit_unauthenticated: Optional[pulumi.Input[_builtins.int]] = None,
                 prometheus_metrics_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 protected_ci_variables: Optional[pulumi.Input[_builtins.bool]] = None,
                 push_event_activities_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 push_event_hooks_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 pypi_package_requests_forwarding: Optional[pulumi.Input[_builtins.bool]] = None,
                 rate_limiting_response_text: Optional[pulumi.Input[_builtins.str]] = None,
                 raw_blob_request_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 recaptcha_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 recaptcha_private_key: Optional[pulumi.Input[_builtins.str]] = None,
                 recaptcha_site_key: Optional[pulumi.Input[_builtins.str]] = None,
                 receive_max_input_size: Optional[pulumi.Input[_builtins.int]] = None,
                 receptive_cluster_agents_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 remember_me_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 repository_checks_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 repository_size_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 repository_storages_weighted: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.int]]]] = None,
                 require_admin_approval_after_user_signup: Optional[pulumi.Input[_builtins.bool]] = None,
                 require_admin_two_factor_authentication: Optional[pulumi.Input[_builtins.bool]] = None,
                 require_personal_access_token_expiry: Optional[pulumi.Input[_builtins.bool]] = None,
                 require_two_factor_authentication: Optional[pulumi.Input[_builtins.bool]] = None,
                 restricted_visibility_levels: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 rsa_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
                 search_rate_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 search_rate_limit_unauthenticated: Optional[pulumi.Input[_builtins.int]] = None,
                 security_approval_policies_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 security_policy_global_group_approvers_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 security_txt_content: Optional[pulumi.Input[_builtins.str]] = None,
                 send_user_confirmation_email: Optional[pulumi.Input[_builtins.bool]] = None,
                 service_access_tokens_expiration_enforced: Optional[pulumi.Input[_builtins.bool]] = None,
                 session_expire_delay: Optional[pulumi.Input[_builtins.int]] = None,
                 shared_runners_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 shared_runners_minutes: Optional[pulumi.Input[_builtins.int]] = None,
                 shared_runners_text: Optional[pulumi.Input[_builtins.str]] = None,
                 sidekiq_job_limiter_compression_threshold_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 sidekiq_job_limiter_limit_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 sidekiq_job_limiter_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 sign_in_text: Optional[pulumi.Input[_builtins.str]] = None,
                 signup_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 silent_admin_exports_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 silent_mode_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 slack_app_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 slack_app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 slack_app_secret: Optional[pulumi.Input[_builtins.str]] = None,
                 slack_app_signing_secret: Optional[pulumi.Input[_builtins.str]] = None,
                 slack_app_verification_token: Optional[pulumi.Input[_builtins.str]] = None,
                 snippet_size_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 snowplow_app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 snowplow_collector_hostname: Optional[pulumi.Input[_builtins.str]] = None,
                 snowplow_cookie_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 snowplow_database_collector_hostname: Optional[pulumi.Input[_builtins.str]] = None,
                 snowplow_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 sourcegraph_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 sourcegraph_public_only: Optional[pulumi.Input[_builtins.bool]] = None,
                 sourcegraph_url: Optional[pulumi.Input[_builtins.str]] = None,
                 spam_check_api_key: Optional[pulumi.Input[_builtins.str]] = None,
                 spam_check_endpoint_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 spam_check_endpoint_url: Optional[pulumi.Input[_builtins.str]] = None,
                 static_objects_external_storage_auth_token: Optional[pulumi.Input[_builtins.str]] = None,
                 static_objects_external_storage_url: Optional[pulumi.Input[_builtins.str]] = None,
                 suggest_pipeline_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 terminal_max_session_time: Optional[pulumi.Input[_builtins.int]] = None,
                 terms: Optional[pulumi.Input[_builtins.str]] = None,
                 throttle_authenticated_api_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 throttle_authenticated_api_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_authenticated_api_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_authenticated_packages_api_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 throttle_authenticated_packages_api_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_authenticated_packages_api_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_authenticated_web_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 throttle_authenticated_web_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_authenticated_web_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_unauthenticated_api_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 throttle_unauthenticated_api_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_unauthenticated_api_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_unauthenticated_packages_api_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 throttle_unauthenticated_packages_api_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_unauthenticated_packages_api_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_unauthenticated_web_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 throttle_unauthenticated_web_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_unauthenticated_web_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
                 time_tracking_limit_to_hours: Optional[pulumi.Input[_builtins.bool]] = None,
                 two_factor_grace_period: Optional[pulumi.Input[_builtins.int]] = None,
                 unconfirmed_users_delete_after_days: Optional[pulumi.Input[_builtins.int]] = None,
                 unique_ips_limit_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 unique_ips_limit_per_user: Optional[pulumi.Input[_builtins.int]] = None,
                 unique_ips_limit_time_window: Optional[pulumi.Input[_builtins.int]] = None,
                 update_runner_versions_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 usage_ping_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 use_clickhouse_for_analytics: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_deactivation_emails_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_default_external: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_default_internal_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 user_defaults_to_private_profile: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_oauth_applications: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_show_add_ssh_key_message: Optional[pulumi.Input[_builtins.bool]] = None,
                 valid_runner_registrars: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 version_check_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 web_ide_clientside_preview_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 whats_new_variant: Optional[pulumi.Input[_builtins.str]] = None,
                 wiki_page_max_content_bytes: Optional[pulumi.Input[_builtins.int]] = None):
        """
        Input properties used for looking up and filtering ApplicationSettings resources.
        :param pulumi.Input[_builtins.str] abuse_notification_email: If set, abuse reports are sent to this address. Abuse reports are always available in the Admin Area.
        :param pulumi.Input[_builtins.bool] admin_mode: Require administrators to enable Admin Mode by re-authenticating for administrative tasks.
        :param pulumi.Input[_builtins.str] after_sign_out_path: Where to redirect users after logout.
        :param pulumi.Input[_builtins.str] after_sign_up_text: Text shown to the user after signing up.
        :param pulumi.Input[_builtins.str] akismet_api_key: API key for Akismet spam protection.
        :param pulumi.Input[_builtins.bool] akismet_enabled: (If enabled, requires: akismet*api*key) Enable or disable Akismet spam protection.
        :param pulumi.Input[_builtins.bool] allow_account_deletion: Set to true to allow users to delete their accounts. Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] allow_group_owners_to_manage_ldap: Set to true to allow group owners to manage LDAP.
        :param pulumi.Input[_builtins.bool] allow_local_requests_from_system_hooks: Allow requests to the local network from system hooks.
        :param pulumi.Input[_builtins.bool] allow_local_requests_from_web_hooks_and_services: Allow requests to the local network from web hooks and services.
        :param pulumi.Input[_builtins.bool] allow_project_creation_for_guest_and_below: Indicates whether users assigned up to the Guest role can create groups and personal projects.
        :param pulumi.Input[_builtins.bool] allow_runner_registration_token: Allow using a registration token to create a runner.
        :param pulumi.Input[_builtins.str] archive_builds_in_human_readable: Set the duration for which the jobs are considered as old and expired. After that time passes, the jobs are archived and no longer able to be retried. Make it empty to never expire jobs. It has to be no less than 1 day, for example: 15 days, 1 month, 2 years.
        :param pulumi.Input[_builtins.int] asciidoc_max_includes: Maximum limit of AsciiDoc include directives being processed in any one document. Maximum: 64.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] asset_proxy_allowlists: Assets that match these domains are not proxied. Wildcards allowed. Your GitLab installation URL is automatically allowlisted. GitLab restart is required to apply changes.
        :param pulumi.Input[_builtins.bool] asset_proxy_enabled: (If enabled, requires: asset*proxy*url) Enable proxying of assets. GitLab restart is required to apply changes.
        :param pulumi.Input[_builtins.str] asset_proxy_secret_key: Shared secret with the asset proxy server. GitLab restart is required to apply changes.
        :param pulumi.Input[_builtins.str] asset_proxy_url: URL of the asset proxy server. GitLab restart is required to apply changes.
        :param pulumi.Input[_builtins.bool] authorized_keys_enabled: By default, we write to the authorized_keys file to support Git over SSH without additional configuration. GitLab can be optimized to authenticate SSH keys via the database file. Only disable this if you have configured your OpenSSH server to use the AuthorizedKeysCommand.
        :param pulumi.Input[_builtins.bool] auto_ban_user_on_excessive_projects_download: When enabled, users will get automatically banned from the application when they download more than the maximum number of unique projects in the time period specified by max*number*of*repository*downloads and max*number*of*repository*downloads*within*time_period respectively. Self-managed, Ultimate only.
        :param pulumi.Input[_builtins.str] auto_devops_domain: Specify a domain to use by default for every project’s Auto Review Apps and Auto Deploy stages.
        :param pulumi.Input[_builtins.bool] auto_devops_enabled: Enable Auto DevOps for projects by default. It automatically builds, tests, and deploys applications based on a predefined CI/CD configuration.
        :param pulumi.Input[_builtins.bool] automatic_purchased_storage_allocation: Enabling this permits automatic allocation of purchased storage in a namespace.
        :param pulumi.Input[_builtins.int] bulk_import_concurrent_pipeline_batch_limit: Maximum simultaneous Direct Transfer batches to process.
        :param pulumi.Input[_builtins.bool] bulk_import_enabled: Enable migrating GitLab groups by direct transfer.
        :param pulumi.Input[_builtins.int] bulk_import_max_download_file_size: Maximum download file size when importing from source GitLab instances by direct transfer.
        :param pulumi.Input[_builtins.bool] can_create_group: Indicates whether users can create top-level groups.
        :param pulumi.Input[_builtins.bool] check_namespace_plan: Enabling this makes only licensed EE features available to projects if the project namespace’s plan includes the feature or if the project is public.
        :param pulumi.Input[_builtins.int] ci_max_includes: The maximum number of includes per pipeline.
        :param pulumi.Input[_builtins.int] ci_max_total_yaml_size_bytes: The maximum amount of memory, in bytes, that can be allocated for the pipeline configuration, with all included YAML configuration files.
        :param pulumi.Input[_builtins.str] commit_email_hostname: Custom hostname (for private commit emails).
        :param pulumi.Input[_builtins.int] concurrent_bitbucket_import_jobs_limit: Maximum number of simultaneous import jobs for the Bitbucket Cloud importer.
        :param pulumi.Input[_builtins.int] concurrent_bitbucket_server_import_jobs_limit: Maximum number of simultaneous import jobs for the Bitbucket Server importer.
        :param pulumi.Input[_builtins.int] concurrent_github_import_jobs_limit: Maximum number of simultaneous import jobs for the GitHub importer.
        :param pulumi.Input[_builtins.bool] container_expiration_policies_enable_historic_entries: Enable cleanup policies for all projects.
        :param pulumi.Input[_builtins.int] container_registry_cleanup_tags_service_max_list_size: The maximum number of tags that can be deleted in a single execution of cleanup policies.
        :param pulumi.Input[_builtins.int] container_registry_delete_tags_service_timeout: The maximum time, in seconds, that the cleanup process can take to delete a batch of tags for cleanup policies.
        :param pulumi.Input[_builtins.bool] container_registry_expiration_policies_caching: Caching during the execution of cleanup policies.
        :param pulumi.Input[_builtins.int] container_registry_expiration_policies_worker_capacity: Number of workers for cleanup policies.
        :param pulumi.Input[_builtins.int] container_registry_token_expire_delay: Container Registry token duration in minutes.
        :param pulumi.Input[_builtins.bool] deactivate_dormant_users: Enable automatic deactivation of dormant users.
        :param pulumi.Input[_builtins.int] deactivate_dormant_users_period: Length of time (in days) after which a user is considered dormant.
        :param pulumi.Input[_builtins.int] decompress_archive_file_timeout: Default timeout for decompressing archived files, in seconds. Set to 0 to disable timeouts.
        :param pulumi.Input[_builtins.str] default_artifacts_expire_in: Set the default expiration time for each job’s artifacts.
        :param pulumi.Input[_builtins.str] default_branch_name: Instance-level custom initial branch name
        :param pulumi.Input[_builtins.int] default_branch_protection: Determine if developers can push to the default branch. Can take: 0 (not protected, both users with the Developer role or Maintainer role can push new commits and force push), 1 (partially protected, users with the Developer role or Maintainer role can push new commits, but cannot force push) or 2 (fully protected, users with the Developer or Maintainer role cannot push new commits, but users with the Developer or Maintainer role can; no one can force push) as a parameter. Default is 2. Use `default_branch_protection_defaults` instead. To be removed in 19.0.
        :param pulumi.Input['ApplicationSettingsDefaultBranchProtectionDefaultsArgs'] default_branch_protection_defaults: The default*branch*protection*defaults attribute describes the default branch protection defaults. All parameters are optional.
        :param pulumi.Input[_builtins.str] default_ci_config_path: Default CI/CD configuration file and path for new projects (.gitlab-ci.yml if not set).
        :param pulumi.Input[_builtins.str] default_group_visibility: What visibility level new groups receive. Can take private, internal and public as a parameter.
        :param pulumi.Input[_builtins.str] default_preferred_language: Default preferred language for users who are not logged in.
        :param pulumi.Input[_builtins.int] default_project_creation: Default project creation protection. Can take: 0 (No one), 1 (Maintainers) or 2 (Developers + Maintainers).
        :param pulumi.Input[_builtins.str] default_project_visibility: What visibility level new projects receive. Can take private, internal and public as a parameter.
        :param pulumi.Input[_builtins.int] default_projects_limit: Project limit per user.
        :param pulumi.Input[_builtins.str] default_snippet_visibility: What visibility level new snippets receive. Can take private, internal and public as a parameter.
        :param pulumi.Input[_builtins.int] default_syntax_highlighting_theme: Default syntax highlighting theme for users who are new or not signed in. See IDs of available themes (https://gitlab.com/gitlab-org/gitlab/blob/master/lib/gitlab/themes.rb#L16)
        :param pulumi.Input[_builtins.bool] delete_inactive_projects: Enable inactive project deletion feature.
        :param pulumi.Input[_builtins.bool] delete_unconfirmed_users: Specifies whether users who have not confirmed their email should be deleted. When set to true, unconfirmed users are deleted after unconfirmed*users*delete*after*days days. Self-managed, Premium and Ultimate only.
        :param pulumi.Input[_builtins.int] deletion_adjourned_period: The number of days to wait before deleting a project or group that is marked for deletion. Value must be between 1 and 90.
        :param pulumi.Input[_builtins.bool] diagramsnet_enabled: (If enabled, requires diagramsnet_url) Enable Diagrams.net integration.
        :param pulumi.Input[_builtins.str] diagramsnet_url: The Diagrams.net instance URL for integration.
        :param pulumi.Input[_builtins.int] diff_max_files: Maximum files in a diff.
        :param pulumi.Input[_builtins.int] diff_max_lines: Maximum lines in a diff.
        :param pulumi.Input[_builtins.int] diff_max_patch_bytes: Maximum diff patch size, in bytes.
        :param pulumi.Input[_builtins.bool] disable_admin_oauth_scopes: Stops administrators from connecting their GitLab accounts to non-trusted OAuth 2.0 applications that have the api, read*api, read*repository, write*repository, read*registry, write_registry, or sudo scopes.
        :param pulumi.Input[_builtins.bool] disable_feed_token: Disable display of RSS/Atom and calendar feed tokens.
        :param pulumi.Input[_builtins.bool] disable_personal_access_tokens: Disable personal access tokens. Self-managed, Premium and Ultimate only. There is no method available to enable a personal access token that’s been disabled through the API. This is a known issue.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] disabled_oauth_sign_in_sources: Disabled OAuth sign-in sources.
        :param pulumi.Input[_builtins.bool] dns_rebinding_protection_enabled: Enforce DNS rebinding attack protection.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] domain_allowlists: Force people to use only corporate emails for sign-up. Null means there is no restriction.
        :param pulumi.Input[_builtins.bool] domain_denylist_enabled: (If enabled, requires: domain_denylist) Allows blocking sign-ups from emails from specific domains.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] domain_denylists: Users with email addresses that match these domains cannot sign up. Wildcards allowed. Use separate lines for multiple entries. Ex: domain.com, *.domain.com.
        :param pulumi.Input[_builtins.int] downstream_pipeline_trigger_limit_per_project_user_sha: Maximum downstream pipeline trigger rate.
        :param pulumi.Input[_builtins.int] dsa_key_restriction: The minimum allowed bit length of an uploaded DSA key. 0 means no restriction. -1 disables DSA keys.
        :param pulumi.Input[_builtins.bool] duo_features_enabled: Indicates whether GitLab Duo features are enabled for this instance. Self-managed, Premium and Ultimate only.
        :param pulumi.Input[_builtins.int] ecdsa_key_restriction: The minimum allowed curve size (in bits) of an uploaded ECDSA key. 0 means no restriction. -1 disables ECDSA keys.
        :param pulumi.Input[_builtins.int] ecdsa_sk_key_restriction: The minimum allowed curve size (in bits) of an uploaded ECDSA*SK key. 0 means no restriction. -1 disables ECDSA*SK keys.
        :param pulumi.Input[_builtins.int] ed25519_key_restriction: The minimum allowed curve size (in bits) of an uploaded ED25519 key. 0 means no restriction. -1 disables ED25519 keys.
        :param pulumi.Input[_builtins.int] ed25519_sk_key_restriction: The minimum allowed curve size (in bits) of an uploaded ED25519*SK key. 0 means no restriction. -1 disables ED25519*SK keys.
        :param pulumi.Input[_builtins.str] eks_access_key_id: AWS IAM access key ID.
        :param pulumi.Input[_builtins.str] eks_account_id: Amazon account ID.
        :param pulumi.Input[_builtins.bool] eks_integration_enabled: Enable integration with Amazon EKS.
        :param pulumi.Input[_builtins.str] eks_secret_access_key: AWS IAM secret access key.
        :param pulumi.Input[_builtins.bool] elasticsearch_aws: Enable the use of AWS hosted Elasticsearch.
        :param pulumi.Input[_builtins.str] elasticsearch_aws_access_key: AWS IAM access key.
        :param pulumi.Input[_builtins.str] elasticsearch_aws_region: The AWS region the Elasticsearch domain is configured.
        :param pulumi.Input[_builtins.str] elasticsearch_aws_secret_access_key: AWS IAM secret access key.
        :param pulumi.Input[_builtins.int] elasticsearch_indexed_field_length_limit: Maximum size of text fields to index by Elasticsearch. 0 value means no limit. This does not apply to repository and wiki indexing.
        :param pulumi.Input[_builtins.int] elasticsearch_indexed_file_size_limit_kb: Maximum size of repository and wiki files that are indexed by Elasticsearch.
        :param pulumi.Input[_builtins.bool] elasticsearch_indexing: Enable Elasticsearch indexing.
        :param pulumi.Input[_builtins.bool] elasticsearch_limit_indexing: Limit Elasticsearch to index certain namespaces and projects.
        :param pulumi.Input[_builtins.int] elasticsearch_max_bulk_concurrency: Maximum concurrency of Elasticsearch bulk requests per indexing operation. This only applies to repository indexing operations.
        :param pulumi.Input[_builtins.int] elasticsearch_max_bulk_size_mb: Maximum size of Elasticsearch bulk indexing requests in MB. This only applies to repository indexing operations.
        :param pulumi.Input[_builtins.int] elasticsearch_max_code_indexing_concurrency: Maximum concurrency of Elasticsearch code indexing background jobs. This only applies to repository indexing operations. Premium and Ultimate only.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] elasticsearch_namespace_ids: The namespaces to index via Elasticsearch if elasticsearch*limit*indexing is enabled.
        :param pulumi.Input[_builtins.str] elasticsearch_password: The password of your Elasticsearch instance.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] elasticsearch_project_ids: The projects to index via Elasticsearch if elasticsearch*limit*indexing is enabled.
        :param pulumi.Input[_builtins.bool] elasticsearch_requeue_workers: Enable automatic requeuing of indexing workers. This improves non-code indexing throughput by enqueuing Sidekiq jobs until all documents are processed. Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] elasticsearch_search: Enable Elasticsearch search.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] elasticsearch_urls: The URL to use for connecting to Elasticsearch. Use a comma-separated list to support cluster (for example, http://localhost:9200, http://localhost:9201).
        :param pulumi.Input[_builtins.str] elasticsearch_username: The username of your Elasticsearch instance.
        :param pulumi.Input[_builtins.int] elasticsearch_worker_number_of_shards: Number of indexing worker shards. This improves non-code indexing throughput by enqueuing more parallel Sidekiq jobs. Premium and Ultimate only.
        :param pulumi.Input[_builtins.str] email_additional_text: Additional text added to the bottom of every email for legal/auditing/compliance reasons.
        :param pulumi.Input[_builtins.bool] email_author_in_body: Some email servers do not support overriding the email sender name. Enable this option to include the name of the author of the issue, merge request or comment in the email body instead.
        :param pulumi.Input[_builtins.str] email_confirmation_setting: Specifies whether users must confirm their email before sign in. Possible values are off, soft, and hard.
        :param pulumi.Input[_builtins.bool] enable_artifact_external_redirect_warning_page: Show the external redirect page that warns you about user-generated content in GitLab Pages.
        :param pulumi.Input[_builtins.str] enabled_git_access_protocol: Enabled protocols for Git access. Allowed values are: ssh, http, and nil to allow both protocols.
        :param pulumi.Input[_builtins.bool] enforce_namespace_storage_limit: Enabling this permits enforcement of namespace storage limits.
        :param pulumi.Input[_builtins.bool] enforce_terms: (If enabled, requires: terms) Enforce application ToS to all users.
        :param pulumi.Input[_builtins.str] external_auth_client_cert: (If enabled, requires: external*auth*client_key) The certificate to use to authenticate with the external authorization service.
        :param pulumi.Input[_builtins.str] external_auth_client_key: Private key for the certificate when authentication is required for the external authorization service, this is encrypted when stored.
        :param pulumi.Input[_builtins.str] external_auth_client_key_pass: Passphrase to use for the private key when authenticating with the external service this is encrypted when stored.
        :param pulumi.Input[_builtins.str] external_authorization_service_default_label: The default classification label to use when requesting authorization and no classification label has been specified on the project.
        :param pulumi.Input[_builtins.bool] external_authorization_service_enabled: (If enabled, requires: external*authorization*service*default*label, external*authorization*service*timeout and external*authorization*service*url) Enable using an external authorization service for accessing projects.
        :param pulumi.Input[_builtins.float] external_authorization_service_timeout: The timeout after which an authorization request is aborted, in seconds. When a request times out, access is denied to the user. (min: 0.001, max: 10, step: 0.001).
        :param pulumi.Input[_builtins.str] external_authorization_service_url: URL to which authorization requests are directed.
        :param pulumi.Input[_builtins.int] external_pipeline_validation_service_timeout: How long to wait for a response from the pipeline validation service. Assumes OK if it times out.
        :param pulumi.Input[_builtins.str] external_pipeline_validation_service_token: Optional. Token to include as the X-Gitlab-Token header in requests to the URL in external*pipeline*validation*service*url.
        :param pulumi.Input[_builtins.str] external_pipeline_validation_service_url: URL to use for pipeline validation requests.
        :param pulumi.Input[_builtins.int] failed_login_attempts_unlock_period_in_minutes: Time period in minutes after which the user is unlocked when maximum number of failed sign-in attempts reached.
        :param pulumi.Input[_builtins.int] file_template_project_id: The ID of a project to load custom file templates from.
        :param pulumi.Input[_builtins.int] first_day_of_week: Start day of the week for calendar views and date pickers. Valid values are 0 for Sunday, 1 for Monday, and 6 for Saturday.
        :param pulumi.Input[_builtins.str] geo_node_allowed_ips: Comma-separated list of IPs and CIDRs of allowed secondary nodes. For example, 1.1.1.1, 2.2.2.0/24.
        :param pulumi.Input[_builtins.int] geo_status_timeout: The amount of seconds after which a request to get a secondary node status times out.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] git_rate_limit_users_alertlists: List of user IDs that are emailed when the Git abuse rate limit is exceeded. Maximum: 100 user IDs. Self-managed, Ultimate only.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] git_rate_limit_users_allowlists: List of usernames excluded from Git anti-abuse rate limits. Maximum: 100 usernames. Self-managed, Ultimate only.
        :param pulumi.Input[_builtins.int] git_two_factor_session_expiry: Maximum duration (in minutes) of a session for Git operations when 2FA is enabled.
        :param pulumi.Input[_builtins.int] gitaly_timeout_default: Default Gitaly timeout, in seconds. This timeout is not enforced for Git fetch/push operations or Sidekiq jobs. Set to 0 to disable timeouts.
        :param pulumi.Input[_builtins.int] gitaly_timeout_fast: Gitaly fast operation timeout, in seconds. Some Gitaly operations are expected to be fast. If they exceed this threshold, there may be a problem with a storage shard and ‘failing fast’ can help maintain the stability of the GitLab instance. Set to 0 to disable timeouts.
        :param pulumi.Input[_builtins.int] gitaly_timeout_medium: Medium Gitaly timeout, in seconds. This should be a value between the Fast and the Default timeout. Set to 0 to disable timeouts.
        :param pulumi.Input[_builtins.bool] gitlab_dedicated_instance: Indicates whether the instance was provisioned for GitLab Dedicated.
        :param pulumi.Input[_builtins.bool] gitlab_environment_toolkit_instance: Indicates whether the instance was provisioned with the GitLab Environment Toolkit for Service Ping reporting.
        :param pulumi.Input[_builtins.int] gitlab_shell_operation_limit: Maximum number of Git operations per minute a user can perform.
        :param pulumi.Input[_builtins.bool] gitpod_enabled: Enable Gitpod integration.
        :param pulumi.Input[_builtins.str] gitpod_url: The Gitpod instance URL for integration.
        :param pulumi.Input[_builtins.str] globally_allowed_ips: Comma-separated list of IP addresses and CIDRs always allowed for inbound traffic. For example, 1.1.1.1, 2.2.2.0/24.
        :param pulumi.Input[_builtins.bool] grafana_enabled: Enable Grafana.
        :param pulumi.Input[_builtins.str] grafana_url: Grafana URL.
        :param pulumi.Input[_builtins.bool] gravatar_enabled: Enable Gravatar.
        :param pulumi.Input[_builtins.bool] group_owners_can_manage_default_branch_protection: Prevent overrides of default branch protection.
        :param pulumi.Input[_builtins.bool] help_page_hide_commercial_content: Hide marketing-related entries from help.
        :param pulumi.Input[_builtins.str] help_page_support_url: Alternate support URL for help page and help dropdown.
        :param pulumi.Input[_builtins.str] help_page_text: Custom text displayed on the help page.
        :param pulumi.Input[_builtins.str] help_text: GitLab server administrator information.
        :param pulumi.Input[_builtins.bool] hide_third_party_offers: Do not display offers from third parties in GitLab.
        :param pulumi.Input[_builtins.str] home_page_url: Redirect to this URL when not logged in.
        :param pulumi.Input[_builtins.bool] housekeeping_enabled: Enable or disable Git housekeeping. If enabled, requires housekeeping*optimize*repository_period.
        :param pulumi.Input[_builtins.int] housekeeping_optimize_repository_period: Number of Git pushes after which an incremental git-repack is run.
        :param pulumi.Input[_builtins.bool] html_emails_enabled: Enable HTML emails.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] import_sources: Sources to allow project import from. Valid values are: `github`, `bitbucket`, `bitbucket_server`, `fogbugz`, `git`, `Project`, `gitea`, `manifest`
        :param pulumi.Input[_builtins.bool] in_product_marketing_emails_enabled: Enable in-product marketing emails.
        :param pulumi.Input[_builtins.int] inactive_projects_delete_after_months: If delete*inactive*projects is true, the time (in months) to wait before deleting inactive projects.
        :param pulumi.Input[_builtins.int] inactive_projects_min_size_mb: If delete*inactive*projects is true, the minimum repository size for projects to be checked for inactivity.
        :param pulumi.Input[_builtins.int] inactive_projects_send_warning_email_after_months: If delete*inactive*projects is true, sets the time (in months) to wait before emailing maintainers that the project is scheduled be deleted because it is inactive.
        :param pulumi.Input[_builtins.bool] include_optional_metrics_in_service_ping: Whether or not optional metrics are enabled in Service Ping.
        :param pulumi.Input[_builtins.bool] invisible_captcha_enabled: Enable Invisible CAPTCHA spam detection during sign-up.
        :param pulumi.Input[_builtins.int] issues_create_limit: Max number of issue creation requests per minute per user.
        :param pulumi.Input[_builtins.str] jira_connect_application_key: ID of the OAuth application used to authenticate with the GitLab for Jira Cloud app.
        :param pulumi.Input[_builtins.str] jira_connect_proxy_url: URL of the GitLab instance used as a proxy for the GitLab for Jira Cloud app.
        :param pulumi.Input[_builtins.bool] jira_connect_public_key_storage_enabled: Enable public key storage for the GitLab for Jira Cloud app.
        :param pulumi.Input[_builtins.bool] keep_latest_artifact: Prevent the deletion of the artifacts from the most recent successful jobs, regardless of the expiry time.
        :param pulumi.Input[_builtins.int] local_markdown_version: Increase this value when any cached Markdown should be invalidated.
        :param pulumi.Input[_builtins.bool] lock_duo_features_enabled: Indicates whether the GitLab Duo features enabled setting is enforced for all subgroups. Self-managed, Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] lock_memberships_to_ldap: Set to true to lock all memberships to LDAP. Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] mailgun_events_enabled: Enable Mailgun event receiver.
        :param pulumi.Input[_builtins.str] mailgun_signing_key: The Mailgun HTTP webhook signing key for receiving events from webhook.
        :param pulumi.Input[_builtins.bool] maintenance_mode: When instance is in maintenance mode, non-administrative users can sign in with read-only access and make read-only API requests.
        :param pulumi.Input[_builtins.str] maintenance_mode_message: Message displayed when instance is in maintenance mode.
        :param pulumi.Input[_builtins.bool] maven_package_requests_forwarding: Use repo.maven.apache.org as a default remote repository when the package is not found in the GitLab Package Registry for Maven. Premium and Ultimate only.
        :param pulumi.Input[_builtins.int] max_artifacts_size: Maximum artifacts size in MB.
        :param pulumi.Input[_builtins.int] max_attachment_size: Limit attachment size in MB.
        :param pulumi.Input[_builtins.int] max_decompressed_archive_size: Maximum decompressed archive size in bytes.
        :param pulumi.Input[_builtins.int] max_export_size: Maximum export size in MB. 0 for unlimited.
        :param pulumi.Input[_builtins.int] max_import_remote_file_size: Maximum remote file size for imports from external object storages.
        :param pulumi.Input[_builtins.int] max_import_size: Maximum import size in MB. 0 for unlimited.
        :param pulumi.Input[_builtins.int] max_login_attempts: Maximum number of sign-in attempts before locking out the user.
        :param pulumi.Input[_builtins.int] max_number_of_repository_downloads: Maximum number of unique repositories a user can download in the specified time period before they are banned. Maximum: 10,000 repositories.
        :param pulumi.Input[_builtins.int] max_number_of_repository_downloads_within_time_period: Reporting time period (in seconds). Maximum: 864000 seconds (10 days).
        :param pulumi.Input[_builtins.int] max_pages_size: Maximum size of pages repositories in MB.
        :param pulumi.Input[_builtins.int] max_personal_access_token_lifetime: Maximum allowable lifetime for access tokens in days.
        :param pulumi.Input[_builtins.int] max_ssh_key_lifetime: Maximum allowable lifetime for SSH keys in days.
        :param pulumi.Input[_builtins.int] metrics_method_call_threshold: A method call is only tracked when it takes longer than the given amount of milliseconds.
        :param pulumi.Input[_builtins.int] minimum_password_length: Indicates whether passwords require a minimum length. Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] mirror_available: Allow repository mirroring to configured by project Maintainers. If disabled, only Administrators can configure repository mirroring.
        :param pulumi.Input[_builtins.int] mirror_capacity_threshold: Minimum capacity to be available before scheduling more mirrors preemptively.
        :param pulumi.Input[_builtins.int] mirror_max_capacity: Maximum number of mirrors that can be synchronizing at the same time.
        :param pulumi.Input[_builtins.int] mirror_max_delay: Maximum time (in minutes) between updates that a mirror can have when scheduled to synchronize.
        :param pulumi.Input[_builtins.bool] npm_package_requests_forwarding: Use npmjs.org as a default remote repository when the package is not found in the GitLab Package Registry for npm.
        :param pulumi.Input[_builtins.bool] nuget_skip_metadata_url_validation: Indicates whether to skip metadata URL validation for the NuGet package.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] outbound_local_requests_whitelists: Define a list of trusted domains or IP addresses to which local requests are allowed when local requests for hooks and services are disabled.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] package_metadata_purl_types: List of package registry metadata to sync. See the list of the available values (https://gitlab.com/gitlab-org/gitlab/-/blob/ace16c20d5da7c4928dd03fb139692638b557fe3/app/models/concerns/enums/package_metadata.rb#L5). Self-managed, Ultimate only.
        :param pulumi.Input[_builtins.bool] package_registry_allow_anyone_to_pull_option: Enable to allow anyone to pull from Package Registry visible and changeable.
        :param pulumi.Input[_builtins.int] package_registry_cleanup_policies_worker_capacity: Number of workers assigned to the packages cleanup policies.
        :param pulumi.Input[_builtins.bool] pages_domain_verification_enabled: Require users to prove ownership of custom domains. Domain verification is an essential security measure for public GitLab sites. Users are required to demonstrate they control a domain before it is enabled.
        :param pulumi.Input[_builtins.bool] password_authentication_enabled_for_git: Enable authentication for Git over HTTP(S) via a GitLab account password.
        :param pulumi.Input[_builtins.bool] password_authentication_enabled_for_web: Enable authentication for the web interface via a GitLab account password.
        :param pulumi.Input[_builtins.bool] password_lowercase_required: Indicates whether passwords require at least one lowercase letter.
        :param pulumi.Input[_builtins.bool] password_number_required: Indicates whether passwords require at least one number.
        :param pulumi.Input[_builtins.bool] password_symbol_required: Indicates whether passwords require at least one symbol character.
        :param pulumi.Input[_builtins.bool] password_uppercase_required: Indicates whether passwords require at least one uppercase letter.
        :param pulumi.Input[_builtins.str] performance_bar_allowed_group_path: Path of the group that is allowed to toggle the performance bar.
        :param pulumi.Input[_builtins.str] personal_access_token_prefix: Prefix for all generated personal access tokens.
        :param pulumi.Input[_builtins.int] pipeline_limit_per_project_user_sha: Maximum number of pipeline creation requests per minute per user and commit.
        :param pulumi.Input[_builtins.bool] plantuml_enabled: (If enabled, requires: plantuml_url) Enable PlantUML integration.
        :param pulumi.Input[_builtins.str] plantuml_url: The PlantUML instance URL for integration.
        :param pulumi.Input[_builtins.float] polling_interval_multiplier: Interval multiplier used by endpoints that perform polling. Set to 0 to disable polling.
        :param pulumi.Input[_builtins.bool] project_export_enabled: Enable project export.
        :param pulumi.Input[_builtins.int] project_jobs_api_rate_limit: Maximum authenticated requests to /project/:id/jobs per minute.
        :param pulumi.Input[_builtins.int] projects_api_rate_limit_unauthenticated: Max number of requests per 10 minutes per IP address for unauthenticated requests to the list all projects API. To disable throttling set to 0.
        :param pulumi.Input[_builtins.bool] prometheus_metrics_enabled: Enable Prometheus metrics.
        :param pulumi.Input[_builtins.bool] protected_ci_variables: CI/CD variables are protected by default.
        :param pulumi.Input[_builtins.int] push_event_activities_limit: Number of changes (branches or tags) in a single push to determine whether individual push events or bulk push events are created. Bulk push events are created if it surpasses that value.
        :param pulumi.Input[_builtins.int] push_event_hooks_limit: Number of changes (branches or tags) in a single push to determine whether webhooks and services fire or not. Webhooks and services aren’t submitted if it surpasses that value.
        :param pulumi.Input[_builtins.bool] pypi_package_requests_forwarding: Use pypi.org as a default remote repository when the package is not found in the GitLab Package Registry for PyPI.
        :param pulumi.Input[_builtins.str] rate_limiting_response_text: When rate limiting is enabled via the throttle_* settings, send this plain text response when a rate limit is exceeded. ‘Retry later’ is sent if this is blank.
        :param pulumi.Input[_builtins.int] raw_blob_request_limit: Max number of requests per minute for each raw path. To disable throttling set to 0.
        :param pulumi.Input[_builtins.bool] recaptcha_enabled: (If enabled, requires: recaptcha*private*key and recaptcha*site*key) Enable reCAPTCHA.
        :param pulumi.Input[_builtins.str] recaptcha_private_key: Private key for reCAPTCHA.
        :param pulumi.Input[_builtins.str] recaptcha_site_key: Site key for reCAPTCHA.
        :param pulumi.Input[_builtins.int] receive_max_input_size: Maximum push size (MB).
        :param pulumi.Input[_builtins.bool] receptive_cluster_agents_enabled: Enable receptive mode for GitLab Agents for Kubernetes.
        :param pulumi.Input[_builtins.bool] remember_me_enabled: Enable Remember me setting.
        :param pulumi.Input[_builtins.bool] repository_checks_enabled: GitLab periodically runs git fsck in all project and wiki repositories to look for silent disk corruption issues.
        :param pulumi.Input[_builtins.int] repository_size_limit: Size limit per repository (MB).
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.int]]] repository_storages_weighted: Hash of names taken from gitlab.yml to weights. New projects are created in one of these stores, chosen by a weighted random selection.
        :param pulumi.Input[_builtins.bool] require_admin_approval_after_user_signup: When enabled, any user that signs up for an account using the registration form is placed under a Pending approval state and has to be explicitly approved by an administrator.
        :param pulumi.Input[_builtins.bool] require_admin_two_factor_authentication: Allow administrators to require 2FA for all administrators on the instance.
        :param pulumi.Input[_builtins.bool] require_personal_access_token_expiry: When enabled, users must set an expiration date when creating a group or project access token, or a personal access token owned by a non-service account.
        :param pulumi.Input[_builtins.bool] require_two_factor_authentication: (If enabled, requires: two*factor*grace_period) Require all users to set up Two-factor authentication.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] restricted_visibility_levels: Selected levels cannot be used by non-Administrator users for groups, projects or snippets. Can take private, internal and public as a parameter. Null means there is no restriction.
        :param pulumi.Input[_builtins.int] rsa_key_restriction: The minimum allowed bit length of an uploaded RSA key. 0 means no restriction. -1 disables RSA keys.
        :param pulumi.Input[_builtins.int] search_rate_limit: Max number of requests per minute for performing a search while authenticated. To disable throttling set to 0.
        :param pulumi.Input[_builtins.int] search_rate_limit_unauthenticated: Max number of requests per minute for performing a search while unauthenticated. To disable throttling set to 0.
        :param pulumi.Input[_builtins.int] security_approval_policies_limit: Maximum number of active merge request approval policies per security policy project. Maximum: 20
        :param pulumi.Input[_builtins.bool] security_policy_global_group_approvers_enabled: Whether to look up merge request approval policy approval groups globally or within project hierarchies.
        :param pulumi.Input[_builtins.str] security_txt_content: Public security contact information.
        :param pulumi.Input[_builtins.bool] send_user_confirmation_email: Send confirmation email on sign-up.
        :param pulumi.Input[_builtins.bool] service_access_tokens_expiration_enforced: Flag to indicate if token expiry date can be optional for service account users
        :param pulumi.Input[_builtins.int] session_expire_delay: Session duration in minutes. GitLab restart is required to apply changes.
        :param pulumi.Input[_builtins.bool] shared_runners_enabled: (If enabled, requires: shared*runners*text and shared*runners*minutes) Enable shared runners for new projects.
        :param pulumi.Input[_builtins.int] shared_runners_minutes: Set the maximum number of CI/CD minutes that a group can use on shared runners per month.
        :param pulumi.Input[_builtins.str] shared_runners_text: Shared runners text.
        :param pulumi.Input[_builtins.int] sidekiq_job_limiter_compression_threshold_bytes: The threshold in bytes at which Sidekiq jobs are compressed before being stored in Redis.
        :param pulumi.Input[_builtins.int] sidekiq_job_limiter_limit_bytes: The threshold in bytes at which Sidekiq jobs are rejected. 0 means do not reject any job.
        :param pulumi.Input[_builtins.str] sidekiq_job_limiter_mode: track or compress. Sets the behavior for Sidekiq job size limits.
        :param pulumi.Input[_builtins.str] sign_in_text: Text on the login page.
        :param pulumi.Input[_builtins.bool] signup_enabled: Enable registration.
        :param pulumi.Input[_builtins.bool] silent_admin_exports_enabled: Enable Silent admin exports.
        :param pulumi.Input[_builtins.bool] silent_mode_enabled: Enable Silent mode.
        :param pulumi.Input[_builtins.bool] slack_app_enabled: (If enabled, requires: slack*app*id, slack*app*secret and slack*app*secret) Enable Slack app.
        :param pulumi.Input[_builtins.str] slack_app_id: The app ID of the Slack-app.
        :param pulumi.Input[_builtins.str] slack_app_secret: The app secret of the Slack-app.
        :param pulumi.Input[_builtins.str] slack_app_signing_secret: The signing secret of the Slack-app.
        :param pulumi.Input[_builtins.str] slack_app_verification_token: The verification token of the Slack-app.
        :param pulumi.Input[_builtins.int] snippet_size_limit: Max snippet content size in bytes.
        :param pulumi.Input[_builtins.str] snowplow_app_id: The Snowplow site name / application ID. (for example, gitlab)
        :param pulumi.Input[_builtins.str] snowplow_collector_hostname: The Snowplow collector hostname. (for example, snowplow.trx.gitlab.net)
        :param pulumi.Input[_builtins.str] snowplow_cookie_domain: The Snowplow cookie domain. (for example, .gitlab.com)
        :param pulumi.Input[_builtins.str] snowplow_database_collector_hostname: The Snowplow collector for database events hostname. (for example, db-snowplow.trx.gitlab.net)
        :param pulumi.Input[_builtins.bool] snowplow_enabled: Enable snowplow tracking.
        :param pulumi.Input[_builtins.bool] sourcegraph_enabled: Enables Sourcegraph integration. If enabled, requires sourcegraph_url.
        :param pulumi.Input[_builtins.bool] sourcegraph_public_only: Blocks Sourcegraph from being loaded on private and internal projects.
        :param pulumi.Input[_builtins.str] sourcegraph_url: The Sourcegraph instance URL for integration.
        :param pulumi.Input[_builtins.str] spam_check_api_key: API key used by GitLab for accessing the Spam Check service endpoint.
        :param pulumi.Input[_builtins.bool] spam_check_endpoint_enabled: Enables spam checking using external Spam Check API endpoint.
        :param pulumi.Input[_builtins.str] spam_check_endpoint_url: URL of the external Spamcheck service endpoint. Valid URI schemes are grpc or tls. Specifying tls forces communication to be encrypted.
        :param pulumi.Input[_builtins.str] static_objects_external_storage_auth_token: Authentication token for the external storage linked in static*objects*external*storage*url.
        :param pulumi.Input[_builtins.str] static_objects_external_storage_url: URL to an external storage for repository static objects.
        :param pulumi.Input[_builtins.bool] suggest_pipeline_enabled: Enable pipeline suggestion banner.
        :param pulumi.Input[_builtins.int] terminal_max_session_time: Maximum time for web terminal websocket connection (in seconds). Set to 0 for unlimited time.
        :param pulumi.Input[_builtins.str] terms: (Required by: enforce_terms) Markdown content for the ToS.
        :param pulumi.Input[_builtins.bool] throttle_authenticated_api_enabled: (If enabled, requires: throttle*authenticated*api*period*in*seconds and throttle*authenticated*api*requests*per*period) Enable authenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        :param pulumi.Input[_builtins.int] throttle_authenticated_api_period_in_seconds: Rate limit period (in seconds).
        :param pulumi.Input[_builtins.int] throttle_authenticated_api_requests_per_period: Maximum requests per period per user.
        :param pulumi.Input[_builtins.bool] throttle_authenticated_packages_api_enabled: (If enabled, requires: throttle*authenticated*packages*api*period*in*seconds and throttle*authenticated*packages*api*requests*per*period) Enable authenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots). View Package Registry rate limits for more details.
        :param pulumi.Input[_builtins.int] throttle_authenticated_packages_api_period_in_seconds: Rate limit period (in seconds). View Package Registry rate limits for more details.
        :param pulumi.Input[_builtins.int] throttle_authenticated_packages_api_requests_per_period: Maximum requests per period per user. View Package Registry rate limits for more details.
        :param pulumi.Input[_builtins.bool] throttle_authenticated_web_enabled: (If enabled, requires: throttle*authenticated*web*period*in*seconds and throttle*authenticated*web*requests*per*period) Enable authenticated web request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        :param pulumi.Input[_builtins.int] throttle_authenticated_web_period_in_seconds: Rate limit period (in seconds).
        :param pulumi.Input[_builtins.int] throttle_authenticated_web_requests_per_period: Maximum requests per period per user.
        :param pulumi.Input[_builtins.bool] throttle_unauthenticated_api_enabled: (If enabled, requires: throttle*unauthenticated*api*period*in*seconds and throttle*unauthenticated*api*requests*per*period) Enable unauthenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        :param pulumi.Input[_builtins.int] throttle_unauthenticated_api_period_in_seconds: Rate limit period in seconds.
        :param pulumi.Input[_builtins.int] throttle_unauthenticated_api_requests_per_period: Max requests per period per IP.
        :param pulumi.Input[_builtins.bool] throttle_unauthenticated_packages_api_enabled: (If enabled, requires: throttle*unauthenticated*packages*api*period*in*seconds and throttle*unauthenticated*packages*api*requests*per*period) Enable authenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots). View Package Registry rate limits for more details.
        :param pulumi.Input[_builtins.int] throttle_unauthenticated_packages_api_period_in_seconds: Rate limit period (in seconds). View Package Registry rate limits for more details.
        :param pulumi.Input[_builtins.int] throttle_unauthenticated_packages_api_requests_per_period: Maximum requests per period per user. View Package Registry rate limits for more details.
        :param pulumi.Input[_builtins.bool] throttle_unauthenticated_web_enabled: (If enabled, requires: throttle*unauthenticated*web*period*in*seconds and throttle*unauthenticated*web*requests*per*period) Enable unauthenticated web request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        :param pulumi.Input[_builtins.int] throttle_unauthenticated_web_period_in_seconds: Rate limit period in seconds.
        :param pulumi.Input[_builtins.int] throttle_unauthenticated_web_requests_per_period: Max requests per period per IP.
        :param pulumi.Input[_builtins.bool] time_tracking_limit_to_hours: Limit display of time tracking units to hours.
        :param pulumi.Input[_builtins.int] two_factor_grace_period: Amount of time (in hours) that users are allowed to skip forced configuration of two-factor authentication.
        :param pulumi.Input[_builtins.int] unconfirmed_users_delete_after_days: Specifies how many days after sign-up to delete users who have not confirmed their email. Only applicable if delete*unconfirmed*users is set to true. Must be 1 or greater. Self-managed, Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] unique_ips_limit_enabled: (If enabled, requires: unique*ips*limit*per*user and unique*ips*limit*time*window) Limit sign in from multiple IPs.
        :param pulumi.Input[_builtins.int] unique_ips_limit_per_user: Maximum number of IPs per user.
        :param pulumi.Input[_builtins.int] unique_ips_limit_time_window: How many seconds an IP is counted towards the limit.
        :param pulumi.Input[_builtins.bool] update_runner_versions_enabled: Fetch GitLab Runner release version data from GitLab.com.
        :param pulumi.Input[_builtins.bool] usage_ping_enabled: Every week GitLab reports license usage back to GitLab, Inc.
        :param pulumi.Input[_builtins.bool] use_clickhouse_for_analytics: Enables ClickHouse as a data source for analytics reports. ClickHouse must be configured for this setting to take effect. Available on Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] user_deactivation_emails_enabled: Send an email to users upon account deactivation.
        :param pulumi.Input[_builtins.bool] user_default_external: Newly registered users are external by default.
        :param pulumi.Input[_builtins.str] user_default_internal_regex: Specify an email address regex pattern to identify default internal users.
        :param pulumi.Input[_builtins.bool] user_defaults_to_private_profile: Newly created users have private profile by default.
        :param pulumi.Input[_builtins.bool] user_oauth_applications: Allow users to register any application to use GitLab as an OAuth provider.
        :param pulumi.Input[_builtins.bool] user_show_add_ssh_key_message: When set to false disable the You won't be able to pull or push project code via SSH warning shown to users with no uploaded SSH key.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] valid_runner_registrars: List of types which are allowed to register a GitLab Runner. Can be [], ['group'], ['project'] or ['group', 'project'].
        :param pulumi.Input[_builtins.bool] version_check_enabled: Let GitLab inform you when an update is available.
        :param pulumi.Input[_builtins.bool] web_ide_clientside_preview_enabled: Live Preview (allow live previews of JavaScript projects in the Web IDE using CodeSandbox Live Preview).
        :param pulumi.Input[_builtins.str] whats_new_variant: What's new variant, possible values: all*tiers, current*tier, and disabled.
        :param pulumi.Input[_builtins.int] wiki_page_max_content_bytes: Maximum wiki page content size in bytes. The minimum value is 1024 bytes.
        """
        if abuse_notification_email is not None:
            pulumi.set(__self__, "abuse_notification_email", abuse_notification_email)
        if admin_mode is not None:
            pulumi.set(__self__, "admin_mode", admin_mode)
        if after_sign_out_path is not None:
            pulumi.set(__self__, "after_sign_out_path", after_sign_out_path)
        if after_sign_up_text is not None:
            pulumi.set(__self__, "after_sign_up_text", after_sign_up_text)
        if akismet_api_key is not None:
            pulumi.set(__self__, "akismet_api_key", akismet_api_key)
        if akismet_enabled is not None:
            pulumi.set(__self__, "akismet_enabled", akismet_enabled)
        if allow_account_deletion is not None:
            pulumi.set(__self__, "allow_account_deletion", allow_account_deletion)
        if allow_group_owners_to_manage_ldap is not None:
            pulumi.set(__self__, "allow_group_owners_to_manage_ldap", allow_group_owners_to_manage_ldap)
        if allow_local_requests_from_system_hooks is not None:
            pulumi.set(__self__, "allow_local_requests_from_system_hooks", allow_local_requests_from_system_hooks)
        if allow_local_requests_from_web_hooks_and_services is not None:
            pulumi.set(__self__, "allow_local_requests_from_web_hooks_and_services", allow_local_requests_from_web_hooks_and_services)
        if allow_project_creation_for_guest_and_below is not None:
            pulumi.set(__self__, "allow_project_creation_for_guest_and_below", allow_project_creation_for_guest_and_below)
        if allow_runner_registration_token is not None:
            pulumi.set(__self__, "allow_runner_registration_token", allow_runner_registration_token)
        if archive_builds_in_human_readable is not None:
            pulumi.set(__self__, "archive_builds_in_human_readable", archive_builds_in_human_readable)
        if asciidoc_max_includes is not None:
            pulumi.set(__self__, "asciidoc_max_includes", asciidoc_max_includes)
        if asset_proxy_allowlists is not None:
            pulumi.set(__self__, "asset_proxy_allowlists", asset_proxy_allowlists)
        if asset_proxy_enabled is not None:
            pulumi.set(__self__, "asset_proxy_enabled", asset_proxy_enabled)
        if asset_proxy_secret_key is not None:
            pulumi.set(__self__, "asset_proxy_secret_key", asset_proxy_secret_key)
        if asset_proxy_url is not None:
            pulumi.set(__self__, "asset_proxy_url", asset_proxy_url)
        if authorized_keys_enabled is not None:
            pulumi.set(__self__, "authorized_keys_enabled", authorized_keys_enabled)
        if auto_ban_user_on_excessive_projects_download is not None:
            pulumi.set(__self__, "auto_ban_user_on_excessive_projects_download", auto_ban_user_on_excessive_projects_download)
        if auto_devops_domain is not None:
            pulumi.set(__self__, "auto_devops_domain", auto_devops_domain)
        if auto_devops_enabled is not None:
            pulumi.set(__self__, "auto_devops_enabled", auto_devops_enabled)
        if automatic_purchased_storage_allocation is not None:
            pulumi.set(__self__, "automatic_purchased_storage_allocation", automatic_purchased_storage_allocation)
        if bulk_import_concurrent_pipeline_batch_limit is not None:
            pulumi.set(__self__, "bulk_import_concurrent_pipeline_batch_limit", bulk_import_concurrent_pipeline_batch_limit)
        if bulk_import_enabled is not None:
            pulumi.set(__self__, "bulk_import_enabled", bulk_import_enabled)
        if bulk_import_max_download_file_size is not None:
            pulumi.set(__self__, "bulk_import_max_download_file_size", bulk_import_max_download_file_size)
        if can_create_group is not None:
            pulumi.set(__self__, "can_create_group", can_create_group)
        if check_namespace_plan is not None:
            pulumi.set(__self__, "check_namespace_plan", check_namespace_plan)
        if ci_max_includes is not None:
            pulumi.set(__self__, "ci_max_includes", ci_max_includes)
        if ci_max_total_yaml_size_bytes is not None:
            pulumi.set(__self__, "ci_max_total_yaml_size_bytes", ci_max_total_yaml_size_bytes)
        if commit_email_hostname is not None:
            pulumi.set(__self__, "commit_email_hostname", commit_email_hostname)
        if concurrent_bitbucket_import_jobs_limit is not None:
            pulumi.set(__self__, "concurrent_bitbucket_import_jobs_limit", concurrent_bitbucket_import_jobs_limit)
        if concurrent_bitbucket_server_import_jobs_limit is not None:
            pulumi.set(__self__, "concurrent_bitbucket_server_import_jobs_limit", concurrent_bitbucket_server_import_jobs_limit)
        if concurrent_github_import_jobs_limit is not None:
            pulumi.set(__self__, "concurrent_github_import_jobs_limit", concurrent_github_import_jobs_limit)
        if container_expiration_policies_enable_historic_entries is not None:
            pulumi.set(__self__, "container_expiration_policies_enable_historic_entries", container_expiration_policies_enable_historic_entries)
        if container_registry_cleanup_tags_service_max_list_size is not None:
            pulumi.set(__self__, "container_registry_cleanup_tags_service_max_list_size", container_registry_cleanup_tags_service_max_list_size)
        if container_registry_delete_tags_service_timeout is not None:
            pulumi.set(__self__, "container_registry_delete_tags_service_timeout", container_registry_delete_tags_service_timeout)
        if container_registry_expiration_policies_caching is not None:
            pulumi.set(__self__, "container_registry_expiration_policies_caching", container_registry_expiration_policies_caching)
        if container_registry_expiration_policies_worker_capacity is not None:
            pulumi.set(__self__, "container_registry_expiration_policies_worker_capacity", container_registry_expiration_policies_worker_capacity)
        if container_registry_token_expire_delay is not None:
            pulumi.set(__self__, "container_registry_token_expire_delay", container_registry_token_expire_delay)
        if deactivate_dormant_users is not None:
            pulumi.set(__self__, "deactivate_dormant_users", deactivate_dormant_users)
        if deactivate_dormant_users_period is not None:
            pulumi.set(__self__, "deactivate_dormant_users_period", deactivate_dormant_users_period)
        if decompress_archive_file_timeout is not None:
            pulumi.set(__self__, "decompress_archive_file_timeout", decompress_archive_file_timeout)
        if default_artifacts_expire_in is not None:
            pulumi.set(__self__, "default_artifacts_expire_in", default_artifacts_expire_in)
        if default_branch_name is not None:
            pulumi.set(__self__, "default_branch_name", default_branch_name)
        if default_branch_protection is not None:
            warnings.warn("""Use `default_branch_protection_defaults` instead. To be removed in 19.0.""", DeprecationWarning)
            pulumi.log.warn("""default_branch_protection is deprecated: Use `default_branch_protection_defaults` instead. To be removed in 19.0.""")
        if default_branch_protection is not None:
            pulumi.set(__self__, "default_branch_protection", default_branch_protection)
        if default_branch_protection_defaults is not None:
            pulumi.set(__self__, "default_branch_protection_defaults", default_branch_protection_defaults)
        if default_ci_config_path is not None:
            pulumi.set(__self__, "default_ci_config_path", default_ci_config_path)
        if default_group_visibility is not None:
            pulumi.set(__self__, "default_group_visibility", default_group_visibility)
        if default_preferred_language is not None:
            pulumi.set(__self__, "default_preferred_language", default_preferred_language)
        if default_project_creation is not None:
            pulumi.set(__self__, "default_project_creation", default_project_creation)
        if default_project_visibility is not None:
            pulumi.set(__self__, "default_project_visibility", default_project_visibility)
        if default_projects_limit is not None:
            pulumi.set(__self__, "default_projects_limit", default_projects_limit)
        if default_snippet_visibility is not None:
            pulumi.set(__self__, "default_snippet_visibility", default_snippet_visibility)
        if default_syntax_highlighting_theme is not None:
            pulumi.set(__self__, "default_syntax_highlighting_theme", default_syntax_highlighting_theme)
        if delete_inactive_projects is not None:
            pulumi.set(__self__, "delete_inactive_projects", delete_inactive_projects)
        if delete_unconfirmed_users is not None:
            pulumi.set(__self__, "delete_unconfirmed_users", delete_unconfirmed_users)
        if deletion_adjourned_period is not None:
            pulumi.set(__self__, "deletion_adjourned_period", deletion_adjourned_period)
        if diagramsnet_enabled is not None:
            pulumi.set(__self__, "diagramsnet_enabled", diagramsnet_enabled)
        if diagramsnet_url is not None:
            pulumi.set(__self__, "diagramsnet_url", diagramsnet_url)
        if diff_max_files is not None:
            pulumi.set(__self__, "diff_max_files", diff_max_files)
        if diff_max_lines is not None:
            pulumi.set(__self__, "diff_max_lines", diff_max_lines)
        if diff_max_patch_bytes is not None:
            pulumi.set(__self__, "diff_max_patch_bytes", diff_max_patch_bytes)
        if disable_admin_oauth_scopes is not None:
            pulumi.set(__self__, "disable_admin_oauth_scopes", disable_admin_oauth_scopes)
        if disable_feed_token is not None:
            pulumi.set(__self__, "disable_feed_token", disable_feed_token)
        if disable_personal_access_tokens is not None:
            pulumi.set(__self__, "disable_personal_access_tokens", disable_personal_access_tokens)
        if disabled_oauth_sign_in_sources is not None:
            pulumi.set(__self__, "disabled_oauth_sign_in_sources", disabled_oauth_sign_in_sources)
        if dns_rebinding_protection_enabled is not None:
            pulumi.set(__self__, "dns_rebinding_protection_enabled", dns_rebinding_protection_enabled)
        if domain_allowlists is not None:
            pulumi.set(__self__, "domain_allowlists", domain_allowlists)
        if domain_denylist_enabled is not None:
            pulumi.set(__self__, "domain_denylist_enabled", domain_denylist_enabled)
        if domain_denylists is not None:
            pulumi.set(__self__, "domain_denylists", domain_denylists)
        if downstream_pipeline_trigger_limit_per_project_user_sha is not None:
            pulumi.set(__self__, "downstream_pipeline_trigger_limit_per_project_user_sha", downstream_pipeline_trigger_limit_per_project_user_sha)
        if dsa_key_restriction is not None:
            pulumi.set(__self__, "dsa_key_restriction", dsa_key_restriction)
        if duo_features_enabled is not None:
            pulumi.set(__self__, "duo_features_enabled", duo_features_enabled)
        if ecdsa_key_restriction is not None:
            pulumi.set(__self__, "ecdsa_key_restriction", ecdsa_key_restriction)
        if ecdsa_sk_key_restriction is not None:
            pulumi.set(__self__, "ecdsa_sk_key_restriction", ecdsa_sk_key_restriction)
        if ed25519_key_restriction is not None:
            pulumi.set(__self__, "ed25519_key_restriction", ed25519_key_restriction)
        if ed25519_sk_key_restriction is not None:
            pulumi.set(__self__, "ed25519_sk_key_restriction", ed25519_sk_key_restriction)
        if eks_access_key_id is not None:
            pulumi.set(__self__, "eks_access_key_id", eks_access_key_id)
        if eks_account_id is not None:
            pulumi.set(__self__, "eks_account_id", eks_account_id)
        if eks_integration_enabled is not None:
            pulumi.set(__self__, "eks_integration_enabled", eks_integration_enabled)
        if eks_secret_access_key is not None:
            pulumi.set(__self__, "eks_secret_access_key", eks_secret_access_key)
        if elasticsearch_aws is not None:
            pulumi.set(__self__, "elasticsearch_aws", elasticsearch_aws)
        if elasticsearch_aws_access_key is not None:
            pulumi.set(__self__, "elasticsearch_aws_access_key", elasticsearch_aws_access_key)
        if elasticsearch_aws_region is not None:
            pulumi.set(__self__, "elasticsearch_aws_region", elasticsearch_aws_region)
        if elasticsearch_aws_secret_access_key is not None:
            pulumi.set(__self__, "elasticsearch_aws_secret_access_key", elasticsearch_aws_secret_access_key)
        if elasticsearch_indexed_field_length_limit is not None:
            pulumi.set(__self__, "elasticsearch_indexed_field_length_limit", elasticsearch_indexed_field_length_limit)
        if elasticsearch_indexed_file_size_limit_kb is not None:
            pulumi.set(__self__, "elasticsearch_indexed_file_size_limit_kb", elasticsearch_indexed_file_size_limit_kb)
        if elasticsearch_indexing is not None:
            pulumi.set(__self__, "elasticsearch_indexing", elasticsearch_indexing)
        if elasticsearch_limit_indexing is not None:
            pulumi.set(__self__, "elasticsearch_limit_indexing", elasticsearch_limit_indexing)
        if elasticsearch_max_bulk_concurrency is not None:
            pulumi.set(__self__, "elasticsearch_max_bulk_concurrency", elasticsearch_max_bulk_concurrency)
        if elasticsearch_max_bulk_size_mb is not None:
            pulumi.set(__self__, "elasticsearch_max_bulk_size_mb", elasticsearch_max_bulk_size_mb)
        if elasticsearch_max_code_indexing_concurrency is not None:
            pulumi.set(__self__, "elasticsearch_max_code_indexing_concurrency", elasticsearch_max_code_indexing_concurrency)
        if elasticsearch_namespace_ids is not None:
            pulumi.set(__self__, "elasticsearch_namespace_ids", elasticsearch_namespace_ids)
        if elasticsearch_password is not None:
            pulumi.set(__self__, "elasticsearch_password", elasticsearch_password)
        if elasticsearch_project_ids is not None:
            pulumi.set(__self__, "elasticsearch_project_ids", elasticsearch_project_ids)
        if elasticsearch_requeue_workers is not None:
            pulumi.set(__self__, "elasticsearch_requeue_workers", elasticsearch_requeue_workers)
        if elasticsearch_search is not None:
            pulumi.set(__self__, "elasticsearch_search", elasticsearch_search)
        if elasticsearch_urls is not None:
            pulumi.set(__self__, "elasticsearch_urls", elasticsearch_urls)
        if elasticsearch_username is not None:
            pulumi.set(__self__, "elasticsearch_username", elasticsearch_username)
        if elasticsearch_worker_number_of_shards is not None:
            pulumi.set(__self__, "elasticsearch_worker_number_of_shards", elasticsearch_worker_number_of_shards)
        if email_additional_text is not None:
            pulumi.set(__self__, "email_additional_text", email_additional_text)
        if email_author_in_body is not None:
            pulumi.set(__self__, "email_author_in_body", email_author_in_body)
        if email_confirmation_setting is not None:
            pulumi.set(__self__, "email_confirmation_setting", email_confirmation_setting)
        if enable_artifact_external_redirect_warning_page is not None:
            pulumi.set(__self__, "enable_artifact_external_redirect_warning_page", enable_artifact_external_redirect_warning_page)
        if enabled_git_access_protocol is not None:
            pulumi.set(__self__, "enabled_git_access_protocol", enabled_git_access_protocol)
        if enforce_namespace_storage_limit is not None:
            pulumi.set(__self__, "enforce_namespace_storage_limit", enforce_namespace_storage_limit)
        if enforce_terms is not None:
            pulumi.set(__self__, "enforce_terms", enforce_terms)
        if external_auth_client_cert is not None:
            pulumi.set(__self__, "external_auth_client_cert", external_auth_client_cert)
        if external_auth_client_key is not None:
            pulumi.set(__self__, "external_auth_client_key", external_auth_client_key)
        if external_auth_client_key_pass is not None:
            pulumi.set(__self__, "external_auth_client_key_pass", external_auth_client_key_pass)
        if external_authorization_service_default_label is not None:
            pulumi.set(__self__, "external_authorization_service_default_label", external_authorization_service_default_label)
        if external_authorization_service_enabled is not None:
            pulumi.set(__self__, "external_authorization_service_enabled", external_authorization_service_enabled)
        if external_authorization_service_timeout is not None:
            pulumi.set(__self__, "external_authorization_service_timeout", external_authorization_service_timeout)
        if external_authorization_service_url is not None:
            pulumi.set(__self__, "external_authorization_service_url", external_authorization_service_url)
        if external_pipeline_validation_service_timeout is not None:
            pulumi.set(__self__, "external_pipeline_validation_service_timeout", external_pipeline_validation_service_timeout)
        if external_pipeline_validation_service_token is not None:
            pulumi.set(__self__, "external_pipeline_validation_service_token", external_pipeline_validation_service_token)
        if external_pipeline_validation_service_url is not None:
            pulumi.set(__self__, "external_pipeline_validation_service_url", external_pipeline_validation_service_url)
        if failed_login_attempts_unlock_period_in_minutes is not None:
            pulumi.set(__self__, "failed_login_attempts_unlock_period_in_minutes", failed_login_attempts_unlock_period_in_minutes)
        if file_template_project_id is not None:
            pulumi.set(__self__, "file_template_project_id", file_template_project_id)
        if first_day_of_week is not None:
            pulumi.set(__self__, "first_day_of_week", first_day_of_week)
        if geo_node_allowed_ips is not None:
            pulumi.set(__self__, "geo_node_allowed_ips", geo_node_allowed_ips)
        if geo_status_timeout is not None:
            pulumi.set(__self__, "geo_status_timeout", geo_status_timeout)
        if git_rate_limit_users_alertlists is not None:
            pulumi.set(__self__, "git_rate_limit_users_alertlists", git_rate_limit_users_alertlists)
        if git_rate_limit_users_allowlists is not None:
            pulumi.set(__self__, "git_rate_limit_users_allowlists", git_rate_limit_users_allowlists)
        if git_two_factor_session_expiry is not None:
            pulumi.set(__self__, "git_two_factor_session_expiry", git_two_factor_session_expiry)
        if gitaly_timeout_default is not None:
            pulumi.set(__self__, "gitaly_timeout_default", gitaly_timeout_default)
        if gitaly_timeout_fast is not None:
            pulumi.set(__self__, "gitaly_timeout_fast", gitaly_timeout_fast)
        if gitaly_timeout_medium is not None:
            pulumi.set(__self__, "gitaly_timeout_medium", gitaly_timeout_medium)
        if gitlab_dedicated_instance is not None:
            pulumi.set(__self__, "gitlab_dedicated_instance", gitlab_dedicated_instance)
        if gitlab_environment_toolkit_instance is not None:
            pulumi.set(__self__, "gitlab_environment_toolkit_instance", gitlab_environment_toolkit_instance)
        if gitlab_shell_operation_limit is not None:
            pulumi.set(__self__, "gitlab_shell_operation_limit", gitlab_shell_operation_limit)
        if gitpod_enabled is not None:
            pulumi.set(__self__, "gitpod_enabled", gitpod_enabled)
        if gitpod_url is not None:
            pulumi.set(__self__, "gitpod_url", gitpod_url)
        if globally_allowed_ips is not None:
            pulumi.set(__self__, "globally_allowed_ips", globally_allowed_ips)
        if grafana_enabled is not None:
            pulumi.set(__self__, "grafana_enabled", grafana_enabled)
        if grafana_url is not None:
            pulumi.set(__self__, "grafana_url", grafana_url)
        if gravatar_enabled is not None:
            pulumi.set(__self__, "gravatar_enabled", gravatar_enabled)
        if group_owners_can_manage_default_branch_protection is not None:
            pulumi.set(__self__, "group_owners_can_manage_default_branch_protection", group_owners_can_manage_default_branch_protection)
        if help_page_hide_commercial_content is not None:
            pulumi.set(__self__, "help_page_hide_commercial_content", help_page_hide_commercial_content)
        if help_page_support_url is not None:
            pulumi.set(__self__, "help_page_support_url", help_page_support_url)
        if help_page_text is not None:
            pulumi.set(__self__, "help_page_text", help_page_text)
        if help_text is not None:
            pulumi.set(__self__, "help_text", help_text)
        if hide_third_party_offers is not None:
            pulumi.set(__self__, "hide_third_party_offers", hide_third_party_offers)
        if home_page_url is not None:
            pulumi.set(__self__, "home_page_url", home_page_url)
        if housekeeping_enabled is not None:
            pulumi.set(__self__, "housekeeping_enabled", housekeeping_enabled)
        if housekeeping_optimize_repository_period is not None:
            pulumi.set(__self__, "housekeeping_optimize_repository_period", housekeeping_optimize_repository_period)
        if html_emails_enabled is not None:
            pulumi.set(__self__, "html_emails_enabled", html_emails_enabled)
        if import_sources is not None:
            pulumi.set(__self__, "import_sources", import_sources)
        if in_product_marketing_emails_enabled is not None:
            pulumi.set(__self__, "in_product_marketing_emails_enabled", in_product_marketing_emails_enabled)
        if inactive_projects_delete_after_months is not None:
            pulumi.set(__self__, "inactive_projects_delete_after_months", inactive_projects_delete_after_months)
        if inactive_projects_min_size_mb is not None:
            pulumi.set(__self__, "inactive_projects_min_size_mb", inactive_projects_min_size_mb)
        if inactive_projects_send_warning_email_after_months is not None:
            pulumi.set(__self__, "inactive_projects_send_warning_email_after_months", inactive_projects_send_warning_email_after_months)
        if include_optional_metrics_in_service_ping is not None:
            pulumi.set(__self__, "include_optional_metrics_in_service_ping", include_optional_metrics_in_service_ping)
        if invisible_captcha_enabled is not None:
            pulumi.set(__self__, "invisible_captcha_enabled", invisible_captcha_enabled)
        if issues_create_limit is not None:
            pulumi.set(__self__, "issues_create_limit", issues_create_limit)
        if jira_connect_application_key is not None:
            pulumi.set(__self__, "jira_connect_application_key", jira_connect_application_key)
        if jira_connect_proxy_url is not None:
            pulumi.set(__self__, "jira_connect_proxy_url", jira_connect_proxy_url)
        if jira_connect_public_key_storage_enabled is not None:
            pulumi.set(__self__, "jira_connect_public_key_storage_enabled", jira_connect_public_key_storage_enabled)
        if keep_latest_artifact is not None:
            pulumi.set(__self__, "keep_latest_artifact", keep_latest_artifact)
        if local_markdown_version is not None:
            pulumi.set(__self__, "local_markdown_version", local_markdown_version)
        if lock_duo_features_enabled is not None:
            pulumi.set(__self__, "lock_duo_features_enabled", lock_duo_features_enabled)
        if lock_memberships_to_ldap is not None:
            pulumi.set(__self__, "lock_memberships_to_ldap", lock_memberships_to_ldap)
        if mailgun_events_enabled is not None:
            pulumi.set(__self__, "mailgun_events_enabled", mailgun_events_enabled)
        if mailgun_signing_key is not None:
            pulumi.set(__self__, "mailgun_signing_key", mailgun_signing_key)
        if maintenance_mode is not None:
            pulumi.set(__self__, "maintenance_mode", maintenance_mode)
        if maintenance_mode_message is not None:
            pulumi.set(__self__, "maintenance_mode_message", maintenance_mode_message)
        if maven_package_requests_forwarding is not None:
            pulumi.set(__self__, "maven_package_requests_forwarding", maven_package_requests_forwarding)
        if max_artifacts_size is not None:
            pulumi.set(__self__, "max_artifacts_size", max_artifacts_size)
        if max_attachment_size is not None:
            pulumi.set(__self__, "max_attachment_size", max_attachment_size)
        if max_decompressed_archive_size is not None:
            pulumi.set(__self__, "max_decompressed_archive_size", max_decompressed_archive_size)
        if max_export_size is not None:
            pulumi.set(__self__, "max_export_size", max_export_size)
        if max_import_remote_file_size is not None:
            pulumi.set(__self__, "max_import_remote_file_size", max_import_remote_file_size)
        if max_import_size is not None:
            pulumi.set(__self__, "max_import_size", max_import_size)
        if max_login_attempts is not None:
            pulumi.set(__self__, "max_login_attempts", max_login_attempts)
        if max_number_of_repository_downloads is not None:
            pulumi.set(__self__, "max_number_of_repository_downloads", max_number_of_repository_downloads)
        if max_number_of_repository_downloads_within_time_period is not None:
            pulumi.set(__self__, "max_number_of_repository_downloads_within_time_period", max_number_of_repository_downloads_within_time_period)
        if max_pages_size is not None:
            pulumi.set(__self__, "max_pages_size", max_pages_size)
        if max_personal_access_token_lifetime is not None:
            pulumi.set(__self__, "max_personal_access_token_lifetime", max_personal_access_token_lifetime)
        if max_ssh_key_lifetime is not None:
            pulumi.set(__self__, "max_ssh_key_lifetime", max_ssh_key_lifetime)
        if max_terraform_state_size_bytes is not None:
            pulumi.set(__self__, "max_terraform_state_size_bytes", max_terraform_state_size_bytes)
        if metrics_method_call_threshold is not None:
            pulumi.set(__self__, "metrics_method_call_threshold", metrics_method_call_threshold)
        if minimum_password_length is not None:
            pulumi.set(__self__, "minimum_password_length", minimum_password_length)
        if mirror_available is not None:
            pulumi.set(__self__, "mirror_available", mirror_available)
        if mirror_capacity_threshold is not None:
            pulumi.set(__self__, "mirror_capacity_threshold", mirror_capacity_threshold)
        if mirror_max_capacity is not None:
            pulumi.set(__self__, "mirror_max_capacity", mirror_max_capacity)
        if mirror_max_delay is not None:
            pulumi.set(__self__, "mirror_max_delay", mirror_max_delay)
        if npm_package_requests_forwarding is not None:
            pulumi.set(__self__, "npm_package_requests_forwarding", npm_package_requests_forwarding)
        if nuget_skip_metadata_url_validation is not None:
            pulumi.set(__self__, "nuget_skip_metadata_url_validation", nuget_skip_metadata_url_validation)
        if outbound_local_requests_whitelists is not None:
            pulumi.set(__self__, "outbound_local_requests_whitelists", outbound_local_requests_whitelists)
        if package_metadata_purl_types is not None:
            pulumi.set(__self__, "package_metadata_purl_types", package_metadata_purl_types)
        if package_registry_allow_anyone_to_pull_option is not None:
            pulumi.set(__self__, "package_registry_allow_anyone_to_pull_option", package_registry_allow_anyone_to_pull_option)
        if package_registry_cleanup_policies_worker_capacity is not None:
            pulumi.set(__self__, "package_registry_cleanup_policies_worker_capacity", package_registry_cleanup_policies_worker_capacity)
        if pages_domain_verification_enabled is not None:
            pulumi.set(__self__, "pages_domain_verification_enabled", pages_domain_verification_enabled)
        if password_authentication_enabled_for_git is not None:
            pulumi.set(__self__, "password_authentication_enabled_for_git", password_authentication_enabled_for_git)
        if password_authentication_enabled_for_web is not None:
            pulumi.set(__self__, "password_authentication_enabled_for_web", password_authentication_enabled_for_web)
        if password_lowercase_required is not None:
            pulumi.set(__self__, "password_lowercase_required", password_lowercase_required)
        if password_number_required is not None:
            pulumi.set(__self__, "password_number_required", password_number_required)
        if password_symbol_required is not None:
            pulumi.set(__self__, "password_symbol_required", password_symbol_required)
        if password_uppercase_required is not None:
            pulumi.set(__self__, "password_uppercase_required", password_uppercase_required)
        if performance_bar_allowed_group_path is not None:
            pulumi.set(__self__, "performance_bar_allowed_group_path", performance_bar_allowed_group_path)
        if personal_access_token_prefix is not None:
            pulumi.set(__self__, "personal_access_token_prefix", personal_access_token_prefix)
        if pipeline_limit_per_project_user_sha is not None:
            pulumi.set(__self__, "pipeline_limit_per_project_user_sha", pipeline_limit_per_project_user_sha)
        if plantuml_enabled is not None:
            pulumi.set(__self__, "plantuml_enabled", plantuml_enabled)
        if plantuml_url is not None:
            pulumi.set(__self__, "plantuml_url", plantuml_url)
        if polling_interval_multiplier is not None:
            pulumi.set(__self__, "polling_interval_multiplier", polling_interval_multiplier)
        if project_export_enabled is not None:
            pulumi.set(__self__, "project_export_enabled", project_export_enabled)
        if project_jobs_api_rate_limit is not None:
            pulumi.set(__self__, "project_jobs_api_rate_limit", project_jobs_api_rate_limit)
        if projects_api_rate_limit_unauthenticated is not None:
            pulumi.set(__self__, "projects_api_rate_limit_unauthenticated", projects_api_rate_limit_unauthenticated)
        if prometheus_metrics_enabled is not None:
            pulumi.set(__self__, "prometheus_metrics_enabled", prometheus_metrics_enabled)
        if protected_ci_variables is not None:
            pulumi.set(__self__, "protected_ci_variables", protected_ci_variables)
        if push_event_activities_limit is not None:
            pulumi.set(__self__, "push_event_activities_limit", push_event_activities_limit)
        if push_event_hooks_limit is not None:
            pulumi.set(__self__, "push_event_hooks_limit", push_event_hooks_limit)
        if pypi_package_requests_forwarding is not None:
            pulumi.set(__self__, "pypi_package_requests_forwarding", pypi_package_requests_forwarding)
        if rate_limiting_response_text is not None:
            pulumi.set(__self__, "rate_limiting_response_text", rate_limiting_response_text)
        if raw_blob_request_limit is not None:
            pulumi.set(__self__, "raw_blob_request_limit", raw_blob_request_limit)
        if recaptcha_enabled is not None:
            pulumi.set(__self__, "recaptcha_enabled", recaptcha_enabled)
        if recaptcha_private_key is not None:
            pulumi.set(__self__, "recaptcha_private_key", recaptcha_private_key)
        if recaptcha_site_key is not None:
            pulumi.set(__self__, "recaptcha_site_key", recaptcha_site_key)
        if receive_max_input_size is not None:
            pulumi.set(__self__, "receive_max_input_size", receive_max_input_size)
        if receptive_cluster_agents_enabled is not None:
            pulumi.set(__self__, "receptive_cluster_agents_enabled", receptive_cluster_agents_enabled)
        if remember_me_enabled is not None:
            pulumi.set(__self__, "remember_me_enabled", remember_me_enabled)
        if repository_checks_enabled is not None:
            pulumi.set(__self__, "repository_checks_enabled", repository_checks_enabled)
        if repository_size_limit is not None:
            pulumi.set(__self__, "repository_size_limit", repository_size_limit)
        if repository_storages_weighted is not None:
            pulumi.set(__self__, "repository_storages_weighted", repository_storages_weighted)
        if require_admin_approval_after_user_signup is not None:
            pulumi.set(__self__, "require_admin_approval_after_user_signup", require_admin_approval_after_user_signup)
        if require_admin_two_factor_authentication is not None:
            pulumi.set(__self__, "require_admin_two_factor_authentication", require_admin_two_factor_authentication)
        if require_personal_access_token_expiry is not None:
            pulumi.set(__self__, "require_personal_access_token_expiry", require_personal_access_token_expiry)
        if require_two_factor_authentication is not None:
            pulumi.set(__self__, "require_two_factor_authentication", require_two_factor_authentication)
        if restricted_visibility_levels is not None:
            pulumi.set(__self__, "restricted_visibility_levels", restricted_visibility_levels)
        if rsa_key_restriction is not None:
            pulumi.set(__self__, "rsa_key_restriction", rsa_key_restriction)
        if search_rate_limit is not None:
            pulumi.set(__self__, "search_rate_limit", search_rate_limit)
        if search_rate_limit_unauthenticated is not None:
            pulumi.set(__self__, "search_rate_limit_unauthenticated", search_rate_limit_unauthenticated)
        if security_approval_policies_limit is not None:
            pulumi.set(__self__, "security_approval_policies_limit", security_approval_policies_limit)
        if security_policy_global_group_approvers_enabled is not None:
            pulumi.set(__self__, "security_policy_global_group_approvers_enabled", security_policy_global_group_approvers_enabled)
        if security_txt_content is not None:
            pulumi.set(__self__, "security_txt_content", security_txt_content)
        if send_user_confirmation_email is not None:
            pulumi.set(__self__, "send_user_confirmation_email", send_user_confirmation_email)
        if service_access_tokens_expiration_enforced is not None:
            pulumi.set(__self__, "service_access_tokens_expiration_enforced", service_access_tokens_expiration_enforced)
        if session_expire_delay is not None:
            pulumi.set(__self__, "session_expire_delay", session_expire_delay)
        if shared_runners_enabled is not None:
            pulumi.set(__self__, "shared_runners_enabled", shared_runners_enabled)
        if shared_runners_minutes is not None:
            pulumi.set(__self__, "shared_runners_minutes", shared_runners_minutes)
        if shared_runners_text is not None:
            pulumi.set(__self__, "shared_runners_text", shared_runners_text)
        if sidekiq_job_limiter_compression_threshold_bytes is not None:
            pulumi.set(__self__, "sidekiq_job_limiter_compression_threshold_bytes", sidekiq_job_limiter_compression_threshold_bytes)
        if sidekiq_job_limiter_limit_bytes is not None:
            pulumi.set(__self__, "sidekiq_job_limiter_limit_bytes", sidekiq_job_limiter_limit_bytes)
        if sidekiq_job_limiter_mode is not None:
            pulumi.set(__self__, "sidekiq_job_limiter_mode", sidekiq_job_limiter_mode)
        if sign_in_text is not None:
            pulumi.set(__self__, "sign_in_text", sign_in_text)
        if signup_enabled is not None:
            pulumi.set(__self__, "signup_enabled", signup_enabled)
        if silent_admin_exports_enabled is not None:
            pulumi.set(__self__, "silent_admin_exports_enabled", silent_admin_exports_enabled)
        if silent_mode_enabled is not None:
            pulumi.set(__self__, "silent_mode_enabled", silent_mode_enabled)
        if slack_app_enabled is not None:
            pulumi.set(__self__, "slack_app_enabled", slack_app_enabled)
        if slack_app_id is not None:
            pulumi.set(__self__, "slack_app_id", slack_app_id)
        if slack_app_secret is not None:
            pulumi.set(__self__, "slack_app_secret", slack_app_secret)
        if slack_app_signing_secret is not None:
            pulumi.set(__self__, "slack_app_signing_secret", slack_app_signing_secret)
        if slack_app_verification_token is not None:
            pulumi.set(__self__, "slack_app_verification_token", slack_app_verification_token)
        if snippet_size_limit is not None:
            pulumi.set(__self__, "snippet_size_limit", snippet_size_limit)
        if snowplow_app_id is not None:
            pulumi.set(__self__, "snowplow_app_id", snowplow_app_id)
        if snowplow_collector_hostname is not None:
            pulumi.set(__self__, "snowplow_collector_hostname", snowplow_collector_hostname)
        if snowplow_cookie_domain is not None:
            pulumi.set(__self__, "snowplow_cookie_domain", snowplow_cookie_domain)
        if snowplow_database_collector_hostname is not None:
            pulumi.set(__self__, "snowplow_database_collector_hostname", snowplow_database_collector_hostname)
        if snowplow_enabled is not None:
            pulumi.set(__self__, "snowplow_enabled", snowplow_enabled)
        if sourcegraph_enabled is not None:
            pulumi.set(__self__, "sourcegraph_enabled", sourcegraph_enabled)
        if sourcegraph_public_only is not None:
            pulumi.set(__self__, "sourcegraph_public_only", sourcegraph_public_only)
        if sourcegraph_url is not None:
            pulumi.set(__self__, "sourcegraph_url", sourcegraph_url)
        if spam_check_api_key is not None:
            pulumi.set(__self__, "spam_check_api_key", spam_check_api_key)
        if spam_check_endpoint_enabled is not None:
            pulumi.set(__self__, "spam_check_endpoint_enabled", spam_check_endpoint_enabled)
        if spam_check_endpoint_url is not None:
            pulumi.set(__self__, "spam_check_endpoint_url", spam_check_endpoint_url)
        if static_objects_external_storage_auth_token is not None:
            pulumi.set(__self__, "static_objects_external_storage_auth_token", static_objects_external_storage_auth_token)
        if static_objects_external_storage_url is not None:
            pulumi.set(__self__, "static_objects_external_storage_url", static_objects_external_storage_url)
        if suggest_pipeline_enabled is not None:
            pulumi.set(__self__, "suggest_pipeline_enabled", suggest_pipeline_enabled)
        if terminal_max_session_time is not None:
            pulumi.set(__self__, "terminal_max_session_time", terminal_max_session_time)
        if terms is not None:
            pulumi.set(__self__, "terms", terms)
        if throttle_authenticated_api_enabled is not None:
            pulumi.set(__self__, "throttle_authenticated_api_enabled", throttle_authenticated_api_enabled)
        if throttle_authenticated_api_period_in_seconds is not None:
            pulumi.set(__self__, "throttle_authenticated_api_period_in_seconds", throttle_authenticated_api_period_in_seconds)
        if throttle_authenticated_api_requests_per_period is not None:
            pulumi.set(__self__, "throttle_authenticated_api_requests_per_period", throttle_authenticated_api_requests_per_period)
        if throttle_authenticated_packages_api_enabled is not None:
            pulumi.set(__self__, "throttle_authenticated_packages_api_enabled", throttle_authenticated_packages_api_enabled)
        if throttle_authenticated_packages_api_period_in_seconds is not None:
            pulumi.set(__self__, "throttle_authenticated_packages_api_period_in_seconds", throttle_authenticated_packages_api_period_in_seconds)
        if throttle_authenticated_packages_api_requests_per_period is not None:
            pulumi.set(__self__, "throttle_authenticated_packages_api_requests_per_period", throttle_authenticated_packages_api_requests_per_period)
        if throttle_authenticated_web_enabled is not None:
            pulumi.set(__self__, "throttle_authenticated_web_enabled", throttle_authenticated_web_enabled)
        if throttle_authenticated_web_period_in_seconds is not None:
            pulumi.set(__self__, "throttle_authenticated_web_period_in_seconds", throttle_authenticated_web_period_in_seconds)
        if throttle_authenticated_web_requests_per_period is not None:
            pulumi.set(__self__, "throttle_authenticated_web_requests_per_period", throttle_authenticated_web_requests_per_period)
        if throttle_unauthenticated_api_enabled is not None:
            pulumi.set(__self__, "throttle_unauthenticated_api_enabled", throttle_unauthenticated_api_enabled)
        if throttle_unauthenticated_api_period_in_seconds is not None:
            pulumi.set(__self__, "throttle_unauthenticated_api_period_in_seconds", throttle_unauthenticated_api_period_in_seconds)
        if throttle_unauthenticated_api_requests_per_period is not None:
            pulumi.set(__self__, "throttle_unauthenticated_api_requests_per_period", throttle_unauthenticated_api_requests_per_period)
        if throttle_unauthenticated_packages_api_enabled is not None:
            pulumi.set(__self__, "throttle_unauthenticated_packages_api_enabled", throttle_unauthenticated_packages_api_enabled)
        if throttle_unauthenticated_packages_api_period_in_seconds is not None:
            pulumi.set(__self__, "throttle_unauthenticated_packages_api_period_in_seconds", throttle_unauthenticated_packages_api_period_in_seconds)
        if throttle_unauthenticated_packages_api_requests_per_period is not None:
            pulumi.set(__self__, "throttle_unauthenticated_packages_api_requests_per_period", throttle_unauthenticated_packages_api_requests_per_period)
        if throttle_unauthenticated_web_enabled is not None:
            pulumi.set(__self__, "throttle_unauthenticated_web_enabled", throttle_unauthenticated_web_enabled)
        if throttle_unauthenticated_web_period_in_seconds is not None:
            pulumi.set(__self__, "throttle_unauthenticated_web_period_in_seconds", throttle_unauthenticated_web_period_in_seconds)
        if throttle_unauthenticated_web_requests_per_period is not None:
            pulumi.set(__self__, "throttle_unauthenticated_web_requests_per_period", throttle_unauthenticated_web_requests_per_period)
        if time_tracking_limit_to_hours is not None:
            pulumi.set(__self__, "time_tracking_limit_to_hours", time_tracking_limit_to_hours)
        if two_factor_grace_period is not None:
            pulumi.set(__self__, "two_factor_grace_period", two_factor_grace_period)
        if unconfirmed_users_delete_after_days is not None:
            pulumi.set(__self__, "unconfirmed_users_delete_after_days", unconfirmed_users_delete_after_days)
        if unique_ips_limit_enabled is not None:
            pulumi.set(__self__, "unique_ips_limit_enabled", unique_ips_limit_enabled)
        if unique_ips_limit_per_user is not None:
            pulumi.set(__self__, "unique_ips_limit_per_user", unique_ips_limit_per_user)
        if unique_ips_limit_time_window is not None:
            pulumi.set(__self__, "unique_ips_limit_time_window", unique_ips_limit_time_window)
        if update_runner_versions_enabled is not None:
            pulumi.set(__self__, "update_runner_versions_enabled", update_runner_versions_enabled)
        if usage_ping_enabled is not None:
            pulumi.set(__self__, "usage_ping_enabled", usage_ping_enabled)
        if use_clickhouse_for_analytics is not None:
            pulumi.set(__self__, "use_clickhouse_for_analytics", use_clickhouse_for_analytics)
        if user_deactivation_emails_enabled is not None:
            pulumi.set(__self__, "user_deactivation_emails_enabled", user_deactivation_emails_enabled)
        if user_default_external is not None:
            pulumi.set(__self__, "user_default_external", user_default_external)
        if user_default_internal_regex is not None:
            pulumi.set(__self__, "user_default_internal_regex", user_default_internal_regex)
        if user_defaults_to_private_profile is not None:
            pulumi.set(__self__, "user_defaults_to_private_profile", user_defaults_to_private_profile)
        if user_oauth_applications is not None:
            pulumi.set(__self__, "user_oauth_applications", user_oauth_applications)
        if user_show_add_ssh_key_message is not None:
            pulumi.set(__self__, "user_show_add_ssh_key_message", user_show_add_ssh_key_message)
        if valid_runner_registrars is not None:
            pulumi.set(__self__, "valid_runner_registrars", valid_runner_registrars)
        if version_check_enabled is not None:
            pulumi.set(__self__, "version_check_enabled", version_check_enabled)
        if web_ide_clientside_preview_enabled is not None:
            pulumi.set(__self__, "web_ide_clientside_preview_enabled", web_ide_clientside_preview_enabled)
        if whats_new_variant is not None:
            pulumi.set(__self__, "whats_new_variant", whats_new_variant)
        if wiki_page_max_content_bytes is not None:
            pulumi.set(__self__, "wiki_page_max_content_bytes", wiki_page_max_content_bytes)

    @_builtins.property
    @pulumi.getter(name="abuseNotificationEmail")
    def abuse_notification_email(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        If set, abuse reports are sent to this address. Abuse reports are always available in the Admin Area.
        """
        return pulumi.get(self, "abuse_notification_email")

    @abuse_notification_email.setter
    def abuse_notification_email(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "abuse_notification_email", value)

    @_builtins.property
    @pulumi.getter(name="adminMode")
    def admin_mode(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Require administrators to enable Admin Mode by re-authenticating for administrative tasks.
        """
        return pulumi.get(self, "admin_mode")

    @admin_mode.setter
    def admin_mode(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "admin_mode", value)

    @_builtins.property
    @pulumi.getter(name="afterSignOutPath")
    def after_sign_out_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Where to redirect users after logout.
        """
        return pulumi.get(self, "after_sign_out_path")

    @after_sign_out_path.setter
    def after_sign_out_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "after_sign_out_path", value)

    @_builtins.property
    @pulumi.getter(name="afterSignUpText")
    def after_sign_up_text(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Text shown to the user after signing up.
        """
        return pulumi.get(self, "after_sign_up_text")

    @after_sign_up_text.setter
    def after_sign_up_text(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "after_sign_up_text", value)

    @_builtins.property
    @pulumi.getter(name="akismetApiKey")
    def akismet_api_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        API key for Akismet spam protection.
        """
        return pulumi.get(self, "akismet_api_key")

    @akismet_api_key.setter
    def akismet_api_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "akismet_api_key", value)

    @_builtins.property
    @pulumi.getter(name="akismetEnabled")
    def akismet_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: akismet*api*key) Enable or disable Akismet spam protection.
        """
        return pulumi.get(self, "akismet_enabled")

    @akismet_enabled.setter
    def akismet_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "akismet_enabled", value)

    @_builtins.property
    @pulumi.getter(name="allowAccountDeletion")
    def allow_account_deletion(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to true to allow users to delete their accounts. Premium and Ultimate only.
        """
        return pulumi.get(self, "allow_account_deletion")

    @allow_account_deletion.setter
    def allow_account_deletion(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_account_deletion", value)

    @_builtins.property
    @pulumi.getter(name="allowGroupOwnersToManageLdap")
    def allow_group_owners_to_manage_ldap(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to true to allow group owners to manage LDAP.
        """
        return pulumi.get(self, "allow_group_owners_to_manage_ldap")

    @allow_group_owners_to_manage_ldap.setter
    def allow_group_owners_to_manage_ldap(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_group_owners_to_manage_ldap", value)

    @_builtins.property
    @pulumi.getter(name="allowLocalRequestsFromSystemHooks")
    def allow_local_requests_from_system_hooks(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow requests to the local network from system hooks.
        """
        return pulumi.get(self, "allow_local_requests_from_system_hooks")

    @allow_local_requests_from_system_hooks.setter
    def allow_local_requests_from_system_hooks(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_local_requests_from_system_hooks", value)

    @_builtins.property
    @pulumi.getter(name="allowLocalRequestsFromWebHooksAndServices")
    def allow_local_requests_from_web_hooks_and_services(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow requests to the local network from web hooks and services.
        """
        return pulumi.get(self, "allow_local_requests_from_web_hooks_and_services")

    @allow_local_requests_from_web_hooks_and_services.setter
    def allow_local_requests_from_web_hooks_and_services(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_local_requests_from_web_hooks_and_services", value)

    @_builtins.property
    @pulumi.getter(name="allowProjectCreationForGuestAndBelow")
    def allow_project_creation_for_guest_and_below(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether users assigned up to the Guest role can create groups and personal projects.
        """
        return pulumi.get(self, "allow_project_creation_for_guest_and_below")

    @allow_project_creation_for_guest_and_below.setter
    def allow_project_creation_for_guest_and_below(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_project_creation_for_guest_and_below", value)

    @_builtins.property
    @pulumi.getter(name="allowRunnerRegistrationToken")
    def allow_runner_registration_token(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow using a registration token to create a runner.
        """
        return pulumi.get(self, "allow_runner_registration_token")

    @allow_runner_registration_token.setter
    def allow_runner_registration_token(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_runner_registration_token", value)

    @_builtins.property
    @pulumi.getter(name="archiveBuildsInHumanReadable")
    def archive_builds_in_human_readable(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Set the duration for which the jobs are considered as old and expired. After that time passes, the jobs are archived and no longer able to be retried. Make it empty to never expire jobs. It has to be no less than 1 day, for example: 15 days, 1 month, 2 years.
        """
        return pulumi.get(self, "archive_builds_in_human_readable")

    @archive_builds_in_human_readable.setter
    def archive_builds_in_human_readable(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "archive_builds_in_human_readable", value)

    @_builtins.property
    @pulumi.getter(name="asciidocMaxIncludes")
    def asciidoc_max_includes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum limit of AsciiDoc include directives being processed in any one document. Maximum: 64.
        """
        return pulumi.get(self, "asciidoc_max_includes")

    @asciidoc_max_includes.setter
    def asciidoc_max_includes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "asciidoc_max_includes", value)

    @_builtins.property
    @pulumi.getter(name="assetProxyAllowlists")
    def asset_proxy_allowlists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Assets that match these domains are not proxied. Wildcards allowed. Your GitLab installation URL is automatically allowlisted. GitLab restart is required to apply changes.
        """
        return pulumi.get(self, "asset_proxy_allowlists")

    @asset_proxy_allowlists.setter
    def asset_proxy_allowlists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "asset_proxy_allowlists", value)

    @_builtins.property
    @pulumi.getter(name="assetProxyEnabled")
    def asset_proxy_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: asset*proxy*url) Enable proxying of assets. GitLab restart is required to apply changes.
        """
        return pulumi.get(self, "asset_proxy_enabled")

    @asset_proxy_enabled.setter
    def asset_proxy_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "asset_proxy_enabled", value)

    @_builtins.property
    @pulumi.getter(name="assetProxySecretKey")
    def asset_proxy_secret_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Shared secret with the asset proxy server. GitLab restart is required to apply changes.
        """
        return pulumi.get(self, "asset_proxy_secret_key")

    @asset_proxy_secret_key.setter
    def asset_proxy_secret_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "asset_proxy_secret_key", value)

    @_builtins.property
    @pulumi.getter(name="assetProxyUrl")
    def asset_proxy_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        URL of the asset proxy server. GitLab restart is required to apply changes.
        """
        return pulumi.get(self, "asset_proxy_url")

    @asset_proxy_url.setter
    def asset_proxy_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "asset_proxy_url", value)

    @_builtins.property
    @pulumi.getter(name="authorizedKeysEnabled")
    def authorized_keys_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        By default, we write to the authorized_keys file to support Git over SSH without additional configuration. GitLab can be optimized to authenticate SSH keys via the database file. Only disable this if you have configured your OpenSSH server to use the AuthorizedKeysCommand.
        """
        return pulumi.get(self, "authorized_keys_enabled")

    @authorized_keys_enabled.setter
    def authorized_keys_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "authorized_keys_enabled", value)

    @_builtins.property
    @pulumi.getter(name="autoBanUserOnExcessiveProjectsDownload")
    def auto_ban_user_on_excessive_projects_download(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When enabled, users will get automatically banned from the application when they download more than the maximum number of unique projects in the time period specified by max*number*of*repository*downloads and max*number*of*repository*downloads*within*time_period respectively. Self-managed, Ultimate only.
        """
        return pulumi.get(self, "auto_ban_user_on_excessive_projects_download")

    @auto_ban_user_on_excessive_projects_download.setter
    def auto_ban_user_on_excessive_projects_download(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "auto_ban_user_on_excessive_projects_download", value)

    @_builtins.property
    @pulumi.getter(name="autoDevopsDomain")
    def auto_devops_domain(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specify a domain to use by default for every project’s Auto Review Apps and Auto Deploy stages.
        """
        return pulumi.get(self, "auto_devops_domain")

    @auto_devops_domain.setter
    def auto_devops_domain(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "auto_devops_domain", value)

    @_builtins.property
    @pulumi.getter(name="autoDevopsEnabled")
    def auto_devops_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable Auto DevOps for projects by default. It automatically builds, tests, and deploys applications based on a predefined CI/CD configuration.
        """
        return pulumi.get(self, "auto_devops_enabled")

    @auto_devops_enabled.setter
    def auto_devops_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "auto_devops_enabled", value)

    @_builtins.property
    @pulumi.getter(name="automaticPurchasedStorageAllocation")
    def automatic_purchased_storage_allocation(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enabling this permits automatic allocation of purchased storage in a namespace.
        """
        return pulumi.get(self, "automatic_purchased_storage_allocation")

    @automatic_purchased_storage_allocation.setter
    def automatic_purchased_storage_allocation(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "automatic_purchased_storage_allocation", value)

    @_builtins.property
    @pulumi.getter(name="bulkImportConcurrentPipelineBatchLimit")
    def bulk_import_concurrent_pipeline_batch_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum simultaneous Direct Transfer batches to process.
        """
        return pulumi.get(self, "bulk_import_concurrent_pipeline_batch_limit")

    @bulk_import_concurrent_pipeline_batch_limit.setter
    def bulk_import_concurrent_pipeline_batch_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "bulk_import_concurrent_pipeline_batch_limit", value)

    @_builtins.property
    @pulumi.getter(name="bulkImportEnabled")
    def bulk_import_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable migrating GitLab groups by direct transfer.
        """
        return pulumi.get(self, "bulk_import_enabled")

    @bulk_import_enabled.setter
    def bulk_import_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "bulk_import_enabled", value)

    @_builtins.property
    @pulumi.getter(name="bulkImportMaxDownloadFileSize")
    def bulk_import_max_download_file_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum download file size when importing from source GitLab instances by direct transfer.
        """
        return pulumi.get(self, "bulk_import_max_download_file_size")

    @bulk_import_max_download_file_size.setter
    def bulk_import_max_download_file_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "bulk_import_max_download_file_size", value)

    @_builtins.property
    @pulumi.getter(name="canCreateGroup")
    def can_create_group(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether users can create top-level groups.
        """
        return pulumi.get(self, "can_create_group")

    @can_create_group.setter
    def can_create_group(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "can_create_group", value)

    @_builtins.property
    @pulumi.getter(name="checkNamespacePlan")
    def check_namespace_plan(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enabling this makes only licensed EE features available to projects if the project namespace’s plan includes the feature or if the project is public.
        """
        return pulumi.get(self, "check_namespace_plan")

    @check_namespace_plan.setter
    def check_namespace_plan(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "check_namespace_plan", value)

    @_builtins.property
    @pulumi.getter(name="ciMaxIncludes")
    def ci_max_includes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum number of includes per pipeline.
        """
        return pulumi.get(self, "ci_max_includes")

    @ci_max_includes.setter
    def ci_max_includes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "ci_max_includes", value)

    @_builtins.property
    @pulumi.getter(name="ciMaxTotalYamlSizeBytes")
    def ci_max_total_yaml_size_bytes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum amount of memory, in bytes, that can be allocated for the pipeline configuration, with all included YAML configuration files.
        """
        return pulumi.get(self, "ci_max_total_yaml_size_bytes")

    @ci_max_total_yaml_size_bytes.setter
    def ci_max_total_yaml_size_bytes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "ci_max_total_yaml_size_bytes", value)

    @_builtins.property
    @pulumi.getter(name="commitEmailHostname")
    def commit_email_hostname(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Custom hostname (for private commit emails).
        """
        return pulumi.get(self, "commit_email_hostname")

    @commit_email_hostname.setter
    def commit_email_hostname(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "commit_email_hostname", value)

    @_builtins.property
    @pulumi.getter(name="concurrentBitbucketImportJobsLimit")
    def concurrent_bitbucket_import_jobs_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum number of simultaneous import jobs for the Bitbucket Cloud importer.
        """
        return pulumi.get(self, "concurrent_bitbucket_import_jobs_limit")

    @concurrent_bitbucket_import_jobs_limit.setter
    def concurrent_bitbucket_import_jobs_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "concurrent_bitbucket_import_jobs_limit", value)

    @_builtins.property
    @pulumi.getter(name="concurrentBitbucketServerImportJobsLimit")
    def concurrent_bitbucket_server_import_jobs_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum number of simultaneous import jobs for the Bitbucket Server importer.
        """
        return pulumi.get(self, "concurrent_bitbucket_server_import_jobs_limit")

    @concurrent_bitbucket_server_import_jobs_limit.setter
    def concurrent_bitbucket_server_import_jobs_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "concurrent_bitbucket_server_import_jobs_limit", value)

    @_builtins.property
    @pulumi.getter(name="concurrentGithubImportJobsLimit")
    def concurrent_github_import_jobs_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum number of simultaneous import jobs for the GitHub importer.
        """
        return pulumi.get(self, "concurrent_github_import_jobs_limit")

    @concurrent_github_import_jobs_limit.setter
    def concurrent_github_import_jobs_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "concurrent_github_import_jobs_limit", value)

    @_builtins.property
    @pulumi.getter(name="containerExpirationPoliciesEnableHistoricEntries")
    def container_expiration_policies_enable_historic_entries(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable cleanup policies for all projects.
        """
        return pulumi.get(self, "container_expiration_policies_enable_historic_entries")

    @container_expiration_policies_enable_historic_entries.setter
    def container_expiration_policies_enable_historic_entries(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "container_expiration_policies_enable_historic_entries", value)

    @_builtins.property
    @pulumi.getter(name="containerRegistryCleanupTagsServiceMaxListSize")
    def container_registry_cleanup_tags_service_max_list_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum number of tags that can be deleted in a single execution of cleanup policies.
        """
        return pulumi.get(self, "container_registry_cleanup_tags_service_max_list_size")

    @container_registry_cleanup_tags_service_max_list_size.setter
    def container_registry_cleanup_tags_service_max_list_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "container_registry_cleanup_tags_service_max_list_size", value)

    @_builtins.property
    @pulumi.getter(name="containerRegistryDeleteTagsServiceTimeout")
    def container_registry_delete_tags_service_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum time, in seconds, that the cleanup process can take to delete a batch of tags for cleanup policies.
        """
        return pulumi.get(self, "container_registry_delete_tags_service_timeout")

    @container_registry_delete_tags_service_timeout.setter
    def container_registry_delete_tags_service_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "container_registry_delete_tags_service_timeout", value)

    @_builtins.property
    @pulumi.getter(name="containerRegistryExpirationPoliciesCaching")
    def container_registry_expiration_policies_caching(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Caching during the execution of cleanup policies.
        """
        return pulumi.get(self, "container_registry_expiration_policies_caching")

    @container_registry_expiration_policies_caching.setter
    def container_registry_expiration_policies_caching(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "container_registry_expiration_policies_caching", value)

    @_builtins.property
    @pulumi.getter(name="containerRegistryExpirationPoliciesWorkerCapacity")
    def container_registry_expiration_policies_worker_capacity(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Number of workers for cleanup policies.
        """
        return pulumi.get(self, "container_registry_expiration_policies_worker_capacity")

    @container_registry_expiration_policies_worker_capacity.setter
    def container_registry_expiration_policies_worker_capacity(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "container_registry_expiration_policies_worker_capacity", value)

    @_builtins.property
    @pulumi.getter(name="containerRegistryTokenExpireDelay")
    def container_registry_token_expire_delay(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Container Registry token duration in minutes.
        """
        return pulumi.get(self, "container_registry_token_expire_delay")

    @container_registry_token_expire_delay.setter
    def container_registry_token_expire_delay(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "container_registry_token_expire_delay", value)

    @_builtins.property
    @pulumi.getter(name="deactivateDormantUsers")
    def deactivate_dormant_users(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable automatic deactivation of dormant users.
        """
        return pulumi.get(self, "deactivate_dormant_users")

    @deactivate_dormant_users.setter
    def deactivate_dormant_users(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "deactivate_dormant_users", value)

    @_builtins.property
    @pulumi.getter(name="deactivateDormantUsersPeriod")
    def deactivate_dormant_users_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Length of time (in days) after which a user is considered dormant.
        """
        return pulumi.get(self, "deactivate_dormant_users_period")

    @deactivate_dormant_users_period.setter
    def deactivate_dormant_users_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "deactivate_dormant_users_period", value)

    @_builtins.property
    @pulumi.getter(name="decompressArchiveFileTimeout")
    def decompress_archive_file_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Default timeout for decompressing archived files, in seconds. Set to 0 to disable timeouts.
        """
        return pulumi.get(self, "decompress_archive_file_timeout")

    @decompress_archive_file_timeout.setter
    def decompress_archive_file_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "decompress_archive_file_timeout", value)

    @_builtins.property
    @pulumi.getter(name="defaultArtifactsExpireIn")
    def default_artifacts_expire_in(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Set the default expiration time for each job’s artifacts.
        """
        return pulumi.get(self, "default_artifacts_expire_in")

    @default_artifacts_expire_in.setter
    def default_artifacts_expire_in(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_artifacts_expire_in", value)

    @_builtins.property
    @pulumi.getter(name="defaultBranchName")
    def default_branch_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Instance-level custom initial branch name
        """
        return pulumi.get(self, "default_branch_name")

    @default_branch_name.setter
    def default_branch_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_branch_name", value)

    @_builtins.property
    @pulumi.getter(name="defaultBranchProtection")
    @_utilities.deprecated("""Use `default_branch_protection_defaults` instead. To be removed in 19.0.""")
    def default_branch_protection(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Determine if developers can push to the default branch. Can take: 0 (not protected, both users with the Developer role or Maintainer role can push new commits and force push), 1 (partially protected, users with the Developer role or Maintainer role can push new commits, but cannot force push) or 2 (fully protected, users with the Developer or Maintainer role cannot push new commits, but users with the Developer or Maintainer role can; no one can force push) as a parameter. Default is 2. Use `default_branch_protection_defaults` instead. To be removed in 19.0.
        """
        return pulumi.get(self, "default_branch_protection")

    @default_branch_protection.setter
    def default_branch_protection(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "default_branch_protection", value)

    @_builtins.property
    @pulumi.getter(name="defaultBranchProtectionDefaults")
    def default_branch_protection_defaults(self) -> Optional[pulumi.Input['ApplicationSettingsDefaultBranchProtectionDefaultsArgs']]:
        """
        The default*branch*protection*defaults attribute describes the default branch protection defaults. All parameters are optional.
        """
        return pulumi.get(self, "default_branch_protection_defaults")

    @default_branch_protection_defaults.setter
    def default_branch_protection_defaults(self, value: Optional[pulumi.Input['ApplicationSettingsDefaultBranchProtectionDefaultsArgs']]):
        pulumi.set(self, "default_branch_protection_defaults", value)

    @_builtins.property
    @pulumi.getter(name="defaultCiConfigPath")
    def default_ci_config_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Default CI/CD configuration file and path for new projects (.gitlab-ci.yml if not set).
        """
        return pulumi.get(self, "default_ci_config_path")

    @default_ci_config_path.setter
    def default_ci_config_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_ci_config_path", value)

    @_builtins.property
    @pulumi.getter(name="defaultGroupVisibility")
    def default_group_visibility(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        What visibility level new groups receive. Can take private, internal and public as a parameter.
        """
        return pulumi.get(self, "default_group_visibility")

    @default_group_visibility.setter
    def default_group_visibility(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_group_visibility", value)

    @_builtins.property
    @pulumi.getter(name="defaultPreferredLanguage")
    def default_preferred_language(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Default preferred language for users who are not logged in.
        """
        return pulumi.get(self, "default_preferred_language")

    @default_preferred_language.setter
    def default_preferred_language(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_preferred_language", value)

    @_builtins.property
    @pulumi.getter(name="defaultProjectCreation")
    def default_project_creation(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Default project creation protection. Can take: 0 (No one), 1 (Maintainers) or 2 (Developers + Maintainers).
        """
        return pulumi.get(self, "default_project_creation")

    @default_project_creation.setter
    def default_project_creation(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "default_project_creation", value)

    @_builtins.property
    @pulumi.getter(name="defaultProjectVisibility")
    def default_project_visibility(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        What visibility level new projects receive. Can take private, internal and public as a parameter.
        """
        return pulumi.get(self, "default_project_visibility")

    @default_project_visibility.setter
    def default_project_visibility(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_project_visibility", value)

    @_builtins.property
    @pulumi.getter(name="defaultProjectsLimit")
    def default_projects_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Project limit per user.
        """
        return pulumi.get(self, "default_projects_limit")

    @default_projects_limit.setter
    def default_projects_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "default_projects_limit", value)

    @_builtins.property
    @pulumi.getter(name="defaultSnippetVisibility")
    def default_snippet_visibility(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        What visibility level new snippets receive. Can take private, internal and public as a parameter.
        """
        return pulumi.get(self, "default_snippet_visibility")

    @default_snippet_visibility.setter
    def default_snippet_visibility(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_snippet_visibility", value)

    @_builtins.property
    @pulumi.getter(name="defaultSyntaxHighlightingTheme")
    def default_syntax_highlighting_theme(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Default syntax highlighting theme for users who are new or not signed in. See IDs of available themes (https://gitlab.com/gitlab-org/gitlab/blob/master/lib/gitlab/themes.rb#L16)
        """
        return pulumi.get(self, "default_syntax_highlighting_theme")

    @default_syntax_highlighting_theme.setter
    def default_syntax_highlighting_theme(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "default_syntax_highlighting_theme", value)

    @_builtins.property
    @pulumi.getter(name="deleteInactiveProjects")
    def delete_inactive_projects(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable inactive project deletion feature.
        """
        return pulumi.get(self, "delete_inactive_projects")

    @delete_inactive_projects.setter
    def delete_inactive_projects(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "delete_inactive_projects", value)

    @_builtins.property
    @pulumi.getter(name="deleteUnconfirmedUsers")
    def delete_unconfirmed_users(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Specifies whether users who have not confirmed their email should be deleted. When set to true, unconfirmed users are deleted after unconfirmed*users*delete*after*days days. Self-managed, Premium and Ultimate only.
        """
        return pulumi.get(self, "delete_unconfirmed_users")

    @delete_unconfirmed_users.setter
    def delete_unconfirmed_users(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "delete_unconfirmed_users", value)

    @_builtins.property
    @pulumi.getter(name="deletionAdjournedPeriod")
    def deletion_adjourned_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of days to wait before deleting a project or group that is marked for deletion. Value must be between 1 and 90.
        """
        return pulumi.get(self, "deletion_adjourned_period")

    @deletion_adjourned_period.setter
    def deletion_adjourned_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "deletion_adjourned_period", value)

    @_builtins.property
    @pulumi.getter(name="diagramsnetEnabled")
    def diagramsnet_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires diagramsnet_url) Enable Diagrams.net integration.
        """
        return pulumi.get(self, "diagramsnet_enabled")

    @diagramsnet_enabled.setter
    def diagramsnet_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "diagramsnet_enabled", value)

    @_builtins.property
    @pulumi.getter(name="diagramsnetUrl")
    def diagramsnet_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Diagrams.net instance URL for integration.
        """
        return pulumi.get(self, "diagramsnet_url")

    @diagramsnet_url.setter
    def diagramsnet_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "diagramsnet_url", value)

    @_builtins.property
    @pulumi.getter(name="diffMaxFiles")
    def diff_max_files(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum files in a diff.
        """
        return pulumi.get(self, "diff_max_files")

    @diff_max_files.setter
    def diff_max_files(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "diff_max_files", value)

    @_builtins.property
    @pulumi.getter(name="diffMaxLines")
    def diff_max_lines(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum lines in a diff.
        """
        return pulumi.get(self, "diff_max_lines")

    @diff_max_lines.setter
    def diff_max_lines(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "diff_max_lines", value)

    @_builtins.property
    @pulumi.getter(name="diffMaxPatchBytes")
    def diff_max_patch_bytes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum diff patch size, in bytes.
        """
        return pulumi.get(self, "diff_max_patch_bytes")

    @diff_max_patch_bytes.setter
    def diff_max_patch_bytes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "diff_max_patch_bytes", value)

    @_builtins.property
    @pulumi.getter(name="disableAdminOauthScopes")
    def disable_admin_oauth_scopes(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Stops administrators from connecting their GitLab accounts to non-trusted OAuth 2.0 applications that have the api, read*api, read*repository, write*repository, read*registry, write_registry, or sudo scopes.
        """
        return pulumi.get(self, "disable_admin_oauth_scopes")

    @disable_admin_oauth_scopes.setter
    def disable_admin_oauth_scopes(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disable_admin_oauth_scopes", value)

    @_builtins.property
    @pulumi.getter(name="disableFeedToken")
    def disable_feed_token(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Disable display of RSS/Atom and calendar feed tokens.
        """
        return pulumi.get(self, "disable_feed_token")

    @disable_feed_token.setter
    def disable_feed_token(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disable_feed_token", value)

    @_builtins.property
    @pulumi.getter(name="disablePersonalAccessTokens")
    def disable_personal_access_tokens(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Disable personal access tokens. Self-managed, Premium and Ultimate only. There is no method available to enable a personal access token that’s been disabled through the API. This is a known issue.
        """
        return pulumi.get(self, "disable_personal_access_tokens")

    @disable_personal_access_tokens.setter
    def disable_personal_access_tokens(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disable_personal_access_tokens", value)

    @_builtins.property
    @pulumi.getter(name="disabledOauthSignInSources")
    def disabled_oauth_sign_in_sources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Disabled OAuth sign-in sources.
        """
        return pulumi.get(self, "disabled_oauth_sign_in_sources")

    @disabled_oauth_sign_in_sources.setter
    def disabled_oauth_sign_in_sources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "disabled_oauth_sign_in_sources", value)

    @_builtins.property
    @pulumi.getter(name="dnsRebindingProtectionEnabled")
    def dns_rebinding_protection_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enforce DNS rebinding attack protection.
        """
        return pulumi.get(self, "dns_rebinding_protection_enabled")

    @dns_rebinding_protection_enabled.setter
    def dns_rebinding_protection_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "dns_rebinding_protection_enabled", value)

    @_builtins.property
    @pulumi.getter(name="domainAllowlists")
    def domain_allowlists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Force people to use only corporate emails for sign-up. Null means there is no restriction.
        """
        return pulumi.get(self, "domain_allowlists")

    @domain_allowlists.setter
    def domain_allowlists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "domain_allowlists", value)

    @_builtins.property
    @pulumi.getter(name="domainDenylistEnabled")
    def domain_denylist_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: domain_denylist) Allows blocking sign-ups from emails from specific domains.
        """
        return pulumi.get(self, "domain_denylist_enabled")

    @domain_denylist_enabled.setter
    def domain_denylist_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "domain_denylist_enabled", value)

    @_builtins.property
    @pulumi.getter(name="domainDenylists")
    def domain_denylists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Users with email addresses that match these domains cannot sign up. Wildcards allowed. Use separate lines for multiple entries. Ex: domain.com, *.domain.com.
        """
        return pulumi.get(self, "domain_denylists")

    @domain_denylists.setter
    def domain_denylists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "domain_denylists", value)

    @_builtins.property
    @pulumi.getter(name="downstreamPipelineTriggerLimitPerProjectUserSha")
    def downstream_pipeline_trigger_limit_per_project_user_sha(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum downstream pipeline trigger rate.
        """
        return pulumi.get(self, "downstream_pipeline_trigger_limit_per_project_user_sha")

    @downstream_pipeline_trigger_limit_per_project_user_sha.setter
    def downstream_pipeline_trigger_limit_per_project_user_sha(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "downstream_pipeline_trigger_limit_per_project_user_sha", value)

    @_builtins.property
    @pulumi.getter(name="dsaKeyRestriction")
    def dsa_key_restriction(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The minimum allowed bit length of an uploaded DSA key. 0 means no restriction. -1 disables DSA keys.
        """
        return pulumi.get(self, "dsa_key_restriction")

    @dsa_key_restriction.setter
    def dsa_key_restriction(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "dsa_key_restriction", value)

    @_builtins.property
    @pulumi.getter(name="duoFeaturesEnabled")
    def duo_features_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether GitLab Duo features are enabled for this instance. Self-managed, Premium and Ultimate only.
        """
        return pulumi.get(self, "duo_features_enabled")

    @duo_features_enabled.setter
    def duo_features_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "duo_features_enabled", value)

    @_builtins.property
    @pulumi.getter(name="ecdsaKeyRestriction")
    def ecdsa_key_restriction(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The minimum allowed curve size (in bits) of an uploaded ECDSA key. 0 means no restriction. -1 disables ECDSA keys.
        """
        return pulumi.get(self, "ecdsa_key_restriction")

    @ecdsa_key_restriction.setter
    def ecdsa_key_restriction(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "ecdsa_key_restriction", value)

    @_builtins.property
    @pulumi.getter(name="ecdsaSkKeyRestriction")
    def ecdsa_sk_key_restriction(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The minimum allowed curve size (in bits) of an uploaded ECDSA*SK key. 0 means no restriction. -1 disables ECDSA*SK keys.
        """
        return pulumi.get(self, "ecdsa_sk_key_restriction")

    @ecdsa_sk_key_restriction.setter
    def ecdsa_sk_key_restriction(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "ecdsa_sk_key_restriction", value)

    @_builtins.property
    @pulumi.getter(name="ed25519KeyRestriction")
    def ed25519_key_restriction(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The minimum allowed curve size (in bits) of an uploaded ED25519 key. 0 means no restriction. -1 disables ED25519 keys.
        """
        return pulumi.get(self, "ed25519_key_restriction")

    @ed25519_key_restriction.setter
    def ed25519_key_restriction(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "ed25519_key_restriction", value)

    @_builtins.property
    @pulumi.getter(name="ed25519SkKeyRestriction")
    def ed25519_sk_key_restriction(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The minimum allowed curve size (in bits) of an uploaded ED25519*SK key. 0 means no restriction. -1 disables ED25519*SK keys.
        """
        return pulumi.get(self, "ed25519_sk_key_restriction")

    @ed25519_sk_key_restriction.setter
    def ed25519_sk_key_restriction(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "ed25519_sk_key_restriction", value)

    @_builtins.property
    @pulumi.getter(name="eksAccessKeyId")
    def eks_access_key_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        AWS IAM access key ID.
        """
        return pulumi.get(self, "eks_access_key_id")

    @eks_access_key_id.setter
    def eks_access_key_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "eks_access_key_id", value)

    @_builtins.property
    @pulumi.getter(name="eksAccountId")
    def eks_account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Amazon account ID.
        """
        return pulumi.get(self, "eks_account_id")

    @eks_account_id.setter
    def eks_account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "eks_account_id", value)

    @_builtins.property
    @pulumi.getter(name="eksIntegrationEnabled")
    def eks_integration_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable integration with Amazon EKS.
        """
        return pulumi.get(self, "eks_integration_enabled")

    @eks_integration_enabled.setter
    def eks_integration_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "eks_integration_enabled", value)

    @_builtins.property
    @pulumi.getter(name="eksSecretAccessKey")
    def eks_secret_access_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        AWS IAM secret access key.
        """
        return pulumi.get(self, "eks_secret_access_key")

    @eks_secret_access_key.setter
    def eks_secret_access_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "eks_secret_access_key", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchAws")
    def elasticsearch_aws(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable the use of AWS hosted Elasticsearch.
        """
        return pulumi.get(self, "elasticsearch_aws")

    @elasticsearch_aws.setter
    def elasticsearch_aws(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "elasticsearch_aws", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchAwsAccessKey")
    def elasticsearch_aws_access_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        AWS IAM access key.
        """
        return pulumi.get(self, "elasticsearch_aws_access_key")

    @elasticsearch_aws_access_key.setter
    def elasticsearch_aws_access_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "elasticsearch_aws_access_key", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchAwsRegion")
    def elasticsearch_aws_region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The AWS region the Elasticsearch domain is configured.
        """
        return pulumi.get(self, "elasticsearch_aws_region")

    @elasticsearch_aws_region.setter
    def elasticsearch_aws_region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "elasticsearch_aws_region", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchAwsSecretAccessKey")
    def elasticsearch_aws_secret_access_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        AWS IAM secret access key.
        """
        return pulumi.get(self, "elasticsearch_aws_secret_access_key")

    @elasticsearch_aws_secret_access_key.setter
    def elasticsearch_aws_secret_access_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "elasticsearch_aws_secret_access_key", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchIndexedFieldLengthLimit")
    def elasticsearch_indexed_field_length_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum size of text fields to index by Elasticsearch. 0 value means no limit. This does not apply to repository and wiki indexing.
        """
        return pulumi.get(self, "elasticsearch_indexed_field_length_limit")

    @elasticsearch_indexed_field_length_limit.setter
    def elasticsearch_indexed_field_length_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "elasticsearch_indexed_field_length_limit", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchIndexedFileSizeLimitKb")
    def elasticsearch_indexed_file_size_limit_kb(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum size of repository and wiki files that are indexed by Elasticsearch.
        """
        return pulumi.get(self, "elasticsearch_indexed_file_size_limit_kb")

    @elasticsearch_indexed_file_size_limit_kb.setter
    def elasticsearch_indexed_file_size_limit_kb(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "elasticsearch_indexed_file_size_limit_kb", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchIndexing")
    def elasticsearch_indexing(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable Elasticsearch indexing.
        """
        return pulumi.get(self, "elasticsearch_indexing")

    @elasticsearch_indexing.setter
    def elasticsearch_indexing(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "elasticsearch_indexing", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchLimitIndexing")
    def elasticsearch_limit_indexing(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Limit Elasticsearch to index certain namespaces and projects.
        """
        return pulumi.get(self, "elasticsearch_limit_indexing")

    @elasticsearch_limit_indexing.setter
    def elasticsearch_limit_indexing(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "elasticsearch_limit_indexing", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchMaxBulkConcurrency")
    def elasticsearch_max_bulk_concurrency(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum concurrency of Elasticsearch bulk requests per indexing operation. This only applies to repository indexing operations.
        """
        return pulumi.get(self, "elasticsearch_max_bulk_concurrency")

    @elasticsearch_max_bulk_concurrency.setter
    def elasticsearch_max_bulk_concurrency(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "elasticsearch_max_bulk_concurrency", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchMaxBulkSizeMb")
    def elasticsearch_max_bulk_size_mb(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum size of Elasticsearch bulk indexing requests in MB. This only applies to repository indexing operations.
        """
        return pulumi.get(self, "elasticsearch_max_bulk_size_mb")

    @elasticsearch_max_bulk_size_mb.setter
    def elasticsearch_max_bulk_size_mb(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "elasticsearch_max_bulk_size_mb", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchMaxCodeIndexingConcurrency")
    def elasticsearch_max_code_indexing_concurrency(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum concurrency of Elasticsearch code indexing background jobs. This only applies to repository indexing operations. Premium and Ultimate only.
        """
        return pulumi.get(self, "elasticsearch_max_code_indexing_concurrency")

    @elasticsearch_max_code_indexing_concurrency.setter
    def elasticsearch_max_code_indexing_concurrency(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "elasticsearch_max_code_indexing_concurrency", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchNamespaceIds")
    def elasticsearch_namespace_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]:
        """
        The namespaces to index via Elasticsearch if elasticsearch*limit*indexing is enabled.
        """
        return pulumi.get(self, "elasticsearch_namespace_ids")

    @elasticsearch_namespace_ids.setter
    def elasticsearch_namespace_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]):
        pulumi.set(self, "elasticsearch_namespace_ids", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchPassword")
    def elasticsearch_password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The password of your Elasticsearch instance.
        """
        return pulumi.get(self, "elasticsearch_password")

    @elasticsearch_password.setter
    def elasticsearch_password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "elasticsearch_password", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchProjectIds")
    def elasticsearch_project_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]:
        """
        The projects to index via Elasticsearch if elasticsearch*limit*indexing is enabled.
        """
        return pulumi.get(self, "elasticsearch_project_ids")

    @elasticsearch_project_ids.setter
    def elasticsearch_project_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]):
        pulumi.set(self, "elasticsearch_project_ids", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchRequeueWorkers")
    def elasticsearch_requeue_workers(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable automatic requeuing of indexing workers. This improves non-code indexing throughput by enqueuing Sidekiq jobs until all documents are processed. Premium and Ultimate only.
        """
        return pulumi.get(self, "elasticsearch_requeue_workers")

    @elasticsearch_requeue_workers.setter
    def elasticsearch_requeue_workers(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "elasticsearch_requeue_workers", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchSearch")
    def elasticsearch_search(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable Elasticsearch search.
        """
        return pulumi.get(self, "elasticsearch_search")

    @elasticsearch_search.setter
    def elasticsearch_search(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "elasticsearch_search", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchUrls")
    def elasticsearch_urls(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The URL to use for connecting to Elasticsearch. Use a comma-separated list to support cluster (for example, http://localhost:9200, http://localhost:9201).
        """
        return pulumi.get(self, "elasticsearch_urls")

    @elasticsearch_urls.setter
    def elasticsearch_urls(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "elasticsearch_urls", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchUsername")
    def elasticsearch_username(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The username of your Elasticsearch instance.
        """
        return pulumi.get(self, "elasticsearch_username")

    @elasticsearch_username.setter
    def elasticsearch_username(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "elasticsearch_username", value)

    @_builtins.property
    @pulumi.getter(name="elasticsearchWorkerNumberOfShards")
    def elasticsearch_worker_number_of_shards(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Number of indexing worker shards. This improves non-code indexing throughput by enqueuing more parallel Sidekiq jobs. Premium and Ultimate only.
        """
        return pulumi.get(self, "elasticsearch_worker_number_of_shards")

    @elasticsearch_worker_number_of_shards.setter
    def elasticsearch_worker_number_of_shards(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "elasticsearch_worker_number_of_shards", value)

    @_builtins.property
    @pulumi.getter(name="emailAdditionalText")
    def email_additional_text(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Additional text added to the bottom of every email for legal/auditing/compliance reasons.
        """
        return pulumi.get(self, "email_additional_text")

    @email_additional_text.setter
    def email_additional_text(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "email_additional_text", value)

    @_builtins.property
    @pulumi.getter(name="emailAuthorInBody")
    def email_author_in_body(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Some email servers do not support overriding the email sender name. Enable this option to include the name of the author of the issue, merge request or comment in the email body instead.
        """
        return pulumi.get(self, "email_author_in_body")

    @email_author_in_body.setter
    def email_author_in_body(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "email_author_in_body", value)

    @_builtins.property
    @pulumi.getter(name="emailConfirmationSetting")
    def email_confirmation_setting(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies whether users must confirm their email before sign in. Possible values are off, soft, and hard.
        """
        return pulumi.get(self, "email_confirmation_setting")

    @email_confirmation_setting.setter
    def email_confirmation_setting(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "email_confirmation_setting", value)

    @_builtins.property
    @pulumi.getter(name="enableArtifactExternalRedirectWarningPage")
    def enable_artifact_external_redirect_warning_page(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Show the external redirect page that warns you about user-generated content in GitLab Pages.
        """
        return pulumi.get(self, "enable_artifact_external_redirect_warning_page")

    @enable_artifact_external_redirect_warning_page.setter
    def enable_artifact_external_redirect_warning_page(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enable_artifact_external_redirect_warning_page", value)

    @_builtins.property
    @pulumi.getter(name="enabledGitAccessProtocol")
    def enabled_git_access_protocol(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Enabled protocols for Git access. Allowed values are: ssh, http, and nil to allow both protocols.
        """
        return pulumi.get(self, "enabled_git_access_protocol")

    @enabled_git_access_protocol.setter
    def enabled_git_access_protocol(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "enabled_git_access_protocol", value)

    @_builtins.property
    @pulumi.getter(name="enforceNamespaceStorageLimit")
    def enforce_namespace_storage_limit(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enabling this permits enforcement of namespace storage limits.
        """
        return pulumi.get(self, "enforce_namespace_storage_limit")

    @enforce_namespace_storage_limit.setter
    def enforce_namespace_storage_limit(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enforce_namespace_storage_limit", value)

    @_builtins.property
    @pulumi.getter(name="enforceTerms")
    def enforce_terms(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: terms) Enforce application ToS to all users.
        """
        return pulumi.get(self, "enforce_terms")

    @enforce_terms.setter
    def enforce_terms(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enforce_terms", value)

    @_builtins.property
    @pulumi.getter(name="externalAuthClientCert")
    def external_auth_client_cert(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (If enabled, requires: external*auth*client_key) The certificate to use to authenticate with the external authorization service.
        """
        return pulumi.get(self, "external_auth_client_cert")

    @external_auth_client_cert.setter
    def external_auth_client_cert(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "external_auth_client_cert", value)

    @_builtins.property
    @pulumi.getter(name="externalAuthClientKey")
    def external_auth_client_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Private key for the certificate when authentication is required for the external authorization service, this is encrypted when stored.
        """
        return pulumi.get(self, "external_auth_client_key")

    @external_auth_client_key.setter
    def external_auth_client_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "external_auth_client_key", value)

    @_builtins.property
    @pulumi.getter(name="externalAuthClientKeyPass")
    def external_auth_client_key_pass(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Passphrase to use for the private key when authenticating with the external service this is encrypted when stored.
        """
        return pulumi.get(self, "external_auth_client_key_pass")

    @external_auth_client_key_pass.setter
    def external_auth_client_key_pass(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "external_auth_client_key_pass", value)

    @_builtins.property
    @pulumi.getter(name="externalAuthorizationServiceDefaultLabel")
    def external_authorization_service_default_label(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The default classification label to use when requesting authorization and no classification label has been specified on the project.
        """
        return pulumi.get(self, "external_authorization_service_default_label")

    @external_authorization_service_default_label.setter
    def external_authorization_service_default_label(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "external_authorization_service_default_label", value)

    @_builtins.property
    @pulumi.getter(name="externalAuthorizationServiceEnabled")
    def external_authorization_service_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: external*authorization*service*default*label, external*authorization*service*timeout and external*authorization*service*url) Enable using an external authorization service for accessing projects.
        """
        return pulumi.get(self, "external_authorization_service_enabled")

    @external_authorization_service_enabled.setter
    def external_authorization_service_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "external_authorization_service_enabled", value)

    @_builtins.property
    @pulumi.getter(name="externalAuthorizationServiceTimeout")
    def external_authorization_service_timeout(self) -> Optional[pulumi.Input[_builtins.float]]:
        """
        The timeout after which an authorization request is aborted, in seconds. When a request times out, access is denied to the user. (min: 0.001, max: 10, step: 0.001).
        """
        return pulumi.get(self, "external_authorization_service_timeout")

    @external_authorization_service_timeout.setter
    def external_authorization_service_timeout(self, value: Optional[pulumi.Input[_builtins.float]]):
        pulumi.set(self, "external_authorization_service_timeout", value)

    @_builtins.property
    @pulumi.getter(name="externalAuthorizationServiceUrl")
    def external_authorization_service_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        URL to which authorization requests are directed.
        """
        return pulumi.get(self, "external_authorization_service_url")

    @external_authorization_service_url.setter
    def external_authorization_service_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "external_authorization_service_url", value)

    @_builtins.property
    @pulumi.getter(name="externalPipelineValidationServiceTimeout")
    def external_pipeline_validation_service_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        How long to wait for a response from the pipeline validation service. Assumes OK if it times out.
        """
        return pulumi.get(self, "external_pipeline_validation_service_timeout")

    @external_pipeline_validation_service_timeout.setter
    def external_pipeline_validation_service_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "external_pipeline_validation_service_timeout", value)

    @_builtins.property
    @pulumi.getter(name="externalPipelineValidationServiceToken")
    def external_pipeline_validation_service_token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Optional. Token to include as the X-Gitlab-Token header in requests to the URL in external*pipeline*validation*service*url.
        """
        return pulumi.get(self, "external_pipeline_validation_service_token")

    @external_pipeline_validation_service_token.setter
    def external_pipeline_validation_service_token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "external_pipeline_validation_service_token", value)

    @_builtins.property
    @pulumi.getter(name="externalPipelineValidationServiceUrl")
    def external_pipeline_validation_service_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        URL to use for pipeline validation requests.
        """
        return pulumi.get(self, "external_pipeline_validation_service_url")

    @external_pipeline_validation_service_url.setter
    def external_pipeline_validation_service_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "external_pipeline_validation_service_url", value)

    @_builtins.property
    @pulumi.getter(name="failedLoginAttemptsUnlockPeriodInMinutes")
    def failed_login_attempts_unlock_period_in_minutes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Time period in minutes after which the user is unlocked when maximum number of failed sign-in attempts reached.
        """
        return pulumi.get(self, "failed_login_attempts_unlock_period_in_minutes")

    @failed_login_attempts_unlock_period_in_minutes.setter
    def failed_login_attempts_unlock_period_in_minutes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "failed_login_attempts_unlock_period_in_minutes", value)

    @_builtins.property
    @pulumi.getter(name="fileTemplateProjectId")
    def file_template_project_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The ID of a project to load custom file templates from.
        """
        return pulumi.get(self, "file_template_project_id")

    @file_template_project_id.setter
    def file_template_project_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "file_template_project_id", value)

    @_builtins.property
    @pulumi.getter(name="firstDayOfWeek")
    def first_day_of_week(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Start day of the week for calendar views and date pickers. Valid values are 0 for Sunday, 1 for Monday, and 6 for Saturday.
        """
        return pulumi.get(self, "first_day_of_week")

    @first_day_of_week.setter
    def first_day_of_week(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "first_day_of_week", value)

    @_builtins.property
    @pulumi.getter(name="geoNodeAllowedIps")
    def geo_node_allowed_ips(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Comma-separated list of IPs and CIDRs of allowed secondary nodes. For example, 1.1.1.1, 2.2.2.0/24.
        """
        return pulumi.get(self, "geo_node_allowed_ips")

    @geo_node_allowed_ips.setter
    def geo_node_allowed_ips(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "geo_node_allowed_ips", value)

    @_builtins.property
    @pulumi.getter(name="geoStatusTimeout")
    def geo_status_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The amount of seconds after which a request to get a secondary node status times out.
        """
        return pulumi.get(self, "geo_status_timeout")

    @geo_status_timeout.setter
    def geo_status_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "geo_status_timeout", value)

    @_builtins.property
    @pulumi.getter(name="gitRateLimitUsersAlertlists")
    def git_rate_limit_users_alertlists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]:
        """
        List of user IDs that are emailed when the Git abuse rate limit is exceeded. Maximum: 100 user IDs. Self-managed, Ultimate only.
        """
        return pulumi.get(self, "git_rate_limit_users_alertlists")

    @git_rate_limit_users_alertlists.setter
    def git_rate_limit_users_alertlists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]):
        pulumi.set(self, "git_rate_limit_users_alertlists", value)

    @_builtins.property
    @pulumi.getter(name="gitRateLimitUsersAllowlists")
    def git_rate_limit_users_allowlists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of usernames excluded from Git anti-abuse rate limits. Maximum: 100 usernames. Self-managed, Ultimate only.
        """
        return pulumi.get(self, "git_rate_limit_users_allowlists")

    @git_rate_limit_users_allowlists.setter
    def git_rate_limit_users_allowlists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "git_rate_limit_users_allowlists", value)

    @_builtins.property
    @pulumi.getter(name="gitTwoFactorSessionExpiry")
    def git_two_factor_session_expiry(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum duration (in minutes) of a session for Git operations when 2FA is enabled.
        """
        return pulumi.get(self, "git_two_factor_session_expiry")

    @git_two_factor_session_expiry.setter
    def git_two_factor_session_expiry(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "git_two_factor_session_expiry", value)

    @_builtins.property
    @pulumi.getter(name="gitalyTimeoutDefault")
    def gitaly_timeout_default(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Default Gitaly timeout, in seconds. This timeout is not enforced for Git fetch/push operations or Sidekiq jobs. Set to 0 to disable timeouts.
        """
        return pulumi.get(self, "gitaly_timeout_default")

    @gitaly_timeout_default.setter
    def gitaly_timeout_default(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "gitaly_timeout_default", value)

    @_builtins.property
    @pulumi.getter(name="gitalyTimeoutFast")
    def gitaly_timeout_fast(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Gitaly fast operation timeout, in seconds. Some Gitaly operations are expected to be fast. If they exceed this threshold, there may be a problem with a storage shard and ‘failing fast’ can help maintain the stability of the GitLab instance. Set to 0 to disable timeouts.
        """
        return pulumi.get(self, "gitaly_timeout_fast")

    @gitaly_timeout_fast.setter
    def gitaly_timeout_fast(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "gitaly_timeout_fast", value)

    @_builtins.property
    @pulumi.getter(name="gitalyTimeoutMedium")
    def gitaly_timeout_medium(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Medium Gitaly timeout, in seconds. This should be a value between the Fast and the Default timeout. Set to 0 to disable timeouts.
        """
        return pulumi.get(self, "gitaly_timeout_medium")

    @gitaly_timeout_medium.setter
    def gitaly_timeout_medium(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "gitaly_timeout_medium", value)

    @_builtins.property
    @pulumi.getter(name="gitlabDedicatedInstance")
    def gitlab_dedicated_instance(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the instance was provisioned for GitLab Dedicated.
        """
        return pulumi.get(self, "gitlab_dedicated_instance")

    @gitlab_dedicated_instance.setter
    def gitlab_dedicated_instance(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "gitlab_dedicated_instance", value)

    @_builtins.property
    @pulumi.getter(name="gitlabEnvironmentToolkitInstance")
    def gitlab_environment_toolkit_instance(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the instance was provisioned with the GitLab Environment Toolkit for Service Ping reporting.
        """
        return pulumi.get(self, "gitlab_environment_toolkit_instance")

    @gitlab_environment_toolkit_instance.setter
    def gitlab_environment_toolkit_instance(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "gitlab_environment_toolkit_instance", value)

    @_builtins.property
    @pulumi.getter(name="gitlabShellOperationLimit")
    def gitlab_shell_operation_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum number of Git operations per minute a user can perform.
        """
        return pulumi.get(self, "gitlab_shell_operation_limit")

    @gitlab_shell_operation_limit.setter
    def gitlab_shell_operation_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "gitlab_shell_operation_limit", value)

    @_builtins.property
    @pulumi.getter(name="gitpodEnabled")
    def gitpod_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable Gitpod integration.
        """
        return pulumi.get(self, "gitpod_enabled")

    @gitpod_enabled.setter
    def gitpod_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "gitpod_enabled", value)

    @_builtins.property
    @pulumi.getter(name="gitpodUrl")
    def gitpod_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Gitpod instance URL for integration.
        """
        return pulumi.get(self, "gitpod_url")

    @gitpod_url.setter
    def gitpod_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "gitpod_url", value)

    @_builtins.property
    @pulumi.getter(name="globallyAllowedIps")
    def globally_allowed_ips(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Comma-separated list of IP addresses and CIDRs always allowed for inbound traffic. For example, 1.1.1.1, 2.2.2.0/24.
        """
        return pulumi.get(self, "globally_allowed_ips")

    @globally_allowed_ips.setter
    def globally_allowed_ips(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "globally_allowed_ips", value)

    @_builtins.property
    @pulumi.getter(name="grafanaEnabled")
    def grafana_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable Grafana.
        """
        return pulumi.get(self, "grafana_enabled")

    @grafana_enabled.setter
    def grafana_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "grafana_enabled", value)

    @_builtins.property
    @pulumi.getter(name="grafanaUrl")
    def grafana_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Grafana URL.
        """
        return pulumi.get(self, "grafana_url")

    @grafana_url.setter
    def grafana_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "grafana_url", value)

    @_builtins.property
    @pulumi.getter(name="gravatarEnabled")
    def gravatar_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable Gravatar.
        """
        return pulumi.get(self, "gravatar_enabled")

    @gravatar_enabled.setter
    def gravatar_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "gravatar_enabled", value)

    @_builtins.property
    @pulumi.getter(name="groupOwnersCanManageDefaultBranchProtection")
    def group_owners_can_manage_default_branch_protection(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Prevent overrides of default branch protection.
        """
        return pulumi.get(self, "group_owners_can_manage_default_branch_protection")

    @group_owners_can_manage_default_branch_protection.setter
    def group_owners_can_manage_default_branch_protection(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "group_owners_can_manage_default_branch_protection", value)

    @_builtins.property
    @pulumi.getter(name="helpPageHideCommercialContent")
    def help_page_hide_commercial_content(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Hide marketing-related entries from help.
        """
        return pulumi.get(self, "help_page_hide_commercial_content")

    @help_page_hide_commercial_content.setter
    def help_page_hide_commercial_content(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "help_page_hide_commercial_content", value)

    @_builtins.property
    @pulumi.getter(name="helpPageSupportUrl")
    def help_page_support_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Alternate support URL for help page and help dropdown.
        """
        return pulumi.get(self, "help_page_support_url")

    @help_page_support_url.setter
    def help_page_support_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "help_page_support_url", value)

    @_builtins.property
    @pulumi.getter(name="helpPageText")
    def help_page_text(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Custom text displayed on the help page.
        """
        return pulumi.get(self, "help_page_text")

    @help_page_text.setter
    def help_page_text(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "help_page_text", value)

    @_builtins.property
    @pulumi.getter(name="helpText")
    def help_text(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        GitLab server administrator information.
        """
        return pulumi.get(self, "help_text")

    @help_text.setter
    def help_text(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "help_text", value)

    @_builtins.property
    @pulumi.getter(name="hideThirdPartyOffers")
    def hide_third_party_offers(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Do not display offers from third parties in GitLab.
        """
        return pulumi.get(self, "hide_third_party_offers")

    @hide_third_party_offers.setter
    def hide_third_party_offers(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "hide_third_party_offers", value)

    @_builtins.property
    @pulumi.getter(name="homePageUrl")
    def home_page_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Redirect to this URL when not logged in.
        """
        return pulumi.get(self, "home_page_url")

    @home_page_url.setter
    def home_page_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "home_page_url", value)

    @_builtins.property
    @pulumi.getter(name="housekeepingEnabled")
    def housekeeping_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable or disable Git housekeeping. If enabled, requires housekeeping*optimize*repository_period.
        """
        return pulumi.get(self, "housekeeping_enabled")

    @housekeeping_enabled.setter
    def housekeeping_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "housekeeping_enabled", value)

    @_builtins.property
    @pulumi.getter(name="housekeepingOptimizeRepositoryPeriod")
    def housekeeping_optimize_repository_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Number of Git pushes after which an incremental git-repack is run.
        """
        return pulumi.get(self, "housekeeping_optimize_repository_period")

    @housekeeping_optimize_repository_period.setter
    def housekeeping_optimize_repository_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "housekeeping_optimize_repository_period", value)

    @_builtins.property
    @pulumi.getter(name="htmlEmailsEnabled")
    def html_emails_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable HTML emails.
        """
        return pulumi.get(self, "html_emails_enabled")

    @html_emails_enabled.setter
    def html_emails_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "html_emails_enabled", value)

    @_builtins.property
    @pulumi.getter(name="importSources")
    def import_sources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Sources to allow project import from. Valid values are: `github`, `bitbucket`, `bitbucket_server`, `fogbugz`, `git`, `Project`, `gitea`, `manifest`
        """
        return pulumi.get(self, "import_sources")

    @import_sources.setter
    def import_sources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "import_sources", value)

    @_builtins.property
    @pulumi.getter(name="inProductMarketingEmailsEnabled")
    def in_product_marketing_emails_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable in-product marketing emails.
        """
        return pulumi.get(self, "in_product_marketing_emails_enabled")

    @in_product_marketing_emails_enabled.setter
    def in_product_marketing_emails_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "in_product_marketing_emails_enabled", value)

    @_builtins.property
    @pulumi.getter(name="inactiveProjectsDeleteAfterMonths")
    def inactive_projects_delete_after_months(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        If delete*inactive*projects is true, the time (in months) to wait before deleting inactive projects.
        """
        return pulumi.get(self, "inactive_projects_delete_after_months")

    @inactive_projects_delete_after_months.setter
    def inactive_projects_delete_after_months(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "inactive_projects_delete_after_months", value)

    @_builtins.property
    @pulumi.getter(name="inactiveProjectsMinSizeMb")
    def inactive_projects_min_size_mb(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        If delete*inactive*projects is true, the minimum repository size for projects to be checked for inactivity.
        """
        return pulumi.get(self, "inactive_projects_min_size_mb")

    @inactive_projects_min_size_mb.setter
    def inactive_projects_min_size_mb(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "inactive_projects_min_size_mb", value)

    @_builtins.property
    @pulumi.getter(name="inactiveProjectsSendWarningEmailAfterMonths")
    def inactive_projects_send_warning_email_after_months(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        If delete*inactive*projects is true, sets the time (in months) to wait before emailing maintainers that the project is scheduled be deleted because it is inactive.
        """
        return pulumi.get(self, "inactive_projects_send_warning_email_after_months")

    @inactive_projects_send_warning_email_after_months.setter
    def inactive_projects_send_warning_email_after_months(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "inactive_projects_send_warning_email_after_months", value)

    @_builtins.property
    @pulumi.getter(name="includeOptionalMetricsInServicePing")
    def include_optional_metrics_in_service_ping(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether or not optional metrics are enabled in Service Ping.
        """
        return pulumi.get(self, "include_optional_metrics_in_service_ping")

    @include_optional_metrics_in_service_ping.setter
    def include_optional_metrics_in_service_ping(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "include_optional_metrics_in_service_ping", value)

    @_builtins.property
    @pulumi.getter(name="invisibleCaptchaEnabled")
    def invisible_captcha_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable Invisible CAPTCHA spam detection during sign-up.
        """
        return pulumi.get(self, "invisible_captcha_enabled")

    @invisible_captcha_enabled.setter
    def invisible_captcha_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "invisible_captcha_enabled", value)

    @_builtins.property
    @pulumi.getter(name="issuesCreateLimit")
    def issues_create_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Max number of issue creation requests per minute per user.
        """
        return pulumi.get(self, "issues_create_limit")

    @issues_create_limit.setter
    def issues_create_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "issues_create_limit", value)

    @_builtins.property
    @pulumi.getter(name="jiraConnectApplicationKey")
    def jira_connect_application_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the OAuth application used to authenticate with the GitLab for Jira Cloud app.
        """
        return pulumi.get(self, "jira_connect_application_key")

    @jira_connect_application_key.setter
    def jira_connect_application_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "jira_connect_application_key", value)

    @_builtins.property
    @pulumi.getter(name="jiraConnectProxyUrl")
    def jira_connect_proxy_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        URL of the GitLab instance used as a proxy for the GitLab for Jira Cloud app.
        """
        return pulumi.get(self, "jira_connect_proxy_url")

    @jira_connect_proxy_url.setter
    def jira_connect_proxy_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "jira_connect_proxy_url", value)

    @_builtins.property
    @pulumi.getter(name="jiraConnectPublicKeyStorageEnabled")
    def jira_connect_public_key_storage_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable public key storage for the GitLab for Jira Cloud app.
        """
        return pulumi.get(self, "jira_connect_public_key_storage_enabled")

    @jira_connect_public_key_storage_enabled.setter
    def jira_connect_public_key_storage_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "jira_connect_public_key_storage_enabled", value)

    @_builtins.property
    @pulumi.getter(name="keepLatestArtifact")
    def keep_latest_artifact(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Prevent the deletion of the artifacts from the most recent successful jobs, regardless of the expiry time.
        """
        return pulumi.get(self, "keep_latest_artifact")

    @keep_latest_artifact.setter
    def keep_latest_artifact(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "keep_latest_artifact", value)

    @_builtins.property
    @pulumi.getter(name="localMarkdownVersion")
    def local_markdown_version(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Increase this value when any cached Markdown should be invalidated.
        """
        return pulumi.get(self, "local_markdown_version")

    @local_markdown_version.setter
    def local_markdown_version(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "local_markdown_version", value)

    @_builtins.property
    @pulumi.getter(name="lockDuoFeaturesEnabled")
    def lock_duo_features_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the GitLab Duo features enabled setting is enforced for all subgroups. Self-managed, Premium and Ultimate only.
        """
        return pulumi.get(self, "lock_duo_features_enabled")

    @lock_duo_features_enabled.setter
    def lock_duo_features_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "lock_duo_features_enabled", value)

    @_builtins.property
    @pulumi.getter(name="lockMembershipsToLdap")
    def lock_memberships_to_ldap(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to true to lock all memberships to LDAP. Premium and Ultimate only.
        """
        return pulumi.get(self, "lock_memberships_to_ldap")

    @lock_memberships_to_ldap.setter
    def lock_memberships_to_ldap(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "lock_memberships_to_ldap", value)

    @_builtins.property
    @pulumi.getter(name="mailgunEventsEnabled")
    def mailgun_events_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable Mailgun event receiver.
        """
        return pulumi.get(self, "mailgun_events_enabled")

    @mailgun_events_enabled.setter
    def mailgun_events_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "mailgun_events_enabled", value)

    @_builtins.property
    @pulumi.getter(name="mailgunSigningKey")
    def mailgun_signing_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Mailgun HTTP webhook signing key for receiving events from webhook.
        """
        return pulumi.get(self, "mailgun_signing_key")

    @mailgun_signing_key.setter
    def mailgun_signing_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mailgun_signing_key", value)

    @_builtins.property
    @pulumi.getter(name="maintenanceMode")
    def maintenance_mode(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When instance is in maintenance mode, non-administrative users can sign in with read-only access and make read-only API requests.
        """
        return pulumi.get(self, "maintenance_mode")

    @maintenance_mode.setter
    def maintenance_mode(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "maintenance_mode", value)

    @_builtins.property
    @pulumi.getter(name="maintenanceModeMessage")
    def maintenance_mode_message(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Message displayed when instance is in maintenance mode.
        """
        return pulumi.get(self, "maintenance_mode_message")

    @maintenance_mode_message.setter
    def maintenance_mode_message(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "maintenance_mode_message", value)

    @_builtins.property
    @pulumi.getter(name="mavenPackageRequestsForwarding")
    def maven_package_requests_forwarding(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Use repo.maven.apache.org as a default remote repository when the package is not found in the GitLab Package Registry for Maven. Premium and Ultimate only.
        """
        return pulumi.get(self, "maven_package_requests_forwarding")

    @maven_package_requests_forwarding.setter
    def maven_package_requests_forwarding(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "maven_package_requests_forwarding", value)

    @_builtins.property
    @pulumi.getter(name="maxArtifactsSize")
    def max_artifacts_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum artifacts size in MB.
        """
        return pulumi.get(self, "max_artifacts_size")

    @max_artifacts_size.setter
    def max_artifacts_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_artifacts_size", value)

    @_builtins.property
    @pulumi.getter(name="maxAttachmentSize")
    def max_attachment_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Limit attachment size in MB.
        """
        return pulumi.get(self, "max_attachment_size")

    @max_attachment_size.setter
    def max_attachment_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_attachment_size", value)

    @_builtins.property
    @pulumi.getter(name="maxDecompressedArchiveSize")
    def max_decompressed_archive_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum decompressed archive size in bytes.
        """
        return pulumi.get(self, "max_decompressed_archive_size")

    @max_decompressed_archive_size.setter
    def max_decompressed_archive_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_decompressed_archive_size", value)

    @_builtins.property
    @pulumi.getter(name="maxExportSize")
    def max_export_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum export size in MB. 0 for unlimited.
        """
        return pulumi.get(self, "max_export_size")

    @max_export_size.setter
    def max_export_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_export_size", value)

    @_builtins.property
    @pulumi.getter(name="maxImportRemoteFileSize")
    def max_import_remote_file_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum remote file size for imports from external object storages.
        """
        return pulumi.get(self, "max_import_remote_file_size")

    @max_import_remote_file_size.setter
    def max_import_remote_file_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_import_remote_file_size", value)

    @_builtins.property
    @pulumi.getter(name="maxImportSize")
    def max_import_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum import size in MB. 0 for unlimited.
        """
        return pulumi.get(self, "max_import_size")

    @max_import_size.setter
    def max_import_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_import_size", value)

    @_builtins.property
    @pulumi.getter(name="maxLoginAttempts")
    def max_login_attempts(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum number of sign-in attempts before locking out the user.
        """
        return pulumi.get(self, "max_login_attempts")

    @max_login_attempts.setter
    def max_login_attempts(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_login_attempts", value)

    @_builtins.property
    @pulumi.getter(name="maxNumberOfRepositoryDownloads")
    def max_number_of_repository_downloads(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum number of unique repositories a user can download in the specified time period before they are banned. Maximum: 10,000 repositories.
        """
        return pulumi.get(self, "max_number_of_repository_downloads")

    @max_number_of_repository_downloads.setter
    def max_number_of_repository_downloads(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_number_of_repository_downloads", value)

    @_builtins.property
    @pulumi.getter(name="maxNumberOfRepositoryDownloadsWithinTimePeriod")
    def max_number_of_repository_downloads_within_time_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Reporting time period (in seconds). Maximum: 864000 seconds (10 days).
        """
        return pulumi.get(self, "max_number_of_repository_downloads_within_time_period")

    @max_number_of_repository_downloads_within_time_period.setter
    def max_number_of_repository_downloads_within_time_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_number_of_repository_downloads_within_time_period", value)

    @_builtins.property
    @pulumi.getter(name="maxPagesSize")
    def max_pages_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum size of pages repositories in MB.
        """
        return pulumi.get(self, "max_pages_size")

    @max_pages_size.setter
    def max_pages_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_pages_size", value)

    @_builtins.property
    @pulumi.getter(name="maxPersonalAccessTokenLifetime")
    def max_personal_access_token_lifetime(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum allowable lifetime for access tokens in days.
        """
        return pulumi.get(self, "max_personal_access_token_lifetime")

    @max_personal_access_token_lifetime.setter
    def max_personal_access_token_lifetime(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_personal_access_token_lifetime", value)

    @_builtins.property
    @pulumi.getter(name="maxSshKeyLifetime")
    def max_ssh_key_lifetime(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum allowable lifetime for SSH keys in days.
        """
        return pulumi.get(self, "max_ssh_key_lifetime")

    @max_ssh_key_lifetime.setter
    def max_ssh_key_lifetime(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_ssh_key_lifetime", value)

    @_builtins.property
    @pulumi.getter(name="maxTerraformStateSizeBytes")
    def max_terraform_state_size_bytes(self) -> Optional[pulumi.Input[_builtins.int]]:
        return pulumi.get(self, "max_terraform_state_size_bytes")

    @max_terraform_state_size_bytes.setter
    def max_terraform_state_size_bytes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_terraform_state_size_bytes", value)

    @_builtins.property
    @pulumi.getter(name="metricsMethodCallThreshold")
    def metrics_method_call_threshold(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        A method call is only tracked when it takes longer than the given amount of milliseconds.
        """
        return pulumi.get(self, "metrics_method_call_threshold")

    @metrics_method_call_threshold.setter
    def metrics_method_call_threshold(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "metrics_method_call_threshold", value)

    @_builtins.property
    @pulumi.getter(name="minimumPasswordLength")
    def minimum_password_length(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Indicates whether passwords require a minimum length. Premium and Ultimate only.
        """
        return pulumi.get(self, "minimum_password_length")

    @minimum_password_length.setter
    def minimum_password_length(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "minimum_password_length", value)

    @_builtins.property
    @pulumi.getter(name="mirrorAvailable")
    def mirror_available(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow repository mirroring to configured by project Maintainers. If disabled, only Administrators can configure repository mirroring.
        """
        return pulumi.get(self, "mirror_available")

    @mirror_available.setter
    def mirror_available(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "mirror_available", value)

    @_builtins.property
    @pulumi.getter(name="mirrorCapacityThreshold")
    def mirror_capacity_threshold(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Minimum capacity to be available before scheduling more mirrors preemptively.
        """
        return pulumi.get(self, "mirror_capacity_threshold")

    @mirror_capacity_threshold.setter
    def mirror_capacity_threshold(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "mirror_capacity_threshold", value)

    @_builtins.property
    @pulumi.getter(name="mirrorMaxCapacity")
    def mirror_max_capacity(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum number of mirrors that can be synchronizing at the same time.
        """
        return pulumi.get(self, "mirror_max_capacity")

    @mirror_max_capacity.setter
    def mirror_max_capacity(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "mirror_max_capacity", value)

    @_builtins.property
    @pulumi.getter(name="mirrorMaxDelay")
    def mirror_max_delay(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum time (in minutes) between updates that a mirror can have when scheduled to synchronize.
        """
        return pulumi.get(self, "mirror_max_delay")

    @mirror_max_delay.setter
    def mirror_max_delay(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "mirror_max_delay", value)

    @_builtins.property
    @pulumi.getter(name="npmPackageRequestsForwarding")
    def npm_package_requests_forwarding(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Use npmjs.org as a default remote repository when the package is not found in the GitLab Package Registry for npm.
        """
        return pulumi.get(self, "npm_package_requests_forwarding")

    @npm_package_requests_forwarding.setter
    def npm_package_requests_forwarding(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "npm_package_requests_forwarding", value)

    @_builtins.property
    @pulumi.getter(name="nugetSkipMetadataUrlValidation")
    def nuget_skip_metadata_url_validation(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether to skip metadata URL validation for the NuGet package.
        """
        return pulumi.get(self, "nuget_skip_metadata_url_validation")

    @nuget_skip_metadata_url_validation.setter
    def nuget_skip_metadata_url_validation(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "nuget_skip_metadata_url_validation", value)

    @_builtins.property
    @pulumi.getter(name="outboundLocalRequestsWhitelists")
    def outbound_local_requests_whitelists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Define a list of trusted domains or IP addresses to which local requests are allowed when local requests for hooks and services are disabled.
        """
        return pulumi.get(self, "outbound_local_requests_whitelists")

    @outbound_local_requests_whitelists.setter
    def outbound_local_requests_whitelists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "outbound_local_requests_whitelists", value)

    @_builtins.property
    @pulumi.getter(name="packageMetadataPurlTypes")
    def package_metadata_purl_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]:
        """
        List of package registry metadata to sync. See the list of the available values (https://gitlab.com/gitlab-org/gitlab/-/blob/ace16c20d5da7c4928dd03fb139692638b557fe3/app/models/concerns/enums/package_metadata.rb#L5). Self-managed, Ultimate only.
        """
        return pulumi.get(self, "package_metadata_purl_types")

    @package_metadata_purl_types.setter
    def package_metadata_purl_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]):
        pulumi.set(self, "package_metadata_purl_types", value)

    @_builtins.property
    @pulumi.getter(name="packageRegistryAllowAnyoneToPullOption")
    def package_registry_allow_anyone_to_pull_option(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable to allow anyone to pull from Package Registry visible and changeable.
        """
        return pulumi.get(self, "package_registry_allow_anyone_to_pull_option")

    @package_registry_allow_anyone_to_pull_option.setter
    def package_registry_allow_anyone_to_pull_option(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "package_registry_allow_anyone_to_pull_option", value)

    @_builtins.property
    @pulumi.getter(name="packageRegistryCleanupPoliciesWorkerCapacity")
    def package_registry_cleanup_policies_worker_capacity(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Number of workers assigned to the packages cleanup policies.
        """
        return pulumi.get(self, "package_registry_cleanup_policies_worker_capacity")

    @package_registry_cleanup_policies_worker_capacity.setter
    def package_registry_cleanup_policies_worker_capacity(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "package_registry_cleanup_policies_worker_capacity", value)

    @_builtins.property
    @pulumi.getter(name="pagesDomainVerificationEnabled")
    def pages_domain_verification_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Require users to prove ownership of custom domains. Domain verification is an essential security measure for public GitLab sites. Users are required to demonstrate they control a domain before it is enabled.
        """
        return pulumi.get(self, "pages_domain_verification_enabled")

    @pages_domain_verification_enabled.setter
    def pages_domain_verification_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "pages_domain_verification_enabled", value)

    @_builtins.property
    @pulumi.getter(name="passwordAuthenticationEnabledForGit")
    def password_authentication_enabled_for_git(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable authentication for Git over HTTP(S) via a GitLab account password.
        """
        return pulumi.get(self, "password_authentication_enabled_for_git")

    @password_authentication_enabled_for_git.setter
    def password_authentication_enabled_for_git(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "password_authentication_enabled_for_git", value)

    @_builtins.property
    @pulumi.getter(name="passwordAuthenticationEnabledForWeb")
    def password_authentication_enabled_for_web(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable authentication for the web interface via a GitLab account password.
        """
        return pulumi.get(self, "password_authentication_enabled_for_web")

    @password_authentication_enabled_for_web.setter
    def password_authentication_enabled_for_web(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "password_authentication_enabled_for_web", value)

    @_builtins.property
    @pulumi.getter(name="passwordLowercaseRequired")
    def password_lowercase_required(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether passwords require at least one lowercase letter.
        """
        return pulumi.get(self, "password_lowercase_required")

    @password_lowercase_required.setter
    def password_lowercase_required(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "password_lowercase_required", value)

    @_builtins.property
    @pulumi.getter(name="passwordNumberRequired")
    def password_number_required(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether passwords require at least one number.
        """
        return pulumi.get(self, "password_number_required")

    @password_number_required.setter
    def password_number_required(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "password_number_required", value)

    @_builtins.property
    @pulumi.getter(name="passwordSymbolRequired")
    def password_symbol_required(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether passwords require at least one symbol character.
        """
        return pulumi.get(self, "password_symbol_required")

    @password_symbol_required.setter
    def password_symbol_required(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "password_symbol_required", value)

    @_builtins.property
    @pulumi.getter(name="passwordUppercaseRequired")
    def password_uppercase_required(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether passwords require at least one uppercase letter.
        """
        return pulumi.get(self, "password_uppercase_required")

    @password_uppercase_required.setter
    def password_uppercase_required(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "password_uppercase_required", value)

    @_builtins.property
    @pulumi.getter(name="performanceBarAllowedGroupPath")
    def performance_bar_allowed_group_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Path of the group that is allowed to toggle the performance bar.
        """
        return pulumi.get(self, "performance_bar_allowed_group_path")

    @performance_bar_allowed_group_path.setter
    def performance_bar_allowed_group_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "performance_bar_allowed_group_path", value)

    @_builtins.property
    @pulumi.getter(name="personalAccessTokenPrefix")
    def personal_access_token_prefix(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Prefix for all generated personal access tokens.
        """
        return pulumi.get(self, "personal_access_token_prefix")

    @personal_access_token_prefix.setter
    def personal_access_token_prefix(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "personal_access_token_prefix", value)

    @_builtins.property
    @pulumi.getter(name="pipelineLimitPerProjectUserSha")
    def pipeline_limit_per_project_user_sha(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum number of pipeline creation requests per minute per user and commit.
        """
        return pulumi.get(self, "pipeline_limit_per_project_user_sha")

    @pipeline_limit_per_project_user_sha.setter
    def pipeline_limit_per_project_user_sha(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "pipeline_limit_per_project_user_sha", value)

    @_builtins.property
    @pulumi.getter(name="plantumlEnabled")
    def plantuml_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: plantuml_url) Enable PlantUML integration.
        """
        return pulumi.get(self, "plantuml_enabled")

    @plantuml_enabled.setter
    def plantuml_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "plantuml_enabled", value)

    @_builtins.property
    @pulumi.getter(name="plantumlUrl")
    def plantuml_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The PlantUML instance URL for integration.
        """
        return pulumi.get(self, "plantuml_url")

    @plantuml_url.setter
    def plantuml_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "plantuml_url", value)

    @_builtins.property
    @pulumi.getter(name="pollingIntervalMultiplier")
    def polling_interval_multiplier(self) -> Optional[pulumi.Input[_builtins.float]]:
        """
        Interval multiplier used by endpoints that perform polling. Set to 0 to disable polling.
        """
        return pulumi.get(self, "polling_interval_multiplier")

    @polling_interval_multiplier.setter
    def polling_interval_multiplier(self, value: Optional[pulumi.Input[_builtins.float]]):
        pulumi.set(self, "polling_interval_multiplier", value)

    @_builtins.property
    @pulumi.getter(name="projectExportEnabled")
    def project_export_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable project export.
        """
        return pulumi.get(self, "project_export_enabled")

    @project_export_enabled.setter
    def project_export_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "project_export_enabled", value)

    @_builtins.property
    @pulumi.getter(name="projectJobsApiRateLimit")
    def project_jobs_api_rate_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum authenticated requests to /project/:id/jobs per minute.
        """
        return pulumi.get(self, "project_jobs_api_rate_limit")

    @project_jobs_api_rate_limit.setter
    def project_jobs_api_rate_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "project_jobs_api_rate_limit", value)

    @_builtins.property
    @pulumi.getter(name="projectsApiRateLimitUnauthenticated")
    def projects_api_rate_limit_unauthenticated(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Max number of requests per 10 minutes per IP address for unauthenticated requests to the list all projects API. To disable throttling set to 0.
        """
        return pulumi.get(self, "projects_api_rate_limit_unauthenticated")

    @projects_api_rate_limit_unauthenticated.setter
    def projects_api_rate_limit_unauthenticated(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "projects_api_rate_limit_unauthenticated", value)

    @_builtins.property
    @pulumi.getter(name="prometheusMetricsEnabled")
    def prometheus_metrics_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable Prometheus metrics.
        """
        return pulumi.get(self, "prometheus_metrics_enabled")

    @prometheus_metrics_enabled.setter
    def prometheus_metrics_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "prometheus_metrics_enabled", value)

    @_builtins.property
    @pulumi.getter(name="protectedCiVariables")
    def protected_ci_variables(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        CI/CD variables are protected by default.
        """
        return pulumi.get(self, "protected_ci_variables")

    @protected_ci_variables.setter
    def protected_ci_variables(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "protected_ci_variables", value)

    @_builtins.property
    @pulumi.getter(name="pushEventActivitiesLimit")
    def push_event_activities_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Number of changes (branches or tags) in a single push to determine whether individual push events or bulk push events are created. Bulk push events are created if it surpasses that value.
        """
        return pulumi.get(self, "push_event_activities_limit")

    @push_event_activities_limit.setter
    def push_event_activities_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "push_event_activities_limit", value)

    @_builtins.property
    @pulumi.getter(name="pushEventHooksLimit")
    def push_event_hooks_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Number of changes (branches or tags) in a single push to determine whether webhooks and services fire or not. Webhooks and services aren’t submitted if it surpasses that value.
        """
        return pulumi.get(self, "push_event_hooks_limit")

    @push_event_hooks_limit.setter
    def push_event_hooks_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "push_event_hooks_limit", value)

    @_builtins.property
    @pulumi.getter(name="pypiPackageRequestsForwarding")
    def pypi_package_requests_forwarding(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Use pypi.org as a default remote repository when the package is not found in the GitLab Package Registry for PyPI.
        """
        return pulumi.get(self, "pypi_package_requests_forwarding")

    @pypi_package_requests_forwarding.setter
    def pypi_package_requests_forwarding(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "pypi_package_requests_forwarding", value)

    @_builtins.property
    @pulumi.getter(name="rateLimitingResponseText")
    def rate_limiting_response_text(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        When rate limiting is enabled via the throttle_* settings, send this plain text response when a rate limit is exceeded. ‘Retry later’ is sent if this is blank.
        """
        return pulumi.get(self, "rate_limiting_response_text")

    @rate_limiting_response_text.setter
    def rate_limiting_response_text(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "rate_limiting_response_text", value)

    @_builtins.property
    @pulumi.getter(name="rawBlobRequestLimit")
    def raw_blob_request_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Max number of requests per minute for each raw path. To disable throttling set to 0.
        """
        return pulumi.get(self, "raw_blob_request_limit")

    @raw_blob_request_limit.setter
    def raw_blob_request_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "raw_blob_request_limit", value)

    @_builtins.property
    @pulumi.getter(name="recaptchaEnabled")
    def recaptcha_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: recaptcha*private*key and recaptcha*site*key) Enable reCAPTCHA.
        """
        return pulumi.get(self, "recaptcha_enabled")

    @recaptcha_enabled.setter
    def recaptcha_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "recaptcha_enabled", value)

    @_builtins.property
    @pulumi.getter(name="recaptchaPrivateKey")
    def recaptcha_private_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Private key for reCAPTCHA.
        """
        return pulumi.get(self, "recaptcha_private_key")

    @recaptcha_private_key.setter
    def recaptcha_private_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "recaptcha_private_key", value)

    @_builtins.property
    @pulumi.getter(name="recaptchaSiteKey")
    def recaptcha_site_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Site key for reCAPTCHA.
        """
        return pulumi.get(self, "recaptcha_site_key")

    @recaptcha_site_key.setter
    def recaptcha_site_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "recaptcha_site_key", value)

    @_builtins.property
    @pulumi.getter(name="receiveMaxInputSize")
    def receive_max_input_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum push size (MB).
        """
        return pulumi.get(self, "receive_max_input_size")

    @receive_max_input_size.setter
    def receive_max_input_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "receive_max_input_size", value)

    @_builtins.property
    @pulumi.getter(name="receptiveClusterAgentsEnabled")
    def receptive_cluster_agents_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable receptive mode for GitLab Agents for Kubernetes.
        """
        return pulumi.get(self, "receptive_cluster_agents_enabled")

    @receptive_cluster_agents_enabled.setter
    def receptive_cluster_agents_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "receptive_cluster_agents_enabled", value)

    @_builtins.property
    @pulumi.getter(name="rememberMeEnabled")
    def remember_me_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable Remember me setting.
        """
        return pulumi.get(self, "remember_me_enabled")

    @remember_me_enabled.setter
    def remember_me_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "remember_me_enabled", value)

    @_builtins.property
    @pulumi.getter(name="repositoryChecksEnabled")
    def repository_checks_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        GitLab periodically runs git fsck in all project and wiki repositories to look for silent disk corruption issues.
        """
        return pulumi.get(self, "repository_checks_enabled")

    @repository_checks_enabled.setter
    def repository_checks_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "repository_checks_enabled", value)

    @_builtins.property
    @pulumi.getter(name="repositorySizeLimit")
    def repository_size_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Size limit per repository (MB).
        """
        return pulumi.get(self, "repository_size_limit")

    @repository_size_limit.setter
    def repository_size_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "repository_size_limit", value)

    @_builtins.property
    @pulumi.getter(name="repositoryStoragesWeighted")
    def repository_storages_weighted(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.int]]]]:
        """
        Hash of names taken from gitlab.yml to weights. New projects are created in one of these stores, chosen by a weighted random selection.
        """
        return pulumi.get(self, "repository_storages_weighted")

    @repository_storages_weighted.setter
    def repository_storages_weighted(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.int]]]]):
        pulumi.set(self, "repository_storages_weighted", value)

    @_builtins.property
    @pulumi.getter(name="requireAdminApprovalAfterUserSignup")
    def require_admin_approval_after_user_signup(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When enabled, any user that signs up for an account using the registration form is placed under a Pending approval state and has to be explicitly approved by an administrator.
        """
        return pulumi.get(self, "require_admin_approval_after_user_signup")

    @require_admin_approval_after_user_signup.setter
    def require_admin_approval_after_user_signup(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "require_admin_approval_after_user_signup", value)

    @_builtins.property
    @pulumi.getter(name="requireAdminTwoFactorAuthentication")
    def require_admin_two_factor_authentication(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow administrators to require 2FA for all administrators on the instance.
        """
        return pulumi.get(self, "require_admin_two_factor_authentication")

    @require_admin_two_factor_authentication.setter
    def require_admin_two_factor_authentication(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "require_admin_two_factor_authentication", value)

    @_builtins.property
    @pulumi.getter(name="requirePersonalAccessTokenExpiry")
    def require_personal_access_token_expiry(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When enabled, users must set an expiration date when creating a group or project access token, or a personal access token owned by a non-service account.
        """
        return pulumi.get(self, "require_personal_access_token_expiry")

    @require_personal_access_token_expiry.setter
    def require_personal_access_token_expiry(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "require_personal_access_token_expiry", value)

    @_builtins.property
    @pulumi.getter(name="requireTwoFactorAuthentication")
    def require_two_factor_authentication(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: two*factor*grace_period) Require all users to set up Two-factor authentication.
        """
        return pulumi.get(self, "require_two_factor_authentication")

    @require_two_factor_authentication.setter
    def require_two_factor_authentication(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "require_two_factor_authentication", value)

    @_builtins.property
    @pulumi.getter(name="restrictedVisibilityLevels")
    def restricted_visibility_levels(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Selected levels cannot be used by non-Administrator users for groups, projects or snippets. Can take private, internal and public as a parameter. Null means there is no restriction.
        """
        return pulumi.get(self, "restricted_visibility_levels")

    @restricted_visibility_levels.setter
    def restricted_visibility_levels(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "restricted_visibility_levels", value)

    @_builtins.property
    @pulumi.getter(name="rsaKeyRestriction")
    def rsa_key_restriction(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The minimum allowed bit length of an uploaded RSA key. 0 means no restriction. -1 disables RSA keys.
        """
        return pulumi.get(self, "rsa_key_restriction")

    @rsa_key_restriction.setter
    def rsa_key_restriction(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "rsa_key_restriction", value)

    @_builtins.property
    @pulumi.getter(name="searchRateLimit")
    def search_rate_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Max number of requests per minute for performing a search while authenticated. To disable throttling set to 0.
        """
        return pulumi.get(self, "search_rate_limit")

    @search_rate_limit.setter
    def search_rate_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "search_rate_limit", value)

    @_builtins.property
    @pulumi.getter(name="searchRateLimitUnauthenticated")
    def search_rate_limit_unauthenticated(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Max number of requests per minute for performing a search while unauthenticated. To disable throttling set to 0.
        """
        return pulumi.get(self, "search_rate_limit_unauthenticated")

    @search_rate_limit_unauthenticated.setter
    def search_rate_limit_unauthenticated(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "search_rate_limit_unauthenticated", value)

    @_builtins.property
    @pulumi.getter(name="securityApprovalPoliciesLimit")
    def security_approval_policies_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum number of active merge request approval policies per security policy project. Maximum: 20
        """
        return pulumi.get(self, "security_approval_policies_limit")

    @security_approval_policies_limit.setter
    def security_approval_policies_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "security_approval_policies_limit", value)

    @_builtins.property
    @pulumi.getter(name="securityPolicyGlobalGroupApproversEnabled")
    def security_policy_global_group_approvers_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to look up merge request approval policy approval groups globally or within project hierarchies.
        """
        return pulumi.get(self, "security_policy_global_group_approvers_enabled")

    @security_policy_global_group_approvers_enabled.setter
    def security_policy_global_group_approvers_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "security_policy_global_group_approvers_enabled", value)

    @_builtins.property
    @pulumi.getter(name="securityTxtContent")
    def security_txt_content(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Public security contact information.
        """
        return pulumi.get(self, "security_txt_content")

    @security_txt_content.setter
    def security_txt_content(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "security_txt_content", value)

    @_builtins.property
    @pulumi.getter(name="sendUserConfirmationEmail")
    def send_user_confirmation_email(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Send confirmation email on sign-up.
        """
        return pulumi.get(self, "send_user_confirmation_email")

    @send_user_confirmation_email.setter
    def send_user_confirmation_email(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "send_user_confirmation_email", value)

    @_builtins.property
    @pulumi.getter(name="serviceAccessTokensExpirationEnforced")
    def service_access_tokens_expiration_enforced(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Flag to indicate if token expiry date can be optional for service account users
        """
        return pulumi.get(self, "service_access_tokens_expiration_enforced")

    @service_access_tokens_expiration_enforced.setter
    def service_access_tokens_expiration_enforced(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "service_access_tokens_expiration_enforced", value)

    @_builtins.property
    @pulumi.getter(name="sessionExpireDelay")
    def session_expire_delay(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Session duration in minutes. GitLab restart is required to apply changes.
        """
        return pulumi.get(self, "session_expire_delay")

    @session_expire_delay.setter
    def session_expire_delay(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "session_expire_delay", value)

    @_builtins.property
    @pulumi.getter(name="sharedRunnersEnabled")
    def shared_runners_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: shared*runners*text and shared*runners*minutes) Enable shared runners for new projects.
        """
        return pulumi.get(self, "shared_runners_enabled")

    @shared_runners_enabled.setter
    def shared_runners_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "shared_runners_enabled", value)

    @_builtins.property
    @pulumi.getter(name="sharedRunnersMinutes")
    def shared_runners_minutes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Set the maximum number of CI/CD minutes that a group can use on shared runners per month.
        """
        return pulumi.get(self, "shared_runners_minutes")

    @shared_runners_minutes.setter
    def shared_runners_minutes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "shared_runners_minutes", value)

    @_builtins.property
    @pulumi.getter(name="sharedRunnersText")
    def shared_runners_text(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Shared runners text.
        """
        return pulumi.get(self, "shared_runners_text")

    @shared_runners_text.setter
    def shared_runners_text(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "shared_runners_text", value)

    @_builtins.property
    @pulumi.getter(name="sidekiqJobLimiterCompressionThresholdBytes")
    def sidekiq_job_limiter_compression_threshold_bytes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The threshold in bytes at which Sidekiq jobs are compressed before being stored in Redis.
        """
        return pulumi.get(self, "sidekiq_job_limiter_compression_threshold_bytes")

    @sidekiq_job_limiter_compression_threshold_bytes.setter
    def sidekiq_job_limiter_compression_threshold_bytes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "sidekiq_job_limiter_compression_threshold_bytes", value)

    @_builtins.property
    @pulumi.getter(name="sidekiqJobLimiterLimitBytes")
    def sidekiq_job_limiter_limit_bytes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The threshold in bytes at which Sidekiq jobs are rejected. 0 means do not reject any job.
        """
        return pulumi.get(self, "sidekiq_job_limiter_limit_bytes")

    @sidekiq_job_limiter_limit_bytes.setter
    def sidekiq_job_limiter_limit_bytes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "sidekiq_job_limiter_limit_bytes", value)

    @_builtins.property
    @pulumi.getter(name="sidekiqJobLimiterMode")
    def sidekiq_job_limiter_mode(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        track or compress. Sets the behavior for Sidekiq job size limits.
        """
        return pulumi.get(self, "sidekiq_job_limiter_mode")

    @sidekiq_job_limiter_mode.setter
    def sidekiq_job_limiter_mode(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sidekiq_job_limiter_mode", value)

    @_builtins.property
    @pulumi.getter(name="signInText")
    def sign_in_text(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Text on the login page.
        """
        return pulumi.get(self, "sign_in_text")

    @sign_in_text.setter
    def sign_in_text(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sign_in_text", value)

    @_builtins.property
    @pulumi.getter(name="signupEnabled")
    def signup_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable registration.
        """
        return pulumi.get(self, "signup_enabled")

    @signup_enabled.setter
    def signup_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "signup_enabled", value)

    @_builtins.property
    @pulumi.getter(name="silentAdminExportsEnabled")
    def silent_admin_exports_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable Silent admin exports.
        """
        return pulumi.get(self, "silent_admin_exports_enabled")

    @silent_admin_exports_enabled.setter
    def silent_admin_exports_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "silent_admin_exports_enabled", value)

    @_builtins.property
    @pulumi.getter(name="silentModeEnabled")
    def silent_mode_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable Silent mode.
        """
        return pulumi.get(self, "silent_mode_enabled")

    @silent_mode_enabled.setter
    def silent_mode_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "silent_mode_enabled", value)

    @_builtins.property
    @pulumi.getter(name="slackAppEnabled")
    def slack_app_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: slack*app*id, slack*app*secret and slack*app*secret) Enable Slack app.
        """
        return pulumi.get(self, "slack_app_enabled")

    @slack_app_enabled.setter
    def slack_app_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "slack_app_enabled", value)

    @_builtins.property
    @pulumi.getter(name="slackAppId")
    def slack_app_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The app ID of the Slack-app.
        """
        return pulumi.get(self, "slack_app_id")

    @slack_app_id.setter
    def slack_app_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "slack_app_id", value)

    @_builtins.property
    @pulumi.getter(name="slackAppSecret")
    def slack_app_secret(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The app secret of the Slack-app.
        """
        return pulumi.get(self, "slack_app_secret")

    @slack_app_secret.setter
    def slack_app_secret(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "slack_app_secret", value)

    @_builtins.property
    @pulumi.getter(name="slackAppSigningSecret")
    def slack_app_signing_secret(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The signing secret of the Slack-app.
        """
        return pulumi.get(self, "slack_app_signing_secret")

    @slack_app_signing_secret.setter
    def slack_app_signing_secret(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "slack_app_signing_secret", value)

    @_builtins.property
    @pulumi.getter(name="slackAppVerificationToken")
    def slack_app_verification_token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The verification token of the Slack-app.
        """
        return pulumi.get(self, "slack_app_verification_token")

    @slack_app_verification_token.setter
    def slack_app_verification_token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "slack_app_verification_token", value)

    @_builtins.property
    @pulumi.getter(name="snippetSizeLimit")
    def snippet_size_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Max snippet content size in bytes.
        """
        return pulumi.get(self, "snippet_size_limit")

    @snippet_size_limit.setter
    def snippet_size_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "snippet_size_limit", value)

    @_builtins.property
    @pulumi.getter(name="snowplowAppId")
    def snowplow_app_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Snowplow site name / application ID. (for example, gitlab)
        """
        return pulumi.get(self, "snowplow_app_id")

    @snowplow_app_id.setter
    def snowplow_app_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "snowplow_app_id", value)

    @_builtins.property
    @pulumi.getter(name="snowplowCollectorHostname")
    def snowplow_collector_hostname(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Snowplow collector hostname. (for example, snowplow.trx.gitlab.net)
        """
        return pulumi.get(self, "snowplow_collector_hostname")

    @snowplow_collector_hostname.setter
    def snowplow_collector_hostname(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "snowplow_collector_hostname", value)

    @_builtins.property
    @pulumi.getter(name="snowplowCookieDomain")
    def snowplow_cookie_domain(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Snowplow cookie domain. (for example, .gitlab.com)
        """
        return pulumi.get(self, "snowplow_cookie_domain")

    @snowplow_cookie_domain.setter
    def snowplow_cookie_domain(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "snowplow_cookie_domain", value)

    @_builtins.property
    @pulumi.getter(name="snowplowDatabaseCollectorHostname")
    def snowplow_database_collector_hostname(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Snowplow collector for database events hostname. (for example, db-snowplow.trx.gitlab.net)
        """
        return pulumi.get(self, "snowplow_database_collector_hostname")

    @snowplow_database_collector_hostname.setter
    def snowplow_database_collector_hostname(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "snowplow_database_collector_hostname", value)

    @_builtins.property
    @pulumi.getter(name="snowplowEnabled")
    def snowplow_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable snowplow tracking.
        """
        return pulumi.get(self, "snowplow_enabled")

    @snowplow_enabled.setter
    def snowplow_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "snowplow_enabled", value)

    @_builtins.property
    @pulumi.getter(name="sourcegraphEnabled")
    def sourcegraph_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enables Sourcegraph integration. If enabled, requires sourcegraph_url.
        """
        return pulumi.get(self, "sourcegraph_enabled")

    @sourcegraph_enabled.setter
    def sourcegraph_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "sourcegraph_enabled", value)

    @_builtins.property
    @pulumi.getter(name="sourcegraphPublicOnly")
    def sourcegraph_public_only(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Blocks Sourcegraph from being loaded on private and internal projects.
        """
        return pulumi.get(self, "sourcegraph_public_only")

    @sourcegraph_public_only.setter
    def sourcegraph_public_only(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "sourcegraph_public_only", value)

    @_builtins.property
    @pulumi.getter(name="sourcegraphUrl")
    def sourcegraph_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Sourcegraph instance URL for integration.
        """
        return pulumi.get(self, "sourcegraph_url")

    @sourcegraph_url.setter
    def sourcegraph_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sourcegraph_url", value)

    @_builtins.property
    @pulumi.getter(name="spamCheckApiKey")
    def spam_check_api_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        API key used by GitLab for accessing the Spam Check service endpoint.
        """
        return pulumi.get(self, "spam_check_api_key")

    @spam_check_api_key.setter
    def spam_check_api_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "spam_check_api_key", value)

    @_builtins.property
    @pulumi.getter(name="spamCheckEndpointEnabled")
    def spam_check_endpoint_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enables spam checking using external Spam Check API endpoint.
        """
        return pulumi.get(self, "spam_check_endpoint_enabled")

    @spam_check_endpoint_enabled.setter
    def spam_check_endpoint_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "spam_check_endpoint_enabled", value)

    @_builtins.property
    @pulumi.getter(name="spamCheckEndpointUrl")
    def spam_check_endpoint_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        URL of the external Spamcheck service endpoint. Valid URI schemes are grpc or tls. Specifying tls forces communication to be encrypted.
        """
        return pulumi.get(self, "spam_check_endpoint_url")

    @spam_check_endpoint_url.setter
    def spam_check_endpoint_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "spam_check_endpoint_url", value)

    @_builtins.property
    @pulumi.getter(name="staticObjectsExternalStorageAuthToken")
    def static_objects_external_storage_auth_token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Authentication token for the external storage linked in static*objects*external*storage*url.
        """
        return pulumi.get(self, "static_objects_external_storage_auth_token")

    @static_objects_external_storage_auth_token.setter
    def static_objects_external_storage_auth_token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "static_objects_external_storage_auth_token", value)

    @_builtins.property
    @pulumi.getter(name="staticObjectsExternalStorageUrl")
    def static_objects_external_storage_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        URL to an external storage for repository static objects.
        """
        return pulumi.get(self, "static_objects_external_storage_url")

    @static_objects_external_storage_url.setter
    def static_objects_external_storage_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "static_objects_external_storage_url", value)

    @_builtins.property
    @pulumi.getter(name="suggestPipelineEnabled")
    def suggest_pipeline_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable pipeline suggestion banner.
        """
        return pulumi.get(self, "suggest_pipeline_enabled")

    @suggest_pipeline_enabled.setter
    def suggest_pipeline_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "suggest_pipeline_enabled", value)

    @_builtins.property
    @pulumi.getter(name="terminalMaxSessionTime")
    def terminal_max_session_time(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum time for web terminal websocket connection (in seconds). Set to 0 for unlimited time.
        """
        return pulumi.get(self, "terminal_max_session_time")

    @terminal_max_session_time.setter
    def terminal_max_session_time(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "terminal_max_session_time", value)

    @_builtins.property
    @pulumi.getter
    def terms(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Required by: enforce_terms) Markdown content for the ToS.
        """
        return pulumi.get(self, "terms")

    @terms.setter
    def terms(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "terms", value)

    @_builtins.property
    @pulumi.getter(name="throttleAuthenticatedApiEnabled")
    def throttle_authenticated_api_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: throttle*authenticated*api*period*in*seconds and throttle*authenticated*api*requests*per*period) Enable authenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        """
        return pulumi.get(self, "throttle_authenticated_api_enabled")

    @throttle_authenticated_api_enabled.setter
    def throttle_authenticated_api_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "throttle_authenticated_api_enabled", value)

    @_builtins.property
    @pulumi.getter(name="throttleAuthenticatedApiPeriodInSeconds")
    def throttle_authenticated_api_period_in_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Rate limit period (in seconds).
        """
        return pulumi.get(self, "throttle_authenticated_api_period_in_seconds")

    @throttle_authenticated_api_period_in_seconds.setter
    def throttle_authenticated_api_period_in_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "throttle_authenticated_api_period_in_seconds", value)

    @_builtins.property
    @pulumi.getter(name="throttleAuthenticatedApiRequestsPerPeriod")
    def throttle_authenticated_api_requests_per_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum requests per period per user.
        """
        return pulumi.get(self, "throttle_authenticated_api_requests_per_period")

    @throttle_authenticated_api_requests_per_period.setter
    def throttle_authenticated_api_requests_per_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "throttle_authenticated_api_requests_per_period", value)

    @_builtins.property
    @pulumi.getter(name="throttleAuthenticatedPackagesApiEnabled")
    def throttle_authenticated_packages_api_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: throttle*authenticated*packages*api*period*in*seconds and throttle*authenticated*packages*api*requests*per*period) Enable authenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots). View Package Registry rate limits for more details.
        """
        return pulumi.get(self, "throttle_authenticated_packages_api_enabled")

    @throttle_authenticated_packages_api_enabled.setter
    def throttle_authenticated_packages_api_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "throttle_authenticated_packages_api_enabled", value)

    @_builtins.property
    @pulumi.getter(name="throttleAuthenticatedPackagesApiPeriodInSeconds")
    def throttle_authenticated_packages_api_period_in_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Rate limit period (in seconds). View Package Registry rate limits for more details.
        """
        return pulumi.get(self, "throttle_authenticated_packages_api_period_in_seconds")

    @throttle_authenticated_packages_api_period_in_seconds.setter
    def throttle_authenticated_packages_api_period_in_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "throttle_authenticated_packages_api_period_in_seconds", value)

    @_builtins.property
    @pulumi.getter(name="throttleAuthenticatedPackagesApiRequestsPerPeriod")
    def throttle_authenticated_packages_api_requests_per_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum requests per period per user. View Package Registry rate limits for more details.
        """
        return pulumi.get(self, "throttle_authenticated_packages_api_requests_per_period")

    @throttle_authenticated_packages_api_requests_per_period.setter
    def throttle_authenticated_packages_api_requests_per_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "throttle_authenticated_packages_api_requests_per_period", value)

    @_builtins.property
    @pulumi.getter(name="throttleAuthenticatedWebEnabled")
    def throttle_authenticated_web_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: throttle*authenticated*web*period*in*seconds and throttle*authenticated*web*requests*per*period) Enable authenticated web request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        """
        return pulumi.get(self, "throttle_authenticated_web_enabled")

    @throttle_authenticated_web_enabled.setter
    def throttle_authenticated_web_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "throttle_authenticated_web_enabled", value)

    @_builtins.property
    @pulumi.getter(name="throttleAuthenticatedWebPeriodInSeconds")
    def throttle_authenticated_web_period_in_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Rate limit period (in seconds).
        """
        return pulumi.get(self, "throttle_authenticated_web_period_in_seconds")

    @throttle_authenticated_web_period_in_seconds.setter
    def throttle_authenticated_web_period_in_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "throttle_authenticated_web_period_in_seconds", value)

    @_builtins.property
    @pulumi.getter(name="throttleAuthenticatedWebRequestsPerPeriod")
    def throttle_authenticated_web_requests_per_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum requests per period per user.
        """
        return pulumi.get(self, "throttle_authenticated_web_requests_per_period")

    @throttle_authenticated_web_requests_per_period.setter
    def throttle_authenticated_web_requests_per_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "throttle_authenticated_web_requests_per_period", value)

    @_builtins.property
    @pulumi.getter(name="throttleUnauthenticatedApiEnabled")
    def throttle_unauthenticated_api_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: throttle*unauthenticated*api*period*in*seconds and throttle*unauthenticated*api*requests*per*period) Enable unauthenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        """
        return pulumi.get(self, "throttle_unauthenticated_api_enabled")

    @throttle_unauthenticated_api_enabled.setter
    def throttle_unauthenticated_api_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "throttle_unauthenticated_api_enabled", value)

    @_builtins.property
    @pulumi.getter(name="throttleUnauthenticatedApiPeriodInSeconds")
    def throttle_unauthenticated_api_period_in_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Rate limit period in seconds.
        """
        return pulumi.get(self, "throttle_unauthenticated_api_period_in_seconds")

    @throttle_unauthenticated_api_period_in_seconds.setter
    def throttle_unauthenticated_api_period_in_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "throttle_unauthenticated_api_period_in_seconds", value)

    @_builtins.property
    @pulumi.getter(name="throttleUnauthenticatedApiRequestsPerPeriod")
    def throttle_unauthenticated_api_requests_per_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Max requests per period per IP.
        """
        return pulumi.get(self, "throttle_unauthenticated_api_requests_per_period")

    @throttle_unauthenticated_api_requests_per_period.setter
    def throttle_unauthenticated_api_requests_per_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "throttle_unauthenticated_api_requests_per_period", value)

    @_builtins.property
    @pulumi.getter(name="throttleUnauthenticatedPackagesApiEnabled")
    def throttle_unauthenticated_packages_api_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: throttle*unauthenticated*packages*api*period*in*seconds and throttle*unauthenticated*packages*api*requests*per*period) Enable authenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots). View Package Registry rate limits for more details.
        """
        return pulumi.get(self, "throttle_unauthenticated_packages_api_enabled")

    @throttle_unauthenticated_packages_api_enabled.setter
    def throttle_unauthenticated_packages_api_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "throttle_unauthenticated_packages_api_enabled", value)

    @_builtins.property
    @pulumi.getter(name="throttleUnauthenticatedPackagesApiPeriodInSeconds")
    def throttle_unauthenticated_packages_api_period_in_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Rate limit period (in seconds). View Package Registry rate limits for more details.
        """
        return pulumi.get(self, "throttle_unauthenticated_packages_api_period_in_seconds")

    @throttle_unauthenticated_packages_api_period_in_seconds.setter
    def throttle_unauthenticated_packages_api_period_in_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "throttle_unauthenticated_packages_api_period_in_seconds", value)

    @_builtins.property
    @pulumi.getter(name="throttleUnauthenticatedPackagesApiRequestsPerPeriod")
    def throttle_unauthenticated_packages_api_requests_per_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum requests per period per user. View Package Registry rate limits for more details.
        """
        return pulumi.get(self, "throttle_unauthenticated_packages_api_requests_per_period")

    @throttle_unauthenticated_packages_api_requests_per_period.setter
    def throttle_unauthenticated_packages_api_requests_per_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "throttle_unauthenticated_packages_api_requests_per_period", value)

    @_builtins.property
    @pulumi.getter(name="throttleUnauthenticatedWebEnabled")
    def throttle_unauthenticated_web_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: throttle*unauthenticated*web*period*in*seconds and throttle*unauthenticated*web*requests*per*period) Enable unauthenticated web request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        """
        return pulumi.get(self, "throttle_unauthenticated_web_enabled")

    @throttle_unauthenticated_web_enabled.setter
    def throttle_unauthenticated_web_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "throttle_unauthenticated_web_enabled", value)

    @_builtins.property
    @pulumi.getter(name="throttleUnauthenticatedWebPeriodInSeconds")
    def throttle_unauthenticated_web_period_in_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Rate limit period in seconds.
        """
        return pulumi.get(self, "throttle_unauthenticated_web_period_in_seconds")

    @throttle_unauthenticated_web_period_in_seconds.setter
    def throttle_unauthenticated_web_period_in_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "throttle_unauthenticated_web_period_in_seconds", value)

    @_builtins.property
    @pulumi.getter(name="throttleUnauthenticatedWebRequestsPerPeriod")
    def throttle_unauthenticated_web_requests_per_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Max requests per period per IP.
        """
        return pulumi.get(self, "throttle_unauthenticated_web_requests_per_period")

    @throttle_unauthenticated_web_requests_per_period.setter
    def throttle_unauthenticated_web_requests_per_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "throttle_unauthenticated_web_requests_per_period", value)

    @_builtins.property
    @pulumi.getter(name="timeTrackingLimitToHours")
    def time_tracking_limit_to_hours(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Limit display of time tracking units to hours.
        """
        return pulumi.get(self, "time_tracking_limit_to_hours")

    @time_tracking_limit_to_hours.setter
    def time_tracking_limit_to_hours(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "time_tracking_limit_to_hours", value)

    @_builtins.property
    @pulumi.getter(name="twoFactorGracePeriod")
    def two_factor_grace_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Amount of time (in hours) that users are allowed to skip forced configuration of two-factor authentication.
        """
        return pulumi.get(self, "two_factor_grace_period")

    @two_factor_grace_period.setter
    def two_factor_grace_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "two_factor_grace_period", value)

    @_builtins.property
    @pulumi.getter(name="unconfirmedUsersDeleteAfterDays")
    def unconfirmed_users_delete_after_days(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies how many days after sign-up to delete users who have not confirmed their email. Only applicable if delete*unconfirmed*users is set to true. Must be 1 or greater. Self-managed, Premium and Ultimate only.
        """
        return pulumi.get(self, "unconfirmed_users_delete_after_days")

    @unconfirmed_users_delete_after_days.setter
    def unconfirmed_users_delete_after_days(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "unconfirmed_users_delete_after_days", value)

    @_builtins.property
    @pulumi.getter(name="uniqueIpsLimitEnabled")
    def unique_ips_limit_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (If enabled, requires: unique*ips*limit*per*user and unique*ips*limit*time*window) Limit sign in from multiple IPs.
        """
        return pulumi.get(self, "unique_ips_limit_enabled")

    @unique_ips_limit_enabled.setter
    def unique_ips_limit_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "unique_ips_limit_enabled", value)

    @_builtins.property
    @pulumi.getter(name="uniqueIpsLimitPerUser")
    def unique_ips_limit_per_user(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum number of IPs per user.
        """
        return pulumi.get(self, "unique_ips_limit_per_user")

    @unique_ips_limit_per_user.setter
    def unique_ips_limit_per_user(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "unique_ips_limit_per_user", value)

    @_builtins.property
    @pulumi.getter(name="uniqueIpsLimitTimeWindow")
    def unique_ips_limit_time_window(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        How many seconds an IP is counted towards the limit.
        """
        return pulumi.get(self, "unique_ips_limit_time_window")

    @unique_ips_limit_time_window.setter
    def unique_ips_limit_time_window(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "unique_ips_limit_time_window", value)

    @_builtins.property
    @pulumi.getter(name="updateRunnerVersionsEnabled")
    def update_runner_versions_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Fetch GitLab Runner release version data from GitLab.com.
        """
        return pulumi.get(self, "update_runner_versions_enabled")

    @update_runner_versions_enabled.setter
    def update_runner_versions_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "update_runner_versions_enabled", value)

    @_builtins.property
    @pulumi.getter(name="usagePingEnabled")
    def usage_ping_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Every week GitLab reports license usage back to GitLab, Inc.
        """
        return pulumi.get(self, "usage_ping_enabled")

    @usage_ping_enabled.setter
    def usage_ping_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "usage_ping_enabled", value)

    @_builtins.property
    @pulumi.getter(name="useClickhouseForAnalytics")
    def use_clickhouse_for_analytics(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enables ClickHouse as a data source for analytics reports. ClickHouse must be configured for this setting to take effect. Available on Premium and Ultimate only.
        """
        return pulumi.get(self, "use_clickhouse_for_analytics")

    @use_clickhouse_for_analytics.setter
    def use_clickhouse_for_analytics(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "use_clickhouse_for_analytics", value)

    @_builtins.property
    @pulumi.getter(name="userDeactivationEmailsEnabled")
    def user_deactivation_emails_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Send an email to users upon account deactivation.
        """
        return pulumi.get(self, "user_deactivation_emails_enabled")

    @user_deactivation_emails_enabled.setter
    def user_deactivation_emails_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "user_deactivation_emails_enabled", value)

    @_builtins.property
    @pulumi.getter(name="userDefaultExternal")
    def user_default_external(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Newly registered users are external by default.
        """
        return pulumi.get(self, "user_default_external")

    @user_default_external.setter
    def user_default_external(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "user_default_external", value)

    @_builtins.property
    @pulumi.getter(name="userDefaultInternalRegex")
    def user_default_internal_regex(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specify an email address regex pattern to identify default internal users.
        """
        return pulumi.get(self, "user_default_internal_regex")

    @user_default_internal_regex.setter
    def user_default_internal_regex(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_default_internal_regex", value)

    @_builtins.property
    @pulumi.getter(name="userDefaultsToPrivateProfile")
    def user_defaults_to_private_profile(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Newly created users have private profile by default.
        """
        return pulumi.get(self, "user_defaults_to_private_profile")

    @user_defaults_to_private_profile.setter
    def user_defaults_to_private_profile(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "user_defaults_to_private_profile", value)

    @_builtins.property
    @pulumi.getter(name="userOauthApplications")
    def user_oauth_applications(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow users to register any application to use GitLab as an OAuth provider.
        """
        return pulumi.get(self, "user_oauth_applications")

    @user_oauth_applications.setter
    def user_oauth_applications(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "user_oauth_applications", value)

    @_builtins.property
    @pulumi.getter(name="userShowAddSshKeyMessage")
    def user_show_add_ssh_key_message(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When set to false disable the You won't be able to pull or push project code via SSH warning shown to users with no uploaded SSH key.
        """
        return pulumi.get(self, "user_show_add_ssh_key_message")

    @user_show_add_ssh_key_message.setter
    def user_show_add_ssh_key_message(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "user_show_add_ssh_key_message", value)

    @_builtins.property
    @pulumi.getter(name="validRunnerRegistrars")
    def valid_runner_registrars(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of types which are allowed to register a GitLab Runner. Can be [], ['group'], ['project'] or ['group', 'project'].
        """
        return pulumi.get(self, "valid_runner_registrars")

    @valid_runner_registrars.setter
    def valid_runner_registrars(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "valid_runner_registrars", value)

    @_builtins.property
    @pulumi.getter(name="versionCheckEnabled")
    def version_check_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Let GitLab inform you when an update is available.
        """
        return pulumi.get(self, "version_check_enabled")

    @version_check_enabled.setter
    def version_check_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "version_check_enabled", value)

    @_builtins.property
    @pulumi.getter(name="webIdeClientsidePreviewEnabled")
    def web_ide_clientside_preview_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Live Preview (allow live previews of JavaScript projects in the Web IDE using CodeSandbox Live Preview).
        """
        return pulumi.get(self, "web_ide_clientside_preview_enabled")

    @web_ide_clientside_preview_enabled.setter
    def web_ide_clientside_preview_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "web_ide_clientside_preview_enabled", value)

    @_builtins.property
    @pulumi.getter(name="whatsNewVariant")
    def whats_new_variant(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        What's new variant, possible values: all*tiers, current*tier, and disabled.
        """
        return pulumi.get(self, "whats_new_variant")

    @whats_new_variant.setter
    def whats_new_variant(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "whats_new_variant", value)

    @_builtins.property
    @pulumi.getter(name="wikiPageMaxContentBytes")
    def wiki_page_max_content_bytes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum wiki page content size in bytes. The minimum value is 1024 bytes.
        """
        return pulumi.get(self, "wiki_page_max_content_bytes")

    @wiki_page_max_content_bytes.setter
    def wiki_page_max_content_bytes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "wiki_page_max_content_bytes", value)


@pulumi.type_token("gitlab:index/applicationSettings:ApplicationSettings")
class ApplicationSettings(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 abuse_notification_email: Optional[pulumi.Input[_builtins.str]] = None,
                 admin_mode: Optional[pulumi.Input[_builtins.bool]] = None,
                 after_sign_out_path: Optional[pulumi.Input[_builtins.str]] = None,
                 after_sign_up_text: Optional[pulumi.Input[_builtins.str]] = None,
                 akismet_api_key: Optional[pulumi.Input[_builtins.str]] = None,
                 akismet_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_account_deletion: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_group_owners_to_manage_ldap: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_local_requests_from_system_hooks: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_local_requests_from_web_hooks_and_services: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_project_creation_for_guest_and_below: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_runner_registration_token: Optional[pulumi.Input[_builtins.bool]] = None,
                 archive_builds_in_human_readable: Optional[pulumi.Input[_builtins.str]] = None,
                 asciidoc_max_includes: Optional[pulumi.Input[_builtins.int]] = None,
                 asset_proxy_allowlists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 asset_proxy_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 asset_proxy_secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 asset_proxy_url: Optional[pulumi.Input[_builtins.str]] = None,
                 authorized_keys_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 auto_ban_user_on_excessive_projects_download: Optional[pulumi.Input[_builtins.bool]] = None,
                 auto_devops_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 auto_devops_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 automatic_purchased_storage_allocation: Optional[pulumi.Input[_builtins.bool]] = None,
                 bulk_import_concurrent_pipeline_batch_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 bulk_import_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 bulk_import_max_download_file_size: Optional[pulumi.Input[_builtins.int]] = None,
                 can_create_group: Optional[pulumi.Input[_builtins.bool]] = None,
                 check_namespace_plan: Optional[pulumi.Input[_builtins.bool]] = None,
                 ci_max_includes: Optional[pulumi.Input[_builtins.int]] = None,
                 ci_max_total_yaml_size_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 commit_email_hostname: Optional[pulumi.Input[_builtins.str]] = None,
                 concurrent_bitbucket_import_jobs_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 concurrent_bitbucket_server_import_jobs_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 concurrent_github_import_jobs_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 container_expiration_policies_enable_historic_entries: Optional[pulumi.Input[_builtins.bool]] = None,
                 container_registry_cleanup_tags_service_max_list_size: Optional[pulumi.Input[_builtins.int]] = None,
                 container_registry_delete_tags_service_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 container_registry_expiration_policies_caching: Optional[pulumi.Input[_builtins.bool]] = None,
                 container_registry_expiration_policies_worker_capacity: Optional[pulumi.Input[_builtins.int]] = None,
                 container_registry_token_expire_delay: Optional[pulumi.Input[_builtins.int]] = None,
                 deactivate_dormant_users: Optional[pulumi.Input[_builtins.bool]] = None,
                 deactivate_dormant_users_period: Optional[pulumi.Input[_builtins.int]] = None,
                 decompress_archive_file_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 default_artifacts_expire_in: Optional[pulumi.Input[_builtins.str]] = None,
                 default_branch_name: Optional[pulumi.Input[_builtins.str]] = None,
                 default_branch_protection: Optional[pulumi.Input[_builtins.int]] = None,
                 default_branch_protection_defaults: Optional[pulumi.Input[Union['ApplicationSettingsDefaultBranchProtectionDefaultsArgs', 'ApplicationSettingsDefaultBranchProtectionDefaultsArgsDict']]] = None,
                 default_ci_config_path: Optional[pulumi.Input[_builtins.str]] = None,
                 default_group_visibility: Optional[pulumi.Input[_builtins.str]] = None,
                 default_preferred_language: Optional[pulumi.Input[_builtins.str]] = None,
                 default_project_creation: Optional[pulumi.Input[_builtins.int]] = None,
                 default_project_visibility: Optional[pulumi.Input[_builtins.str]] = None,
                 default_projects_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 default_snippet_visibility: Optional[pulumi.Input[_builtins.str]] = None,
                 default_syntax_highlighting_theme: Optional[pulumi.Input[_builtins.int]] = None,
                 delete_inactive_projects: Optional[pulumi.Input[_builtins.bool]] = None,
                 delete_unconfirmed_users: Optional[pulumi.Input[_builtins.bool]] = None,
                 deletion_adjourned_period: Optional[pulumi.Input[_builtins.int]] = None,
                 diagramsnet_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 diagramsnet_url: Optional[pulumi.Input[_builtins.str]] = None,
                 diff_max_files: Optional[pulumi.Input[_builtins.int]] = None,
                 diff_max_lines: Optional[pulumi.Input[_builtins.int]] = None,
                 diff_max_patch_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 disable_admin_oauth_scopes: Optional[pulumi.Input[_builtins.bool]] = None,
                 disable_feed_token: Optional[pulumi.Input[_builtins.bool]] = None,
                 disable_personal_access_tokens: Optional[pulumi.Input[_builtins.bool]] = None,
                 disabled_oauth_sign_in_sources: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dns_rebinding_protection_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 domain_allowlists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 domain_denylist_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 domain_denylists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 downstream_pipeline_trigger_limit_per_project_user_sha: Optional[pulumi.Input[_builtins.int]] = None,
                 dsa_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
                 duo_features_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 ecdsa_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
                 ecdsa_sk_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
                 ed25519_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
                 ed25519_sk_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
                 eks_access_key_id: Optional[pulumi.Input[_builtins.str]] = None,
                 eks_account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 eks_integration_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 eks_secret_access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 elasticsearch_aws: Optional[pulumi.Input[_builtins.bool]] = None,
                 elasticsearch_aws_access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 elasticsearch_aws_region: Optional[pulumi.Input[_builtins.str]] = None,
                 elasticsearch_aws_secret_access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 elasticsearch_indexed_field_length_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 elasticsearch_indexed_file_size_limit_kb: Optional[pulumi.Input[_builtins.int]] = None,
                 elasticsearch_indexing: Optional[pulumi.Input[_builtins.bool]] = None,
                 elasticsearch_limit_indexing: Optional[pulumi.Input[_builtins.bool]] = None,
                 elasticsearch_max_bulk_concurrency: Optional[pulumi.Input[_builtins.int]] = None,
                 elasticsearch_max_bulk_size_mb: Optional[pulumi.Input[_builtins.int]] = None,
                 elasticsearch_max_code_indexing_concurrency: Optional[pulumi.Input[_builtins.int]] = None,
                 elasticsearch_namespace_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 elasticsearch_password: Optional[pulumi.Input[_builtins.str]] = None,
                 elasticsearch_project_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 elasticsearch_requeue_workers: Optional[pulumi.Input[_builtins.bool]] = None,
                 elasticsearch_search: Optional[pulumi.Input[_builtins.bool]] = None,
                 elasticsearch_urls: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 elasticsearch_username: Optional[pulumi.Input[_builtins.str]] = None,
                 elasticsearch_worker_number_of_shards: Optional[pulumi.Input[_builtins.int]] = None,
                 email_additional_text: Optional[pulumi.Input[_builtins.str]] = None,
                 email_author_in_body: Optional[pulumi.Input[_builtins.bool]] = None,
                 email_confirmation_setting: Optional[pulumi.Input[_builtins.str]] = None,
                 enable_artifact_external_redirect_warning_page: Optional[pulumi.Input[_builtins.bool]] = None,
                 enabled_git_access_protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 enforce_namespace_storage_limit: Optional[pulumi.Input[_builtins.bool]] = None,
                 enforce_terms: Optional[pulumi.Input[_builtins.bool]] = None,
                 external_auth_client_cert: Optional[pulumi.Input[_builtins.str]] = None,
                 external_auth_client_key: Optional[pulumi.Input[_builtins.str]] = None,
                 external_auth_client_key_pass: Optional[pulumi.Input[_builtins.str]] = None,
                 external_authorization_service_default_label: Optional[pulumi.Input[_builtins.str]] = None,
                 external_authorization_service_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 external_authorization_service_timeout: Optional[pulumi.Input[_builtins.float]] = None,
                 external_authorization_service_url: Optional[pulumi.Input[_builtins.str]] = None,
                 external_pipeline_validation_service_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 external_pipeline_validation_service_token: Optional[pulumi.Input[_builtins.str]] = None,
                 external_pipeline_validation_service_url: Optional[pulumi.Input[_builtins.str]] = None,
                 failed_login_attempts_unlock_period_in_minutes: Optional[pulumi.Input[_builtins.int]] = None,
                 file_template_project_id: Optional[pulumi.Input[_builtins.int]] = None,
                 first_day_of_week: Optional[pulumi.Input[_builtins.int]] = None,
                 geo_node_allowed_ips: Optional[pulumi.Input[_builtins.str]] = None,
                 geo_status_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 git_rate_limit_users_alertlists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 git_rate_limit_users_allowlists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 git_two_factor_session_expiry: Optional[pulumi.Input[_builtins.int]] = None,
                 gitaly_timeout_default: Optional[pulumi.Input[_builtins.int]] = None,
                 gitaly_timeout_fast: Optional[pulumi.Input[_builtins.int]] = None,
                 gitaly_timeout_medium: Optional[pulumi.Input[_builtins.int]] = None,
                 gitlab_shell_operation_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 gitpod_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 gitpod_url: Optional[pulumi.Input[_builtins.str]] = None,
                 globally_allowed_ips: Optional[pulumi.Input[_builtins.str]] = None,
                 grafana_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 grafana_url: Optional[pulumi.Input[_builtins.str]] = None,
                 gravatar_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 group_owners_can_manage_default_branch_protection: Optional[pulumi.Input[_builtins.bool]] = None,
                 help_page_hide_commercial_content: Optional[pulumi.Input[_builtins.bool]] = None,
                 help_page_support_url: Optional[pulumi.Input[_builtins.str]] = None,
                 help_page_text: Optional[pulumi.Input[_builtins.str]] = None,
                 help_text: Optional[pulumi.Input[_builtins.str]] = None,
                 hide_third_party_offers: Optional[pulumi.Input[_builtins.bool]] = None,
                 home_page_url: Optional[pulumi.Input[_builtins.str]] = None,
                 housekeeping_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 housekeeping_optimize_repository_period: Optional[pulumi.Input[_builtins.int]] = None,
                 html_emails_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 import_sources: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 in_product_marketing_emails_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 inactive_projects_delete_after_months: Optional[pulumi.Input[_builtins.int]] = None,
                 inactive_projects_min_size_mb: Optional[pulumi.Input[_builtins.int]] = None,
                 inactive_projects_send_warning_email_after_months: Optional[pulumi.Input[_builtins.int]] = None,
                 include_optional_metrics_in_service_ping: Optional[pulumi.Input[_builtins.bool]] = None,
                 invisible_captcha_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 issues_create_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 jira_connect_application_key: Optional[pulumi.Input[_builtins.str]] = None,
                 jira_connect_proxy_url: Optional[pulumi.Input[_builtins.str]] = None,
                 jira_connect_public_key_storage_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 keep_latest_artifact: Optional[pulumi.Input[_builtins.bool]] = None,
                 local_markdown_version: Optional[pulumi.Input[_builtins.int]] = None,
                 lock_duo_features_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 lock_memberships_to_ldap: Optional[pulumi.Input[_builtins.bool]] = None,
                 mailgun_events_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 mailgun_signing_key: Optional[pulumi.Input[_builtins.str]] = None,
                 maintenance_mode: Optional[pulumi.Input[_builtins.bool]] = None,
                 maintenance_mode_message: Optional[pulumi.Input[_builtins.str]] = None,
                 maven_package_requests_forwarding: Optional[pulumi.Input[_builtins.bool]] = None,
                 max_artifacts_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_attachment_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_decompressed_archive_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_export_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_import_remote_file_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_import_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_login_attempts: Optional[pulumi.Input[_builtins.int]] = None,
                 max_number_of_repository_downloads: Optional[pulumi.Input[_builtins.int]] = None,
                 max_number_of_repository_downloads_within_time_period: Optional[pulumi.Input[_builtins.int]] = None,
                 max_pages_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_personal_access_token_lifetime: Optional[pulumi.Input[_builtins.int]] = None,
                 max_ssh_key_lifetime: Optional[pulumi.Input[_builtins.int]] = None,
                 max_terraform_state_size_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 metrics_method_call_threshold: Optional[pulumi.Input[_builtins.int]] = None,
                 minimum_password_length: Optional[pulumi.Input[_builtins.int]] = None,
                 mirror_available: Optional[pulumi.Input[_builtins.bool]] = None,
                 mirror_capacity_threshold: Optional[pulumi.Input[_builtins.int]] = None,
                 mirror_max_capacity: Optional[pulumi.Input[_builtins.int]] = None,
                 mirror_max_delay: Optional[pulumi.Input[_builtins.int]] = None,
                 npm_package_requests_forwarding: Optional[pulumi.Input[_builtins.bool]] = None,
                 nuget_skip_metadata_url_validation: Optional[pulumi.Input[_builtins.bool]] = None,
                 outbound_local_requests_whitelists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 package_metadata_purl_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 package_registry_allow_anyone_to_pull_option: Optional[pulumi.Input[_builtins.bool]] = None,
                 package_registry_cleanup_policies_worker_capacity: Optional[pulumi.Input[_builtins.int]] = None,
                 pages_domain_verification_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 password_authentication_enabled_for_git: Optional[pulumi.Input[_builtins.bool]] = None,
                 password_authentication_enabled_for_web: Optional[pulumi.Input[_builtins.bool]] = None,
                 password_lowercase_required: Optional[pulumi.Input[_builtins.bool]] = None,
                 password_number_required: Optional[pulumi.Input[_builtins.bool]] = None,
                 password_symbol_required: Optional[pulumi.Input[_builtins.bool]] = None,
                 password_uppercase_required: Optional[pulumi.Input[_builtins.bool]] = None,
                 performance_bar_allowed_group_path: Optional[pulumi.Input[_builtins.str]] = None,
                 personal_access_token_prefix: Optional[pulumi.Input[_builtins.str]] = None,
                 pipeline_limit_per_project_user_sha: Optional[pulumi.Input[_builtins.int]] = None,
                 plantuml_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 plantuml_url: Optional[pulumi.Input[_builtins.str]] = None,
                 polling_interval_multiplier: Optional[pulumi.Input[_builtins.float]] = None,
                 project_export_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 project_jobs_api_rate_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 projects_api_rate_limit_unauthenticated: Optional[pulumi.Input[_builtins.int]] = None,
                 prometheus_metrics_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 protected_ci_variables: Optional[pulumi.Input[_builtins.bool]] = None,
                 push_event_activities_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 push_event_hooks_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 pypi_package_requests_forwarding: Optional[pulumi.Input[_builtins.bool]] = None,
                 rate_limiting_response_text: Optional[pulumi.Input[_builtins.str]] = None,
                 raw_blob_request_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 recaptcha_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 recaptcha_private_key: Optional[pulumi.Input[_builtins.str]] = None,
                 recaptcha_site_key: Optional[pulumi.Input[_builtins.str]] = None,
                 receive_max_input_size: Optional[pulumi.Input[_builtins.int]] = None,
                 receptive_cluster_agents_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 remember_me_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 repository_checks_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 repository_size_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 repository_storages_weighted: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.int]]]] = None,
                 require_admin_approval_after_user_signup: Optional[pulumi.Input[_builtins.bool]] = None,
                 require_admin_two_factor_authentication: Optional[pulumi.Input[_builtins.bool]] = None,
                 require_personal_access_token_expiry: Optional[pulumi.Input[_builtins.bool]] = None,
                 require_two_factor_authentication: Optional[pulumi.Input[_builtins.bool]] = None,
                 restricted_visibility_levels: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 rsa_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
                 search_rate_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 search_rate_limit_unauthenticated: Optional[pulumi.Input[_builtins.int]] = None,
                 security_approval_policies_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 security_policy_global_group_approvers_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 security_txt_content: Optional[pulumi.Input[_builtins.str]] = None,
                 send_user_confirmation_email: Optional[pulumi.Input[_builtins.bool]] = None,
                 service_access_tokens_expiration_enforced: Optional[pulumi.Input[_builtins.bool]] = None,
                 session_expire_delay: Optional[pulumi.Input[_builtins.int]] = None,
                 shared_runners_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 shared_runners_minutes: Optional[pulumi.Input[_builtins.int]] = None,
                 shared_runners_text: Optional[pulumi.Input[_builtins.str]] = None,
                 sidekiq_job_limiter_compression_threshold_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 sidekiq_job_limiter_limit_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 sidekiq_job_limiter_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 sign_in_text: Optional[pulumi.Input[_builtins.str]] = None,
                 signup_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 silent_admin_exports_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 silent_mode_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 slack_app_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 slack_app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 slack_app_secret: Optional[pulumi.Input[_builtins.str]] = None,
                 slack_app_signing_secret: Optional[pulumi.Input[_builtins.str]] = None,
                 slack_app_verification_token: Optional[pulumi.Input[_builtins.str]] = None,
                 snippet_size_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 snowplow_app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 snowplow_collector_hostname: Optional[pulumi.Input[_builtins.str]] = None,
                 snowplow_cookie_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 snowplow_database_collector_hostname: Optional[pulumi.Input[_builtins.str]] = None,
                 snowplow_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 sourcegraph_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 sourcegraph_public_only: Optional[pulumi.Input[_builtins.bool]] = None,
                 sourcegraph_url: Optional[pulumi.Input[_builtins.str]] = None,
                 spam_check_api_key: Optional[pulumi.Input[_builtins.str]] = None,
                 spam_check_endpoint_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 spam_check_endpoint_url: Optional[pulumi.Input[_builtins.str]] = None,
                 static_objects_external_storage_auth_token: Optional[pulumi.Input[_builtins.str]] = None,
                 static_objects_external_storage_url: Optional[pulumi.Input[_builtins.str]] = None,
                 suggest_pipeline_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 terminal_max_session_time: Optional[pulumi.Input[_builtins.int]] = None,
                 terms: Optional[pulumi.Input[_builtins.str]] = None,
                 throttle_authenticated_api_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 throttle_authenticated_api_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_authenticated_api_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_authenticated_packages_api_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 throttle_authenticated_packages_api_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_authenticated_packages_api_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_authenticated_web_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 throttle_authenticated_web_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_authenticated_web_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_unauthenticated_api_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 throttle_unauthenticated_api_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_unauthenticated_api_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_unauthenticated_packages_api_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 throttle_unauthenticated_packages_api_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_unauthenticated_packages_api_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_unauthenticated_web_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 throttle_unauthenticated_web_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_unauthenticated_web_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
                 time_tracking_limit_to_hours: Optional[pulumi.Input[_builtins.bool]] = None,
                 two_factor_grace_period: Optional[pulumi.Input[_builtins.int]] = None,
                 unconfirmed_users_delete_after_days: Optional[pulumi.Input[_builtins.int]] = None,
                 unique_ips_limit_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 unique_ips_limit_per_user: Optional[pulumi.Input[_builtins.int]] = None,
                 unique_ips_limit_time_window: Optional[pulumi.Input[_builtins.int]] = None,
                 update_runner_versions_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 usage_ping_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 use_clickhouse_for_analytics: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_deactivation_emails_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_default_external: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_default_internal_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 user_defaults_to_private_profile: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_oauth_applications: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_show_add_ssh_key_message: Optional[pulumi.Input[_builtins.bool]] = None,
                 valid_runner_registrars: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 version_check_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 web_ide_clientside_preview_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 whats_new_variant: Optional[pulumi.Input[_builtins.str]] = None,
                 wiki_page_max_content_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        """
        ## Example Usage

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] abuse_notification_email: If set, abuse reports are sent to this address. Abuse reports are always available in the Admin Area.
        :param pulumi.Input[_builtins.bool] admin_mode: Require administrators to enable Admin Mode by re-authenticating for administrative tasks.
        :param pulumi.Input[_builtins.str] after_sign_out_path: Where to redirect users after logout.
        :param pulumi.Input[_builtins.str] after_sign_up_text: Text shown to the user after signing up.
        :param pulumi.Input[_builtins.str] akismet_api_key: API key for Akismet spam protection.
        :param pulumi.Input[_builtins.bool] akismet_enabled: (If enabled, requires: akismet*api*key) Enable or disable Akismet spam protection.
        :param pulumi.Input[_builtins.bool] allow_account_deletion: Set to true to allow users to delete their accounts. Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] allow_group_owners_to_manage_ldap: Set to true to allow group owners to manage LDAP.
        :param pulumi.Input[_builtins.bool] allow_local_requests_from_system_hooks: Allow requests to the local network from system hooks.
        :param pulumi.Input[_builtins.bool] allow_local_requests_from_web_hooks_and_services: Allow requests to the local network from web hooks and services.
        :param pulumi.Input[_builtins.bool] allow_project_creation_for_guest_and_below: Indicates whether users assigned up to the Guest role can create groups and personal projects.
        :param pulumi.Input[_builtins.bool] allow_runner_registration_token: Allow using a registration token to create a runner.
        :param pulumi.Input[_builtins.str] archive_builds_in_human_readable: Set the duration for which the jobs are considered as old and expired. After that time passes, the jobs are archived and no longer able to be retried. Make it empty to never expire jobs. It has to be no less than 1 day, for example: 15 days, 1 month, 2 years.
        :param pulumi.Input[_builtins.int] asciidoc_max_includes: Maximum limit of AsciiDoc include directives being processed in any one document. Maximum: 64.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] asset_proxy_allowlists: Assets that match these domains are not proxied. Wildcards allowed. Your GitLab installation URL is automatically allowlisted. GitLab restart is required to apply changes.
        :param pulumi.Input[_builtins.bool] asset_proxy_enabled: (If enabled, requires: asset*proxy*url) Enable proxying of assets. GitLab restart is required to apply changes.
        :param pulumi.Input[_builtins.str] asset_proxy_secret_key: Shared secret with the asset proxy server. GitLab restart is required to apply changes.
        :param pulumi.Input[_builtins.str] asset_proxy_url: URL of the asset proxy server. GitLab restart is required to apply changes.
        :param pulumi.Input[_builtins.bool] authorized_keys_enabled: By default, we write to the authorized_keys file to support Git over SSH without additional configuration. GitLab can be optimized to authenticate SSH keys via the database file. Only disable this if you have configured your OpenSSH server to use the AuthorizedKeysCommand.
        :param pulumi.Input[_builtins.bool] auto_ban_user_on_excessive_projects_download: When enabled, users will get automatically banned from the application when they download more than the maximum number of unique projects in the time period specified by max*number*of*repository*downloads and max*number*of*repository*downloads*within*time_period respectively. Self-managed, Ultimate only.
        :param pulumi.Input[_builtins.str] auto_devops_domain: Specify a domain to use by default for every project’s Auto Review Apps and Auto Deploy stages.
        :param pulumi.Input[_builtins.bool] auto_devops_enabled: Enable Auto DevOps for projects by default. It automatically builds, tests, and deploys applications based on a predefined CI/CD configuration.
        :param pulumi.Input[_builtins.bool] automatic_purchased_storage_allocation: Enabling this permits automatic allocation of purchased storage in a namespace.
        :param pulumi.Input[_builtins.int] bulk_import_concurrent_pipeline_batch_limit: Maximum simultaneous Direct Transfer batches to process.
        :param pulumi.Input[_builtins.bool] bulk_import_enabled: Enable migrating GitLab groups by direct transfer.
        :param pulumi.Input[_builtins.int] bulk_import_max_download_file_size: Maximum download file size when importing from source GitLab instances by direct transfer.
        :param pulumi.Input[_builtins.bool] can_create_group: Indicates whether users can create top-level groups.
        :param pulumi.Input[_builtins.bool] check_namespace_plan: Enabling this makes only licensed EE features available to projects if the project namespace’s plan includes the feature or if the project is public.
        :param pulumi.Input[_builtins.int] ci_max_includes: The maximum number of includes per pipeline.
        :param pulumi.Input[_builtins.int] ci_max_total_yaml_size_bytes: The maximum amount of memory, in bytes, that can be allocated for the pipeline configuration, with all included YAML configuration files.
        :param pulumi.Input[_builtins.str] commit_email_hostname: Custom hostname (for private commit emails).
        :param pulumi.Input[_builtins.int] concurrent_bitbucket_import_jobs_limit: Maximum number of simultaneous import jobs for the Bitbucket Cloud importer.
        :param pulumi.Input[_builtins.int] concurrent_bitbucket_server_import_jobs_limit: Maximum number of simultaneous import jobs for the Bitbucket Server importer.
        :param pulumi.Input[_builtins.int] concurrent_github_import_jobs_limit: Maximum number of simultaneous import jobs for the GitHub importer.
        :param pulumi.Input[_builtins.bool] container_expiration_policies_enable_historic_entries: Enable cleanup policies for all projects.
        :param pulumi.Input[_builtins.int] container_registry_cleanup_tags_service_max_list_size: The maximum number of tags that can be deleted in a single execution of cleanup policies.
        :param pulumi.Input[_builtins.int] container_registry_delete_tags_service_timeout: The maximum time, in seconds, that the cleanup process can take to delete a batch of tags for cleanup policies.
        :param pulumi.Input[_builtins.bool] container_registry_expiration_policies_caching: Caching during the execution of cleanup policies.
        :param pulumi.Input[_builtins.int] container_registry_expiration_policies_worker_capacity: Number of workers for cleanup policies.
        :param pulumi.Input[_builtins.int] container_registry_token_expire_delay: Container Registry token duration in minutes.
        :param pulumi.Input[_builtins.bool] deactivate_dormant_users: Enable automatic deactivation of dormant users.
        :param pulumi.Input[_builtins.int] deactivate_dormant_users_period: Length of time (in days) after which a user is considered dormant.
        :param pulumi.Input[_builtins.int] decompress_archive_file_timeout: Default timeout for decompressing archived files, in seconds. Set to 0 to disable timeouts.
        :param pulumi.Input[_builtins.str] default_artifacts_expire_in: Set the default expiration time for each job’s artifacts.
        :param pulumi.Input[_builtins.str] default_branch_name: Instance-level custom initial branch name
        :param pulumi.Input[_builtins.int] default_branch_protection: Determine if developers can push to the default branch. Can take: 0 (not protected, both users with the Developer role or Maintainer role can push new commits and force push), 1 (partially protected, users with the Developer role or Maintainer role can push new commits, but cannot force push) or 2 (fully protected, users with the Developer or Maintainer role cannot push new commits, but users with the Developer or Maintainer role can; no one can force push) as a parameter. Default is 2. Use `default_branch_protection_defaults` instead. To be removed in 19.0.
        :param pulumi.Input[Union['ApplicationSettingsDefaultBranchProtectionDefaultsArgs', 'ApplicationSettingsDefaultBranchProtectionDefaultsArgsDict']] default_branch_protection_defaults: The default*branch*protection*defaults attribute describes the default branch protection defaults. All parameters are optional.
        :param pulumi.Input[_builtins.str] default_ci_config_path: Default CI/CD configuration file and path for new projects (.gitlab-ci.yml if not set).
        :param pulumi.Input[_builtins.str] default_group_visibility: What visibility level new groups receive. Can take private, internal and public as a parameter.
        :param pulumi.Input[_builtins.str] default_preferred_language: Default preferred language for users who are not logged in.
        :param pulumi.Input[_builtins.int] default_project_creation: Default project creation protection. Can take: 0 (No one), 1 (Maintainers) or 2 (Developers + Maintainers).
        :param pulumi.Input[_builtins.str] default_project_visibility: What visibility level new projects receive. Can take private, internal and public as a parameter.
        :param pulumi.Input[_builtins.int] default_projects_limit: Project limit per user.
        :param pulumi.Input[_builtins.str] default_snippet_visibility: What visibility level new snippets receive. Can take private, internal and public as a parameter.
        :param pulumi.Input[_builtins.int] default_syntax_highlighting_theme: Default syntax highlighting theme for users who are new or not signed in. See IDs of available themes (https://gitlab.com/gitlab-org/gitlab/blob/master/lib/gitlab/themes.rb#L16)
        :param pulumi.Input[_builtins.bool] delete_inactive_projects: Enable inactive project deletion feature.
        :param pulumi.Input[_builtins.bool] delete_unconfirmed_users: Specifies whether users who have not confirmed their email should be deleted. When set to true, unconfirmed users are deleted after unconfirmed*users*delete*after*days days. Self-managed, Premium and Ultimate only.
        :param pulumi.Input[_builtins.int] deletion_adjourned_period: The number of days to wait before deleting a project or group that is marked for deletion. Value must be between 1 and 90.
        :param pulumi.Input[_builtins.bool] diagramsnet_enabled: (If enabled, requires diagramsnet_url) Enable Diagrams.net integration.
        :param pulumi.Input[_builtins.str] diagramsnet_url: The Diagrams.net instance URL for integration.
        :param pulumi.Input[_builtins.int] diff_max_files: Maximum files in a diff.
        :param pulumi.Input[_builtins.int] diff_max_lines: Maximum lines in a diff.
        :param pulumi.Input[_builtins.int] diff_max_patch_bytes: Maximum diff patch size, in bytes.
        :param pulumi.Input[_builtins.bool] disable_admin_oauth_scopes: Stops administrators from connecting their GitLab accounts to non-trusted OAuth 2.0 applications that have the api, read*api, read*repository, write*repository, read*registry, write_registry, or sudo scopes.
        :param pulumi.Input[_builtins.bool] disable_feed_token: Disable display of RSS/Atom and calendar feed tokens.
        :param pulumi.Input[_builtins.bool] disable_personal_access_tokens: Disable personal access tokens. Self-managed, Premium and Ultimate only. There is no method available to enable a personal access token that’s been disabled through the API. This is a known issue.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] disabled_oauth_sign_in_sources: Disabled OAuth sign-in sources.
        :param pulumi.Input[_builtins.bool] dns_rebinding_protection_enabled: Enforce DNS rebinding attack protection.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] domain_allowlists: Force people to use only corporate emails for sign-up. Null means there is no restriction.
        :param pulumi.Input[_builtins.bool] domain_denylist_enabled: (If enabled, requires: domain_denylist) Allows blocking sign-ups from emails from specific domains.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] domain_denylists: Users with email addresses that match these domains cannot sign up. Wildcards allowed. Use separate lines for multiple entries. Ex: domain.com, *.domain.com.
        :param pulumi.Input[_builtins.int] downstream_pipeline_trigger_limit_per_project_user_sha: Maximum downstream pipeline trigger rate.
        :param pulumi.Input[_builtins.int] dsa_key_restriction: The minimum allowed bit length of an uploaded DSA key. 0 means no restriction. -1 disables DSA keys.
        :param pulumi.Input[_builtins.bool] duo_features_enabled: Indicates whether GitLab Duo features are enabled for this instance. Self-managed, Premium and Ultimate only.
        :param pulumi.Input[_builtins.int] ecdsa_key_restriction: The minimum allowed curve size (in bits) of an uploaded ECDSA key. 0 means no restriction. -1 disables ECDSA keys.
        :param pulumi.Input[_builtins.int] ecdsa_sk_key_restriction: The minimum allowed curve size (in bits) of an uploaded ECDSA*SK key. 0 means no restriction. -1 disables ECDSA*SK keys.
        :param pulumi.Input[_builtins.int] ed25519_key_restriction: The minimum allowed curve size (in bits) of an uploaded ED25519 key. 0 means no restriction. -1 disables ED25519 keys.
        :param pulumi.Input[_builtins.int] ed25519_sk_key_restriction: The minimum allowed curve size (in bits) of an uploaded ED25519*SK key. 0 means no restriction. -1 disables ED25519*SK keys.
        :param pulumi.Input[_builtins.str] eks_access_key_id: AWS IAM access key ID.
        :param pulumi.Input[_builtins.str] eks_account_id: Amazon account ID.
        :param pulumi.Input[_builtins.bool] eks_integration_enabled: Enable integration with Amazon EKS.
        :param pulumi.Input[_builtins.str] eks_secret_access_key: AWS IAM secret access key.
        :param pulumi.Input[_builtins.bool] elasticsearch_aws: Enable the use of AWS hosted Elasticsearch.
        :param pulumi.Input[_builtins.str] elasticsearch_aws_access_key: AWS IAM access key.
        :param pulumi.Input[_builtins.str] elasticsearch_aws_region: The AWS region the Elasticsearch domain is configured.
        :param pulumi.Input[_builtins.str] elasticsearch_aws_secret_access_key: AWS IAM secret access key.
        :param pulumi.Input[_builtins.int] elasticsearch_indexed_field_length_limit: Maximum size of text fields to index by Elasticsearch. 0 value means no limit. This does not apply to repository and wiki indexing.
        :param pulumi.Input[_builtins.int] elasticsearch_indexed_file_size_limit_kb: Maximum size of repository and wiki files that are indexed by Elasticsearch.
        :param pulumi.Input[_builtins.bool] elasticsearch_indexing: Enable Elasticsearch indexing.
        :param pulumi.Input[_builtins.bool] elasticsearch_limit_indexing: Limit Elasticsearch to index certain namespaces and projects.
        :param pulumi.Input[_builtins.int] elasticsearch_max_bulk_concurrency: Maximum concurrency of Elasticsearch bulk requests per indexing operation. This only applies to repository indexing operations.
        :param pulumi.Input[_builtins.int] elasticsearch_max_bulk_size_mb: Maximum size of Elasticsearch bulk indexing requests in MB. This only applies to repository indexing operations.
        :param pulumi.Input[_builtins.int] elasticsearch_max_code_indexing_concurrency: Maximum concurrency of Elasticsearch code indexing background jobs. This only applies to repository indexing operations. Premium and Ultimate only.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] elasticsearch_namespace_ids: The namespaces to index via Elasticsearch if elasticsearch*limit*indexing is enabled.
        :param pulumi.Input[_builtins.str] elasticsearch_password: The password of your Elasticsearch instance.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] elasticsearch_project_ids: The projects to index via Elasticsearch if elasticsearch*limit*indexing is enabled.
        :param pulumi.Input[_builtins.bool] elasticsearch_requeue_workers: Enable automatic requeuing of indexing workers. This improves non-code indexing throughput by enqueuing Sidekiq jobs until all documents are processed. Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] elasticsearch_search: Enable Elasticsearch search.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] elasticsearch_urls: The URL to use for connecting to Elasticsearch. Use a comma-separated list to support cluster (for example, http://localhost:9200, http://localhost:9201).
        :param pulumi.Input[_builtins.str] elasticsearch_username: The username of your Elasticsearch instance.
        :param pulumi.Input[_builtins.int] elasticsearch_worker_number_of_shards: Number of indexing worker shards. This improves non-code indexing throughput by enqueuing more parallel Sidekiq jobs. Premium and Ultimate only.
        :param pulumi.Input[_builtins.str] email_additional_text: Additional text added to the bottom of every email for legal/auditing/compliance reasons.
        :param pulumi.Input[_builtins.bool] email_author_in_body: Some email servers do not support overriding the email sender name. Enable this option to include the name of the author of the issue, merge request or comment in the email body instead.
        :param pulumi.Input[_builtins.str] email_confirmation_setting: Specifies whether users must confirm their email before sign in. Possible values are off, soft, and hard.
        :param pulumi.Input[_builtins.bool] enable_artifact_external_redirect_warning_page: Show the external redirect page that warns you about user-generated content in GitLab Pages.
        :param pulumi.Input[_builtins.str] enabled_git_access_protocol: Enabled protocols for Git access. Allowed values are: ssh, http, and nil to allow both protocols.
        :param pulumi.Input[_builtins.bool] enforce_namespace_storage_limit: Enabling this permits enforcement of namespace storage limits.
        :param pulumi.Input[_builtins.bool] enforce_terms: (If enabled, requires: terms) Enforce application ToS to all users.
        :param pulumi.Input[_builtins.str] external_auth_client_cert: (If enabled, requires: external*auth*client_key) The certificate to use to authenticate with the external authorization service.
        :param pulumi.Input[_builtins.str] external_auth_client_key: Private key for the certificate when authentication is required for the external authorization service, this is encrypted when stored.
        :param pulumi.Input[_builtins.str] external_auth_client_key_pass: Passphrase to use for the private key when authenticating with the external service this is encrypted when stored.
        :param pulumi.Input[_builtins.str] external_authorization_service_default_label: The default classification label to use when requesting authorization and no classification label has been specified on the project.
        :param pulumi.Input[_builtins.bool] external_authorization_service_enabled: (If enabled, requires: external*authorization*service*default*label, external*authorization*service*timeout and external*authorization*service*url) Enable using an external authorization service for accessing projects.
        :param pulumi.Input[_builtins.float] external_authorization_service_timeout: The timeout after which an authorization request is aborted, in seconds. When a request times out, access is denied to the user. (min: 0.001, max: 10, step: 0.001).
        :param pulumi.Input[_builtins.str] external_authorization_service_url: URL to which authorization requests are directed.
        :param pulumi.Input[_builtins.int] external_pipeline_validation_service_timeout: How long to wait for a response from the pipeline validation service. Assumes OK if it times out.
        :param pulumi.Input[_builtins.str] external_pipeline_validation_service_token: Optional. Token to include as the X-Gitlab-Token header in requests to the URL in external*pipeline*validation*service*url.
        :param pulumi.Input[_builtins.str] external_pipeline_validation_service_url: URL to use for pipeline validation requests.
        :param pulumi.Input[_builtins.int] failed_login_attempts_unlock_period_in_minutes: Time period in minutes after which the user is unlocked when maximum number of failed sign-in attempts reached.
        :param pulumi.Input[_builtins.int] file_template_project_id: The ID of a project to load custom file templates from.
        :param pulumi.Input[_builtins.int] first_day_of_week: Start day of the week for calendar views and date pickers. Valid values are 0 for Sunday, 1 for Monday, and 6 for Saturday.
        :param pulumi.Input[_builtins.str] geo_node_allowed_ips: Comma-separated list of IPs and CIDRs of allowed secondary nodes. For example, 1.1.1.1, 2.2.2.0/24.
        :param pulumi.Input[_builtins.int] geo_status_timeout: The amount of seconds after which a request to get a secondary node status times out.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] git_rate_limit_users_alertlists: List of user IDs that are emailed when the Git abuse rate limit is exceeded. Maximum: 100 user IDs. Self-managed, Ultimate only.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] git_rate_limit_users_allowlists: List of usernames excluded from Git anti-abuse rate limits. Maximum: 100 usernames. Self-managed, Ultimate only.
        :param pulumi.Input[_builtins.int] git_two_factor_session_expiry: Maximum duration (in minutes) of a session for Git operations when 2FA is enabled.
        :param pulumi.Input[_builtins.int] gitaly_timeout_default: Default Gitaly timeout, in seconds. This timeout is not enforced for Git fetch/push operations or Sidekiq jobs. Set to 0 to disable timeouts.
        :param pulumi.Input[_builtins.int] gitaly_timeout_fast: Gitaly fast operation timeout, in seconds. Some Gitaly operations are expected to be fast. If they exceed this threshold, there may be a problem with a storage shard and ‘failing fast’ can help maintain the stability of the GitLab instance. Set to 0 to disable timeouts.
        :param pulumi.Input[_builtins.int] gitaly_timeout_medium: Medium Gitaly timeout, in seconds. This should be a value between the Fast and the Default timeout. Set to 0 to disable timeouts.
        :param pulumi.Input[_builtins.int] gitlab_shell_operation_limit: Maximum number of Git operations per minute a user can perform.
        :param pulumi.Input[_builtins.bool] gitpod_enabled: Enable Gitpod integration.
        :param pulumi.Input[_builtins.str] gitpod_url: The Gitpod instance URL for integration.
        :param pulumi.Input[_builtins.str] globally_allowed_ips: Comma-separated list of IP addresses and CIDRs always allowed for inbound traffic. For example, 1.1.1.1, 2.2.2.0/24.
        :param pulumi.Input[_builtins.bool] grafana_enabled: Enable Grafana.
        :param pulumi.Input[_builtins.str] grafana_url: Grafana URL.
        :param pulumi.Input[_builtins.bool] gravatar_enabled: Enable Gravatar.
        :param pulumi.Input[_builtins.bool] group_owners_can_manage_default_branch_protection: Prevent overrides of default branch protection.
        :param pulumi.Input[_builtins.bool] help_page_hide_commercial_content: Hide marketing-related entries from help.
        :param pulumi.Input[_builtins.str] help_page_support_url: Alternate support URL for help page and help dropdown.
        :param pulumi.Input[_builtins.str] help_page_text: Custom text displayed on the help page.
        :param pulumi.Input[_builtins.str] help_text: GitLab server administrator information.
        :param pulumi.Input[_builtins.bool] hide_third_party_offers: Do not display offers from third parties in GitLab.
        :param pulumi.Input[_builtins.str] home_page_url: Redirect to this URL when not logged in.
        :param pulumi.Input[_builtins.bool] housekeeping_enabled: Enable or disable Git housekeeping. If enabled, requires housekeeping*optimize*repository_period.
        :param pulumi.Input[_builtins.int] housekeeping_optimize_repository_period: Number of Git pushes after which an incremental git-repack is run.
        :param pulumi.Input[_builtins.bool] html_emails_enabled: Enable HTML emails.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] import_sources: Sources to allow project import from. Valid values are: `github`, `bitbucket`, `bitbucket_server`, `fogbugz`, `git`, `Project`, `gitea`, `manifest`
        :param pulumi.Input[_builtins.bool] in_product_marketing_emails_enabled: Enable in-product marketing emails.
        :param pulumi.Input[_builtins.int] inactive_projects_delete_after_months: If delete*inactive*projects is true, the time (in months) to wait before deleting inactive projects.
        :param pulumi.Input[_builtins.int] inactive_projects_min_size_mb: If delete*inactive*projects is true, the minimum repository size for projects to be checked for inactivity.
        :param pulumi.Input[_builtins.int] inactive_projects_send_warning_email_after_months: If delete*inactive*projects is true, sets the time (in months) to wait before emailing maintainers that the project is scheduled be deleted because it is inactive.
        :param pulumi.Input[_builtins.bool] include_optional_metrics_in_service_ping: Whether or not optional metrics are enabled in Service Ping.
        :param pulumi.Input[_builtins.bool] invisible_captcha_enabled: Enable Invisible CAPTCHA spam detection during sign-up.
        :param pulumi.Input[_builtins.int] issues_create_limit: Max number of issue creation requests per minute per user.
        :param pulumi.Input[_builtins.str] jira_connect_application_key: ID of the OAuth application used to authenticate with the GitLab for Jira Cloud app.
        :param pulumi.Input[_builtins.str] jira_connect_proxy_url: URL of the GitLab instance used as a proxy for the GitLab for Jira Cloud app.
        :param pulumi.Input[_builtins.bool] jira_connect_public_key_storage_enabled: Enable public key storage for the GitLab for Jira Cloud app.
        :param pulumi.Input[_builtins.bool] keep_latest_artifact: Prevent the deletion of the artifacts from the most recent successful jobs, regardless of the expiry time.
        :param pulumi.Input[_builtins.int] local_markdown_version: Increase this value when any cached Markdown should be invalidated.
        :param pulumi.Input[_builtins.bool] lock_duo_features_enabled: Indicates whether the GitLab Duo features enabled setting is enforced for all subgroups. Self-managed, Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] lock_memberships_to_ldap: Set to true to lock all memberships to LDAP. Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] mailgun_events_enabled: Enable Mailgun event receiver.
        :param pulumi.Input[_builtins.str] mailgun_signing_key: The Mailgun HTTP webhook signing key for receiving events from webhook.
        :param pulumi.Input[_builtins.bool] maintenance_mode: When instance is in maintenance mode, non-administrative users can sign in with read-only access and make read-only API requests.
        :param pulumi.Input[_builtins.str] maintenance_mode_message: Message displayed when instance is in maintenance mode.
        :param pulumi.Input[_builtins.bool] maven_package_requests_forwarding: Use repo.maven.apache.org as a default remote repository when the package is not found in the GitLab Package Registry for Maven. Premium and Ultimate only.
        :param pulumi.Input[_builtins.int] max_artifacts_size: Maximum artifacts size in MB.
        :param pulumi.Input[_builtins.int] max_attachment_size: Limit attachment size in MB.
        :param pulumi.Input[_builtins.int] max_decompressed_archive_size: Maximum decompressed archive size in bytes.
        :param pulumi.Input[_builtins.int] max_export_size: Maximum export size in MB. 0 for unlimited.
        :param pulumi.Input[_builtins.int] max_import_remote_file_size: Maximum remote file size for imports from external object storages.
        :param pulumi.Input[_builtins.int] max_import_size: Maximum import size in MB. 0 for unlimited.
        :param pulumi.Input[_builtins.int] max_login_attempts: Maximum number of sign-in attempts before locking out the user.
        :param pulumi.Input[_builtins.int] max_number_of_repository_downloads: Maximum number of unique repositories a user can download in the specified time period before they are banned. Maximum: 10,000 repositories.
        :param pulumi.Input[_builtins.int] max_number_of_repository_downloads_within_time_period: Reporting time period (in seconds). Maximum: 864000 seconds (10 days).
        :param pulumi.Input[_builtins.int] max_pages_size: Maximum size of pages repositories in MB.
        :param pulumi.Input[_builtins.int] max_personal_access_token_lifetime: Maximum allowable lifetime for access tokens in days.
        :param pulumi.Input[_builtins.int] max_ssh_key_lifetime: Maximum allowable lifetime for SSH keys in days.
        :param pulumi.Input[_builtins.int] metrics_method_call_threshold: A method call is only tracked when it takes longer than the given amount of milliseconds.
        :param pulumi.Input[_builtins.int] minimum_password_length: Indicates whether passwords require a minimum length. Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] mirror_available: Allow repository mirroring to configured by project Maintainers. If disabled, only Administrators can configure repository mirroring.
        :param pulumi.Input[_builtins.int] mirror_capacity_threshold: Minimum capacity to be available before scheduling more mirrors preemptively.
        :param pulumi.Input[_builtins.int] mirror_max_capacity: Maximum number of mirrors that can be synchronizing at the same time.
        :param pulumi.Input[_builtins.int] mirror_max_delay: Maximum time (in minutes) between updates that a mirror can have when scheduled to synchronize.
        :param pulumi.Input[_builtins.bool] npm_package_requests_forwarding: Use npmjs.org as a default remote repository when the package is not found in the GitLab Package Registry for npm.
        :param pulumi.Input[_builtins.bool] nuget_skip_metadata_url_validation: Indicates whether to skip metadata URL validation for the NuGet package.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] outbound_local_requests_whitelists: Define a list of trusted domains or IP addresses to which local requests are allowed when local requests for hooks and services are disabled.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] package_metadata_purl_types: List of package registry metadata to sync. See the list of the available values (https://gitlab.com/gitlab-org/gitlab/-/blob/ace16c20d5da7c4928dd03fb139692638b557fe3/app/models/concerns/enums/package_metadata.rb#L5). Self-managed, Ultimate only.
        :param pulumi.Input[_builtins.bool] package_registry_allow_anyone_to_pull_option: Enable to allow anyone to pull from Package Registry visible and changeable.
        :param pulumi.Input[_builtins.int] package_registry_cleanup_policies_worker_capacity: Number of workers assigned to the packages cleanup policies.
        :param pulumi.Input[_builtins.bool] pages_domain_verification_enabled: Require users to prove ownership of custom domains. Domain verification is an essential security measure for public GitLab sites. Users are required to demonstrate they control a domain before it is enabled.
        :param pulumi.Input[_builtins.bool] password_authentication_enabled_for_git: Enable authentication for Git over HTTP(S) via a GitLab account password.
        :param pulumi.Input[_builtins.bool] password_authentication_enabled_for_web: Enable authentication for the web interface via a GitLab account password.
        :param pulumi.Input[_builtins.bool] password_lowercase_required: Indicates whether passwords require at least one lowercase letter.
        :param pulumi.Input[_builtins.bool] password_number_required: Indicates whether passwords require at least one number.
        :param pulumi.Input[_builtins.bool] password_symbol_required: Indicates whether passwords require at least one symbol character.
        :param pulumi.Input[_builtins.bool] password_uppercase_required: Indicates whether passwords require at least one uppercase letter.
        :param pulumi.Input[_builtins.str] performance_bar_allowed_group_path: Path of the group that is allowed to toggle the performance bar.
        :param pulumi.Input[_builtins.str] personal_access_token_prefix: Prefix for all generated personal access tokens.
        :param pulumi.Input[_builtins.int] pipeline_limit_per_project_user_sha: Maximum number of pipeline creation requests per minute per user and commit.
        :param pulumi.Input[_builtins.bool] plantuml_enabled: (If enabled, requires: plantuml_url) Enable PlantUML integration.
        :param pulumi.Input[_builtins.str] plantuml_url: The PlantUML instance URL for integration.
        :param pulumi.Input[_builtins.float] polling_interval_multiplier: Interval multiplier used by endpoints that perform polling. Set to 0 to disable polling.
        :param pulumi.Input[_builtins.bool] project_export_enabled: Enable project export.
        :param pulumi.Input[_builtins.int] project_jobs_api_rate_limit: Maximum authenticated requests to /project/:id/jobs per minute.
        :param pulumi.Input[_builtins.int] projects_api_rate_limit_unauthenticated: Max number of requests per 10 minutes per IP address for unauthenticated requests to the list all projects API. To disable throttling set to 0.
        :param pulumi.Input[_builtins.bool] prometheus_metrics_enabled: Enable Prometheus metrics.
        :param pulumi.Input[_builtins.bool] protected_ci_variables: CI/CD variables are protected by default.
        :param pulumi.Input[_builtins.int] push_event_activities_limit: Number of changes (branches or tags) in a single push to determine whether individual push events or bulk push events are created. Bulk push events are created if it surpasses that value.
        :param pulumi.Input[_builtins.int] push_event_hooks_limit: Number of changes (branches or tags) in a single push to determine whether webhooks and services fire or not. Webhooks and services aren’t submitted if it surpasses that value.
        :param pulumi.Input[_builtins.bool] pypi_package_requests_forwarding: Use pypi.org as a default remote repository when the package is not found in the GitLab Package Registry for PyPI.
        :param pulumi.Input[_builtins.str] rate_limiting_response_text: When rate limiting is enabled via the throttle_* settings, send this plain text response when a rate limit is exceeded. ‘Retry later’ is sent if this is blank.
        :param pulumi.Input[_builtins.int] raw_blob_request_limit: Max number of requests per minute for each raw path. To disable throttling set to 0.
        :param pulumi.Input[_builtins.bool] recaptcha_enabled: (If enabled, requires: recaptcha*private*key and recaptcha*site*key) Enable reCAPTCHA.
        :param pulumi.Input[_builtins.str] recaptcha_private_key: Private key for reCAPTCHA.
        :param pulumi.Input[_builtins.str] recaptcha_site_key: Site key for reCAPTCHA.
        :param pulumi.Input[_builtins.int] receive_max_input_size: Maximum push size (MB).
        :param pulumi.Input[_builtins.bool] receptive_cluster_agents_enabled: Enable receptive mode for GitLab Agents for Kubernetes.
        :param pulumi.Input[_builtins.bool] remember_me_enabled: Enable Remember me setting.
        :param pulumi.Input[_builtins.bool] repository_checks_enabled: GitLab periodically runs git fsck in all project and wiki repositories to look for silent disk corruption issues.
        :param pulumi.Input[_builtins.int] repository_size_limit: Size limit per repository (MB).
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.int]]] repository_storages_weighted: Hash of names taken from gitlab.yml to weights. New projects are created in one of these stores, chosen by a weighted random selection.
        :param pulumi.Input[_builtins.bool] require_admin_approval_after_user_signup: When enabled, any user that signs up for an account using the registration form is placed under a Pending approval state and has to be explicitly approved by an administrator.
        :param pulumi.Input[_builtins.bool] require_admin_two_factor_authentication: Allow administrators to require 2FA for all administrators on the instance.
        :param pulumi.Input[_builtins.bool] require_personal_access_token_expiry: When enabled, users must set an expiration date when creating a group or project access token, or a personal access token owned by a non-service account.
        :param pulumi.Input[_builtins.bool] require_two_factor_authentication: (If enabled, requires: two*factor*grace_period) Require all users to set up Two-factor authentication.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] restricted_visibility_levels: Selected levels cannot be used by non-Administrator users for groups, projects or snippets. Can take private, internal and public as a parameter. Null means there is no restriction.
        :param pulumi.Input[_builtins.int] rsa_key_restriction: The minimum allowed bit length of an uploaded RSA key. 0 means no restriction. -1 disables RSA keys.
        :param pulumi.Input[_builtins.int] search_rate_limit: Max number of requests per minute for performing a search while authenticated. To disable throttling set to 0.
        :param pulumi.Input[_builtins.int] search_rate_limit_unauthenticated: Max number of requests per minute for performing a search while unauthenticated. To disable throttling set to 0.
        :param pulumi.Input[_builtins.int] security_approval_policies_limit: Maximum number of active merge request approval policies per security policy project. Maximum: 20
        :param pulumi.Input[_builtins.bool] security_policy_global_group_approvers_enabled: Whether to look up merge request approval policy approval groups globally or within project hierarchies.
        :param pulumi.Input[_builtins.str] security_txt_content: Public security contact information.
        :param pulumi.Input[_builtins.bool] send_user_confirmation_email: Send confirmation email on sign-up.
        :param pulumi.Input[_builtins.bool] service_access_tokens_expiration_enforced: Flag to indicate if token expiry date can be optional for service account users
        :param pulumi.Input[_builtins.int] session_expire_delay: Session duration in minutes. GitLab restart is required to apply changes.
        :param pulumi.Input[_builtins.bool] shared_runners_enabled: (If enabled, requires: shared*runners*text and shared*runners*minutes) Enable shared runners for new projects.
        :param pulumi.Input[_builtins.int] shared_runners_minutes: Set the maximum number of CI/CD minutes that a group can use on shared runners per month.
        :param pulumi.Input[_builtins.str] shared_runners_text: Shared runners text.
        :param pulumi.Input[_builtins.int] sidekiq_job_limiter_compression_threshold_bytes: The threshold in bytes at which Sidekiq jobs are compressed before being stored in Redis.
        :param pulumi.Input[_builtins.int] sidekiq_job_limiter_limit_bytes: The threshold in bytes at which Sidekiq jobs are rejected. 0 means do not reject any job.
        :param pulumi.Input[_builtins.str] sidekiq_job_limiter_mode: track or compress. Sets the behavior for Sidekiq job size limits.
        :param pulumi.Input[_builtins.str] sign_in_text: Text on the login page.
        :param pulumi.Input[_builtins.bool] signup_enabled: Enable registration.
        :param pulumi.Input[_builtins.bool] silent_admin_exports_enabled: Enable Silent admin exports.
        :param pulumi.Input[_builtins.bool] silent_mode_enabled: Enable Silent mode.
        :param pulumi.Input[_builtins.bool] slack_app_enabled: (If enabled, requires: slack*app*id, slack*app*secret and slack*app*secret) Enable Slack app.
        :param pulumi.Input[_builtins.str] slack_app_id: The app ID of the Slack-app.
        :param pulumi.Input[_builtins.str] slack_app_secret: The app secret of the Slack-app.
        :param pulumi.Input[_builtins.str] slack_app_signing_secret: The signing secret of the Slack-app.
        :param pulumi.Input[_builtins.str] slack_app_verification_token: The verification token of the Slack-app.
        :param pulumi.Input[_builtins.int] snippet_size_limit: Max snippet content size in bytes.
        :param pulumi.Input[_builtins.str] snowplow_app_id: The Snowplow site name / application ID. (for example, gitlab)
        :param pulumi.Input[_builtins.str] snowplow_collector_hostname: The Snowplow collector hostname. (for example, snowplow.trx.gitlab.net)
        :param pulumi.Input[_builtins.str] snowplow_cookie_domain: The Snowplow cookie domain. (for example, .gitlab.com)
        :param pulumi.Input[_builtins.str] snowplow_database_collector_hostname: The Snowplow collector for database events hostname. (for example, db-snowplow.trx.gitlab.net)
        :param pulumi.Input[_builtins.bool] snowplow_enabled: Enable snowplow tracking.
        :param pulumi.Input[_builtins.bool] sourcegraph_enabled: Enables Sourcegraph integration. If enabled, requires sourcegraph_url.
        :param pulumi.Input[_builtins.bool] sourcegraph_public_only: Blocks Sourcegraph from being loaded on private and internal projects.
        :param pulumi.Input[_builtins.str] sourcegraph_url: The Sourcegraph instance URL for integration.
        :param pulumi.Input[_builtins.str] spam_check_api_key: API key used by GitLab for accessing the Spam Check service endpoint.
        :param pulumi.Input[_builtins.bool] spam_check_endpoint_enabled: Enables spam checking using external Spam Check API endpoint.
        :param pulumi.Input[_builtins.str] spam_check_endpoint_url: URL of the external Spamcheck service endpoint. Valid URI schemes are grpc or tls. Specifying tls forces communication to be encrypted.
        :param pulumi.Input[_builtins.str] static_objects_external_storage_auth_token: Authentication token for the external storage linked in static*objects*external*storage*url.
        :param pulumi.Input[_builtins.str] static_objects_external_storage_url: URL to an external storage for repository static objects.
        :param pulumi.Input[_builtins.bool] suggest_pipeline_enabled: Enable pipeline suggestion banner.
        :param pulumi.Input[_builtins.int] terminal_max_session_time: Maximum time for web terminal websocket connection (in seconds). Set to 0 for unlimited time.
        :param pulumi.Input[_builtins.str] terms: (Required by: enforce_terms) Markdown content for the ToS.
        :param pulumi.Input[_builtins.bool] throttle_authenticated_api_enabled: (If enabled, requires: throttle*authenticated*api*period*in*seconds and throttle*authenticated*api*requests*per*period) Enable authenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        :param pulumi.Input[_builtins.int] throttle_authenticated_api_period_in_seconds: Rate limit period (in seconds).
        :param pulumi.Input[_builtins.int] throttle_authenticated_api_requests_per_period: Maximum requests per period per user.
        :param pulumi.Input[_builtins.bool] throttle_authenticated_packages_api_enabled: (If enabled, requires: throttle*authenticated*packages*api*period*in*seconds and throttle*authenticated*packages*api*requests*per*period) Enable authenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots). View Package Registry rate limits for more details.
        :param pulumi.Input[_builtins.int] throttle_authenticated_packages_api_period_in_seconds: Rate limit period (in seconds). View Package Registry rate limits for more details.
        :param pulumi.Input[_builtins.int] throttle_authenticated_packages_api_requests_per_period: Maximum requests per period per user. View Package Registry rate limits for more details.
        :param pulumi.Input[_builtins.bool] throttle_authenticated_web_enabled: (If enabled, requires: throttle*authenticated*web*period*in*seconds and throttle*authenticated*web*requests*per*period) Enable authenticated web request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        :param pulumi.Input[_builtins.int] throttle_authenticated_web_period_in_seconds: Rate limit period (in seconds).
        :param pulumi.Input[_builtins.int] throttle_authenticated_web_requests_per_period: Maximum requests per period per user.
        :param pulumi.Input[_builtins.bool] throttle_unauthenticated_api_enabled: (If enabled, requires: throttle*unauthenticated*api*period*in*seconds and throttle*unauthenticated*api*requests*per*period) Enable unauthenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        :param pulumi.Input[_builtins.int] throttle_unauthenticated_api_period_in_seconds: Rate limit period in seconds.
        :param pulumi.Input[_builtins.int] throttle_unauthenticated_api_requests_per_period: Max requests per period per IP.
        :param pulumi.Input[_builtins.bool] throttle_unauthenticated_packages_api_enabled: (If enabled, requires: throttle*unauthenticated*packages*api*period*in*seconds and throttle*unauthenticated*packages*api*requests*per*period) Enable authenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots). View Package Registry rate limits for more details.
        :param pulumi.Input[_builtins.int] throttle_unauthenticated_packages_api_period_in_seconds: Rate limit period (in seconds). View Package Registry rate limits for more details.
        :param pulumi.Input[_builtins.int] throttle_unauthenticated_packages_api_requests_per_period: Maximum requests per period per user. View Package Registry rate limits for more details.
        :param pulumi.Input[_builtins.bool] throttle_unauthenticated_web_enabled: (If enabled, requires: throttle*unauthenticated*web*period*in*seconds and throttle*unauthenticated*web*requests*per*period) Enable unauthenticated web request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        :param pulumi.Input[_builtins.int] throttle_unauthenticated_web_period_in_seconds: Rate limit period in seconds.
        :param pulumi.Input[_builtins.int] throttle_unauthenticated_web_requests_per_period: Max requests per period per IP.
        :param pulumi.Input[_builtins.bool] time_tracking_limit_to_hours: Limit display of time tracking units to hours.
        :param pulumi.Input[_builtins.int] two_factor_grace_period: Amount of time (in hours) that users are allowed to skip forced configuration of two-factor authentication.
        :param pulumi.Input[_builtins.int] unconfirmed_users_delete_after_days: Specifies how many days after sign-up to delete users who have not confirmed their email. Only applicable if delete*unconfirmed*users is set to true. Must be 1 or greater. Self-managed, Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] unique_ips_limit_enabled: (If enabled, requires: unique*ips*limit*per*user and unique*ips*limit*time*window) Limit sign in from multiple IPs.
        :param pulumi.Input[_builtins.int] unique_ips_limit_per_user: Maximum number of IPs per user.
        :param pulumi.Input[_builtins.int] unique_ips_limit_time_window: How many seconds an IP is counted towards the limit.
        :param pulumi.Input[_builtins.bool] update_runner_versions_enabled: Fetch GitLab Runner release version data from GitLab.com.
        :param pulumi.Input[_builtins.bool] usage_ping_enabled: Every week GitLab reports license usage back to GitLab, Inc.
        :param pulumi.Input[_builtins.bool] use_clickhouse_for_analytics: Enables ClickHouse as a data source for analytics reports. ClickHouse must be configured for this setting to take effect. Available on Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] user_deactivation_emails_enabled: Send an email to users upon account deactivation.
        :param pulumi.Input[_builtins.bool] user_default_external: Newly registered users are external by default.
        :param pulumi.Input[_builtins.str] user_default_internal_regex: Specify an email address regex pattern to identify default internal users.
        :param pulumi.Input[_builtins.bool] user_defaults_to_private_profile: Newly created users have private profile by default.
        :param pulumi.Input[_builtins.bool] user_oauth_applications: Allow users to register any application to use GitLab as an OAuth provider.
        :param pulumi.Input[_builtins.bool] user_show_add_ssh_key_message: When set to false disable the You won't be able to pull or push project code via SSH warning shown to users with no uploaded SSH key.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] valid_runner_registrars: List of types which are allowed to register a GitLab Runner. Can be [], ['group'], ['project'] or ['group', 'project'].
        :param pulumi.Input[_builtins.bool] version_check_enabled: Let GitLab inform you when an update is available.
        :param pulumi.Input[_builtins.bool] web_ide_clientside_preview_enabled: Live Preview (allow live previews of JavaScript projects in the Web IDE using CodeSandbox Live Preview).
        :param pulumi.Input[_builtins.str] whats_new_variant: What's new variant, possible values: all*tiers, current*tier, and disabled.
        :param pulumi.Input[_builtins.int] wiki_page_max_content_bytes: Maximum wiki page content size in bytes. The minimum value is 1024 bytes.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ApplicationSettingsArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        :param str resource_name: The name of the resource.
        :param ApplicationSettingsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ApplicationSettingsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 abuse_notification_email: Optional[pulumi.Input[_builtins.str]] = None,
                 admin_mode: Optional[pulumi.Input[_builtins.bool]] = None,
                 after_sign_out_path: Optional[pulumi.Input[_builtins.str]] = None,
                 after_sign_up_text: Optional[pulumi.Input[_builtins.str]] = None,
                 akismet_api_key: Optional[pulumi.Input[_builtins.str]] = None,
                 akismet_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_account_deletion: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_group_owners_to_manage_ldap: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_local_requests_from_system_hooks: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_local_requests_from_web_hooks_and_services: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_project_creation_for_guest_and_below: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_runner_registration_token: Optional[pulumi.Input[_builtins.bool]] = None,
                 archive_builds_in_human_readable: Optional[pulumi.Input[_builtins.str]] = None,
                 asciidoc_max_includes: Optional[pulumi.Input[_builtins.int]] = None,
                 asset_proxy_allowlists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 asset_proxy_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 asset_proxy_secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 asset_proxy_url: Optional[pulumi.Input[_builtins.str]] = None,
                 authorized_keys_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 auto_ban_user_on_excessive_projects_download: Optional[pulumi.Input[_builtins.bool]] = None,
                 auto_devops_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 auto_devops_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 automatic_purchased_storage_allocation: Optional[pulumi.Input[_builtins.bool]] = None,
                 bulk_import_concurrent_pipeline_batch_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 bulk_import_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 bulk_import_max_download_file_size: Optional[pulumi.Input[_builtins.int]] = None,
                 can_create_group: Optional[pulumi.Input[_builtins.bool]] = None,
                 check_namespace_plan: Optional[pulumi.Input[_builtins.bool]] = None,
                 ci_max_includes: Optional[pulumi.Input[_builtins.int]] = None,
                 ci_max_total_yaml_size_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 commit_email_hostname: Optional[pulumi.Input[_builtins.str]] = None,
                 concurrent_bitbucket_import_jobs_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 concurrent_bitbucket_server_import_jobs_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 concurrent_github_import_jobs_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 container_expiration_policies_enable_historic_entries: Optional[pulumi.Input[_builtins.bool]] = None,
                 container_registry_cleanup_tags_service_max_list_size: Optional[pulumi.Input[_builtins.int]] = None,
                 container_registry_delete_tags_service_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 container_registry_expiration_policies_caching: Optional[pulumi.Input[_builtins.bool]] = None,
                 container_registry_expiration_policies_worker_capacity: Optional[pulumi.Input[_builtins.int]] = None,
                 container_registry_token_expire_delay: Optional[pulumi.Input[_builtins.int]] = None,
                 deactivate_dormant_users: Optional[pulumi.Input[_builtins.bool]] = None,
                 deactivate_dormant_users_period: Optional[pulumi.Input[_builtins.int]] = None,
                 decompress_archive_file_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 default_artifacts_expire_in: Optional[pulumi.Input[_builtins.str]] = None,
                 default_branch_name: Optional[pulumi.Input[_builtins.str]] = None,
                 default_branch_protection: Optional[pulumi.Input[_builtins.int]] = None,
                 default_branch_protection_defaults: Optional[pulumi.Input[Union['ApplicationSettingsDefaultBranchProtectionDefaultsArgs', 'ApplicationSettingsDefaultBranchProtectionDefaultsArgsDict']]] = None,
                 default_ci_config_path: Optional[pulumi.Input[_builtins.str]] = None,
                 default_group_visibility: Optional[pulumi.Input[_builtins.str]] = None,
                 default_preferred_language: Optional[pulumi.Input[_builtins.str]] = None,
                 default_project_creation: Optional[pulumi.Input[_builtins.int]] = None,
                 default_project_visibility: Optional[pulumi.Input[_builtins.str]] = None,
                 default_projects_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 default_snippet_visibility: Optional[pulumi.Input[_builtins.str]] = None,
                 default_syntax_highlighting_theme: Optional[pulumi.Input[_builtins.int]] = None,
                 delete_inactive_projects: Optional[pulumi.Input[_builtins.bool]] = None,
                 delete_unconfirmed_users: Optional[pulumi.Input[_builtins.bool]] = None,
                 deletion_adjourned_period: Optional[pulumi.Input[_builtins.int]] = None,
                 diagramsnet_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 diagramsnet_url: Optional[pulumi.Input[_builtins.str]] = None,
                 diff_max_files: Optional[pulumi.Input[_builtins.int]] = None,
                 diff_max_lines: Optional[pulumi.Input[_builtins.int]] = None,
                 diff_max_patch_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 disable_admin_oauth_scopes: Optional[pulumi.Input[_builtins.bool]] = None,
                 disable_feed_token: Optional[pulumi.Input[_builtins.bool]] = None,
                 disable_personal_access_tokens: Optional[pulumi.Input[_builtins.bool]] = None,
                 disabled_oauth_sign_in_sources: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dns_rebinding_protection_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 domain_allowlists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 domain_denylist_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 domain_denylists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 downstream_pipeline_trigger_limit_per_project_user_sha: Optional[pulumi.Input[_builtins.int]] = None,
                 dsa_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
                 duo_features_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 ecdsa_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
                 ecdsa_sk_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
                 ed25519_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
                 ed25519_sk_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
                 eks_access_key_id: Optional[pulumi.Input[_builtins.str]] = None,
                 eks_account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 eks_integration_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 eks_secret_access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 elasticsearch_aws: Optional[pulumi.Input[_builtins.bool]] = None,
                 elasticsearch_aws_access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 elasticsearch_aws_region: Optional[pulumi.Input[_builtins.str]] = None,
                 elasticsearch_aws_secret_access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 elasticsearch_indexed_field_length_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 elasticsearch_indexed_file_size_limit_kb: Optional[pulumi.Input[_builtins.int]] = None,
                 elasticsearch_indexing: Optional[pulumi.Input[_builtins.bool]] = None,
                 elasticsearch_limit_indexing: Optional[pulumi.Input[_builtins.bool]] = None,
                 elasticsearch_max_bulk_concurrency: Optional[pulumi.Input[_builtins.int]] = None,
                 elasticsearch_max_bulk_size_mb: Optional[pulumi.Input[_builtins.int]] = None,
                 elasticsearch_max_code_indexing_concurrency: Optional[pulumi.Input[_builtins.int]] = None,
                 elasticsearch_namespace_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 elasticsearch_password: Optional[pulumi.Input[_builtins.str]] = None,
                 elasticsearch_project_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 elasticsearch_requeue_workers: Optional[pulumi.Input[_builtins.bool]] = None,
                 elasticsearch_search: Optional[pulumi.Input[_builtins.bool]] = None,
                 elasticsearch_urls: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 elasticsearch_username: Optional[pulumi.Input[_builtins.str]] = None,
                 elasticsearch_worker_number_of_shards: Optional[pulumi.Input[_builtins.int]] = None,
                 email_additional_text: Optional[pulumi.Input[_builtins.str]] = None,
                 email_author_in_body: Optional[pulumi.Input[_builtins.bool]] = None,
                 email_confirmation_setting: Optional[pulumi.Input[_builtins.str]] = None,
                 enable_artifact_external_redirect_warning_page: Optional[pulumi.Input[_builtins.bool]] = None,
                 enabled_git_access_protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 enforce_namespace_storage_limit: Optional[pulumi.Input[_builtins.bool]] = None,
                 enforce_terms: Optional[pulumi.Input[_builtins.bool]] = None,
                 external_auth_client_cert: Optional[pulumi.Input[_builtins.str]] = None,
                 external_auth_client_key: Optional[pulumi.Input[_builtins.str]] = None,
                 external_auth_client_key_pass: Optional[pulumi.Input[_builtins.str]] = None,
                 external_authorization_service_default_label: Optional[pulumi.Input[_builtins.str]] = None,
                 external_authorization_service_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 external_authorization_service_timeout: Optional[pulumi.Input[_builtins.float]] = None,
                 external_authorization_service_url: Optional[pulumi.Input[_builtins.str]] = None,
                 external_pipeline_validation_service_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 external_pipeline_validation_service_token: Optional[pulumi.Input[_builtins.str]] = None,
                 external_pipeline_validation_service_url: Optional[pulumi.Input[_builtins.str]] = None,
                 failed_login_attempts_unlock_period_in_minutes: Optional[pulumi.Input[_builtins.int]] = None,
                 file_template_project_id: Optional[pulumi.Input[_builtins.int]] = None,
                 first_day_of_week: Optional[pulumi.Input[_builtins.int]] = None,
                 geo_node_allowed_ips: Optional[pulumi.Input[_builtins.str]] = None,
                 geo_status_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 git_rate_limit_users_alertlists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 git_rate_limit_users_allowlists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 git_two_factor_session_expiry: Optional[pulumi.Input[_builtins.int]] = None,
                 gitaly_timeout_default: Optional[pulumi.Input[_builtins.int]] = None,
                 gitaly_timeout_fast: Optional[pulumi.Input[_builtins.int]] = None,
                 gitaly_timeout_medium: Optional[pulumi.Input[_builtins.int]] = None,
                 gitlab_shell_operation_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 gitpod_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 gitpod_url: Optional[pulumi.Input[_builtins.str]] = None,
                 globally_allowed_ips: Optional[pulumi.Input[_builtins.str]] = None,
                 grafana_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 grafana_url: Optional[pulumi.Input[_builtins.str]] = None,
                 gravatar_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 group_owners_can_manage_default_branch_protection: Optional[pulumi.Input[_builtins.bool]] = None,
                 help_page_hide_commercial_content: Optional[pulumi.Input[_builtins.bool]] = None,
                 help_page_support_url: Optional[pulumi.Input[_builtins.str]] = None,
                 help_page_text: Optional[pulumi.Input[_builtins.str]] = None,
                 help_text: Optional[pulumi.Input[_builtins.str]] = None,
                 hide_third_party_offers: Optional[pulumi.Input[_builtins.bool]] = None,
                 home_page_url: Optional[pulumi.Input[_builtins.str]] = None,
                 housekeeping_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 housekeeping_optimize_repository_period: Optional[pulumi.Input[_builtins.int]] = None,
                 html_emails_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 import_sources: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 in_product_marketing_emails_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 inactive_projects_delete_after_months: Optional[pulumi.Input[_builtins.int]] = None,
                 inactive_projects_min_size_mb: Optional[pulumi.Input[_builtins.int]] = None,
                 inactive_projects_send_warning_email_after_months: Optional[pulumi.Input[_builtins.int]] = None,
                 include_optional_metrics_in_service_ping: Optional[pulumi.Input[_builtins.bool]] = None,
                 invisible_captcha_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 issues_create_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 jira_connect_application_key: Optional[pulumi.Input[_builtins.str]] = None,
                 jira_connect_proxy_url: Optional[pulumi.Input[_builtins.str]] = None,
                 jira_connect_public_key_storage_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 keep_latest_artifact: Optional[pulumi.Input[_builtins.bool]] = None,
                 local_markdown_version: Optional[pulumi.Input[_builtins.int]] = None,
                 lock_duo_features_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 lock_memberships_to_ldap: Optional[pulumi.Input[_builtins.bool]] = None,
                 mailgun_events_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 mailgun_signing_key: Optional[pulumi.Input[_builtins.str]] = None,
                 maintenance_mode: Optional[pulumi.Input[_builtins.bool]] = None,
                 maintenance_mode_message: Optional[pulumi.Input[_builtins.str]] = None,
                 maven_package_requests_forwarding: Optional[pulumi.Input[_builtins.bool]] = None,
                 max_artifacts_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_attachment_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_decompressed_archive_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_export_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_import_remote_file_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_import_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_login_attempts: Optional[pulumi.Input[_builtins.int]] = None,
                 max_number_of_repository_downloads: Optional[pulumi.Input[_builtins.int]] = None,
                 max_number_of_repository_downloads_within_time_period: Optional[pulumi.Input[_builtins.int]] = None,
                 max_pages_size: Optional[pulumi.Input[_builtins.int]] = None,
                 max_personal_access_token_lifetime: Optional[pulumi.Input[_builtins.int]] = None,
                 max_ssh_key_lifetime: Optional[pulumi.Input[_builtins.int]] = None,
                 max_terraform_state_size_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 metrics_method_call_threshold: Optional[pulumi.Input[_builtins.int]] = None,
                 minimum_password_length: Optional[pulumi.Input[_builtins.int]] = None,
                 mirror_available: Optional[pulumi.Input[_builtins.bool]] = None,
                 mirror_capacity_threshold: Optional[pulumi.Input[_builtins.int]] = None,
                 mirror_max_capacity: Optional[pulumi.Input[_builtins.int]] = None,
                 mirror_max_delay: Optional[pulumi.Input[_builtins.int]] = None,
                 npm_package_requests_forwarding: Optional[pulumi.Input[_builtins.bool]] = None,
                 nuget_skip_metadata_url_validation: Optional[pulumi.Input[_builtins.bool]] = None,
                 outbound_local_requests_whitelists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 package_metadata_purl_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 package_registry_allow_anyone_to_pull_option: Optional[pulumi.Input[_builtins.bool]] = None,
                 package_registry_cleanup_policies_worker_capacity: Optional[pulumi.Input[_builtins.int]] = None,
                 pages_domain_verification_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 password_authentication_enabled_for_git: Optional[pulumi.Input[_builtins.bool]] = None,
                 password_authentication_enabled_for_web: Optional[pulumi.Input[_builtins.bool]] = None,
                 password_lowercase_required: Optional[pulumi.Input[_builtins.bool]] = None,
                 password_number_required: Optional[pulumi.Input[_builtins.bool]] = None,
                 password_symbol_required: Optional[pulumi.Input[_builtins.bool]] = None,
                 password_uppercase_required: Optional[pulumi.Input[_builtins.bool]] = None,
                 performance_bar_allowed_group_path: Optional[pulumi.Input[_builtins.str]] = None,
                 personal_access_token_prefix: Optional[pulumi.Input[_builtins.str]] = None,
                 pipeline_limit_per_project_user_sha: Optional[pulumi.Input[_builtins.int]] = None,
                 plantuml_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 plantuml_url: Optional[pulumi.Input[_builtins.str]] = None,
                 polling_interval_multiplier: Optional[pulumi.Input[_builtins.float]] = None,
                 project_export_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 project_jobs_api_rate_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 projects_api_rate_limit_unauthenticated: Optional[pulumi.Input[_builtins.int]] = None,
                 prometheus_metrics_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 protected_ci_variables: Optional[pulumi.Input[_builtins.bool]] = None,
                 push_event_activities_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 push_event_hooks_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 pypi_package_requests_forwarding: Optional[pulumi.Input[_builtins.bool]] = None,
                 rate_limiting_response_text: Optional[pulumi.Input[_builtins.str]] = None,
                 raw_blob_request_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 recaptcha_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 recaptcha_private_key: Optional[pulumi.Input[_builtins.str]] = None,
                 recaptcha_site_key: Optional[pulumi.Input[_builtins.str]] = None,
                 receive_max_input_size: Optional[pulumi.Input[_builtins.int]] = None,
                 receptive_cluster_agents_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 remember_me_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 repository_checks_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 repository_size_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 repository_storages_weighted: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.int]]]] = None,
                 require_admin_approval_after_user_signup: Optional[pulumi.Input[_builtins.bool]] = None,
                 require_admin_two_factor_authentication: Optional[pulumi.Input[_builtins.bool]] = None,
                 require_personal_access_token_expiry: Optional[pulumi.Input[_builtins.bool]] = None,
                 require_two_factor_authentication: Optional[pulumi.Input[_builtins.bool]] = None,
                 restricted_visibility_levels: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 rsa_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
                 search_rate_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 search_rate_limit_unauthenticated: Optional[pulumi.Input[_builtins.int]] = None,
                 security_approval_policies_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 security_policy_global_group_approvers_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 security_txt_content: Optional[pulumi.Input[_builtins.str]] = None,
                 send_user_confirmation_email: Optional[pulumi.Input[_builtins.bool]] = None,
                 service_access_tokens_expiration_enforced: Optional[pulumi.Input[_builtins.bool]] = None,
                 session_expire_delay: Optional[pulumi.Input[_builtins.int]] = None,
                 shared_runners_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 shared_runners_minutes: Optional[pulumi.Input[_builtins.int]] = None,
                 shared_runners_text: Optional[pulumi.Input[_builtins.str]] = None,
                 sidekiq_job_limiter_compression_threshold_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 sidekiq_job_limiter_limit_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 sidekiq_job_limiter_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 sign_in_text: Optional[pulumi.Input[_builtins.str]] = None,
                 signup_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 silent_admin_exports_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 silent_mode_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 slack_app_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 slack_app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 slack_app_secret: Optional[pulumi.Input[_builtins.str]] = None,
                 slack_app_signing_secret: Optional[pulumi.Input[_builtins.str]] = None,
                 slack_app_verification_token: Optional[pulumi.Input[_builtins.str]] = None,
                 snippet_size_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 snowplow_app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 snowplow_collector_hostname: Optional[pulumi.Input[_builtins.str]] = None,
                 snowplow_cookie_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 snowplow_database_collector_hostname: Optional[pulumi.Input[_builtins.str]] = None,
                 snowplow_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 sourcegraph_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 sourcegraph_public_only: Optional[pulumi.Input[_builtins.bool]] = None,
                 sourcegraph_url: Optional[pulumi.Input[_builtins.str]] = None,
                 spam_check_api_key: Optional[pulumi.Input[_builtins.str]] = None,
                 spam_check_endpoint_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 spam_check_endpoint_url: Optional[pulumi.Input[_builtins.str]] = None,
                 static_objects_external_storage_auth_token: Optional[pulumi.Input[_builtins.str]] = None,
                 static_objects_external_storage_url: Optional[pulumi.Input[_builtins.str]] = None,
                 suggest_pipeline_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 terminal_max_session_time: Optional[pulumi.Input[_builtins.int]] = None,
                 terms: Optional[pulumi.Input[_builtins.str]] = None,
                 throttle_authenticated_api_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 throttle_authenticated_api_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_authenticated_api_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_authenticated_packages_api_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 throttle_authenticated_packages_api_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_authenticated_packages_api_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_authenticated_web_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 throttle_authenticated_web_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_authenticated_web_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_unauthenticated_api_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 throttle_unauthenticated_api_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_unauthenticated_api_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_unauthenticated_packages_api_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 throttle_unauthenticated_packages_api_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_unauthenticated_packages_api_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_unauthenticated_web_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 throttle_unauthenticated_web_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 throttle_unauthenticated_web_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
                 time_tracking_limit_to_hours: Optional[pulumi.Input[_builtins.bool]] = None,
                 two_factor_grace_period: Optional[pulumi.Input[_builtins.int]] = None,
                 unconfirmed_users_delete_after_days: Optional[pulumi.Input[_builtins.int]] = None,
                 unique_ips_limit_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 unique_ips_limit_per_user: Optional[pulumi.Input[_builtins.int]] = None,
                 unique_ips_limit_time_window: Optional[pulumi.Input[_builtins.int]] = None,
                 update_runner_versions_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 usage_ping_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 use_clickhouse_for_analytics: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_deactivation_emails_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_default_external: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_default_internal_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 user_defaults_to_private_profile: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_oauth_applications: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_show_add_ssh_key_message: Optional[pulumi.Input[_builtins.bool]] = None,
                 valid_runner_registrars: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 version_check_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 web_ide_clientside_preview_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 whats_new_variant: Optional[pulumi.Input[_builtins.str]] = None,
                 wiki_page_max_content_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ApplicationSettingsArgs.__new__(ApplicationSettingsArgs)

            __props__.__dict__["abuse_notification_email"] = abuse_notification_email
            __props__.__dict__["admin_mode"] = admin_mode
            __props__.__dict__["after_sign_out_path"] = after_sign_out_path
            __props__.__dict__["after_sign_up_text"] = after_sign_up_text
            __props__.__dict__["akismet_api_key"] = None if akismet_api_key is None else pulumi.Output.secret(akismet_api_key)
            __props__.__dict__["akismet_enabled"] = akismet_enabled
            __props__.__dict__["allow_account_deletion"] = allow_account_deletion
            __props__.__dict__["allow_group_owners_to_manage_ldap"] = allow_group_owners_to_manage_ldap
            __props__.__dict__["allow_local_requests_from_system_hooks"] = allow_local_requests_from_system_hooks
            __props__.__dict__["allow_local_requests_from_web_hooks_and_services"] = allow_local_requests_from_web_hooks_and_services
            __props__.__dict__["allow_project_creation_for_guest_and_below"] = allow_project_creation_for_guest_and_below
            __props__.__dict__["allow_runner_registration_token"] = allow_runner_registration_token
            __props__.__dict__["archive_builds_in_human_readable"] = archive_builds_in_human_readable
            __props__.__dict__["asciidoc_max_includes"] = asciidoc_max_includes
            __props__.__dict__["asset_proxy_allowlists"] = asset_proxy_allowlists
            __props__.__dict__["asset_proxy_enabled"] = asset_proxy_enabled
            __props__.__dict__["asset_proxy_secret_key"] = None if asset_proxy_secret_key is None else pulumi.Output.secret(asset_proxy_secret_key)
            __props__.__dict__["asset_proxy_url"] = asset_proxy_url
            __props__.__dict__["authorized_keys_enabled"] = authorized_keys_enabled
            __props__.__dict__["auto_ban_user_on_excessive_projects_download"] = auto_ban_user_on_excessive_projects_download
            __props__.__dict__["auto_devops_domain"] = auto_devops_domain
            __props__.__dict__["auto_devops_enabled"] = auto_devops_enabled
            __props__.__dict__["automatic_purchased_storage_allocation"] = automatic_purchased_storage_allocation
            __props__.__dict__["bulk_import_concurrent_pipeline_batch_limit"] = bulk_import_concurrent_pipeline_batch_limit
            __props__.__dict__["bulk_import_enabled"] = bulk_import_enabled
            __props__.__dict__["bulk_import_max_download_file_size"] = bulk_import_max_download_file_size
            __props__.__dict__["can_create_group"] = can_create_group
            __props__.__dict__["check_namespace_plan"] = check_namespace_plan
            __props__.__dict__["ci_max_includes"] = ci_max_includes
            __props__.__dict__["ci_max_total_yaml_size_bytes"] = ci_max_total_yaml_size_bytes
            __props__.__dict__["commit_email_hostname"] = commit_email_hostname
            __props__.__dict__["concurrent_bitbucket_import_jobs_limit"] = concurrent_bitbucket_import_jobs_limit
            __props__.__dict__["concurrent_bitbucket_server_import_jobs_limit"] = concurrent_bitbucket_server_import_jobs_limit
            __props__.__dict__["concurrent_github_import_jobs_limit"] = concurrent_github_import_jobs_limit
            __props__.__dict__["container_expiration_policies_enable_historic_entries"] = container_expiration_policies_enable_historic_entries
            __props__.__dict__["container_registry_cleanup_tags_service_max_list_size"] = container_registry_cleanup_tags_service_max_list_size
            __props__.__dict__["container_registry_delete_tags_service_timeout"] = container_registry_delete_tags_service_timeout
            __props__.__dict__["container_registry_expiration_policies_caching"] = container_registry_expiration_policies_caching
            __props__.__dict__["container_registry_expiration_policies_worker_capacity"] = container_registry_expiration_policies_worker_capacity
            __props__.__dict__["container_registry_token_expire_delay"] = container_registry_token_expire_delay
            __props__.__dict__["deactivate_dormant_users"] = deactivate_dormant_users
            __props__.__dict__["deactivate_dormant_users_period"] = deactivate_dormant_users_period
            __props__.__dict__["decompress_archive_file_timeout"] = decompress_archive_file_timeout
            __props__.__dict__["default_artifacts_expire_in"] = default_artifacts_expire_in
            __props__.__dict__["default_branch_name"] = default_branch_name
            __props__.__dict__["default_branch_protection"] = default_branch_protection
            __props__.__dict__["default_branch_protection_defaults"] = default_branch_protection_defaults
            __props__.__dict__["default_ci_config_path"] = default_ci_config_path
            __props__.__dict__["default_group_visibility"] = default_group_visibility
            __props__.__dict__["default_preferred_language"] = default_preferred_language
            __props__.__dict__["default_project_creation"] = default_project_creation
            __props__.__dict__["default_project_visibility"] = default_project_visibility
            __props__.__dict__["default_projects_limit"] = default_projects_limit
            __props__.__dict__["default_snippet_visibility"] = default_snippet_visibility
            __props__.__dict__["default_syntax_highlighting_theme"] = default_syntax_highlighting_theme
            __props__.__dict__["delete_inactive_projects"] = delete_inactive_projects
            __props__.__dict__["delete_unconfirmed_users"] = delete_unconfirmed_users
            __props__.__dict__["deletion_adjourned_period"] = deletion_adjourned_period
            __props__.__dict__["diagramsnet_enabled"] = diagramsnet_enabled
            __props__.__dict__["diagramsnet_url"] = diagramsnet_url
            __props__.__dict__["diff_max_files"] = diff_max_files
            __props__.__dict__["diff_max_lines"] = diff_max_lines
            __props__.__dict__["diff_max_patch_bytes"] = diff_max_patch_bytes
            __props__.__dict__["disable_admin_oauth_scopes"] = disable_admin_oauth_scopes
            __props__.__dict__["disable_feed_token"] = disable_feed_token
            __props__.__dict__["disable_personal_access_tokens"] = disable_personal_access_tokens
            __props__.__dict__["disabled_oauth_sign_in_sources"] = disabled_oauth_sign_in_sources
            __props__.__dict__["dns_rebinding_protection_enabled"] = dns_rebinding_protection_enabled
            __props__.__dict__["domain_allowlists"] = domain_allowlists
            __props__.__dict__["domain_denylist_enabled"] = domain_denylist_enabled
            __props__.__dict__["domain_denylists"] = domain_denylists
            __props__.__dict__["downstream_pipeline_trigger_limit_per_project_user_sha"] = downstream_pipeline_trigger_limit_per_project_user_sha
            __props__.__dict__["dsa_key_restriction"] = dsa_key_restriction
            __props__.__dict__["duo_features_enabled"] = duo_features_enabled
            __props__.__dict__["ecdsa_key_restriction"] = ecdsa_key_restriction
            __props__.__dict__["ecdsa_sk_key_restriction"] = ecdsa_sk_key_restriction
            __props__.__dict__["ed25519_key_restriction"] = ed25519_key_restriction
            __props__.__dict__["ed25519_sk_key_restriction"] = ed25519_sk_key_restriction
            __props__.__dict__["eks_access_key_id"] = None if eks_access_key_id is None else pulumi.Output.secret(eks_access_key_id)
            __props__.__dict__["eks_account_id"] = eks_account_id
            __props__.__dict__["eks_integration_enabled"] = eks_integration_enabled
            __props__.__dict__["eks_secret_access_key"] = None if eks_secret_access_key is None else pulumi.Output.secret(eks_secret_access_key)
            __props__.__dict__["elasticsearch_aws"] = elasticsearch_aws
            __props__.__dict__["elasticsearch_aws_access_key"] = None if elasticsearch_aws_access_key is None else pulumi.Output.secret(elasticsearch_aws_access_key)
            __props__.__dict__["elasticsearch_aws_region"] = elasticsearch_aws_region
            __props__.__dict__["elasticsearch_aws_secret_access_key"] = None if elasticsearch_aws_secret_access_key is None else pulumi.Output.secret(elasticsearch_aws_secret_access_key)
            __props__.__dict__["elasticsearch_indexed_field_length_limit"] = elasticsearch_indexed_field_length_limit
            __props__.__dict__["elasticsearch_indexed_file_size_limit_kb"] = elasticsearch_indexed_file_size_limit_kb
            __props__.__dict__["elasticsearch_indexing"] = elasticsearch_indexing
            __props__.__dict__["elasticsearch_limit_indexing"] = elasticsearch_limit_indexing
            __props__.__dict__["elasticsearch_max_bulk_concurrency"] = elasticsearch_max_bulk_concurrency
            __props__.__dict__["elasticsearch_max_bulk_size_mb"] = elasticsearch_max_bulk_size_mb
            __props__.__dict__["elasticsearch_max_code_indexing_concurrency"] = elasticsearch_max_code_indexing_concurrency
            __props__.__dict__["elasticsearch_namespace_ids"] = elasticsearch_namespace_ids
            __props__.__dict__["elasticsearch_password"] = None if elasticsearch_password is None else pulumi.Output.secret(elasticsearch_password)
            __props__.__dict__["elasticsearch_project_ids"] = elasticsearch_project_ids
            __props__.__dict__["elasticsearch_requeue_workers"] = elasticsearch_requeue_workers
            __props__.__dict__["elasticsearch_search"] = elasticsearch_search
            __props__.__dict__["elasticsearch_urls"] = elasticsearch_urls
            __props__.__dict__["elasticsearch_username"] = elasticsearch_username
            __props__.__dict__["elasticsearch_worker_number_of_shards"] = elasticsearch_worker_number_of_shards
            __props__.__dict__["email_additional_text"] = email_additional_text
            __props__.__dict__["email_author_in_body"] = email_author_in_body
            __props__.__dict__["email_confirmation_setting"] = email_confirmation_setting
            __props__.__dict__["enable_artifact_external_redirect_warning_page"] = enable_artifact_external_redirect_warning_page
            __props__.__dict__["enabled_git_access_protocol"] = enabled_git_access_protocol
            __props__.__dict__["enforce_namespace_storage_limit"] = enforce_namespace_storage_limit
            __props__.__dict__["enforce_terms"] = enforce_terms
            __props__.__dict__["external_auth_client_cert"] = external_auth_client_cert
            __props__.__dict__["external_auth_client_key"] = None if external_auth_client_key is None else pulumi.Output.secret(external_auth_client_key)
            __props__.__dict__["external_auth_client_key_pass"] = None if external_auth_client_key_pass is None else pulumi.Output.secret(external_auth_client_key_pass)
            __props__.__dict__["external_authorization_service_default_label"] = external_authorization_service_default_label
            __props__.__dict__["external_authorization_service_enabled"] = external_authorization_service_enabled
            __props__.__dict__["external_authorization_service_timeout"] = external_authorization_service_timeout
            __props__.__dict__["external_authorization_service_url"] = external_authorization_service_url
            __props__.__dict__["external_pipeline_validation_service_timeout"] = external_pipeline_validation_service_timeout
            __props__.__dict__["external_pipeline_validation_service_token"] = external_pipeline_validation_service_token
            __props__.__dict__["external_pipeline_validation_service_url"] = external_pipeline_validation_service_url
            __props__.__dict__["failed_login_attempts_unlock_period_in_minutes"] = failed_login_attempts_unlock_period_in_minutes
            __props__.__dict__["file_template_project_id"] = file_template_project_id
            __props__.__dict__["first_day_of_week"] = first_day_of_week
            __props__.__dict__["geo_node_allowed_ips"] = geo_node_allowed_ips
            __props__.__dict__["geo_status_timeout"] = geo_status_timeout
            __props__.__dict__["git_rate_limit_users_alertlists"] = git_rate_limit_users_alertlists
            __props__.__dict__["git_rate_limit_users_allowlists"] = git_rate_limit_users_allowlists
            __props__.__dict__["git_two_factor_session_expiry"] = git_two_factor_session_expiry
            __props__.__dict__["gitaly_timeout_default"] = gitaly_timeout_default
            __props__.__dict__["gitaly_timeout_fast"] = gitaly_timeout_fast
            __props__.__dict__["gitaly_timeout_medium"] = gitaly_timeout_medium
            __props__.__dict__["gitlab_shell_operation_limit"] = gitlab_shell_operation_limit
            __props__.__dict__["gitpod_enabled"] = gitpod_enabled
            __props__.__dict__["gitpod_url"] = gitpod_url
            __props__.__dict__["globally_allowed_ips"] = globally_allowed_ips
            __props__.__dict__["grafana_enabled"] = grafana_enabled
            __props__.__dict__["grafana_url"] = grafana_url
            __props__.__dict__["gravatar_enabled"] = gravatar_enabled
            __props__.__dict__["group_owners_can_manage_default_branch_protection"] = group_owners_can_manage_default_branch_protection
            __props__.__dict__["help_page_hide_commercial_content"] = help_page_hide_commercial_content
            __props__.__dict__["help_page_support_url"] = help_page_support_url
            __props__.__dict__["help_page_text"] = help_page_text
            __props__.__dict__["help_text"] = help_text
            __props__.__dict__["hide_third_party_offers"] = hide_third_party_offers
            __props__.__dict__["home_page_url"] = home_page_url
            __props__.__dict__["housekeeping_enabled"] = housekeeping_enabled
            __props__.__dict__["housekeeping_optimize_repository_period"] = housekeeping_optimize_repository_period
            __props__.__dict__["html_emails_enabled"] = html_emails_enabled
            __props__.__dict__["import_sources"] = import_sources
            __props__.__dict__["in_product_marketing_emails_enabled"] = in_product_marketing_emails_enabled
            __props__.__dict__["inactive_projects_delete_after_months"] = inactive_projects_delete_after_months
            __props__.__dict__["inactive_projects_min_size_mb"] = inactive_projects_min_size_mb
            __props__.__dict__["inactive_projects_send_warning_email_after_months"] = inactive_projects_send_warning_email_after_months
            __props__.__dict__["include_optional_metrics_in_service_ping"] = include_optional_metrics_in_service_ping
            __props__.__dict__["invisible_captcha_enabled"] = invisible_captcha_enabled
            __props__.__dict__["issues_create_limit"] = issues_create_limit
            __props__.__dict__["jira_connect_application_key"] = jira_connect_application_key
            __props__.__dict__["jira_connect_proxy_url"] = jira_connect_proxy_url
            __props__.__dict__["jira_connect_public_key_storage_enabled"] = jira_connect_public_key_storage_enabled
            __props__.__dict__["keep_latest_artifact"] = keep_latest_artifact
            __props__.__dict__["local_markdown_version"] = local_markdown_version
            __props__.__dict__["lock_duo_features_enabled"] = lock_duo_features_enabled
            __props__.__dict__["lock_memberships_to_ldap"] = lock_memberships_to_ldap
            __props__.__dict__["mailgun_events_enabled"] = mailgun_events_enabled
            __props__.__dict__["mailgun_signing_key"] = None if mailgun_signing_key is None else pulumi.Output.secret(mailgun_signing_key)
            __props__.__dict__["maintenance_mode"] = maintenance_mode
            __props__.__dict__["maintenance_mode_message"] = maintenance_mode_message
            __props__.__dict__["maven_package_requests_forwarding"] = maven_package_requests_forwarding
            __props__.__dict__["max_artifacts_size"] = max_artifacts_size
            __props__.__dict__["max_attachment_size"] = max_attachment_size
            __props__.__dict__["max_decompressed_archive_size"] = max_decompressed_archive_size
            __props__.__dict__["max_export_size"] = max_export_size
            __props__.__dict__["max_import_remote_file_size"] = max_import_remote_file_size
            __props__.__dict__["max_import_size"] = max_import_size
            __props__.__dict__["max_login_attempts"] = max_login_attempts
            __props__.__dict__["max_number_of_repository_downloads"] = max_number_of_repository_downloads
            __props__.__dict__["max_number_of_repository_downloads_within_time_period"] = max_number_of_repository_downloads_within_time_period
            __props__.__dict__["max_pages_size"] = max_pages_size
            __props__.__dict__["max_personal_access_token_lifetime"] = max_personal_access_token_lifetime
            __props__.__dict__["max_ssh_key_lifetime"] = max_ssh_key_lifetime
            __props__.__dict__["max_terraform_state_size_bytes"] = max_terraform_state_size_bytes
            __props__.__dict__["metrics_method_call_threshold"] = metrics_method_call_threshold
            __props__.__dict__["minimum_password_length"] = minimum_password_length
            __props__.__dict__["mirror_available"] = mirror_available
            __props__.__dict__["mirror_capacity_threshold"] = mirror_capacity_threshold
            __props__.__dict__["mirror_max_capacity"] = mirror_max_capacity
            __props__.__dict__["mirror_max_delay"] = mirror_max_delay
            __props__.__dict__["npm_package_requests_forwarding"] = npm_package_requests_forwarding
            __props__.__dict__["nuget_skip_metadata_url_validation"] = nuget_skip_metadata_url_validation
            __props__.__dict__["outbound_local_requests_whitelists"] = outbound_local_requests_whitelists
            __props__.__dict__["package_metadata_purl_types"] = package_metadata_purl_types
            __props__.__dict__["package_registry_allow_anyone_to_pull_option"] = package_registry_allow_anyone_to_pull_option
            __props__.__dict__["package_registry_cleanup_policies_worker_capacity"] = package_registry_cleanup_policies_worker_capacity
            __props__.__dict__["pages_domain_verification_enabled"] = pages_domain_verification_enabled
            __props__.__dict__["password_authentication_enabled_for_git"] = password_authentication_enabled_for_git
            __props__.__dict__["password_authentication_enabled_for_web"] = password_authentication_enabled_for_web
            __props__.__dict__["password_lowercase_required"] = password_lowercase_required
            __props__.__dict__["password_number_required"] = password_number_required
            __props__.__dict__["password_symbol_required"] = password_symbol_required
            __props__.__dict__["password_uppercase_required"] = password_uppercase_required
            __props__.__dict__["performance_bar_allowed_group_path"] = performance_bar_allowed_group_path
            __props__.__dict__["personal_access_token_prefix"] = personal_access_token_prefix
            __props__.__dict__["pipeline_limit_per_project_user_sha"] = pipeline_limit_per_project_user_sha
            __props__.__dict__["plantuml_enabled"] = plantuml_enabled
            __props__.__dict__["plantuml_url"] = plantuml_url
            __props__.__dict__["polling_interval_multiplier"] = polling_interval_multiplier
            __props__.__dict__["project_export_enabled"] = project_export_enabled
            __props__.__dict__["project_jobs_api_rate_limit"] = project_jobs_api_rate_limit
            __props__.__dict__["projects_api_rate_limit_unauthenticated"] = projects_api_rate_limit_unauthenticated
            __props__.__dict__["prometheus_metrics_enabled"] = prometheus_metrics_enabled
            __props__.__dict__["protected_ci_variables"] = protected_ci_variables
            __props__.__dict__["push_event_activities_limit"] = push_event_activities_limit
            __props__.__dict__["push_event_hooks_limit"] = push_event_hooks_limit
            __props__.__dict__["pypi_package_requests_forwarding"] = pypi_package_requests_forwarding
            __props__.__dict__["rate_limiting_response_text"] = rate_limiting_response_text
            __props__.__dict__["raw_blob_request_limit"] = raw_blob_request_limit
            __props__.__dict__["recaptcha_enabled"] = recaptcha_enabled
            __props__.__dict__["recaptcha_private_key"] = None if recaptcha_private_key is None else pulumi.Output.secret(recaptcha_private_key)
            __props__.__dict__["recaptcha_site_key"] = None if recaptcha_site_key is None else pulumi.Output.secret(recaptcha_site_key)
            __props__.__dict__["receive_max_input_size"] = receive_max_input_size
            __props__.__dict__["receptive_cluster_agents_enabled"] = receptive_cluster_agents_enabled
            __props__.__dict__["remember_me_enabled"] = remember_me_enabled
            __props__.__dict__["repository_checks_enabled"] = repository_checks_enabled
            __props__.__dict__["repository_size_limit"] = repository_size_limit
            __props__.__dict__["repository_storages_weighted"] = repository_storages_weighted
            __props__.__dict__["require_admin_approval_after_user_signup"] = require_admin_approval_after_user_signup
            __props__.__dict__["require_admin_two_factor_authentication"] = require_admin_two_factor_authentication
            __props__.__dict__["require_personal_access_token_expiry"] = require_personal_access_token_expiry
            __props__.__dict__["require_two_factor_authentication"] = require_two_factor_authentication
            __props__.__dict__["restricted_visibility_levels"] = restricted_visibility_levels
            __props__.__dict__["rsa_key_restriction"] = rsa_key_restriction
            __props__.__dict__["search_rate_limit"] = search_rate_limit
            __props__.__dict__["search_rate_limit_unauthenticated"] = search_rate_limit_unauthenticated
            __props__.__dict__["security_approval_policies_limit"] = security_approval_policies_limit
            __props__.__dict__["security_policy_global_group_approvers_enabled"] = security_policy_global_group_approvers_enabled
            __props__.__dict__["security_txt_content"] = security_txt_content
            __props__.__dict__["send_user_confirmation_email"] = send_user_confirmation_email
            __props__.__dict__["service_access_tokens_expiration_enforced"] = service_access_tokens_expiration_enforced
            __props__.__dict__["session_expire_delay"] = session_expire_delay
            __props__.__dict__["shared_runners_enabled"] = shared_runners_enabled
            __props__.__dict__["shared_runners_minutes"] = shared_runners_minutes
            __props__.__dict__["shared_runners_text"] = shared_runners_text
            __props__.__dict__["sidekiq_job_limiter_compression_threshold_bytes"] = sidekiq_job_limiter_compression_threshold_bytes
            __props__.__dict__["sidekiq_job_limiter_limit_bytes"] = sidekiq_job_limiter_limit_bytes
            __props__.__dict__["sidekiq_job_limiter_mode"] = sidekiq_job_limiter_mode
            __props__.__dict__["sign_in_text"] = sign_in_text
            __props__.__dict__["signup_enabled"] = signup_enabled
            __props__.__dict__["silent_admin_exports_enabled"] = silent_admin_exports_enabled
            __props__.__dict__["silent_mode_enabled"] = silent_mode_enabled
            __props__.__dict__["slack_app_enabled"] = slack_app_enabled
            __props__.__dict__["slack_app_id"] = slack_app_id
            __props__.__dict__["slack_app_secret"] = None if slack_app_secret is None else pulumi.Output.secret(slack_app_secret)
            __props__.__dict__["slack_app_signing_secret"] = None if slack_app_signing_secret is None else pulumi.Output.secret(slack_app_signing_secret)
            __props__.__dict__["slack_app_verification_token"] = slack_app_verification_token
            __props__.__dict__["snippet_size_limit"] = snippet_size_limit
            __props__.__dict__["snowplow_app_id"] = snowplow_app_id
            __props__.__dict__["snowplow_collector_hostname"] = snowplow_collector_hostname
            __props__.__dict__["snowplow_cookie_domain"] = snowplow_cookie_domain
            __props__.__dict__["snowplow_database_collector_hostname"] = snowplow_database_collector_hostname
            __props__.__dict__["snowplow_enabled"] = snowplow_enabled
            __props__.__dict__["sourcegraph_enabled"] = sourcegraph_enabled
            __props__.__dict__["sourcegraph_public_only"] = sourcegraph_public_only
            __props__.__dict__["sourcegraph_url"] = sourcegraph_url
            __props__.__dict__["spam_check_api_key"] = None if spam_check_api_key is None else pulumi.Output.secret(spam_check_api_key)
            __props__.__dict__["spam_check_endpoint_enabled"] = spam_check_endpoint_enabled
            __props__.__dict__["spam_check_endpoint_url"] = spam_check_endpoint_url
            __props__.__dict__["static_objects_external_storage_auth_token"] = None if static_objects_external_storage_auth_token is None else pulumi.Output.secret(static_objects_external_storage_auth_token)
            __props__.__dict__["static_objects_external_storage_url"] = None if static_objects_external_storage_url is None else pulumi.Output.secret(static_objects_external_storage_url)
            __props__.__dict__["suggest_pipeline_enabled"] = suggest_pipeline_enabled
            __props__.__dict__["terminal_max_session_time"] = terminal_max_session_time
            __props__.__dict__["terms"] = terms
            __props__.__dict__["throttle_authenticated_api_enabled"] = throttle_authenticated_api_enabled
            __props__.__dict__["throttle_authenticated_api_period_in_seconds"] = throttle_authenticated_api_period_in_seconds
            __props__.__dict__["throttle_authenticated_api_requests_per_period"] = throttle_authenticated_api_requests_per_period
            __props__.__dict__["throttle_authenticated_packages_api_enabled"] = throttle_authenticated_packages_api_enabled
            __props__.__dict__["throttle_authenticated_packages_api_period_in_seconds"] = throttle_authenticated_packages_api_period_in_seconds
            __props__.__dict__["throttle_authenticated_packages_api_requests_per_period"] = throttle_authenticated_packages_api_requests_per_period
            __props__.__dict__["throttle_authenticated_web_enabled"] = throttle_authenticated_web_enabled
            __props__.__dict__["throttle_authenticated_web_period_in_seconds"] = throttle_authenticated_web_period_in_seconds
            __props__.__dict__["throttle_authenticated_web_requests_per_period"] = throttle_authenticated_web_requests_per_period
            __props__.__dict__["throttle_unauthenticated_api_enabled"] = throttle_unauthenticated_api_enabled
            __props__.__dict__["throttle_unauthenticated_api_period_in_seconds"] = throttle_unauthenticated_api_period_in_seconds
            __props__.__dict__["throttle_unauthenticated_api_requests_per_period"] = throttle_unauthenticated_api_requests_per_period
            __props__.__dict__["throttle_unauthenticated_packages_api_enabled"] = throttle_unauthenticated_packages_api_enabled
            __props__.__dict__["throttle_unauthenticated_packages_api_period_in_seconds"] = throttle_unauthenticated_packages_api_period_in_seconds
            __props__.__dict__["throttle_unauthenticated_packages_api_requests_per_period"] = throttle_unauthenticated_packages_api_requests_per_period
            __props__.__dict__["throttle_unauthenticated_web_enabled"] = throttle_unauthenticated_web_enabled
            __props__.__dict__["throttle_unauthenticated_web_period_in_seconds"] = throttle_unauthenticated_web_period_in_seconds
            __props__.__dict__["throttle_unauthenticated_web_requests_per_period"] = throttle_unauthenticated_web_requests_per_period
            __props__.__dict__["time_tracking_limit_to_hours"] = time_tracking_limit_to_hours
            __props__.__dict__["two_factor_grace_period"] = two_factor_grace_period
            __props__.__dict__["unconfirmed_users_delete_after_days"] = unconfirmed_users_delete_after_days
            __props__.__dict__["unique_ips_limit_enabled"] = unique_ips_limit_enabled
            __props__.__dict__["unique_ips_limit_per_user"] = unique_ips_limit_per_user
            __props__.__dict__["unique_ips_limit_time_window"] = unique_ips_limit_time_window
            __props__.__dict__["update_runner_versions_enabled"] = update_runner_versions_enabled
            __props__.__dict__["usage_ping_enabled"] = usage_ping_enabled
            __props__.__dict__["use_clickhouse_for_analytics"] = use_clickhouse_for_analytics
            __props__.__dict__["user_deactivation_emails_enabled"] = user_deactivation_emails_enabled
            __props__.__dict__["user_default_external"] = user_default_external
            __props__.__dict__["user_default_internal_regex"] = user_default_internal_regex
            __props__.__dict__["user_defaults_to_private_profile"] = user_defaults_to_private_profile
            __props__.__dict__["user_oauth_applications"] = user_oauth_applications
            __props__.__dict__["user_show_add_ssh_key_message"] = user_show_add_ssh_key_message
            __props__.__dict__["valid_runner_registrars"] = valid_runner_registrars
            __props__.__dict__["version_check_enabled"] = version_check_enabled
            __props__.__dict__["web_ide_clientside_preview_enabled"] = web_ide_clientside_preview_enabled
            __props__.__dict__["whats_new_variant"] = whats_new_variant
            __props__.__dict__["wiki_page_max_content_bytes"] = wiki_page_max_content_bytes
            __props__.__dict__["gitlab_dedicated_instance"] = None
            __props__.__dict__["gitlab_environment_toolkit_instance"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["akismetApiKey", "assetProxySecretKey", "eksAccessKeyId", "eksSecretAccessKey", "elasticsearchAwsAccessKey", "elasticsearchAwsSecretAccessKey", "elasticsearchPassword", "externalAuthClientKey", "externalAuthClientKeyPass", "mailgunSigningKey", "recaptchaPrivateKey", "recaptchaSiteKey", "slackAppSecret", "slackAppSigningSecret", "spamCheckApiKey", "staticObjectsExternalStorageAuthToken", "staticObjectsExternalStorageUrl"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ApplicationSettings, __self__).__init__(
            'gitlab:index/applicationSettings:ApplicationSettings',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            abuse_notification_email: Optional[pulumi.Input[_builtins.str]] = None,
            admin_mode: Optional[pulumi.Input[_builtins.bool]] = None,
            after_sign_out_path: Optional[pulumi.Input[_builtins.str]] = None,
            after_sign_up_text: Optional[pulumi.Input[_builtins.str]] = None,
            akismet_api_key: Optional[pulumi.Input[_builtins.str]] = None,
            akismet_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            allow_account_deletion: Optional[pulumi.Input[_builtins.bool]] = None,
            allow_group_owners_to_manage_ldap: Optional[pulumi.Input[_builtins.bool]] = None,
            allow_local_requests_from_system_hooks: Optional[pulumi.Input[_builtins.bool]] = None,
            allow_local_requests_from_web_hooks_and_services: Optional[pulumi.Input[_builtins.bool]] = None,
            allow_project_creation_for_guest_and_below: Optional[pulumi.Input[_builtins.bool]] = None,
            allow_runner_registration_token: Optional[pulumi.Input[_builtins.bool]] = None,
            archive_builds_in_human_readable: Optional[pulumi.Input[_builtins.str]] = None,
            asciidoc_max_includes: Optional[pulumi.Input[_builtins.int]] = None,
            asset_proxy_allowlists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            asset_proxy_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            asset_proxy_secret_key: Optional[pulumi.Input[_builtins.str]] = None,
            asset_proxy_url: Optional[pulumi.Input[_builtins.str]] = None,
            authorized_keys_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            auto_ban_user_on_excessive_projects_download: Optional[pulumi.Input[_builtins.bool]] = None,
            auto_devops_domain: Optional[pulumi.Input[_builtins.str]] = None,
            auto_devops_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            automatic_purchased_storage_allocation: Optional[pulumi.Input[_builtins.bool]] = None,
            bulk_import_concurrent_pipeline_batch_limit: Optional[pulumi.Input[_builtins.int]] = None,
            bulk_import_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            bulk_import_max_download_file_size: Optional[pulumi.Input[_builtins.int]] = None,
            can_create_group: Optional[pulumi.Input[_builtins.bool]] = None,
            check_namespace_plan: Optional[pulumi.Input[_builtins.bool]] = None,
            ci_max_includes: Optional[pulumi.Input[_builtins.int]] = None,
            ci_max_total_yaml_size_bytes: Optional[pulumi.Input[_builtins.int]] = None,
            commit_email_hostname: Optional[pulumi.Input[_builtins.str]] = None,
            concurrent_bitbucket_import_jobs_limit: Optional[pulumi.Input[_builtins.int]] = None,
            concurrent_bitbucket_server_import_jobs_limit: Optional[pulumi.Input[_builtins.int]] = None,
            concurrent_github_import_jobs_limit: Optional[pulumi.Input[_builtins.int]] = None,
            container_expiration_policies_enable_historic_entries: Optional[pulumi.Input[_builtins.bool]] = None,
            container_registry_cleanup_tags_service_max_list_size: Optional[pulumi.Input[_builtins.int]] = None,
            container_registry_delete_tags_service_timeout: Optional[pulumi.Input[_builtins.int]] = None,
            container_registry_expiration_policies_caching: Optional[pulumi.Input[_builtins.bool]] = None,
            container_registry_expiration_policies_worker_capacity: Optional[pulumi.Input[_builtins.int]] = None,
            container_registry_token_expire_delay: Optional[pulumi.Input[_builtins.int]] = None,
            deactivate_dormant_users: Optional[pulumi.Input[_builtins.bool]] = None,
            deactivate_dormant_users_period: Optional[pulumi.Input[_builtins.int]] = None,
            decompress_archive_file_timeout: Optional[pulumi.Input[_builtins.int]] = None,
            default_artifacts_expire_in: Optional[pulumi.Input[_builtins.str]] = None,
            default_branch_name: Optional[pulumi.Input[_builtins.str]] = None,
            default_branch_protection: Optional[pulumi.Input[_builtins.int]] = None,
            default_branch_protection_defaults: Optional[pulumi.Input[Union['ApplicationSettingsDefaultBranchProtectionDefaultsArgs', 'ApplicationSettingsDefaultBranchProtectionDefaultsArgsDict']]] = None,
            default_ci_config_path: Optional[pulumi.Input[_builtins.str]] = None,
            default_group_visibility: Optional[pulumi.Input[_builtins.str]] = None,
            default_preferred_language: Optional[pulumi.Input[_builtins.str]] = None,
            default_project_creation: Optional[pulumi.Input[_builtins.int]] = None,
            default_project_visibility: Optional[pulumi.Input[_builtins.str]] = None,
            default_projects_limit: Optional[pulumi.Input[_builtins.int]] = None,
            default_snippet_visibility: Optional[pulumi.Input[_builtins.str]] = None,
            default_syntax_highlighting_theme: Optional[pulumi.Input[_builtins.int]] = None,
            delete_inactive_projects: Optional[pulumi.Input[_builtins.bool]] = None,
            delete_unconfirmed_users: Optional[pulumi.Input[_builtins.bool]] = None,
            deletion_adjourned_period: Optional[pulumi.Input[_builtins.int]] = None,
            diagramsnet_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            diagramsnet_url: Optional[pulumi.Input[_builtins.str]] = None,
            diff_max_files: Optional[pulumi.Input[_builtins.int]] = None,
            diff_max_lines: Optional[pulumi.Input[_builtins.int]] = None,
            diff_max_patch_bytes: Optional[pulumi.Input[_builtins.int]] = None,
            disable_admin_oauth_scopes: Optional[pulumi.Input[_builtins.bool]] = None,
            disable_feed_token: Optional[pulumi.Input[_builtins.bool]] = None,
            disable_personal_access_tokens: Optional[pulumi.Input[_builtins.bool]] = None,
            disabled_oauth_sign_in_sources: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            dns_rebinding_protection_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            domain_allowlists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            domain_denylist_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            domain_denylists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            downstream_pipeline_trigger_limit_per_project_user_sha: Optional[pulumi.Input[_builtins.int]] = None,
            dsa_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
            duo_features_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            ecdsa_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
            ecdsa_sk_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
            ed25519_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
            ed25519_sk_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
            eks_access_key_id: Optional[pulumi.Input[_builtins.str]] = None,
            eks_account_id: Optional[pulumi.Input[_builtins.str]] = None,
            eks_integration_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            eks_secret_access_key: Optional[pulumi.Input[_builtins.str]] = None,
            elasticsearch_aws: Optional[pulumi.Input[_builtins.bool]] = None,
            elasticsearch_aws_access_key: Optional[pulumi.Input[_builtins.str]] = None,
            elasticsearch_aws_region: Optional[pulumi.Input[_builtins.str]] = None,
            elasticsearch_aws_secret_access_key: Optional[pulumi.Input[_builtins.str]] = None,
            elasticsearch_indexed_field_length_limit: Optional[pulumi.Input[_builtins.int]] = None,
            elasticsearch_indexed_file_size_limit_kb: Optional[pulumi.Input[_builtins.int]] = None,
            elasticsearch_indexing: Optional[pulumi.Input[_builtins.bool]] = None,
            elasticsearch_limit_indexing: Optional[pulumi.Input[_builtins.bool]] = None,
            elasticsearch_max_bulk_concurrency: Optional[pulumi.Input[_builtins.int]] = None,
            elasticsearch_max_bulk_size_mb: Optional[pulumi.Input[_builtins.int]] = None,
            elasticsearch_max_code_indexing_concurrency: Optional[pulumi.Input[_builtins.int]] = None,
            elasticsearch_namespace_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
            elasticsearch_password: Optional[pulumi.Input[_builtins.str]] = None,
            elasticsearch_project_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
            elasticsearch_requeue_workers: Optional[pulumi.Input[_builtins.bool]] = None,
            elasticsearch_search: Optional[pulumi.Input[_builtins.bool]] = None,
            elasticsearch_urls: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            elasticsearch_username: Optional[pulumi.Input[_builtins.str]] = None,
            elasticsearch_worker_number_of_shards: Optional[pulumi.Input[_builtins.int]] = None,
            email_additional_text: Optional[pulumi.Input[_builtins.str]] = None,
            email_author_in_body: Optional[pulumi.Input[_builtins.bool]] = None,
            email_confirmation_setting: Optional[pulumi.Input[_builtins.str]] = None,
            enable_artifact_external_redirect_warning_page: Optional[pulumi.Input[_builtins.bool]] = None,
            enabled_git_access_protocol: Optional[pulumi.Input[_builtins.str]] = None,
            enforce_namespace_storage_limit: Optional[pulumi.Input[_builtins.bool]] = None,
            enforce_terms: Optional[pulumi.Input[_builtins.bool]] = None,
            external_auth_client_cert: Optional[pulumi.Input[_builtins.str]] = None,
            external_auth_client_key: Optional[pulumi.Input[_builtins.str]] = None,
            external_auth_client_key_pass: Optional[pulumi.Input[_builtins.str]] = None,
            external_authorization_service_default_label: Optional[pulumi.Input[_builtins.str]] = None,
            external_authorization_service_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            external_authorization_service_timeout: Optional[pulumi.Input[_builtins.float]] = None,
            external_authorization_service_url: Optional[pulumi.Input[_builtins.str]] = None,
            external_pipeline_validation_service_timeout: Optional[pulumi.Input[_builtins.int]] = None,
            external_pipeline_validation_service_token: Optional[pulumi.Input[_builtins.str]] = None,
            external_pipeline_validation_service_url: Optional[pulumi.Input[_builtins.str]] = None,
            failed_login_attempts_unlock_period_in_minutes: Optional[pulumi.Input[_builtins.int]] = None,
            file_template_project_id: Optional[pulumi.Input[_builtins.int]] = None,
            first_day_of_week: Optional[pulumi.Input[_builtins.int]] = None,
            geo_node_allowed_ips: Optional[pulumi.Input[_builtins.str]] = None,
            geo_status_timeout: Optional[pulumi.Input[_builtins.int]] = None,
            git_rate_limit_users_alertlists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
            git_rate_limit_users_allowlists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            git_two_factor_session_expiry: Optional[pulumi.Input[_builtins.int]] = None,
            gitaly_timeout_default: Optional[pulumi.Input[_builtins.int]] = None,
            gitaly_timeout_fast: Optional[pulumi.Input[_builtins.int]] = None,
            gitaly_timeout_medium: Optional[pulumi.Input[_builtins.int]] = None,
            gitlab_dedicated_instance: Optional[pulumi.Input[_builtins.bool]] = None,
            gitlab_environment_toolkit_instance: Optional[pulumi.Input[_builtins.bool]] = None,
            gitlab_shell_operation_limit: Optional[pulumi.Input[_builtins.int]] = None,
            gitpod_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            gitpod_url: Optional[pulumi.Input[_builtins.str]] = None,
            globally_allowed_ips: Optional[pulumi.Input[_builtins.str]] = None,
            grafana_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            grafana_url: Optional[pulumi.Input[_builtins.str]] = None,
            gravatar_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            group_owners_can_manage_default_branch_protection: Optional[pulumi.Input[_builtins.bool]] = None,
            help_page_hide_commercial_content: Optional[pulumi.Input[_builtins.bool]] = None,
            help_page_support_url: Optional[pulumi.Input[_builtins.str]] = None,
            help_page_text: Optional[pulumi.Input[_builtins.str]] = None,
            help_text: Optional[pulumi.Input[_builtins.str]] = None,
            hide_third_party_offers: Optional[pulumi.Input[_builtins.bool]] = None,
            home_page_url: Optional[pulumi.Input[_builtins.str]] = None,
            housekeeping_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            housekeeping_optimize_repository_period: Optional[pulumi.Input[_builtins.int]] = None,
            html_emails_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            import_sources: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            in_product_marketing_emails_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            inactive_projects_delete_after_months: Optional[pulumi.Input[_builtins.int]] = None,
            inactive_projects_min_size_mb: Optional[pulumi.Input[_builtins.int]] = None,
            inactive_projects_send_warning_email_after_months: Optional[pulumi.Input[_builtins.int]] = None,
            include_optional_metrics_in_service_ping: Optional[pulumi.Input[_builtins.bool]] = None,
            invisible_captcha_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            issues_create_limit: Optional[pulumi.Input[_builtins.int]] = None,
            jira_connect_application_key: Optional[pulumi.Input[_builtins.str]] = None,
            jira_connect_proxy_url: Optional[pulumi.Input[_builtins.str]] = None,
            jira_connect_public_key_storage_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            keep_latest_artifact: Optional[pulumi.Input[_builtins.bool]] = None,
            local_markdown_version: Optional[pulumi.Input[_builtins.int]] = None,
            lock_duo_features_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            lock_memberships_to_ldap: Optional[pulumi.Input[_builtins.bool]] = None,
            mailgun_events_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            mailgun_signing_key: Optional[pulumi.Input[_builtins.str]] = None,
            maintenance_mode: Optional[pulumi.Input[_builtins.bool]] = None,
            maintenance_mode_message: Optional[pulumi.Input[_builtins.str]] = None,
            maven_package_requests_forwarding: Optional[pulumi.Input[_builtins.bool]] = None,
            max_artifacts_size: Optional[pulumi.Input[_builtins.int]] = None,
            max_attachment_size: Optional[pulumi.Input[_builtins.int]] = None,
            max_decompressed_archive_size: Optional[pulumi.Input[_builtins.int]] = None,
            max_export_size: Optional[pulumi.Input[_builtins.int]] = None,
            max_import_remote_file_size: Optional[pulumi.Input[_builtins.int]] = None,
            max_import_size: Optional[pulumi.Input[_builtins.int]] = None,
            max_login_attempts: Optional[pulumi.Input[_builtins.int]] = None,
            max_number_of_repository_downloads: Optional[pulumi.Input[_builtins.int]] = None,
            max_number_of_repository_downloads_within_time_period: Optional[pulumi.Input[_builtins.int]] = None,
            max_pages_size: Optional[pulumi.Input[_builtins.int]] = None,
            max_personal_access_token_lifetime: Optional[pulumi.Input[_builtins.int]] = None,
            max_ssh_key_lifetime: Optional[pulumi.Input[_builtins.int]] = None,
            max_terraform_state_size_bytes: Optional[pulumi.Input[_builtins.int]] = None,
            metrics_method_call_threshold: Optional[pulumi.Input[_builtins.int]] = None,
            minimum_password_length: Optional[pulumi.Input[_builtins.int]] = None,
            mirror_available: Optional[pulumi.Input[_builtins.bool]] = None,
            mirror_capacity_threshold: Optional[pulumi.Input[_builtins.int]] = None,
            mirror_max_capacity: Optional[pulumi.Input[_builtins.int]] = None,
            mirror_max_delay: Optional[pulumi.Input[_builtins.int]] = None,
            npm_package_requests_forwarding: Optional[pulumi.Input[_builtins.bool]] = None,
            nuget_skip_metadata_url_validation: Optional[pulumi.Input[_builtins.bool]] = None,
            outbound_local_requests_whitelists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            package_metadata_purl_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
            package_registry_allow_anyone_to_pull_option: Optional[pulumi.Input[_builtins.bool]] = None,
            package_registry_cleanup_policies_worker_capacity: Optional[pulumi.Input[_builtins.int]] = None,
            pages_domain_verification_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            password_authentication_enabled_for_git: Optional[pulumi.Input[_builtins.bool]] = None,
            password_authentication_enabled_for_web: Optional[pulumi.Input[_builtins.bool]] = None,
            password_lowercase_required: Optional[pulumi.Input[_builtins.bool]] = None,
            password_number_required: Optional[pulumi.Input[_builtins.bool]] = None,
            password_symbol_required: Optional[pulumi.Input[_builtins.bool]] = None,
            password_uppercase_required: Optional[pulumi.Input[_builtins.bool]] = None,
            performance_bar_allowed_group_path: Optional[pulumi.Input[_builtins.str]] = None,
            personal_access_token_prefix: Optional[pulumi.Input[_builtins.str]] = None,
            pipeline_limit_per_project_user_sha: Optional[pulumi.Input[_builtins.int]] = None,
            plantuml_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            plantuml_url: Optional[pulumi.Input[_builtins.str]] = None,
            polling_interval_multiplier: Optional[pulumi.Input[_builtins.float]] = None,
            project_export_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            project_jobs_api_rate_limit: Optional[pulumi.Input[_builtins.int]] = None,
            projects_api_rate_limit_unauthenticated: Optional[pulumi.Input[_builtins.int]] = None,
            prometheus_metrics_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            protected_ci_variables: Optional[pulumi.Input[_builtins.bool]] = None,
            push_event_activities_limit: Optional[pulumi.Input[_builtins.int]] = None,
            push_event_hooks_limit: Optional[pulumi.Input[_builtins.int]] = None,
            pypi_package_requests_forwarding: Optional[pulumi.Input[_builtins.bool]] = None,
            rate_limiting_response_text: Optional[pulumi.Input[_builtins.str]] = None,
            raw_blob_request_limit: Optional[pulumi.Input[_builtins.int]] = None,
            recaptcha_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            recaptcha_private_key: Optional[pulumi.Input[_builtins.str]] = None,
            recaptcha_site_key: Optional[pulumi.Input[_builtins.str]] = None,
            receive_max_input_size: Optional[pulumi.Input[_builtins.int]] = None,
            receptive_cluster_agents_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            remember_me_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            repository_checks_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            repository_size_limit: Optional[pulumi.Input[_builtins.int]] = None,
            repository_storages_weighted: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.int]]]] = None,
            require_admin_approval_after_user_signup: Optional[pulumi.Input[_builtins.bool]] = None,
            require_admin_two_factor_authentication: Optional[pulumi.Input[_builtins.bool]] = None,
            require_personal_access_token_expiry: Optional[pulumi.Input[_builtins.bool]] = None,
            require_two_factor_authentication: Optional[pulumi.Input[_builtins.bool]] = None,
            restricted_visibility_levels: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            rsa_key_restriction: Optional[pulumi.Input[_builtins.int]] = None,
            search_rate_limit: Optional[pulumi.Input[_builtins.int]] = None,
            search_rate_limit_unauthenticated: Optional[pulumi.Input[_builtins.int]] = None,
            security_approval_policies_limit: Optional[pulumi.Input[_builtins.int]] = None,
            security_policy_global_group_approvers_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            security_txt_content: Optional[pulumi.Input[_builtins.str]] = None,
            send_user_confirmation_email: Optional[pulumi.Input[_builtins.bool]] = None,
            service_access_tokens_expiration_enforced: Optional[pulumi.Input[_builtins.bool]] = None,
            session_expire_delay: Optional[pulumi.Input[_builtins.int]] = None,
            shared_runners_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            shared_runners_minutes: Optional[pulumi.Input[_builtins.int]] = None,
            shared_runners_text: Optional[pulumi.Input[_builtins.str]] = None,
            sidekiq_job_limiter_compression_threshold_bytes: Optional[pulumi.Input[_builtins.int]] = None,
            sidekiq_job_limiter_limit_bytes: Optional[pulumi.Input[_builtins.int]] = None,
            sidekiq_job_limiter_mode: Optional[pulumi.Input[_builtins.str]] = None,
            sign_in_text: Optional[pulumi.Input[_builtins.str]] = None,
            signup_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            silent_admin_exports_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            silent_mode_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            slack_app_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            slack_app_id: Optional[pulumi.Input[_builtins.str]] = None,
            slack_app_secret: Optional[pulumi.Input[_builtins.str]] = None,
            slack_app_signing_secret: Optional[pulumi.Input[_builtins.str]] = None,
            slack_app_verification_token: Optional[pulumi.Input[_builtins.str]] = None,
            snippet_size_limit: Optional[pulumi.Input[_builtins.int]] = None,
            snowplow_app_id: Optional[pulumi.Input[_builtins.str]] = None,
            snowplow_collector_hostname: Optional[pulumi.Input[_builtins.str]] = None,
            snowplow_cookie_domain: Optional[pulumi.Input[_builtins.str]] = None,
            snowplow_database_collector_hostname: Optional[pulumi.Input[_builtins.str]] = None,
            snowplow_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            sourcegraph_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            sourcegraph_public_only: Optional[pulumi.Input[_builtins.bool]] = None,
            sourcegraph_url: Optional[pulumi.Input[_builtins.str]] = None,
            spam_check_api_key: Optional[pulumi.Input[_builtins.str]] = None,
            spam_check_endpoint_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            spam_check_endpoint_url: Optional[pulumi.Input[_builtins.str]] = None,
            static_objects_external_storage_auth_token: Optional[pulumi.Input[_builtins.str]] = None,
            static_objects_external_storage_url: Optional[pulumi.Input[_builtins.str]] = None,
            suggest_pipeline_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            terminal_max_session_time: Optional[pulumi.Input[_builtins.int]] = None,
            terms: Optional[pulumi.Input[_builtins.str]] = None,
            throttle_authenticated_api_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            throttle_authenticated_api_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
            throttle_authenticated_api_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
            throttle_authenticated_packages_api_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            throttle_authenticated_packages_api_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
            throttle_authenticated_packages_api_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
            throttle_authenticated_web_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            throttle_authenticated_web_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
            throttle_authenticated_web_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
            throttle_unauthenticated_api_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            throttle_unauthenticated_api_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
            throttle_unauthenticated_api_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
            throttle_unauthenticated_packages_api_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            throttle_unauthenticated_packages_api_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
            throttle_unauthenticated_packages_api_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
            throttle_unauthenticated_web_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            throttle_unauthenticated_web_period_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
            throttle_unauthenticated_web_requests_per_period: Optional[pulumi.Input[_builtins.int]] = None,
            time_tracking_limit_to_hours: Optional[pulumi.Input[_builtins.bool]] = None,
            two_factor_grace_period: Optional[pulumi.Input[_builtins.int]] = None,
            unconfirmed_users_delete_after_days: Optional[pulumi.Input[_builtins.int]] = None,
            unique_ips_limit_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            unique_ips_limit_per_user: Optional[pulumi.Input[_builtins.int]] = None,
            unique_ips_limit_time_window: Optional[pulumi.Input[_builtins.int]] = None,
            update_runner_versions_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            usage_ping_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            use_clickhouse_for_analytics: Optional[pulumi.Input[_builtins.bool]] = None,
            user_deactivation_emails_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            user_default_external: Optional[pulumi.Input[_builtins.bool]] = None,
            user_default_internal_regex: Optional[pulumi.Input[_builtins.str]] = None,
            user_defaults_to_private_profile: Optional[pulumi.Input[_builtins.bool]] = None,
            user_oauth_applications: Optional[pulumi.Input[_builtins.bool]] = None,
            user_show_add_ssh_key_message: Optional[pulumi.Input[_builtins.bool]] = None,
            valid_runner_registrars: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            version_check_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            web_ide_clientside_preview_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            whats_new_variant: Optional[pulumi.Input[_builtins.str]] = None,
            wiki_page_max_content_bytes: Optional[pulumi.Input[_builtins.int]] = None) -> 'ApplicationSettings':
        """
        Get an existing ApplicationSettings resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] abuse_notification_email: If set, abuse reports are sent to this address. Abuse reports are always available in the Admin Area.
        :param pulumi.Input[_builtins.bool] admin_mode: Require administrators to enable Admin Mode by re-authenticating for administrative tasks.
        :param pulumi.Input[_builtins.str] after_sign_out_path: Where to redirect users after logout.
        :param pulumi.Input[_builtins.str] after_sign_up_text: Text shown to the user after signing up.
        :param pulumi.Input[_builtins.str] akismet_api_key: API key for Akismet spam protection.
        :param pulumi.Input[_builtins.bool] akismet_enabled: (If enabled, requires: akismet*api*key) Enable or disable Akismet spam protection.
        :param pulumi.Input[_builtins.bool] allow_account_deletion: Set to true to allow users to delete their accounts. Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] allow_group_owners_to_manage_ldap: Set to true to allow group owners to manage LDAP.
        :param pulumi.Input[_builtins.bool] allow_local_requests_from_system_hooks: Allow requests to the local network from system hooks.
        :param pulumi.Input[_builtins.bool] allow_local_requests_from_web_hooks_and_services: Allow requests to the local network from web hooks and services.
        :param pulumi.Input[_builtins.bool] allow_project_creation_for_guest_and_below: Indicates whether users assigned up to the Guest role can create groups and personal projects.
        :param pulumi.Input[_builtins.bool] allow_runner_registration_token: Allow using a registration token to create a runner.
        :param pulumi.Input[_builtins.str] archive_builds_in_human_readable: Set the duration for which the jobs are considered as old and expired. After that time passes, the jobs are archived and no longer able to be retried. Make it empty to never expire jobs. It has to be no less than 1 day, for example: 15 days, 1 month, 2 years.
        :param pulumi.Input[_builtins.int] asciidoc_max_includes: Maximum limit of AsciiDoc include directives being processed in any one document. Maximum: 64.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] asset_proxy_allowlists: Assets that match these domains are not proxied. Wildcards allowed. Your GitLab installation URL is automatically allowlisted. GitLab restart is required to apply changes.
        :param pulumi.Input[_builtins.bool] asset_proxy_enabled: (If enabled, requires: asset*proxy*url) Enable proxying of assets. GitLab restart is required to apply changes.
        :param pulumi.Input[_builtins.str] asset_proxy_secret_key: Shared secret with the asset proxy server. GitLab restart is required to apply changes.
        :param pulumi.Input[_builtins.str] asset_proxy_url: URL of the asset proxy server. GitLab restart is required to apply changes.
        :param pulumi.Input[_builtins.bool] authorized_keys_enabled: By default, we write to the authorized_keys file to support Git over SSH without additional configuration. GitLab can be optimized to authenticate SSH keys via the database file. Only disable this if you have configured your OpenSSH server to use the AuthorizedKeysCommand.
        :param pulumi.Input[_builtins.bool] auto_ban_user_on_excessive_projects_download: When enabled, users will get automatically banned from the application when they download more than the maximum number of unique projects in the time period specified by max*number*of*repository*downloads and max*number*of*repository*downloads*within*time_period respectively. Self-managed, Ultimate only.
        :param pulumi.Input[_builtins.str] auto_devops_domain: Specify a domain to use by default for every project’s Auto Review Apps and Auto Deploy stages.
        :param pulumi.Input[_builtins.bool] auto_devops_enabled: Enable Auto DevOps for projects by default. It automatically builds, tests, and deploys applications based on a predefined CI/CD configuration.
        :param pulumi.Input[_builtins.bool] automatic_purchased_storage_allocation: Enabling this permits automatic allocation of purchased storage in a namespace.
        :param pulumi.Input[_builtins.int] bulk_import_concurrent_pipeline_batch_limit: Maximum simultaneous Direct Transfer batches to process.
        :param pulumi.Input[_builtins.bool] bulk_import_enabled: Enable migrating GitLab groups by direct transfer.
        :param pulumi.Input[_builtins.int] bulk_import_max_download_file_size: Maximum download file size when importing from source GitLab instances by direct transfer.
        :param pulumi.Input[_builtins.bool] can_create_group: Indicates whether users can create top-level groups.
        :param pulumi.Input[_builtins.bool] check_namespace_plan: Enabling this makes only licensed EE features available to projects if the project namespace’s plan includes the feature or if the project is public.
        :param pulumi.Input[_builtins.int] ci_max_includes: The maximum number of includes per pipeline.
        :param pulumi.Input[_builtins.int] ci_max_total_yaml_size_bytes: The maximum amount of memory, in bytes, that can be allocated for the pipeline configuration, with all included YAML configuration files.
        :param pulumi.Input[_builtins.str] commit_email_hostname: Custom hostname (for private commit emails).
        :param pulumi.Input[_builtins.int] concurrent_bitbucket_import_jobs_limit: Maximum number of simultaneous import jobs for the Bitbucket Cloud importer.
        :param pulumi.Input[_builtins.int] concurrent_bitbucket_server_import_jobs_limit: Maximum number of simultaneous import jobs for the Bitbucket Server importer.
        :param pulumi.Input[_builtins.int] concurrent_github_import_jobs_limit: Maximum number of simultaneous import jobs for the GitHub importer.
        :param pulumi.Input[_builtins.bool] container_expiration_policies_enable_historic_entries: Enable cleanup policies for all projects.
        :param pulumi.Input[_builtins.int] container_registry_cleanup_tags_service_max_list_size: The maximum number of tags that can be deleted in a single execution of cleanup policies.
        :param pulumi.Input[_builtins.int] container_registry_delete_tags_service_timeout: The maximum time, in seconds, that the cleanup process can take to delete a batch of tags for cleanup policies.
        :param pulumi.Input[_builtins.bool] container_registry_expiration_policies_caching: Caching during the execution of cleanup policies.
        :param pulumi.Input[_builtins.int] container_registry_expiration_policies_worker_capacity: Number of workers for cleanup policies.
        :param pulumi.Input[_builtins.int] container_registry_token_expire_delay: Container Registry token duration in minutes.
        :param pulumi.Input[_builtins.bool] deactivate_dormant_users: Enable automatic deactivation of dormant users.
        :param pulumi.Input[_builtins.int] deactivate_dormant_users_period: Length of time (in days) after which a user is considered dormant.
        :param pulumi.Input[_builtins.int] decompress_archive_file_timeout: Default timeout for decompressing archived files, in seconds. Set to 0 to disable timeouts.
        :param pulumi.Input[_builtins.str] default_artifacts_expire_in: Set the default expiration time for each job’s artifacts.
        :param pulumi.Input[_builtins.str] default_branch_name: Instance-level custom initial branch name
        :param pulumi.Input[_builtins.int] default_branch_protection: Determine if developers can push to the default branch. Can take: 0 (not protected, both users with the Developer role or Maintainer role can push new commits and force push), 1 (partially protected, users with the Developer role or Maintainer role can push new commits, but cannot force push) or 2 (fully protected, users with the Developer or Maintainer role cannot push new commits, but users with the Developer or Maintainer role can; no one can force push) as a parameter. Default is 2. Use `default_branch_protection_defaults` instead. To be removed in 19.0.
        :param pulumi.Input[Union['ApplicationSettingsDefaultBranchProtectionDefaultsArgs', 'ApplicationSettingsDefaultBranchProtectionDefaultsArgsDict']] default_branch_protection_defaults: The default*branch*protection*defaults attribute describes the default branch protection defaults. All parameters are optional.
        :param pulumi.Input[_builtins.str] default_ci_config_path: Default CI/CD configuration file and path for new projects (.gitlab-ci.yml if not set).
        :param pulumi.Input[_builtins.str] default_group_visibility: What visibility level new groups receive. Can take private, internal and public as a parameter.
        :param pulumi.Input[_builtins.str] default_preferred_language: Default preferred language for users who are not logged in.
        :param pulumi.Input[_builtins.int] default_project_creation: Default project creation protection. Can take: 0 (No one), 1 (Maintainers) or 2 (Developers + Maintainers).
        :param pulumi.Input[_builtins.str] default_project_visibility: What visibility level new projects receive. Can take private, internal and public as a parameter.
        :param pulumi.Input[_builtins.int] default_projects_limit: Project limit per user.
        :param pulumi.Input[_builtins.str] default_snippet_visibility: What visibility level new snippets receive. Can take private, internal and public as a parameter.
        :param pulumi.Input[_builtins.int] default_syntax_highlighting_theme: Default syntax highlighting theme for users who are new or not signed in. See IDs of available themes (https://gitlab.com/gitlab-org/gitlab/blob/master/lib/gitlab/themes.rb#L16)
        :param pulumi.Input[_builtins.bool] delete_inactive_projects: Enable inactive project deletion feature.
        :param pulumi.Input[_builtins.bool] delete_unconfirmed_users: Specifies whether users who have not confirmed their email should be deleted. When set to true, unconfirmed users are deleted after unconfirmed*users*delete*after*days days. Self-managed, Premium and Ultimate only.
        :param pulumi.Input[_builtins.int] deletion_adjourned_period: The number of days to wait before deleting a project or group that is marked for deletion. Value must be between 1 and 90.
        :param pulumi.Input[_builtins.bool] diagramsnet_enabled: (If enabled, requires diagramsnet_url) Enable Diagrams.net integration.
        :param pulumi.Input[_builtins.str] diagramsnet_url: The Diagrams.net instance URL for integration.
        :param pulumi.Input[_builtins.int] diff_max_files: Maximum files in a diff.
        :param pulumi.Input[_builtins.int] diff_max_lines: Maximum lines in a diff.
        :param pulumi.Input[_builtins.int] diff_max_patch_bytes: Maximum diff patch size, in bytes.
        :param pulumi.Input[_builtins.bool] disable_admin_oauth_scopes: Stops administrators from connecting their GitLab accounts to non-trusted OAuth 2.0 applications that have the api, read*api, read*repository, write*repository, read*registry, write_registry, or sudo scopes.
        :param pulumi.Input[_builtins.bool] disable_feed_token: Disable display of RSS/Atom and calendar feed tokens.
        :param pulumi.Input[_builtins.bool] disable_personal_access_tokens: Disable personal access tokens. Self-managed, Premium and Ultimate only. There is no method available to enable a personal access token that’s been disabled through the API. This is a known issue.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] disabled_oauth_sign_in_sources: Disabled OAuth sign-in sources.
        :param pulumi.Input[_builtins.bool] dns_rebinding_protection_enabled: Enforce DNS rebinding attack protection.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] domain_allowlists: Force people to use only corporate emails for sign-up. Null means there is no restriction.
        :param pulumi.Input[_builtins.bool] domain_denylist_enabled: (If enabled, requires: domain_denylist) Allows blocking sign-ups from emails from specific domains.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] domain_denylists: Users with email addresses that match these domains cannot sign up. Wildcards allowed. Use separate lines for multiple entries. Ex: domain.com, *.domain.com.
        :param pulumi.Input[_builtins.int] downstream_pipeline_trigger_limit_per_project_user_sha: Maximum downstream pipeline trigger rate.
        :param pulumi.Input[_builtins.int] dsa_key_restriction: The minimum allowed bit length of an uploaded DSA key. 0 means no restriction. -1 disables DSA keys.
        :param pulumi.Input[_builtins.bool] duo_features_enabled: Indicates whether GitLab Duo features are enabled for this instance. Self-managed, Premium and Ultimate only.
        :param pulumi.Input[_builtins.int] ecdsa_key_restriction: The minimum allowed curve size (in bits) of an uploaded ECDSA key. 0 means no restriction. -1 disables ECDSA keys.
        :param pulumi.Input[_builtins.int] ecdsa_sk_key_restriction: The minimum allowed curve size (in bits) of an uploaded ECDSA*SK key. 0 means no restriction. -1 disables ECDSA*SK keys.
        :param pulumi.Input[_builtins.int] ed25519_key_restriction: The minimum allowed curve size (in bits) of an uploaded ED25519 key. 0 means no restriction. -1 disables ED25519 keys.
        :param pulumi.Input[_builtins.int] ed25519_sk_key_restriction: The minimum allowed curve size (in bits) of an uploaded ED25519*SK key. 0 means no restriction. -1 disables ED25519*SK keys.
        :param pulumi.Input[_builtins.str] eks_access_key_id: AWS IAM access key ID.
        :param pulumi.Input[_builtins.str] eks_account_id: Amazon account ID.
        :param pulumi.Input[_builtins.bool] eks_integration_enabled: Enable integration with Amazon EKS.
        :param pulumi.Input[_builtins.str] eks_secret_access_key: AWS IAM secret access key.
        :param pulumi.Input[_builtins.bool] elasticsearch_aws: Enable the use of AWS hosted Elasticsearch.
        :param pulumi.Input[_builtins.str] elasticsearch_aws_access_key: AWS IAM access key.
        :param pulumi.Input[_builtins.str] elasticsearch_aws_region: The AWS region the Elasticsearch domain is configured.
        :param pulumi.Input[_builtins.str] elasticsearch_aws_secret_access_key: AWS IAM secret access key.
        :param pulumi.Input[_builtins.int] elasticsearch_indexed_field_length_limit: Maximum size of text fields to index by Elasticsearch. 0 value means no limit. This does not apply to repository and wiki indexing.
        :param pulumi.Input[_builtins.int] elasticsearch_indexed_file_size_limit_kb: Maximum size of repository and wiki files that are indexed by Elasticsearch.
        :param pulumi.Input[_builtins.bool] elasticsearch_indexing: Enable Elasticsearch indexing.
        :param pulumi.Input[_builtins.bool] elasticsearch_limit_indexing: Limit Elasticsearch to index certain namespaces and projects.
        :param pulumi.Input[_builtins.int] elasticsearch_max_bulk_concurrency: Maximum concurrency of Elasticsearch bulk requests per indexing operation. This only applies to repository indexing operations.
        :param pulumi.Input[_builtins.int] elasticsearch_max_bulk_size_mb: Maximum size of Elasticsearch bulk indexing requests in MB. This only applies to repository indexing operations.
        :param pulumi.Input[_builtins.int] elasticsearch_max_code_indexing_concurrency: Maximum concurrency of Elasticsearch code indexing background jobs. This only applies to repository indexing operations. Premium and Ultimate only.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] elasticsearch_namespace_ids: The namespaces to index via Elasticsearch if elasticsearch*limit*indexing is enabled.
        :param pulumi.Input[_builtins.str] elasticsearch_password: The password of your Elasticsearch instance.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] elasticsearch_project_ids: The projects to index via Elasticsearch if elasticsearch*limit*indexing is enabled.
        :param pulumi.Input[_builtins.bool] elasticsearch_requeue_workers: Enable automatic requeuing of indexing workers. This improves non-code indexing throughput by enqueuing Sidekiq jobs until all documents are processed. Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] elasticsearch_search: Enable Elasticsearch search.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] elasticsearch_urls: The URL to use for connecting to Elasticsearch. Use a comma-separated list to support cluster (for example, http://localhost:9200, http://localhost:9201).
        :param pulumi.Input[_builtins.str] elasticsearch_username: The username of your Elasticsearch instance.
        :param pulumi.Input[_builtins.int] elasticsearch_worker_number_of_shards: Number of indexing worker shards. This improves non-code indexing throughput by enqueuing more parallel Sidekiq jobs. Premium and Ultimate only.
        :param pulumi.Input[_builtins.str] email_additional_text: Additional text added to the bottom of every email for legal/auditing/compliance reasons.
        :param pulumi.Input[_builtins.bool] email_author_in_body: Some email servers do not support overriding the email sender name. Enable this option to include the name of the author of the issue, merge request or comment in the email body instead.
        :param pulumi.Input[_builtins.str] email_confirmation_setting: Specifies whether users must confirm their email before sign in. Possible values are off, soft, and hard.
        :param pulumi.Input[_builtins.bool] enable_artifact_external_redirect_warning_page: Show the external redirect page that warns you about user-generated content in GitLab Pages.
        :param pulumi.Input[_builtins.str] enabled_git_access_protocol: Enabled protocols for Git access. Allowed values are: ssh, http, and nil to allow both protocols.
        :param pulumi.Input[_builtins.bool] enforce_namespace_storage_limit: Enabling this permits enforcement of namespace storage limits.
        :param pulumi.Input[_builtins.bool] enforce_terms: (If enabled, requires: terms) Enforce application ToS to all users.
        :param pulumi.Input[_builtins.str] external_auth_client_cert: (If enabled, requires: external*auth*client_key) The certificate to use to authenticate with the external authorization service.
        :param pulumi.Input[_builtins.str] external_auth_client_key: Private key for the certificate when authentication is required for the external authorization service, this is encrypted when stored.
        :param pulumi.Input[_builtins.str] external_auth_client_key_pass: Passphrase to use for the private key when authenticating with the external service this is encrypted when stored.
        :param pulumi.Input[_builtins.str] external_authorization_service_default_label: The default classification label to use when requesting authorization and no classification label has been specified on the project.
        :param pulumi.Input[_builtins.bool] external_authorization_service_enabled: (If enabled, requires: external*authorization*service*default*label, external*authorization*service*timeout and external*authorization*service*url) Enable using an external authorization service for accessing projects.
        :param pulumi.Input[_builtins.float] external_authorization_service_timeout: The timeout after which an authorization request is aborted, in seconds. When a request times out, access is denied to the user. (min: 0.001, max: 10, step: 0.001).
        :param pulumi.Input[_builtins.str] external_authorization_service_url: URL to which authorization requests are directed.
        :param pulumi.Input[_builtins.int] external_pipeline_validation_service_timeout: How long to wait for a response from the pipeline validation service. Assumes OK if it times out.
        :param pulumi.Input[_builtins.str] external_pipeline_validation_service_token: Optional. Token to include as the X-Gitlab-Token header in requests to the URL in external*pipeline*validation*service*url.
        :param pulumi.Input[_builtins.str] external_pipeline_validation_service_url: URL to use for pipeline validation requests.
        :param pulumi.Input[_builtins.int] failed_login_attempts_unlock_period_in_minutes: Time period in minutes after which the user is unlocked when maximum number of failed sign-in attempts reached.
        :param pulumi.Input[_builtins.int] file_template_project_id: The ID of a project to load custom file templates from.
        :param pulumi.Input[_builtins.int] first_day_of_week: Start day of the week for calendar views and date pickers. Valid values are 0 for Sunday, 1 for Monday, and 6 for Saturday.
        :param pulumi.Input[_builtins.str] geo_node_allowed_ips: Comma-separated list of IPs and CIDRs of allowed secondary nodes. For example, 1.1.1.1, 2.2.2.0/24.
        :param pulumi.Input[_builtins.int] geo_status_timeout: The amount of seconds after which a request to get a secondary node status times out.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] git_rate_limit_users_alertlists: List of user IDs that are emailed when the Git abuse rate limit is exceeded. Maximum: 100 user IDs. Self-managed, Ultimate only.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] git_rate_limit_users_allowlists: List of usernames excluded from Git anti-abuse rate limits. Maximum: 100 usernames. Self-managed, Ultimate only.
        :param pulumi.Input[_builtins.int] git_two_factor_session_expiry: Maximum duration (in minutes) of a session for Git operations when 2FA is enabled.
        :param pulumi.Input[_builtins.int] gitaly_timeout_default: Default Gitaly timeout, in seconds. This timeout is not enforced for Git fetch/push operations or Sidekiq jobs. Set to 0 to disable timeouts.
        :param pulumi.Input[_builtins.int] gitaly_timeout_fast: Gitaly fast operation timeout, in seconds. Some Gitaly operations are expected to be fast. If they exceed this threshold, there may be a problem with a storage shard and ‘failing fast’ can help maintain the stability of the GitLab instance. Set to 0 to disable timeouts.
        :param pulumi.Input[_builtins.int] gitaly_timeout_medium: Medium Gitaly timeout, in seconds. This should be a value between the Fast and the Default timeout. Set to 0 to disable timeouts.
        :param pulumi.Input[_builtins.bool] gitlab_dedicated_instance: Indicates whether the instance was provisioned for GitLab Dedicated.
        :param pulumi.Input[_builtins.bool] gitlab_environment_toolkit_instance: Indicates whether the instance was provisioned with the GitLab Environment Toolkit for Service Ping reporting.
        :param pulumi.Input[_builtins.int] gitlab_shell_operation_limit: Maximum number of Git operations per minute a user can perform.
        :param pulumi.Input[_builtins.bool] gitpod_enabled: Enable Gitpod integration.
        :param pulumi.Input[_builtins.str] gitpod_url: The Gitpod instance URL for integration.
        :param pulumi.Input[_builtins.str] globally_allowed_ips: Comma-separated list of IP addresses and CIDRs always allowed for inbound traffic. For example, 1.1.1.1, 2.2.2.0/24.
        :param pulumi.Input[_builtins.bool] grafana_enabled: Enable Grafana.
        :param pulumi.Input[_builtins.str] grafana_url: Grafana URL.
        :param pulumi.Input[_builtins.bool] gravatar_enabled: Enable Gravatar.
        :param pulumi.Input[_builtins.bool] group_owners_can_manage_default_branch_protection: Prevent overrides of default branch protection.
        :param pulumi.Input[_builtins.bool] help_page_hide_commercial_content: Hide marketing-related entries from help.
        :param pulumi.Input[_builtins.str] help_page_support_url: Alternate support URL for help page and help dropdown.
        :param pulumi.Input[_builtins.str] help_page_text: Custom text displayed on the help page.
        :param pulumi.Input[_builtins.str] help_text: GitLab server administrator information.
        :param pulumi.Input[_builtins.bool] hide_third_party_offers: Do not display offers from third parties in GitLab.
        :param pulumi.Input[_builtins.str] home_page_url: Redirect to this URL when not logged in.
        :param pulumi.Input[_builtins.bool] housekeeping_enabled: Enable or disable Git housekeeping. If enabled, requires housekeeping*optimize*repository_period.
        :param pulumi.Input[_builtins.int] housekeeping_optimize_repository_period: Number of Git pushes after which an incremental git-repack is run.
        :param pulumi.Input[_builtins.bool] html_emails_enabled: Enable HTML emails.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] import_sources: Sources to allow project import from. Valid values are: `github`, `bitbucket`, `bitbucket_server`, `fogbugz`, `git`, `Project`, `gitea`, `manifest`
        :param pulumi.Input[_builtins.bool] in_product_marketing_emails_enabled: Enable in-product marketing emails.
        :param pulumi.Input[_builtins.int] inactive_projects_delete_after_months: If delete*inactive*projects is true, the time (in months) to wait before deleting inactive projects.
        :param pulumi.Input[_builtins.int] inactive_projects_min_size_mb: If delete*inactive*projects is true, the minimum repository size for projects to be checked for inactivity.
        :param pulumi.Input[_builtins.int] inactive_projects_send_warning_email_after_months: If delete*inactive*projects is true, sets the time (in months) to wait before emailing maintainers that the project is scheduled be deleted because it is inactive.
        :param pulumi.Input[_builtins.bool] include_optional_metrics_in_service_ping: Whether or not optional metrics are enabled in Service Ping.
        :param pulumi.Input[_builtins.bool] invisible_captcha_enabled: Enable Invisible CAPTCHA spam detection during sign-up.
        :param pulumi.Input[_builtins.int] issues_create_limit: Max number of issue creation requests per minute per user.
        :param pulumi.Input[_builtins.str] jira_connect_application_key: ID of the OAuth application used to authenticate with the GitLab for Jira Cloud app.
        :param pulumi.Input[_builtins.str] jira_connect_proxy_url: URL of the GitLab instance used as a proxy for the GitLab for Jira Cloud app.
        :param pulumi.Input[_builtins.bool] jira_connect_public_key_storage_enabled: Enable public key storage for the GitLab for Jira Cloud app.
        :param pulumi.Input[_builtins.bool] keep_latest_artifact: Prevent the deletion of the artifacts from the most recent successful jobs, regardless of the expiry time.
        :param pulumi.Input[_builtins.int] local_markdown_version: Increase this value when any cached Markdown should be invalidated.
        :param pulumi.Input[_builtins.bool] lock_duo_features_enabled: Indicates whether the GitLab Duo features enabled setting is enforced for all subgroups. Self-managed, Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] lock_memberships_to_ldap: Set to true to lock all memberships to LDAP. Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] mailgun_events_enabled: Enable Mailgun event receiver.
        :param pulumi.Input[_builtins.str] mailgun_signing_key: The Mailgun HTTP webhook signing key for receiving events from webhook.
        :param pulumi.Input[_builtins.bool] maintenance_mode: When instance is in maintenance mode, non-administrative users can sign in with read-only access and make read-only API requests.
        :param pulumi.Input[_builtins.str] maintenance_mode_message: Message displayed when instance is in maintenance mode.
        :param pulumi.Input[_builtins.bool] maven_package_requests_forwarding: Use repo.maven.apache.org as a default remote repository when the package is not found in the GitLab Package Registry for Maven. Premium and Ultimate only.
        :param pulumi.Input[_builtins.int] max_artifacts_size: Maximum artifacts size in MB.
        :param pulumi.Input[_builtins.int] max_attachment_size: Limit attachment size in MB.
        :param pulumi.Input[_builtins.int] max_decompressed_archive_size: Maximum decompressed archive size in bytes.
        :param pulumi.Input[_builtins.int] max_export_size: Maximum export size in MB. 0 for unlimited.
        :param pulumi.Input[_builtins.int] max_import_remote_file_size: Maximum remote file size for imports from external object storages.
        :param pulumi.Input[_builtins.int] max_import_size: Maximum import size in MB. 0 for unlimited.
        :param pulumi.Input[_builtins.int] max_login_attempts: Maximum number of sign-in attempts before locking out the user.
        :param pulumi.Input[_builtins.int] max_number_of_repository_downloads: Maximum number of unique repositories a user can download in the specified time period before they are banned. Maximum: 10,000 repositories.
        :param pulumi.Input[_builtins.int] max_number_of_repository_downloads_within_time_period: Reporting time period (in seconds). Maximum: 864000 seconds (10 days).
        :param pulumi.Input[_builtins.int] max_pages_size: Maximum size of pages repositories in MB.
        :param pulumi.Input[_builtins.int] max_personal_access_token_lifetime: Maximum allowable lifetime for access tokens in days.
        :param pulumi.Input[_builtins.int] max_ssh_key_lifetime: Maximum allowable lifetime for SSH keys in days.
        :param pulumi.Input[_builtins.int] metrics_method_call_threshold: A method call is only tracked when it takes longer than the given amount of milliseconds.
        :param pulumi.Input[_builtins.int] minimum_password_length: Indicates whether passwords require a minimum length. Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] mirror_available: Allow repository mirroring to configured by project Maintainers. If disabled, only Administrators can configure repository mirroring.
        :param pulumi.Input[_builtins.int] mirror_capacity_threshold: Minimum capacity to be available before scheduling more mirrors preemptively.
        :param pulumi.Input[_builtins.int] mirror_max_capacity: Maximum number of mirrors that can be synchronizing at the same time.
        :param pulumi.Input[_builtins.int] mirror_max_delay: Maximum time (in minutes) between updates that a mirror can have when scheduled to synchronize.
        :param pulumi.Input[_builtins.bool] npm_package_requests_forwarding: Use npmjs.org as a default remote repository when the package is not found in the GitLab Package Registry for npm.
        :param pulumi.Input[_builtins.bool] nuget_skip_metadata_url_validation: Indicates whether to skip metadata URL validation for the NuGet package.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] outbound_local_requests_whitelists: Define a list of trusted domains or IP addresses to which local requests are allowed when local requests for hooks and services are disabled.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] package_metadata_purl_types: List of package registry metadata to sync. See the list of the available values (https://gitlab.com/gitlab-org/gitlab/-/blob/ace16c20d5da7c4928dd03fb139692638b557fe3/app/models/concerns/enums/package_metadata.rb#L5). Self-managed, Ultimate only.
        :param pulumi.Input[_builtins.bool] package_registry_allow_anyone_to_pull_option: Enable to allow anyone to pull from Package Registry visible and changeable.
        :param pulumi.Input[_builtins.int] package_registry_cleanup_policies_worker_capacity: Number of workers assigned to the packages cleanup policies.
        :param pulumi.Input[_builtins.bool] pages_domain_verification_enabled: Require users to prove ownership of custom domains. Domain verification is an essential security measure for public GitLab sites. Users are required to demonstrate they control a domain before it is enabled.
        :param pulumi.Input[_builtins.bool] password_authentication_enabled_for_git: Enable authentication for Git over HTTP(S) via a GitLab account password.
        :param pulumi.Input[_builtins.bool] password_authentication_enabled_for_web: Enable authentication for the web interface via a GitLab account password.
        :param pulumi.Input[_builtins.bool] password_lowercase_required: Indicates whether passwords require at least one lowercase letter.
        :param pulumi.Input[_builtins.bool] password_number_required: Indicates whether passwords require at least one number.
        :param pulumi.Input[_builtins.bool] password_symbol_required: Indicates whether passwords require at least one symbol character.
        :param pulumi.Input[_builtins.bool] password_uppercase_required: Indicates whether passwords require at least one uppercase letter.
        :param pulumi.Input[_builtins.str] performance_bar_allowed_group_path: Path of the group that is allowed to toggle the performance bar.
        :param pulumi.Input[_builtins.str] personal_access_token_prefix: Prefix for all generated personal access tokens.
        :param pulumi.Input[_builtins.int] pipeline_limit_per_project_user_sha: Maximum number of pipeline creation requests per minute per user and commit.
        :param pulumi.Input[_builtins.bool] plantuml_enabled: (If enabled, requires: plantuml_url) Enable PlantUML integration.
        :param pulumi.Input[_builtins.str] plantuml_url: The PlantUML instance URL for integration.
        :param pulumi.Input[_builtins.float] polling_interval_multiplier: Interval multiplier used by endpoints that perform polling. Set to 0 to disable polling.
        :param pulumi.Input[_builtins.bool] project_export_enabled: Enable project export.
        :param pulumi.Input[_builtins.int] project_jobs_api_rate_limit: Maximum authenticated requests to /project/:id/jobs per minute.
        :param pulumi.Input[_builtins.int] projects_api_rate_limit_unauthenticated: Max number of requests per 10 minutes per IP address for unauthenticated requests to the list all projects API. To disable throttling set to 0.
        :param pulumi.Input[_builtins.bool] prometheus_metrics_enabled: Enable Prometheus metrics.
        :param pulumi.Input[_builtins.bool] protected_ci_variables: CI/CD variables are protected by default.
        :param pulumi.Input[_builtins.int] push_event_activities_limit: Number of changes (branches or tags) in a single push to determine whether individual push events or bulk push events are created. Bulk push events are created if it surpasses that value.
        :param pulumi.Input[_builtins.int] push_event_hooks_limit: Number of changes (branches or tags) in a single push to determine whether webhooks and services fire or not. Webhooks and services aren’t submitted if it surpasses that value.
        :param pulumi.Input[_builtins.bool] pypi_package_requests_forwarding: Use pypi.org as a default remote repository when the package is not found in the GitLab Package Registry for PyPI.
        :param pulumi.Input[_builtins.str] rate_limiting_response_text: When rate limiting is enabled via the throttle_* settings, send this plain text response when a rate limit is exceeded. ‘Retry later’ is sent if this is blank.
        :param pulumi.Input[_builtins.int] raw_blob_request_limit: Max number of requests per minute for each raw path. To disable throttling set to 0.
        :param pulumi.Input[_builtins.bool] recaptcha_enabled: (If enabled, requires: recaptcha*private*key and recaptcha*site*key) Enable reCAPTCHA.
        :param pulumi.Input[_builtins.str] recaptcha_private_key: Private key for reCAPTCHA.
        :param pulumi.Input[_builtins.str] recaptcha_site_key: Site key for reCAPTCHA.
        :param pulumi.Input[_builtins.int] receive_max_input_size: Maximum push size (MB).
        :param pulumi.Input[_builtins.bool] receptive_cluster_agents_enabled: Enable receptive mode for GitLab Agents for Kubernetes.
        :param pulumi.Input[_builtins.bool] remember_me_enabled: Enable Remember me setting.
        :param pulumi.Input[_builtins.bool] repository_checks_enabled: GitLab periodically runs git fsck in all project and wiki repositories to look for silent disk corruption issues.
        :param pulumi.Input[_builtins.int] repository_size_limit: Size limit per repository (MB).
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.int]]] repository_storages_weighted: Hash of names taken from gitlab.yml to weights. New projects are created in one of these stores, chosen by a weighted random selection.
        :param pulumi.Input[_builtins.bool] require_admin_approval_after_user_signup: When enabled, any user that signs up for an account using the registration form is placed under a Pending approval state and has to be explicitly approved by an administrator.
        :param pulumi.Input[_builtins.bool] require_admin_two_factor_authentication: Allow administrators to require 2FA for all administrators on the instance.
        :param pulumi.Input[_builtins.bool] require_personal_access_token_expiry: When enabled, users must set an expiration date when creating a group or project access token, or a personal access token owned by a non-service account.
        :param pulumi.Input[_builtins.bool] require_two_factor_authentication: (If enabled, requires: two*factor*grace_period) Require all users to set up Two-factor authentication.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] restricted_visibility_levels: Selected levels cannot be used by non-Administrator users for groups, projects or snippets. Can take private, internal and public as a parameter. Null means there is no restriction.
        :param pulumi.Input[_builtins.int] rsa_key_restriction: The minimum allowed bit length of an uploaded RSA key. 0 means no restriction. -1 disables RSA keys.
        :param pulumi.Input[_builtins.int] search_rate_limit: Max number of requests per minute for performing a search while authenticated. To disable throttling set to 0.
        :param pulumi.Input[_builtins.int] search_rate_limit_unauthenticated: Max number of requests per minute for performing a search while unauthenticated. To disable throttling set to 0.
        :param pulumi.Input[_builtins.int] security_approval_policies_limit: Maximum number of active merge request approval policies per security policy project. Maximum: 20
        :param pulumi.Input[_builtins.bool] security_policy_global_group_approvers_enabled: Whether to look up merge request approval policy approval groups globally or within project hierarchies.
        :param pulumi.Input[_builtins.str] security_txt_content: Public security contact information.
        :param pulumi.Input[_builtins.bool] send_user_confirmation_email: Send confirmation email on sign-up.
        :param pulumi.Input[_builtins.bool] service_access_tokens_expiration_enforced: Flag to indicate if token expiry date can be optional for service account users
        :param pulumi.Input[_builtins.int] session_expire_delay: Session duration in minutes. GitLab restart is required to apply changes.
        :param pulumi.Input[_builtins.bool] shared_runners_enabled: (If enabled, requires: shared*runners*text and shared*runners*minutes) Enable shared runners for new projects.
        :param pulumi.Input[_builtins.int] shared_runners_minutes: Set the maximum number of CI/CD minutes that a group can use on shared runners per month.
        :param pulumi.Input[_builtins.str] shared_runners_text: Shared runners text.
        :param pulumi.Input[_builtins.int] sidekiq_job_limiter_compression_threshold_bytes: The threshold in bytes at which Sidekiq jobs are compressed before being stored in Redis.
        :param pulumi.Input[_builtins.int] sidekiq_job_limiter_limit_bytes: The threshold in bytes at which Sidekiq jobs are rejected. 0 means do not reject any job.
        :param pulumi.Input[_builtins.str] sidekiq_job_limiter_mode: track or compress. Sets the behavior for Sidekiq job size limits.
        :param pulumi.Input[_builtins.str] sign_in_text: Text on the login page.
        :param pulumi.Input[_builtins.bool] signup_enabled: Enable registration.
        :param pulumi.Input[_builtins.bool] silent_admin_exports_enabled: Enable Silent admin exports.
        :param pulumi.Input[_builtins.bool] silent_mode_enabled: Enable Silent mode.
        :param pulumi.Input[_builtins.bool] slack_app_enabled: (If enabled, requires: slack*app*id, slack*app*secret and slack*app*secret) Enable Slack app.
        :param pulumi.Input[_builtins.str] slack_app_id: The app ID of the Slack-app.
        :param pulumi.Input[_builtins.str] slack_app_secret: The app secret of the Slack-app.
        :param pulumi.Input[_builtins.str] slack_app_signing_secret: The signing secret of the Slack-app.
        :param pulumi.Input[_builtins.str] slack_app_verification_token: The verification token of the Slack-app.
        :param pulumi.Input[_builtins.int] snippet_size_limit: Max snippet content size in bytes.
        :param pulumi.Input[_builtins.str] snowplow_app_id: The Snowplow site name / application ID. (for example, gitlab)
        :param pulumi.Input[_builtins.str] snowplow_collector_hostname: The Snowplow collector hostname. (for example, snowplow.trx.gitlab.net)
        :param pulumi.Input[_builtins.str] snowplow_cookie_domain: The Snowplow cookie domain. (for example, .gitlab.com)
        :param pulumi.Input[_builtins.str] snowplow_database_collector_hostname: The Snowplow collector for database events hostname. (for example, db-snowplow.trx.gitlab.net)
        :param pulumi.Input[_builtins.bool] snowplow_enabled: Enable snowplow tracking.
        :param pulumi.Input[_builtins.bool] sourcegraph_enabled: Enables Sourcegraph integration. If enabled, requires sourcegraph_url.
        :param pulumi.Input[_builtins.bool] sourcegraph_public_only: Blocks Sourcegraph from being loaded on private and internal projects.
        :param pulumi.Input[_builtins.str] sourcegraph_url: The Sourcegraph instance URL for integration.
        :param pulumi.Input[_builtins.str] spam_check_api_key: API key used by GitLab for accessing the Spam Check service endpoint.
        :param pulumi.Input[_builtins.bool] spam_check_endpoint_enabled: Enables spam checking using external Spam Check API endpoint.
        :param pulumi.Input[_builtins.str] spam_check_endpoint_url: URL of the external Spamcheck service endpoint. Valid URI schemes are grpc or tls. Specifying tls forces communication to be encrypted.
        :param pulumi.Input[_builtins.str] static_objects_external_storage_auth_token: Authentication token for the external storage linked in static*objects*external*storage*url.
        :param pulumi.Input[_builtins.str] static_objects_external_storage_url: URL to an external storage for repository static objects.
        :param pulumi.Input[_builtins.bool] suggest_pipeline_enabled: Enable pipeline suggestion banner.
        :param pulumi.Input[_builtins.int] terminal_max_session_time: Maximum time for web terminal websocket connection (in seconds). Set to 0 for unlimited time.
        :param pulumi.Input[_builtins.str] terms: (Required by: enforce_terms) Markdown content for the ToS.
        :param pulumi.Input[_builtins.bool] throttle_authenticated_api_enabled: (If enabled, requires: throttle*authenticated*api*period*in*seconds and throttle*authenticated*api*requests*per*period) Enable authenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        :param pulumi.Input[_builtins.int] throttle_authenticated_api_period_in_seconds: Rate limit period (in seconds).
        :param pulumi.Input[_builtins.int] throttle_authenticated_api_requests_per_period: Maximum requests per period per user.
        :param pulumi.Input[_builtins.bool] throttle_authenticated_packages_api_enabled: (If enabled, requires: throttle*authenticated*packages*api*period*in*seconds and throttle*authenticated*packages*api*requests*per*period) Enable authenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots). View Package Registry rate limits for more details.
        :param pulumi.Input[_builtins.int] throttle_authenticated_packages_api_period_in_seconds: Rate limit period (in seconds). View Package Registry rate limits for more details.
        :param pulumi.Input[_builtins.int] throttle_authenticated_packages_api_requests_per_period: Maximum requests per period per user. View Package Registry rate limits for more details.
        :param pulumi.Input[_builtins.bool] throttle_authenticated_web_enabled: (If enabled, requires: throttle*authenticated*web*period*in*seconds and throttle*authenticated*web*requests*per*period) Enable authenticated web request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        :param pulumi.Input[_builtins.int] throttle_authenticated_web_period_in_seconds: Rate limit period (in seconds).
        :param pulumi.Input[_builtins.int] throttle_authenticated_web_requests_per_period: Maximum requests per period per user.
        :param pulumi.Input[_builtins.bool] throttle_unauthenticated_api_enabled: (If enabled, requires: throttle*unauthenticated*api*period*in*seconds and throttle*unauthenticated*api*requests*per*period) Enable unauthenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        :param pulumi.Input[_builtins.int] throttle_unauthenticated_api_period_in_seconds: Rate limit period in seconds.
        :param pulumi.Input[_builtins.int] throttle_unauthenticated_api_requests_per_period: Max requests per period per IP.
        :param pulumi.Input[_builtins.bool] throttle_unauthenticated_packages_api_enabled: (If enabled, requires: throttle*unauthenticated*packages*api*period*in*seconds and throttle*unauthenticated*packages*api*requests*per*period) Enable authenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots). View Package Registry rate limits for more details.
        :param pulumi.Input[_builtins.int] throttle_unauthenticated_packages_api_period_in_seconds: Rate limit period (in seconds). View Package Registry rate limits for more details.
        :param pulumi.Input[_builtins.int] throttle_unauthenticated_packages_api_requests_per_period: Maximum requests per period per user. View Package Registry rate limits for more details.
        :param pulumi.Input[_builtins.bool] throttle_unauthenticated_web_enabled: (If enabled, requires: throttle*unauthenticated*web*period*in*seconds and throttle*unauthenticated*web*requests*per*period) Enable unauthenticated web request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        :param pulumi.Input[_builtins.int] throttle_unauthenticated_web_period_in_seconds: Rate limit period in seconds.
        :param pulumi.Input[_builtins.int] throttle_unauthenticated_web_requests_per_period: Max requests per period per IP.
        :param pulumi.Input[_builtins.bool] time_tracking_limit_to_hours: Limit display of time tracking units to hours.
        :param pulumi.Input[_builtins.int] two_factor_grace_period: Amount of time (in hours) that users are allowed to skip forced configuration of two-factor authentication.
        :param pulumi.Input[_builtins.int] unconfirmed_users_delete_after_days: Specifies how many days after sign-up to delete users who have not confirmed their email. Only applicable if delete*unconfirmed*users is set to true. Must be 1 or greater. Self-managed, Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] unique_ips_limit_enabled: (If enabled, requires: unique*ips*limit*per*user and unique*ips*limit*time*window) Limit sign in from multiple IPs.
        :param pulumi.Input[_builtins.int] unique_ips_limit_per_user: Maximum number of IPs per user.
        :param pulumi.Input[_builtins.int] unique_ips_limit_time_window: How many seconds an IP is counted towards the limit.
        :param pulumi.Input[_builtins.bool] update_runner_versions_enabled: Fetch GitLab Runner release version data from GitLab.com.
        :param pulumi.Input[_builtins.bool] usage_ping_enabled: Every week GitLab reports license usage back to GitLab, Inc.
        :param pulumi.Input[_builtins.bool] use_clickhouse_for_analytics: Enables ClickHouse as a data source for analytics reports. ClickHouse must be configured for this setting to take effect. Available on Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] user_deactivation_emails_enabled: Send an email to users upon account deactivation.
        :param pulumi.Input[_builtins.bool] user_default_external: Newly registered users are external by default.
        :param pulumi.Input[_builtins.str] user_default_internal_regex: Specify an email address regex pattern to identify default internal users.
        :param pulumi.Input[_builtins.bool] user_defaults_to_private_profile: Newly created users have private profile by default.
        :param pulumi.Input[_builtins.bool] user_oauth_applications: Allow users to register any application to use GitLab as an OAuth provider.
        :param pulumi.Input[_builtins.bool] user_show_add_ssh_key_message: When set to false disable the You won't be able to pull or push project code via SSH warning shown to users with no uploaded SSH key.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] valid_runner_registrars: List of types which are allowed to register a GitLab Runner. Can be [], ['group'], ['project'] or ['group', 'project'].
        :param pulumi.Input[_builtins.bool] version_check_enabled: Let GitLab inform you when an update is available.
        :param pulumi.Input[_builtins.bool] web_ide_clientside_preview_enabled: Live Preview (allow live previews of JavaScript projects in the Web IDE using CodeSandbox Live Preview).
        :param pulumi.Input[_builtins.str] whats_new_variant: What's new variant, possible values: all*tiers, current*tier, and disabled.
        :param pulumi.Input[_builtins.int] wiki_page_max_content_bytes: Maximum wiki page content size in bytes. The minimum value is 1024 bytes.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ApplicationSettingsState.__new__(_ApplicationSettingsState)

        __props__.__dict__["abuse_notification_email"] = abuse_notification_email
        __props__.__dict__["admin_mode"] = admin_mode
        __props__.__dict__["after_sign_out_path"] = after_sign_out_path
        __props__.__dict__["after_sign_up_text"] = after_sign_up_text
        __props__.__dict__["akismet_api_key"] = akismet_api_key
        __props__.__dict__["akismet_enabled"] = akismet_enabled
        __props__.__dict__["allow_account_deletion"] = allow_account_deletion
        __props__.__dict__["allow_group_owners_to_manage_ldap"] = allow_group_owners_to_manage_ldap
        __props__.__dict__["allow_local_requests_from_system_hooks"] = allow_local_requests_from_system_hooks
        __props__.__dict__["allow_local_requests_from_web_hooks_and_services"] = allow_local_requests_from_web_hooks_and_services
        __props__.__dict__["allow_project_creation_for_guest_and_below"] = allow_project_creation_for_guest_and_below
        __props__.__dict__["allow_runner_registration_token"] = allow_runner_registration_token
        __props__.__dict__["archive_builds_in_human_readable"] = archive_builds_in_human_readable
        __props__.__dict__["asciidoc_max_includes"] = asciidoc_max_includes
        __props__.__dict__["asset_proxy_allowlists"] = asset_proxy_allowlists
        __props__.__dict__["asset_proxy_enabled"] = asset_proxy_enabled
        __props__.__dict__["asset_proxy_secret_key"] = asset_proxy_secret_key
        __props__.__dict__["asset_proxy_url"] = asset_proxy_url
        __props__.__dict__["authorized_keys_enabled"] = authorized_keys_enabled
        __props__.__dict__["auto_ban_user_on_excessive_projects_download"] = auto_ban_user_on_excessive_projects_download
        __props__.__dict__["auto_devops_domain"] = auto_devops_domain
        __props__.__dict__["auto_devops_enabled"] = auto_devops_enabled
        __props__.__dict__["automatic_purchased_storage_allocation"] = automatic_purchased_storage_allocation
        __props__.__dict__["bulk_import_concurrent_pipeline_batch_limit"] = bulk_import_concurrent_pipeline_batch_limit
        __props__.__dict__["bulk_import_enabled"] = bulk_import_enabled
        __props__.__dict__["bulk_import_max_download_file_size"] = bulk_import_max_download_file_size
        __props__.__dict__["can_create_group"] = can_create_group
        __props__.__dict__["check_namespace_plan"] = check_namespace_plan
        __props__.__dict__["ci_max_includes"] = ci_max_includes
        __props__.__dict__["ci_max_total_yaml_size_bytes"] = ci_max_total_yaml_size_bytes
        __props__.__dict__["commit_email_hostname"] = commit_email_hostname
        __props__.__dict__["concurrent_bitbucket_import_jobs_limit"] = concurrent_bitbucket_import_jobs_limit
        __props__.__dict__["concurrent_bitbucket_server_import_jobs_limit"] = concurrent_bitbucket_server_import_jobs_limit
        __props__.__dict__["concurrent_github_import_jobs_limit"] = concurrent_github_import_jobs_limit
        __props__.__dict__["container_expiration_policies_enable_historic_entries"] = container_expiration_policies_enable_historic_entries
        __props__.__dict__["container_registry_cleanup_tags_service_max_list_size"] = container_registry_cleanup_tags_service_max_list_size
        __props__.__dict__["container_registry_delete_tags_service_timeout"] = container_registry_delete_tags_service_timeout
        __props__.__dict__["container_registry_expiration_policies_caching"] = container_registry_expiration_policies_caching
        __props__.__dict__["container_registry_expiration_policies_worker_capacity"] = container_registry_expiration_policies_worker_capacity
        __props__.__dict__["container_registry_token_expire_delay"] = container_registry_token_expire_delay
        __props__.__dict__["deactivate_dormant_users"] = deactivate_dormant_users
        __props__.__dict__["deactivate_dormant_users_period"] = deactivate_dormant_users_period
        __props__.__dict__["decompress_archive_file_timeout"] = decompress_archive_file_timeout
        __props__.__dict__["default_artifacts_expire_in"] = default_artifacts_expire_in
        __props__.__dict__["default_branch_name"] = default_branch_name
        __props__.__dict__["default_branch_protection"] = default_branch_protection
        __props__.__dict__["default_branch_protection_defaults"] = default_branch_protection_defaults
        __props__.__dict__["default_ci_config_path"] = default_ci_config_path
        __props__.__dict__["default_group_visibility"] = default_group_visibility
        __props__.__dict__["default_preferred_language"] = default_preferred_language
        __props__.__dict__["default_project_creation"] = default_project_creation
        __props__.__dict__["default_project_visibility"] = default_project_visibility
        __props__.__dict__["default_projects_limit"] = default_projects_limit
        __props__.__dict__["default_snippet_visibility"] = default_snippet_visibility
        __props__.__dict__["default_syntax_highlighting_theme"] = default_syntax_highlighting_theme
        __props__.__dict__["delete_inactive_projects"] = delete_inactive_projects
        __props__.__dict__["delete_unconfirmed_users"] = delete_unconfirmed_users
        __props__.__dict__["deletion_adjourned_period"] = deletion_adjourned_period
        __props__.__dict__["diagramsnet_enabled"] = diagramsnet_enabled
        __props__.__dict__["diagramsnet_url"] = diagramsnet_url
        __props__.__dict__["diff_max_files"] = diff_max_files
        __props__.__dict__["diff_max_lines"] = diff_max_lines
        __props__.__dict__["diff_max_patch_bytes"] = diff_max_patch_bytes
        __props__.__dict__["disable_admin_oauth_scopes"] = disable_admin_oauth_scopes
        __props__.__dict__["disable_feed_token"] = disable_feed_token
        __props__.__dict__["disable_personal_access_tokens"] = disable_personal_access_tokens
        __props__.__dict__["disabled_oauth_sign_in_sources"] = disabled_oauth_sign_in_sources
        __props__.__dict__["dns_rebinding_protection_enabled"] = dns_rebinding_protection_enabled
        __props__.__dict__["domain_allowlists"] = domain_allowlists
        __props__.__dict__["domain_denylist_enabled"] = domain_denylist_enabled
        __props__.__dict__["domain_denylists"] = domain_denylists
        __props__.__dict__["downstream_pipeline_trigger_limit_per_project_user_sha"] = downstream_pipeline_trigger_limit_per_project_user_sha
        __props__.__dict__["dsa_key_restriction"] = dsa_key_restriction
        __props__.__dict__["duo_features_enabled"] = duo_features_enabled
        __props__.__dict__["ecdsa_key_restriction"] = ecdsa_key_restriction
        __props__.__dict__["ecdsa_sk_key_restriction"] = ecdsa_sk_key_restriction
        __props__.__dict__["ed25519_key_restriction"] = ed25519_key_restriction
        __props__.__dict__["ed25519_sk_key_restriction"] = ed25519_sk_key_restriction
        __props__.__dict__["eks_access_key_id"] = eks_access_key_id
        __props__.__dict__["eks_account_id"] = eks_account_id
        __props__.__dict__["eks_integration_enabled"] = eks_integration_enabled
        __props__.__dict__["eks_secret_access_key"] = eks_secret_access_key
        __props__.__dict__["elasticsearch_aws"] = elasticsearch_aws
        __props__.__dict__["elasticsearch_aws_access_key"] = elasticsearch_aws_access_key
        __props__.__dict__["elasticsearch_aws_region"] = elasticsearch_aws_region
        __props__.__dict__["elasticsearch_aws_secret_access_key"] = elasticsearch_aws_secret_access_key
        __props__.__dict__["elasticsearch_indexed_field_length_limit"] = elasticsearch_indexed_field_length_limit
        __props__.__dict__["elasticsearch_indexed_file_size_limit_kb"] = elasticsearch_indexed_file_size_limit_kb
        __props__.__dict__["elasticsearch_indexing"] = elasticsearch_indexing
        __props__.__dict__["elasticsearch_limit_indexing"] = elasticsearch_limit_indexing
        __props__.__dict__["elasticsearch_max_bulk_concurrency"] = elasticsearch_max_bulk_concurrency
        __props__.__dict__["elasticsearch_max_bulk_size_mb"] = elasticsearch_max_bulk_size_mb
        __props__.__dict__["elasticsearch_max_code_indexing_concurrency"] = elasticsearch_max_code_indexing_concurrency
        __props__.__dict__["elasticsearch_namespace_ids"] = elasticsearch_namespace_ids
        __props__.__dict__["elasticsearch_password"] = elasticsearch_password
        __props__.__dict__["elasticsearch_project_ids"] = elasticsearch_project_ids
        __props__.__dict__["elasticsearch_requeue_workers"] = elasticsearch_requeue_workers
        __props__.__dict__["elasticsearch_search"] = elasticsearch_search
        __props__.__dict__["elasticsearch_urls"] = elasticsearch_urls
        __props__.__dict__["elasticsearch_username"] = elasticsearch_username
        __props__.__dict__["elasticsearch_worker_number_of_shards"] = elasticsearch_worker_number_of_shards
        __props__.__dict__["email_additional_text"] = email_additional_text
        __props__.__dict__["email_author_in_body"] = email_author_in_body
        __props__.__dict__["email_confirmation_setting"] = email_confirmation_setting
        __props__.__dict__["enable_artifact_external_redirect_warning_page"] = enable_artifact_external_redirect_warning_page
        __props__.__dict__["enabled_git_access_protocol"] = enabled_git_access_protocol
        __props__.__dict__["enforce_namespace_storage_limit"] = enforce_namespace_storage_limit
        __props__.__dict__["enforce_terms"] = enforce_terms
        __props__.__dict__["external_auth_client_cert"] = external_auth_client_cert
        __props__.__dict__["external_auth_client_key"] = external_auth_client_key
        __props__.__dict__["external_auth_client_key_pass"] = external_auth_client_key_pass
        __props__.__dict__["external_authorization_service_default_label"] = external_authorization_service_default_label
        __props__.__dict__["external_authorization_service_enabled"] = external_authorization_service_enabled
        __props__.__dict__["external_authorization_service_timeout"] = external_authorization_service_timeout
        __props__.__dict__["external_authorization_service_url"] = external_authorization_service_url
        __props__.__dict__["external_pipeline_validation_service_timeout"] = external_pipeline_validation_service_timeout
        __props__.__dict__["external_pipeline_validation_service_token"] = external_pipeline_validation_service_token
        __props__.__dict__["external_pipeline_validation_service_url"] = external_pipeline_validation_service_url
        __props__.__dict__["failed_login_attempts_unlock_period_in_minutes"] = failed_login_attempts_unlock_period_in_minutes
        __props__.__dict__["file_template_project_id"] = file_template_project_id
        __props__.__dict__["first_day_of_week"] = first_day_of_week
        __props__.__dict__["geo_node_allowed_ips"] = geo_node_allowed_ips
        __props__.__dict__["geo_status_timeout"] = geo_status_timeout
        __props__.__dict__["git_rate_limit_users_alertlists"] = git_rate_limit_users_alertlists
        __props__.__dict__["git_rate_limit_users_allowlists"] = git_rate_limit_users_allowlists
        __props__.__dict__["git_two_factor_session_expiry"] = git_two_factor_session_expiry
        __props__.__dict__["gitaly_timeout_default"] = gitaly_timeout_default
        __props__.__dict__["gitaly_timeout_fast"] = gitaly_timeout_fast
        __props__.__dict__["gitaly_timeout_medium"] = gitaly_timeout_medium
        __props__.__dict__["gitlab_dedicated_instance"] = gitlab_dedicated_instance
        __props__.__dict__["gitlab_environment_toolkit_instance"] = gitlab_environment_toolkit_instance
        __props__.__dict__["gitlab_shell_operation_limit"] = gitlab_shell_operation_limit
        __props__.__dict__["gitpod_enabled"] = gitpod_enabled
        __props__.__dict__["gitpod_url"] = gitpod_url
        __props__.__dict__["globally_allowed_ips"] = globally_allowed_ips
        __props__.__dict__["grafana_enabled"] = grafana_enabled
        __props__.__dict__["grafana_url"] = grafana_url
        __props__.__dict__["gravatar_enabled"] = gravatar_enabled
        __props__.__dict__["group_owners_can_manage_default_branch_protection"] = group_owners_can_manage_default_branch_protection
        __props__.__dict__["help_page_hide_commercial_content"] = help_page_hide_commercial_content
        __props__.__dict__["help_page_support_url"] = help_page_support_url
        __props__.__dict__["help_page_text"] = help_page_text
        __props__.__dict__["help_text"] = help_text
        __props__.__dict__["hide_third_party_offers"] = hide_third_party_offers
        __props__.__dict__["home_page_url"] = home_page_url
        __props__.__dict__["housekeeping_enabled"] = housekeeping_enabled
        __props__.__dict__["housekeeping_optimize_repository_period"] = housekeeping_optimize_repository_period
        __props__.__dict__["html_emails_enabled"] = html_emails_enabled
        __props__.__dict__["import_sources"] = import_sources
        __props__.__dict__["in_product_marketing_emails_enabled"] = in_product_marketing_emails_enabled
        __props__.__dict__["inactive_projects_delete_after_months"] = inactive_projects_delete_after_months
        __props__.__dict__["inactive_projects_min_size_mb"] = inactive_projects_min_size_mb
        __props__.__dict__["inactive_projects_send_warning_email_after_months"] = inactive_projects_send_warning_email_after_months
        __props__.__dict__["include_optional_metrics_in_service_ping"] = include_optional_metrics_in_service_ping
        __props__.__dict__["invisible_captcha_enabled"] = invisible_captcha_enabled
        __props__.__dict__["issues_create_limit"] = issues_create_limit
        __props__.__dict__["jira_connect_application_key"] = jira_connect_application_key
        __props__.__dict__["jira_connect_proxy_url"] = jira_connect_proxy_url
        __props__.__dict__["jira_connect_public_key_storage_enabled"] = jira_connect_public_key_storage_enabled
        __props__.__dict__["keep_latest_artifact"] = keep_latest_artifact
        __props__.__dict__["local_markdown_version"] = local_markdown_version
        __props__.__dict__["lock_duo_features_enabled"] = lock_duo_features_enabled
        __props__.__dict__["lock_memberships_to_ldap"] = lock_memberships_to_ldap
        __props__.__dict__["mailgun_events_enabled"] = mailgun_events_enabled
        __props__.__dict__["mailgun_signing_key"] = mailgun_signing_key
        __props__.__dict__["maintenance_mode"] = maintenance_mode
        __props__.__dict__["maintenance_mode_message"] = maintenance_mode_message
        __props__.__dict__["maven_package_requests_forwarding"] = maven_package_requests_forwarding
        __props__.__dict__["max_artifacts_size"] = max_artifacts_size
        __props__.__dict__["max_attachment_size"] = max_attachment_size
        __props__.__dict__["max_decompressed_archive_size"] = max_decompressed_archive_size
        __props__.__dict__["max_export_size"] = max_export_size
        __props__.__dict__["max_import_remote_file_size"] = max_import_remote_file_size
        __props__.__dict__["max_import_size"] = max_import_size
        __props__.__dict__["max_login_attempts"] = max_login_attempts
        __props__.__dict__["max_number_of_repository_downloads"] = max_number_of_repository_downloads
        __props__.__dict__["max_number_of_repository_downloads_within_time_period"] = max_number_of_repository_downloads_within_time_period
        __props__.__dict__["max_pages_size"] = max_pages_size
        __props__.__dict__["max_personal_access_token_lifetime"] = max_personal_access_token_lifetime
        __props__.__dict__["max_ssh_key_lifetime"] = max_ssh_key_lifetime
        __props__.__dict__["max_terraform_state_size_bytes"] = max_terraform_state_size_bytes
        __props__.__dict__["metrics_method_call_threshold"] = metrics_method_call_threshold
        __props__.__dict__["minimum_password_length"] = minimum_password_length
        __props__.__dict__["mirror_available"] = mirror_available
        __props__.__dict__["mirror_capacity_threshold"] = mirror_capacity_threshold
        __props__.__dict__["mirror_max_capacity"] = mirror_max_capacity
        __props__.__dict__["mirror_max_delay"] = mirror_max_delay
        __props__.__dict__["npm_package_requests_forwarding"] = npm_package_requests_forwarding
        __props__.__dict__["nuget_skip_metadata_url_validation"] = nuget_skip_metadata_url_validation
        __props__.__dict__["outbound_local_requests_whitelists"] = outbound_local_requests_whitelists
        __props__.__dict__["package_metadata_purl_types"] = package_metadata_purl_types
        __props__.__dict__["package_registry_allow_anyone_to_pull_option"] = package_registry_allow_anyone_to_pull_option
        __props__.__dict__["package_registry_cleanup_policies_worker_capacity"] = package_registry_cleanup_policies_worker_capacity
        __props__.__dict__["pages_domain_verification_enabled"] = pages_domain_verification_enabled
        __props__.__dict__["password_authentication_enabled_for_git"] = password_authentication_enabled_for_git
        __props__.__dict__["password_authentication_enabled_for_web"] = password_authentication_enabled_for_web
        __props__.__dict__["password_lowercase_required"] = password_lowercase_required
        __props__.__dict__["password_number_required"] = password_number_required
        __props__.__dict__["password_symbol_required"] = password_symbol_required
        __props__.__dict__["password_uppercase_required"] = password_uppercase_required
        __props__.__dict__["performance_bar_allowed_group_path"] = performance_bar_allowed_group_path
        __props__.__dict__["personal_access_token_prefix"] = personal_access_token_prefix
        __props__.__dict__["pipeline_limit_per_project_user_sha"] = pipeline_limit_per_project_user_sha
        __props__.__dict__["plantuml_enabled"] = plantuml_enabled
        __props__.__dict__["plantuml_url"] = plantuml_url
        __props__.__dict__["polling_interval_multiplier"] = polling_interval_multiplier
        __props__.__dict__["project_export_enabled"] = project_export_enabled
        __props__.__dict__["project_jobs_api_rate_limit"] = project_jobs_api_rate_limit
        __props__.__dict__["projects_api_rate_limit_unauthenticated"] = projects_api_rate_limit_unauthenticated
        __props__.__dict__["prometheus_metrics_enabled"] = prometheus_metrics_enabled
        __props__.__dict__["protected_ci_variables"] = protected_ci_variables
        __props__.__dict__["push_event_activities_limit"] = push_event_activities_limit
        __props__.__dict__["push_event_hooks_limit"] = push_event_hooks_limit
        __props__.__dict__["pypi_package_requests_forwarding"] = pypi_package_requests_forwarding
        __props__.__dict__["rate_limiting_response_text"] = rate_limiting_response_text
        __props__.__dict__["raw_blob_request_limit"] = raw_blob_request_limit
        __props__.__dict__["recaptcha_enabled"] = recaptcha_enabled
        __props__.__dict__["recaptcha_private_key"] = recaptcha_private_key
        __props__.__dict__["recaptcha_site_key"] = recaptcha_site_key
        __props__.__dict__["receive_max_input_size"] = receive_max_input_size
        __props__.__dict__["receptive_cluster_agents_enabled"] = receptive_cluster_agents_enabled
        __props__.__dict__["remember_me_enabled"] = remember_me_enabled
        __props__.__dict__["repository_checks_enabled"] = repository_checks_enabled
        __props__.__dict__["repository_size_limit"] = repository_size_limit
        __props__.__dict__["repository_storages_weighted"] = repository_storages_weighted
        __props__.__dict__["require_admin_approval_after_user_signup"] = require_admin_approval_after_user_signup
        __props__.__dict__["require_admin_two_factor_authentication"] = require_admin_two_factor_authentication
        __props__.__dict__["require_personal_access_token_expiry"] = require_personal_access_token_expiry
        __props__.__dict__["require_two_factor_authentication"] = require_two_factor_authentication
        __props__.__dict__["restricted_visibility_levels"] = restricted_visibility_levels
        __props__.__dict__["rsa_key_restriction"] = rsa_key_restriction
        __props__.__dict__["search_rate_limit"] = search_rate_limit
        __props__.__dict__["search_rate_limit_unauthenticated"] = search_rate_limit_unauthenticated
        __props__.__dict__["security_approval_policies_limit"] = security_approval_policies_limit
        __props__.__dict__["security_policy_global_group_approvers_enabled"] = security_policy_global_group_approvers_enabled
        __props__.__dict__["security_txt_content"] = security_txt_content
        __props__.__dict__["send_user_confirmation_email"] = send_user_confirmation_email
        __props__.__dict__["service_access_tokens_expiration_enforced"] = service_access_tokens_expiration_enforced
        __props__.__dict__["session_expire_delay"] = session_expire_delay
        __props__.__dict__["shared_runners_enabled"] = shared_runners_enabled
        __props__.__dict__["shared_runners_minutes"] = shared_runners_minutes
        __props__.__dict__["shared_runners_text"] = shared_runners_text
        __props__.__dict__["sidekiq_job_limiter_compression_threshold_bytes"] = sidekiq_job_limiter_compression_threshold_bytes
        __props__.__dict__["sidekiq_job_limiter_limit_bytes"] = sidekiq_job_limiter_limit_bytes
        __props__.__dict__["sidekiq_job_limiter_mode"] = sidekiq_job_limiter_mode
        __props__.__dict__["sign_in_text"] = sign_in_text
        __props__.__dict__["signup_enabled"] = signup_enabled
        __props__.__dict__["silent_admin_exports_enabled"] = silent_admin_exports_enabled
        __props__.__dict__["silent_mode_enabled"] = silent_mode_enabled
        __props__.__dict__["slack_app_enabled"] = slack_app_enabled
        __props__.__dict__["slack_app_id"] = slack_app_id
        __props__.__dict__["slack_app_secret"] = slack_app_secret
        __props__.__dict__["slack_app_signing_secret"] = slack_app_signing_secret
        __props__.__dict__["slack_app_verification_token"] = slack_app_verification_token
        __props__.__dict__["snippet_size_limit"] = snippet_size_limit
        __props__.__dict__["snowplow_app_id"] = snowplow_app_id
        __props__.__dict__["snowplow_collector_hostname"] = snowplow_collector_hostname
        __props__.__dict__["snowplow_cookie_domain"] = snowplow_cookie_domain
        __props__.__dict__["snowplow_database_collector_hostname"] = snowplow_database_collector_hostname
        __props__.__dict__["snowplow_enabled"] = snowplow_enabled
        __props__.__dict__["sourcegraph_enabled"] = sourcegraph_enabled
        __props__.__dict__["sourcegraph_public_only"] = sourcegraph_public_only
        __props__.__dict__["sourcegraph_url"] = sourcegraph_url
        __props__.__dict__["spam_check_api_key"] = spam_check_api_key
        __props__.__dict__["spam_check_endpoint_enabled"] = spam_check_endpoint_enabled
        __props__.__dict__["spam_check_endpoint_url"] = spam_check_endpoint_url
        __props__.__dict__["static_objects_external_storage_auth_token"] = static_objects_external_storage_auth_token
        __props__.__dict__["static_objects_external_storage_url"] = static_objects_external_storage_url
        __props__.__dict__["suggest_pipeline_enabled"] = suggest_pipeline_enabled
        __props__.__dict__["terminal_max_session_time"] = terminal_max_session_time
        __props__.__dict__["terms"] = terms
        __props__.__dict__["throttle_authenticated_api_enabled"] = throttle_authenticated_api_enabled
        __props__.__dict__["throttle_authenticated_api_period_in_seconds"] = throttle_authenticated_api_period_in_seconds
        __props__.__dict__["throttle_authenticated_api_requests_per_period"] = throttle_authenticated_api_requests_per_period
        __props__.__dict__["throttle_authenticated_packages_api_enabled"] = throttle_authenticated_packages_api_enabled
        __props__.__dict__["throttle_authenticated_packages_api_period_in_seconds"] = throttle_authenticated_packages_api_period_in_seconds
        __props__.__dict__["throttle_authenticated_packages_api_requests_per_period"] = throttle_authenticated_packages_api_requests_per_period
        __props__.__dict__["throttle_authenticated_web_enabled"] = throttle_authenticated_web_enabled
        __props__.__dict__["throttle_authenticated_web_period_in_seconds"] = throttle_authenticated_web_period_in_seconds
        __props__.__dict__["throttle_authenticated_web_requests_per_period"] = throttle_authenticated_web_requests_per_period
        __props__.__dict__["throttle_unauthenticated_api_enabled"] = throttle_unauthenticated_api_enabled
        __props__.__dict__["throttle_unauthenticated_api_period_in_seconds"] = throttle_unauthenticated_api_period_in_seconds
        __props__.__dict__["throttle_unauthenticated_api_requests_per_period"] = throttle_unauthenticated_api_requests_per_period
        __props__.__dict__["throttle_unauthenticated_packages_api_enabled"] = throttle_unauthenticated_packages_api_enabled
        __props__.__dict__["throttle_unauthenticated_packages_api_period_in_seconds"] = throttle_unauthenticated_packages_api_period_in_seconds
        __props__.__dict__["throttle_unauthenticated_packages_api_requests_per_period"] = throttle_unauthenticated_packages_api_requests_per_period
        __props__.__dict__["throttle_unauthenticated_web_enabled"] = throttle_unauthenticated_web_enabled
        __props__.__dict__["throttle_unauthenticated_web_period_in_seconds"] = throttle_unauthenticated_web_period_in_seconds
        __props__.__dict__["throttle_unauthenticated_web_requests_per_period"] = throttle_unauthenticated_web_requests_per_period
        __props__.__dict__["time_tracking_limit_to_hours"] = time_tracking_limit_to_hours
        __props__.__dict__["two_factor_grace_period"] = two_factor_grace_period
        __props__.__dict__["unconfirmed_users_delete_after_days"] = unconfirmed_users_delete_after_days
        __props__.__dict__["unique_ips_limit_enabled"] = unique_ips_limit_enabled
        __props__.__dict__["unique_ips_limit_per_user"] = unique_ips_limit_per_user
        __props__.__dict__["unique_ips_limit_time_window"] = unique_ips_limit_time_window
        __props__.__dict__["update_runner_versions_enabled"] = update_runner_versions_enabled
        __props__.__dict__["usage_ping_enabled"] = usage_ping_enabled
        __props__.__dict__["use_clickhouse_for_analytics"] = use_clickhouse_for_analytics
        __props__.__dict__["user_deactivation_emails_enabled"] = user_deactivation_emails_enabled
        __props__.__dict__["user_default_external"] = user_default_external
        __props__.__dict__["user_default_internal_regex"] = user_default_internal_regex
        __props__.__dict__["user_defaults_to_private_profile"] = user_defaults_to_private_profile
        __props__.__dict__["user_oauth_applications"] = user_oauth_applications
        __props__.__dict__["user_show_add_ssh_key_message"] = user_show_add_ssh_key_message
        __props__.__dict__["valid_runner_registrars"] = valid_runner_registrars
        __props__.__dict__["version_check_enabled"] = version_check_enabled
        __props__.__dict__["web_ide_clientside_preview_enabled"] = web_ide_clientside_preview_enabled
        __props__.__dict__["whats_new_variant"] = whats_new_variant
        __props__.__dict__["wiki_page_max_content_bytes"] = wiki_page_max_content_bytes
        return ApplicationSettings(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="abuseNotificationEmail")
    def abuse_notification_email(self) -> pulumi.Output[_builtins.str]:
        """
        If set, abuse reports are sent to this address. Abuse reports are always available in the Admin Area.
        """
        return pulumi.get(self, "abuse_notification_email")

    @_builtins.property
    @pulumi.getter(name="adminMode")
    def admin_mode(self) -> pulumi.Output[_builtins.bool]:
        """
        Require administrators to enable Admin Mode by re-authenticating for administrative tasks.
        """
        return pulumi.get(self, "admin_mode")

    @_builtins.property
    @pulumi.getter(name="afterSignOutPath")
    def after_sign_out_path(self) -> pulumi.Output[_builtins.str]:
        """
        Where to redirect users after logout.
        """
        return pulumi.get(self, "after_sign_out_path")

    @_builtins.property
    @pulumi.getter(name="afterSignUpText")
    def after_sign_up_text(self) -> pulumi.Output[_builtins.str]:
        """
        Text shown to the user after signing up.
        """
        return pulumi.get(self, "after_sign_up_text")

    @_builtins.property
    @pulumi.getter(name="akismetApiKey")
    def akismet_api_key(self) -> pulumi.Output[_builtins.str]:
        """
        API key for Akismet spam protection.
        """
        return pulumi.get(self, "akismet_api_key")

    @_builtins.property
    @pulumi.getter(name="akismetEnabled")
    def akismet_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        (If enabled, requires: akismet*api*key) Enable or disable Akismet spam protection.
        """
        return pulumi.get(self, "akismet_enabled")

    @_builtins.property
    @pulumi.getter(name="allowAccountDeletion")
    def allow_account_deletion(self) -> pulumi.Output[_builtins.bool]:
        """
        Set to true to allow users to delete their accounts. Premium and Ultimate only.
        """
        return pulumi.get(self, "allow_account_deletion")

    @_builtins.property
    @pulumi.getter(name="allowGroupOwnersToManageLdap")
    def allow_group_owners_to_manage_ldap(self) -> pulumi.Output[_builtins.bool]:
        """
        Set to true to allow group owners to manage LDAP.
        """
        return pulumi.get(self, "allow_group_owners_to_manage_ldap")

    @_builtins.property
    @pulumi.getter(name="allowLocalRequestsFromSystemHooks")
    def allow_local_requests_from_system_hooks(self) -> pulumi.Output[_builtins.bool]:
        """
        Allow requests to the local network from system hooks.
        """
        return pulumi.get(self, "allow_local_requests_from_system_hooks")

    @_builtins.property
    @pulumi.getter(name="allowLocalRequestsFromWebHooksAndServices")
    def allow_local_requests_from_web_hooks_and_services(self) -> pulumi.Output[_builtins.bool]:
        """
        Allow requests to the local network from web hooks and services.
        """
        return pulumi.get(self, "allow_local_requests_from_web_hooks_and_services")

    @_builtins.property
    @pulumi.getter(name="allowProjectCreationForGuestAndBelow")
    def allow_project_creation_for_guest_and_below(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates whether users assigned up to the Guest role can create groups and personal projects.
        """
        return pulumi.get(self, "allow_project_creation_for_guest_and_below")

    @_builtins.property
    @pulumi.getter(name="allowRunnerRegistrationToken")
    def allow_runner_registration_token(self) -> pulumi.Output[_builtins.bool]:
        """
        Allow using a registration token to create a runner.
        """
        return pulumi.get(self, "allow_runner_registration_token")

    @_builtins.property
    @pulumi.getter(name="archiveBuildsInHumanReadable")
    def archive_builds_in_human_readable(self) -> pulumi.Output[_builtins.str]:
        """
        Set the duration for which the jobs are considered as old and expired. After that time passes, the jobs are archived and no longer able to be retried. Make it empty to never expire jobs. It has to be no less than 1 day, for example: 15 days, 1 month, 2 years.
        """
        return pulumi.get(self, "archive_builds_in_human_readable")

    @_builtins.property
    @pulumi.getter(name="asciidocMaxIncludes")
    def asciidoc_max_includes(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum limit of AsciiDoc include directives being processed in any one document. Maximum: 64.
        """
        return pulumi.get(self, "asciidoc_max_includes")

    @_builtins.property
    @pulumi.getter(name="assetProxyAllowlists")
    def asset_proxy_allowlists(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Assets that match these domains are not proxied. Wildcards allowed. Your GitLab installation URL is automatically allowlisted. GitLab restart is required to apply changes.
        """
        return pulumi.get(self, "asset_proxy_allowlists")

    @_builtins.property
    @pulumi.getter(name="assetProxyEnabled")
    def asset_proxy_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        (If enabled, requires: asset*proxy*url) Enable proxying of assets. GitLab restart is required to apply changes.
        """
        return pulumi.get(self, "asset_proxy_enabled")

    @_builtins.property
    @pulumi.getter(name="assetProxySecretKey")
    def asset_proxy_secret_key(self) -> pulumi.Output[_builtins.str]:
        """
        Shared secret with the asset proxy server. GitLab restart is required to apply changes.
        """
        return pulumi.get(self, "asset_proxy_secret_key")

    @_builtins.property
    @pulumi.getter(name="assetProxyUrl")
    def asset_proxy_url(self) -> pulumi.Output[_builtins.str]:
        """
        URL of the asset proxy server. GitLab restart is required to apply changes.
        """
        return pulumi.get(self, "asset_proxy_url")

    @_builtins.property
    @pulumi.getter(name="authorizedKeysEnabled")
    def authorized_keys_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        By default, we write to the authorized_keys file to support Git over SSH without additional configuration. GitLab can be optimized to authenticate SSH keys via the database file. Only disable this if you have configured your OpenSSH server to use the AuthorizedKeysCommand.
        """
        return pulumi.get(self, "authorized_keys_enabled")

    @_builtins.property
    @pulumi.getter(name="autoBanUserOnExcessiveProjectsDownload")
    def auto_ban_user_on_excessive_projects_download(self) -> pulumi.Output[_builtins.bool]:
        """
        When enabled, users will get automatically banned from the application when they download more than the maximum number of unique projects in the time period specified by max*number*of*repository*downloads and max*number*of*repository*downloads*within*time_period respectively. Self-managed, Ultimate only.
        """
        return pulumi.get(self, "auto_ban_user_on_excessive_projects_download")

    @_builtins.property
    @pulumi.getter(name="autoDevopsDomain")
    def auto_devops_domain(self) -> pulumi.Output[_builtins.str]:
        """
        Specify a domain to use by default for every project’s Auto Review Apps and Auto Deploy stages.
        """
        return pulumi.get(self, "auto_devops_domain")

    @_builtins.property
    @pulumi.getter(name="autoDevopsEnabled")
    def auto_devops_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable Auto DevOps for projects by default. It automatically builds, tests, and deploys applications based on a predefined CI/CD configuration.
        """
        return pulumi.get(self, "auto_devops_enabled")

    @_builtins.property
    @pulumi.getter(name="automaticPurchasedStorageAllocation")
    def automatic_purchased_storage_allocation(self) -> pulumi.Output[_builtins.bool]:
        """
        Enabling this permits automatic allocation of purchased storage in a namespace.
        """
        return pulumi.get(self, "automatic_purchased_storage_allocation")

    @_builtins.property
    @pulumi.getter(name="bulkImportConcurrentPipelineBatchLimit")
    def bulk_import_concurrent_pipeline_batch_limit(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum simultaneous Direct Transfer batches to process.
        """
        return pulumi.get(self, "bulk_import_concurrent_pipeline_batch_limit")

    @_builtins.property
    @pulumi.getter(name="bulkImportEnabled")
    def bulk_import_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable migrating GitLab groups by direct transfer.
        """
        return pulumi.get(self, "bulk_import_enabled")

    @_builtins.property
    @pulumi.getter(name="bulkImportMaxDownloadFileSize")
    def bulk_import_max_download_file_size(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum download file size when importing from source GitLab instances by direct transfer.
        """
        return pulumi.get(self, "bulk_import_max_download_file_size")

    @_builtins.property
    @pulumi.getter(name="canCreateGroup")
    def can_create_group(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates whether users can create top-level groups.
        """
        return pulumi.get(self, "can_create_group")

    @_builtins.property
    @pulumi.getter(name="checkNamespacePlan")
    def check_namespace_plan(self) -> pulumi.Output[_builtins.bool]:
        """
        Enabling this makes only licensed EE features available to projects if the project namespace’s plan includes the feature or if the project is public.
        """
        return pulumi.get(self, "check_namespace_plan")

    @_builtins.property
    @pulumi.getter(name="ciMaxIncludes")
    def ci_max_includes(self) -> pulumi.Output[_builtins.int]:
        """
        The maximum number of includes per pipeline.
        """
        return pulumi.get(self, "ci_max_includes")

    @_builtins.property
    @pulumi.getter(name="ciMaxTotalYamlSizeBytes")
    def ci_max_total_yaml_size_bytes(self) -> pulumi.Output[_builtins.int]:
        """
        The maximum amount of memory, in bytes, that can be allocated for the pipeline configuration, with all included YAML configuration files.
        """
        return pulumi.get(self, "ci_max_total_yaml_size_bytes")

    @_builtins.property
    @pulumi.getter(name="commitEmailHostname")
    def commit_email_hostname(self) -> pulumi.Output[_builtins.str]:
        """
        Custom hostname (for private commit emails).
        """
        return pulumi.get(self, "commit_email_hostname")

    @_builtins.property
    @pulumi.getter(name="concurrentBitbucketImportJobsLimit")
    def concurrent_bitbucket_import_jobs_limit(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum number of simultaneous import jobs for the Bitbucket Cloud importer.
        """
        return pulumi.get(self, "concurrent_bitbucket_import_jobs_limit")

    @_builtins.property
    @pulumi.getter(name="concurrentBitbucketServerImportJobsLimit")
    def concurrent_bitbucket_server_import_jobs_limit(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum number of simultaneous import jobs for the Bitbucket Server importer.
        """
        return pulumi.get(self, "concurrent_bitbucket_server_import_jobs_limit")

    @_builtins.property
    @pulumi.getter(name="concurrentGithubImportJobsLimit")
    def concurrent_github_import_jobs_limit(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum number of simultaneous import jobs for the GitHub importer.
        """
        return pulumi.get(self, "concurrent_github_import_jobs_limit")

    @_builtins.property
    @pulumi.getter(name="containerExpirationPoliciesEnableHistoricEntries")
    def container_expiration_policies_enable_historic_entries(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable cleanup policies for all projects.
        """
        return pulumi.get(self, "container_expiration_policies_enable_historic_entries")

    @_builtins.property
    @pulumi.getter(name="containerRegistryCleanupTagsServiceMaxListSize")
    def container_registry_cleanup_tags_service_max_list_size(self) -> pulumi.Output[_builtins.int]:
        """
        The maximum number of tags that can be deleted in a single execution of cleanup policies.
        """
        return pulumi.get(self, "container_registry_cleanup_tags_service_max_list_size")

    @_builtins.property
    @pulumi.getter(name="containerRegistryDeleteTagsServiceTimeout")
    def container_registry_delete_tags_service_timeout(self) -> pulumi.Output[_builtins.int]:
        """
        The maximum time, in seconds, that the cleanup process can take to delete a batch of tags for cleanup policies.
        """
        return pulumi.get(self, "container_registry_delete_tags_service_timeout")

    @_builtins.property
    @pulumi.getter(name="containerRegistryExpirationPoliciesCaching")
    def container_registry_expiration_policies_caching(self) -> pulumi.Output[_builtins.bool]:
        """
        Caching during the execution of cleanup policies.
        """
        return pulumi.get(self, "container_registry_expiration_policies_caching")

    @_builtins.property
    @pulumi.getter(name="containerRegistryExpirationPoliciesWorkerCapacity")
    def container_registry_expiration_policies_worker_capacity(self) -> pulumi.Output[_builtins.int]:
        """
        Number of workers for cleanup policies.
        """
        return pulumi.get(self, "container_registry_expiration_policies_worker_capacity")

    @_builtins.property
    @pulumi.getter(name="containerRegistryTokenExpireDelay")
    def container_registry_token_expire_delay(self) -> pulumi.Output[_builtins.int]:
        """
        Container Registry token duration in minutes.
        """
        return pulumi.get(self, "container_registry_token_expire_delay")

    @_builtins.property
    @pulumi.getter(name="deactivateDormantUsers")
    def deactivate_dormant_users(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable automatic deactivation of dormant users.
        """
        return pulumi.get(self, "deactivate_dormant_users")

    @_builtins.property
    @pulumi.getter(name="deactivateDormantUsersPeriod")
    def deactivate_dormant_users_period(self) -> pulumi.Output[_builtins.int]:
        """
        Length of time (in days) after which a user is considered dormant.
        """
        return pulumi.get(self, "deactivate_dormant_users_period")

    @_builtins.property
    @pulumi.getter(name="decompressArchiveFileTimeout")
    def decompress_archive_file_timeout(self) -> pulumi.Output[_builtins.int]:
        """
        Default timeout for decompressing archived files, in seconds. Set to 0 to disable timeouts.
        """
        return pulumi.get(self, "decompress_archive_file_timeout")

    @_builtins.property
    @pulumi.getter(name="defaultArtifactsExpireIn")
    def default_artifacts_expire_in(self) -> pulumi.Output[_builtins.str]:
        """
        Set the default expiration time for each job’s artifacts.
        """
        return pulumi.get(self, "default_artifacts_expire_in")

    @_builtins.property
    @pulumi.getter(name="defaultBranchName")
    def default_branch_name(self) -> pulumi.Output[_builtins.str]:
        """
        Instance-level custom initial branch name
        """
        return pulumi.get(self, "default_branch_name")

    @_builtins.property
    @pulumi.getter(name="defaultBranchProtection")
    @_utilities.deprecated("""Use `default_branch_protection_defaults` instead. To be removed in 19.0.""")
    def default_branch_protection(self) -> pulumi.Output[_builtins.int]:
        """
        Determine if developers can push to the default branch. Can take: 0 (not protected, both users with the Developer role or Maintainer role can push new commits and force push), 1 (partially protected, users with the Developer role or Maintainer role can push new commits, but cannot force push) or 2 (fully protected, users with the Developer or Maintainer role cannot push new commits, but users with the Developer or Maintainer role can; no one can force push) as a parameter. Default is 2. Use `default_branch_protection_defaults` instead. To be removed in 19.0.
        """
        return pulumi.get(self, "default_branch_protection")

    @_builtins.property
    @pulumi.getter(name="defaultBranchProtectionDefaults")
    def default_branch_protection_defaults(self) -> pulumi.Output['outputs.ApplicationSettingsDefaultBranchProtectionDefaults']:
        """
        The default*branch*protection*defaults attribute describes the default branch protection defaults. All parameters are optional.
        """
        return pulumi.get(self, "default_branch_protection_defaults")

    @_builtins.property
    @pulumi.getter(name="defaultCiConfigPath")
    def default_ci_config_path(self) -> pulumi.Output[_builtins.str]:
        """
        Default CI/CD configuration file and path for new projects (.gitlab-ci.yml if not set).
        """
        return pulumi.get(self, "default_ci_config_path")

    @_builtins.property
    @pulumi.getter(name="defaultGroupVisibility")
    def default_group_visibility(self) -> pulumi.Output[_builtins.str]:
        """
        What visibility level new groups receive. Can take private, internal and public as a parameter.
        """
        return pulumi.get(self, "default_group_visibility")

    @_builtins.property
    @pulumi.getter(name="defaultPreferredLanguage")
    def default_preferred_language(self) -> pulumi.Output[_builtins.str]:
        """
        Default preferred language for users who are not logged in.
        """
        return pulumi.get(self, "default_preferred_language")

    @_builtins.property
    @pulumi.getter(name="defaultProjectCreation")
    def default_project_creation(self) -> pulumi.Output[_builtins.int]:
        """
        Default project creation protection. Can take: 0 (No one), 1 (Maintainers) or 2 (Developers + Maintainers).
        """
        return pulumi.get(self, "default_project_creation")

    @_builtins.property
    @pulumi.getter(name="defaultProjectVisibility")
    def default_project_visibility(self) -> pulumi.Output[_builtins.str]:
        """
        What visibility level new projects receive. Can take private, internal and public as a parameter.
        """
        return pulumi.get(self, "default_project_visibility")

    @_builtins.property
    @pulumi.getter(name="defaultProjectsLimit")
    def default_projects_limit(self) -> pulumi.Output[_builtins.int]:
        """
        Project limit per user.
        """
        return pulumi.get(self, "default_projects_limit")

    @_builtins.property
    @pulumi.getter(name="defaultSnippetVisibility")
    def default_snippet_visibility(self) -> pulumi.Output[_builtins.str]:
        """
        What visibility level new snippets receive. Can take private, internal and public as a parameter.
        """
        return pulumi.get(self, "default_snippet_visibility")

    @_builtins.property
    @pulumi.getter(name="defaultSyntaxHighlightingTheme")
    def default_syntax_highlighting_theme(self) -> pulumi.Output[_builtins.int]:
        """
        Default syntax highlighting theme for users who are new or not signed in. See IDs of available themes (https://gitlab.com/gitlab-org/gitlab/blob/master/lib/gitlab/themes.rb#L16)
        """
        return pulumi.get(self, "default_syntax_highlighting_theme")

    @_builtins.property
    @pulumi.getter(name="deleteInactiveProjects")
    def delete_inactive_projects(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable inactive project deletion feature.
        """
        return pulumi.get(self, "delete_inactive_projects")

    @_builtins.property
    @pulumi.getter(name="deleteUnconfirmedUsers")
    def delete_unconfirmed_users(self) -> pulumi.Output[_builtins.bool]:
        """
        Specifies whether users who have not confirmed their email should be deleted. When set to true, unconfirmed users are deleted after unconfirmed*users*delete*after*days days. Self-managed, Premium and Ultimate only.
        """
        return pulumi.get(self, "delete_unconfirmed_users")

    @_builtins.property
    @pulumi.getter(name="deletionAdjournedPeriod")
    def deletion_adjourned_period(self) -> pulumi.Output[_builtins.int]:
        """
        The number of days to wait before deleting a project or group that is marked for deletion. Value must be between 1 and 90.
        """
        return pulumi.get(self, "deletion_adjourned_period")

    @_builtins.property
    @pulumi.getter(name="diagramsnetEnabled")
    def diagramsnet_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        (If enabled, requires diagramsnet_url) Enable Diagrams.net integration.
        """
        return pulumi.get(self, "diagramsnet_enabled")

    @_builtins.property
    @pulumi.getter(name="diagramsnetUrl")
    def diagramsnet_url(self) -> pulumi.Output[_builtins.str]:
        """
        The Diagrams.net instance URL for integration.
        """
        return pulumi.get(self, "diagramsnet_url")

    @_builtins.property
    @pulumi.getter(name="diffMaxFiles")
    def diff_max_files(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum files in a diff.
        """
        return pulumi.get(self, "diff_max_files")

    @_builtins.property
    @pulumi.getter(name="diffMaxLines")
    def diff_max_lines(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum lines in a diff.
        """
        return pulumi.get(self, "diff_max_lines")

    @_builtins.property
    @pulumi.getter(name="diffMaxPatchBytes")
    def diff_max_patch_bytes(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum diff patch size, in bytes.
        """
        return pulumi.get(self, "diff_max_patch_bytes")

    @_builtins.property
    @pulumi.getter(name="disableAdminOauthScopes")
    def disable_admin_oauth_scopes(self) -> pulumi.Output[_builtins.bool]:
        """
        Stops administrators from connecting their GitLab accounts to non-trusted OAuth 2.0 applications that have the api, read*api, read*repository, write*repository, read*registry, write_registry, or sudo scopes.
        """
        return pulumi.get(self, "disable_admin_oauth_scopes")

    @_builtins.property
    @pulumi.getter(name="disableFeedToken")
    def disable_feed_token(self) -> pulumi.Output[_builtins.bool]:
        """
        Disable display of RSS/Atom and calendar feed tokens.
        """
        return pulumi.get(self, "disable_feed_token")

    @_builtins.property
    @pulumi.getter(name="disablePersonalAccessTokens")
    def disable_personal_access_tokens(self) -> pulumi.Output[_builtins.bool]:
        """
        Disable personal access tokens. Self-managed, Premium and Ultimate only. There is no method available to enable a personal access token that’s been disabled through the API. This is a known issue.
        """
        return pulumi.get(self, "disable_personal_access_tokens")

    @_builtins.property
    @pulumi.getter(name="disabledOauthSignInSources")
    def disabled_oauth_sign_in_sources(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Disabled OAuth sign-in sources.
        """
        return pulumi.get(self, "disabled_oauth_sign_in_sources")

    @_builtins.property
    @pulumi.getter(name="dnsRebindingProtectionEnabled")
    def dns_rebinding_protection_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enforce DNS rebinding attack protection.
        """
        return pulumi.get(self, "dns_rebinding_protection_enabled")

    @_builtins.property
    @pulumi.getter(name="domainAllowlists")
    def domain_allowlists(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Force people to use only corporate emails for sign-up. Null means there is no restriction.
        """
        return pulumi.get(self, "domain_allowlists")

    @_builtins.property
    @pulumi.getter(name="domainDenylistEnabled")
    def domain_denylist_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        (If enabled, requires: domain_denylist) Allows blocking sign-ups from emails from specific domains.
        """
        return pulumi.get(self, "domain_denylist_enabled")

    @_builtins.property
    @pulumi.getter(name="domainDenylists")
    def domain_denylists(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Users with email addresses that match these domains cannot sign up. Wildcards allowed. Use separate lines for multiple entries. Ex: domain.com, *.domain.com.
        """
        return pulumi.get(self, "domain_denylists")

    @_builtins.property
    @pulumi.getter(name="downstreamPipelineTriggerLimitPerProjectUserSha")
    def downstream_pipeline_trigger_limit_per_project_user_sha(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum downstream pipeline trigger rate.
        """
        return pulumi.get(self, "downstream_pipeline_trigger_limit_per_project_user_sha")

    @_builtins.property
    @pulumi.getter(name="dsaKeyRestriction")
    def dsa_key_restriction(self) -> pulumi.Output[_builtins.int]:
        """
        The minimum allowed bit length of an uploaded DSA key. 0 means no restriction. -1 disables DSA keys.
        """
        return pulumi.get(self, "dsa_key_restriction")

    @_builtins.property
    @pulumi.getter(name="duoFeaturesEnabled")
    def duo_features_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates whether GitLab Duo features are enabled for this instance. Self-managed, Premium and Ultimate only.
        """
        return pulumi.get(self, "duo_features_enabled")

    @_builtins.property
    @pulumi.getter(name="ecdsaKeyRestriction")
    def ecdsa_key_restriction(self) -> pulumi.Output[_builtins.int]:
        """
        The minimum allowed curve size (in bits) of an uploaded ECDSA key. 0 means no restriction. -1 disables ECDSA keys.
        """
        return pulumi.get(self, "ecdsa_key_restriction")

    @_builtins.property
    @pulumi.getter(name="ecdsaSkKeyRestriction")
    def ecdsa_sk_key_restriction(self) -> pulumi.Output[_builtins.int]:
        """
        The minimum allowed curve size (in bits) of an uploaded ECDSA*SK key. 0 means no restriction. -1 disables ECDSA*SK keys.
        """
        return pulumi.get(self, "ecdsa_sk_key_restriction")

    @_builtins.property
    @pulumi.getter(name="ed25519KeyRestriction")
    def ed25519_key_restriction(self) -> pulumi.Output[_builtins.int]:
        """
        The minimum allowed curve size (in bits) of an uploaded ED25519 key. 0 means no restriction. -1 disables ED25519 keys.
        """
        return pulumi.get(self, "ed25519_key_restriction")

    @_builtins.property
    @pulumi.getter(name="ed25519SkKeyRestriction")
    def ed25519_sk_key_restriction(self) -> pulumi.Output[_builtins.int]:
        """
        The minimum allowed curve size (in bits) of an uploaded ED25519*SK key. 0 means no restriction. -1 disables ED25519*SK keys.
        """
        return pulumi.get(self, "ed25519_sk_key_restriction")

    @_builtins.property
    @pulumi.getter(name="eksAccessKeyId")
    def eks_access_key_id(self) -> pulumi.Output[_builtins.str]:
        """
        AWS IAM access key ID.
        """
        return pulumi.get(self, "eks_access_key_id")

    @_builtins.property
    @pulumi.getter(name="eksAccountId")
    def eks_account_id(self) -> pulumi.Output[_builtins.str]:
        """
        Amazon account ID.
        """
        return pulumi.get(self, "eks_account_id")

    @_builtins.property
    @pulumi.getter(name="eksIntegrationEnabled")
    def eks_integration_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable integration with Amazon EKS.
        """
        return pulumi.get(self, "eks_integration_enabled")

    @_builtins.property
    @pulumi.getter(name="eksSecretAccessKey")
    def eks_secret_access_key(self) -> pulumi.Output[_builtins.str]:
        """
        AWS IAM secret access key.
        """
        return pulumi.get(self, "eks_secret_access_key")

    @_builtins.property
    @pulumi.getter(name="elasticsearchAws")
    def elasticsearch_aws(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable the use of AWS hosted Elasticsearch.
        """
        return pulumi.get(self, "elasticsearch_aws")

    @_builtins.property
    @pulumi.getter(name="elasticsearchAwsAccessKey")
    def elasticsearch_aws_access_key(self) -> pulumi.Output[_builtins.str]:
        """
        AWS IAM access key.
        """
        return pulumi.get(self, "elasticsearch_aws_access_key")

    @_builtins.property
    @pulumi.getter(name="elasticsearchAwsRegion")
    def elasticsearch_aws_region(self) -> pulumi.Output[_builtins.str]:
        """
        The AWS region the Elasticsearch domain is configured.
        """
        return pulumi.get(self, "elasticsearch_aws_region")

    @_builtins.property
    @pulumi.getter(name="elasticsearchAwsSecretAccessKey")
    def elasticsearch_aws_secret_access_key(self) -> pulumi.Output[_builtins.str]:
        """
        AWS IAM secret access key.
        """
        return pulumi.get(self, "elasticsearch_aws_secret_access_key")

    @_builtins.property
    @pulumi.getter(name="elasticsearchIndexedFieldLengthLimit")
    def elasticsearch_indexed_field_length_limit(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum size of text fields to index by Elasticsearch. 0 value means no limit. This does not apply to repository and wiki indexing.
        """
        return pulumi.get(self, "elasticsearch_indexed_field_length_limit")

    @_builtins.property
    @pulumi.getter(name="elasticsearchIndexedFileSizeLimitKb")
    def elasticsearch_indexed_file_size_limit_kb(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum size of repository and wiki files that are indexed by Elasticsearch.
        """
        return pulumi.get(self, "elasticsearch_indexed_file_size_limit_kb")

    @_builtins.property
    @pulumi.getter(name="elasticsearchIndexing")
    def elasticsearch_indexing(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable Elasticsearch indexing.
        """
        return pulumi.get(self, "elasticsearch_indexing")

    @_builtins.property
    @pulumi.getter(name="elasticsearchLimitIndexing")
    def elasticsearch_limit_indexing(self) -> pulumi.Output[_builtins.bool]:
        """
        Limit Elasticsearch to index certain namespaces and projects.
        """
        return pulumi.get(self, "elasticsearch_limit_indexing")

    @_builtins.property
    @pulumi.getter(name="elasticsearchMaxBulkConcurrency")
    def elasticsearch_max_bulk_concurrency(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum concurrency of Elasticsearch bulk requests per indexing operation. This only applies to repository indexing operations.
        """
        return pulumi.get(self, "elasticsearch_max_bulk_concurrency")

    @_builtins.property
    @pulumi.getter(name="elasticsearchMaxBulkSizeMb")
    def elasticsearch_max_bulk_size_mb(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum size of Elasticsearch bulk indexing requests in MB. This only applies to repository indexing operations.
        """
        return pulumi.get(self, "elasticsearch_max_bulk_size_mb")

    @_builtins.property
    @pulumi.getter(name="elasticsearchMaxCodeIndexingConcurrency")
    def elasticsearch_max_code_indexing_concurrency(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum concurrency of Elasticsearch code indexing background jobs. This only applies to repository indexing operations. Premium and Ultimate only.
        """
        return pulumi.get(self, "elasticsearch_max_code_indexing_concurrency")

    @_builtins.property
    @pulumi.getter(name="elasticsearchNamespaceIds")
    def elasticsearch_namespace_ids(self) -> pulumi.Output[Sequence[_builtins.int]]:
        """
        The namespaces to index via Elasticsearch if elasticsearch*limit*indexing is enabled.
        """
        return pulumi.get(self, "elasticsearch_namespace_ids")

    @_builtins.property
    @pulumi.getter(name="elasticsearchPassword")
    def elasticsearch_password(self) -> pulumi.Output[_builtins.str]:
        """
        The password of your Elasticsearch instance.
        """
        return pulumi.get(self, "elasticsearch_password")

    @_builtins.property
    @pulumi.getter(name="elasticsearchProjectIds")
    def elasticsearch_project_ids(self) -> pulumi.Output[Sequence[_builtins.int]]:
        """
        The projects to index via Elasticsearch if elasticsearch*limit*indexing is enabled.
        """
        return pulumi.get(self, "elasticsearch_project_ids")

    @_builtins.property
    @pulumi.getter(name="elasticsearchRequeueWorkers")
    def elasticsearch_requeue_workers(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable automatic requeuing of indexing workers. This improves non-code indexing throughput by enqueuing Sidekiq jobs until all documents are processed. Premium and Ultimate only.
        """
        return pulumi.get(self, "elasticsearch_requeue_workers")

    @_builtins.property
    @pulumi.getter(name="elasticsearchSearch")
    def elasticsearch_search(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable Elasticsearch search.
        """
        return pulumi.get(self, "elasticsearch_search")

    @_builtins.property
    @pulumi.getter(name="elasticsearchUrls")
    def elasticsearch_urls(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        The URL to use for connecting to Elasticsearch. Use a comma-separated list to support cluster (for example, http://localhost:9200, http://localhost:9201).
        """
        return pulumi.get(self, "elasticsearch_urls")

    @_builtins.property
    @pulumi.getter(name="elasticsearchUsername")
    def elasticsearch_username(self) -> pulumi.Output[_builtins.str]:
        """
        The username of your Elasticsearch instance.
        """
        return pulumi.get(self, "elasticsearch_username")

    @_builtins.property
    @pulumi.getter(name="elasticsearchWorkerNumberOfShards")
    def elasticsearch_worker_number_of_shards(self) -> pulumi.Output[_builtins.int]:
        """
        Number of indexing worker shards. This improves non-code indexing throughput by enqueuing more parallel Sidekiq jobs. Premium and Ultimate only.
        """
        return pulumi.get(self, "elasticsearch_worker_number_of_shards")

    @_builtins.property
    @pulumi.getter(name="emailAdditionalText")
    def email_additional_text(self) -> pulumi.Output[_builtins.str]:
        """
        Additional text added to the bottom of every email for legal/auditing/compliance reasons.
        """
        return pulumi.get(self, "email_additional_text")

    @_builtins.property
    @pulumi.getter(name="emailAuthorInBody")
    def email_author_in_body(self) -> pulumi.Output[_builtins.bool]:
        """
        Some email servers do not support overriding the email sender name. Enable this option to include the name of the author of the issue, merge request or comment in the email body instead.
        """
        return pulumi.get(self, "email_author_in_body")

    @_builtins.property
    @pulumi.getter(name="emailConfirmationSetting")
    def email_confirmation_setting(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies whether users must confirm their email before sign in. Possible values are off, soft, and hard.
        """
        return pulumi.get(self, "email_confirmation_setting")

    @_builtins.property
    @pulumi.getter(name="enableArtifactExternalRedirectWarningPage")
    def enable_artifact_external_redirect_warning_page(self) -> pulumi.Output[_builtins.bool]:
        """
        Show the external redirect page that warns you about user-generated content in GitLab Pages.
        """
        return pulumi.get(self, "enable_artifact_external_redirect_warning_page")

    @_builtins.property
    @pulumi.getter(name="enabledGitAccessProtocol")
    def enabled_git_access_protocol(self) -> pulumi.Output[_builtins.str]:
        """
        Enabled protocols for Git access. Allowed values are: ssh, http, and nil to allow both protocols.
        """
        return pulumi.get(self, "enabled_git_access_protocol")

    @_builtins.property
    @pulumi.getter(name="enforceNamespaceStorageLimit")
    def enforce_namespace_storage_limit(self) -> pulumi.Output[_builtins.bool]:
        """
        Enabling this permits enforcement of namespace storage limits.
        """
        return pulumi.get(self, "enforce_namespace_storage_limit")

    @_builtins.property
    @pulumi.getter(name="enforceTerms")
    def enforce_terms(self) -> pulumi.Output[_builtins.bool]:
        """
        (If enabled, requires: terms) Enforce application ToS to all users.
        """
        return pulumi.get(self, "enforce_terms")

    @_builtins.property
    @pulumi.getter(name="externalAuthClientCert")
    def external_auth_client_cert(self) -> pulumi.Output[_builtins.str]:
        """
        (If enabled, requires: external*auth*client_key) The certificate to use to authenticate with the external authorization service.
        """
        return pulumi.get(self, "external_auth_client_cert")

    @_builtins.property
    @pulumi.getter(name="externalAuthClientKey")
    def external_auth_client_key(self) -> pulumi.Output[_builtins.str]:
        """
        Private key for the certificate when authentication is required for the external authorization service, this is encrypted when stored.
        """
        return pulumi.get(self, "external_auth_client_key")

    @_builtins.property
    @pulumi.getter(name="externalAuthClientKeyPass")
    def external_auth_client_key_pass(self) -> pulumi.Output[_builtins.str]:
        """
        Passphrase to use for the private key when authenticating with the external service this is encrypted when stored.
        """
        return pulumi.get(self, "external_auth_client_key_pass")

    @_builtins.property
    @pulumi.getter(name="externalAuthorizationServiceDefaultLabel")
    def external_authorization_service_default_label(self) -> pulumi.Output[_builtins.str]:
        """
        The default classification label to use when requesting authorization and no classification label has been specified on the project.
        """
        return pulumi.get(self, "external_authorization_service_default_label")

    @_builtins.property
    @pulumi.getter(name="externalAuthorizationServiceEnabled")
    def external_authorization_service_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        (If enabled, requires: external*authorization*service*default*label, external*authorization*service*timeout and external*authorization*service*url) Enable using an external authorization service for accessing projects.
        """
        return pulumi.get(self, "external_authorization_service_enabled")

    @_builtins.property
    @pulumi.getter(name="externalAuthorizationServiceTimeout")
    def external_authorization_service_timeout(self) -> pulumi.Output[_builtins.float]:
        """
        The timeout after which an authorization request is aborted, in seconds. When a request times out, access is denied to the user. (min: 0.001, max: 10, step: 0.001).
        """
        return pulumi.get(self, "external_authorization_service_timeout")

    @_builtins.property
    @pulumi.getter(name="externalAuthorizationServiceUrl")
    def external_authorization_service_url(self) -> pulumi.Output[_builtins.str]:
        """
        URL to which authorization requests are directed.
        """
        return pulumi.get(self, "external_authorization_service_url")

    @_builtins.property
    @pulumi.getter(name="externalPipelineValidationServiceTimeout")
    def external_pipeline_validation_service_timeout(self) -> pulumi.Output[_builtins.int]:
        """
        How long to wait for a response from the pipeline validation service. Assumes OK if it times out.
        """
        return pulumi.get(self, "external_pipeline_validation_service_timeout")

    @_builtins.property
    @pulumi.getter(name="externalPipelineValidationServiceToken")
    def external_pipeline_validation_service_token(self) -> pulumi.Output[_builtins.str]:
        """
        Optional. Token to include as the X-Gitlab-Token header in requests to the URL in external*pipeline*validation*service*url.
        """
        return pulumi.get(self, "external_pipeline_validation_service_token")

    @_builtins.property
    @pulumi.getter(name="externalPipelineValidationServiceUrl")
    def external_pipeline_validation_service_url(self) -> pulumi.Output[_builtins.str]:
        """
        URL to use for pipeline validation requests.
        """
        return pulumi.get(self, "external_pipeline_validation_service_url")

    @_builtins.property
    @pulumi.getter(name="failedLoginAttemptsUnlockPeriodInMinutes")
    def failed_login_attempts_unlock_period_in_minutes(self) -> pulumi.Output[_builtins.int]:
        """
        Time period in minutes after which the user is unlocked when maximum number of failed sign-in attempts reached.
        """
        return pulumi.get(self, "failed_login_attempts_unlock_period_in_minutes")

    @_builtins.property
    @pulumi.getter(name="fileTemplateProjectId")
    def file_template_project_id(self) -> pulumi.Output[_builtins.int]:
        """
        The ID of a project to load custom file templates from.
        """
        return pulumi.get(self, "file_template_project_id")

    @_builtins.property
    @pulumi.getter(name="firstDayOfWeek")
    def first_day_of_week(self) -> pulumi.Output[_builtins.int]:
        """
        Start day of the week for calendar views and date pickers. Valid values are 0 for Sunday, 1 for Monday, and 6 for Saturday.
        """
        return pulumi.get(self, "first_day_of_week")

    @_builtins.property
    @pulumi.getter(name="geoNodeAllowedIps")
    def geo_node_allowed_ips(self) -> pulumi.Output[_builtins.str]:
        """
        Comma-separated list of IPs and CIDRs of allowed secondary nodes. For example, 1.1.1.1, 2.2.2.0/24.
        """
        return pulumi.get(self, "geo_node_allowed_ips")

    @_builtins.property
    @pulumi.getter(name="geoStatusTimeout")
    def geo_status_timeout(self) -> pulumi.Output[_builtins.int]:
        """
        The amount of seconds after which a request to get a secondary node status times out.
        """
        return pulumi.get(self, "geo_status_timeout")

    @_builtins.property
    @pulumi.getter(name="gitRateLimitUsersAlertlists")
    def git_rate_limit_users_alertlists(self) -> pulumi.Output[Sequence[_builtins.int]]:
        """
        List of user IDs that are emailed when the Git abuse rate limit is exceeded. Maximum: 100 user IDs. Self-managed, Ultimate only.
        """
        return pulumi.get(self, "git_rate_limit_users_alertlists")

    @_builtins.property
    @pulumi.getter(name="gitRateLimitUsersAllowlists")
    def git_rate_limit_users_allowlists(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        List of usernames excluded from Git anti-abuse rate limits. Maximum: 100 usernames. Self-managed, Ultimate only.
        """
        return pulumi.get(self, "git_rate_limit_users_allowlists")

    @_builtins.property
    @pulumi.getter(name="gitTwoFactorSessionExpiry")
    def git_two_factor_session_expiry(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum duration (in minutes) of a session for Git operations when 2FA is enabled.
        """
        return pulumi.get(self, "git_two_factor_session_expiry")

    @_builtins.property
    @pulumi.getter(name="gitalyTimeoutDefault")
    def gitaly_timeout_default(self) -> pulumi.Output[_builtins.int]:
        """
        Default Gitaly timeout, in seconds. This timeout is not enforced for Git fetch/push operations or Sidekiq jobs. Set to 0 to disable timeouts.
        """
        return pulumi.get(self, "gitaly_timeout_default")

    @_builtins.property
    @pulumi.getter(name="gitalyTimeoutFast")
    def gitaly_timeout_fast(self) -> pulumi.Output[_builtins.int]:
        """
        Gitaly fast operation timeout, in seconds. Some Gitaly operations are expected to be fast. If they exceed this threshold, there may be a problem with a storage shard and ‘failing fast’ can help maintain the stability of the GitLab instance. Set to 0 to disable timeouts.
        """
        return pulumi.get(self, "gitaly_timeout_fast")

    @_builtins.property
    @pulumi.getter(name="gitalyTimeoutMedium")
    def gitaly_timeout_medium(self) -> pulumi.Output[_builtins.int]:
        """
        Medium Gitaly timeout, in seconds. This should be a value between the Fast and the Default timeout. Set to 0 to disable timeouts.
        """
        return pulumi.get(self, "gitaly_timeout_medium")

    @_builtins.property
    @pulumi.getter(name="gitlabDedicatedInstance")
    def gitlab_dedicated_instance(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates whether the instance was provisioned for GitLab Dedicated.
        """
        return pulumi.get(self, "gitlab_dedicated_instance")

    @_builtins.property
    @pulumi.getter(name="gitlabEnvironmentToolkitInstance")
    def gitlab_environment_toolkit_instance(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates whether the instance was provisioned with the GitLab Environment Toolkit for Service Ping reporting.
        """
        return pulumi.get(self, "gitlab_environment_toolkit_instance")

    @_builtins.property
    @pulumi.getter(name="gitlabShellOperationLimit")
    def gitlab_shell_operation_limit(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum number of Git operations per minute a user can perform.
        """
        return pulumi.get(self, "gitlab_shell_operation_limit")

    @_builtins.property
    @pulumi.getter(name="gitpodEnabled")
    def gitpod_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable Gitpod integration.
        """
        return pulumi.get(self, "gitpod_enabled")

    @_builtins.property
    @pulumi.getter(name="gitpodUrl")
    def gitpod_url(self) -> pulumi.Output[_builtins.str]:
        """
        The Gitpod instance URL for integration.
        """
        return pulumi.get(self, "gitpod_url")

    @_builtins.property
    @pulumi.getter(name="globallyAllowedIps")
    def globally_allowed_ips(self) -> pulumi.Output[_builtins.str]:
        """
        Comma-separated list of IP addresses and CIDRs always allowed for inbound traffic. For example, 1.1.1.1, 2.2.2.0/24.
        """
        return pulumi.get(self, "globally_allowed_ips")

    @_builtins.property
    @pulumi.getter(name="grafanaEnabled")
    def grafana_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable Grafana.
        """
        return pulumi.get(self, "grafana_enabled")

    @_builtins.property
    @pulumi.getter(name="grafanaUrl")
    def grafana_url(self) -> pulumi.Output[_builtins.str]:
        """
        Grafana URL.
        """
        return pulumi.get(self, "grafana_url")

    @_builtins.property
    @pulumi.getter(name="gravatarEnabled")
    def gravatar_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable Gravatar.
        """
        return pulumi.get(self, "gravatar_enabled")

    @_builtins.property
    @pulumi.getter(name="groupOwnersCanManageDefaultBranchProtection")
    def group_owners_can_manage_default_branch_protection(self) -> pulumi.Output[_builtins.bool]:
        """
        Prevent overrides of default branch protection.
        """
        return pulumi.get(self, "group_owners_can_manage_default_branch_protection")

    @_builtins.property
    @pulumi.getter(name="helpPageHideCommercialContent")
    def help_page_hide_commercial_content(self) -> pulumi.Output[_builtins.bool]:
        """
        Hide marketing-related entries from help.
        """
        return pulumi.get(self, "help_page_hide_commercial_content")

    @_builtins.property
    @pulumi.getter(name="helpPageSupportUrl")
    def help_page_support_url(self) -> pulumi.Output[_builtins.str]:
        """
        Alternate support URL for help page and help dropdown.
        """
        return pulumi.get(self, "help_page_support_url")

    @_builtins.property
    @pulumi.getter(name="helpPageText")
    def help_page_text(self) -> pulumi.Output[_builtins.str]:
        """
        Custom text displayed on the help page.
        """
        return pulumi.get(self, "help_page_text")

    @_builtins.property
    @pulumi.getter(name="helpText")
    def help_text(self) -> pulumi.Output[_builtins.str]:
        """
        GitLab server administrator information.
        """
        return pulumi.get(self, "help_text")

    @_builtins.property
    @pulumi.getter(name="hideThirdPartyOffers")
    def hide_third_party_offers(self) -> pulumi.Output[_builtins.bool]:
        """
        Do not display offers from third parties in GitLab.
        """
        return pulumi.get(self, "hide_third_party_offers")

    @_builtins.property
    @pulumi.getter(name="homePageUrl")
    def home_page_url(self) -> pulumi.Output[_builtins.str]:
        """
        Redirect to this URL when not logged in.
        """
        return pulumi.get(self, "home_page_url")

    @_builtins.property
    @pulumi.getter(name="housekeepingEnabled")
    def housekeeping_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable or disable Git housekeeping. If enabled, requires housekeeping*optimize*repository_period.
        """
        return pulumi.get(self, "housekeeping_enabled")

    @_builtins.property
    @pulumi.getter(name="housekeepingOptimizeRepositoryPeriod")
    def housekeeping_optimize_repository_period(self) -> pulumi.Output[_builtins.int]:
        """
        Number of Git pushes after which an incremental git-repack is run.
        """
        return pulumi.get(self, "housekeeping_optimize_repository_period")

    @_builtins.property
    @pulumi.getter(name="htmlEmailsEnabled")
    def html_emails_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable HTML emails.
        """
        return pulumi.get(self, "html_emails_enabled")

    @_builtins.property
    @pulumi.getter(name="importSources")
    def import_sources(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Sources to allow project import from. Valid values are: `github`, `bitbucket`, `bitbucket_server`, `fogbugz`, `git`, `Project`, `gitea`, `manifest`
        """
        return pulumi.get(self, "import_sources")

    @_builtins.property
    @pulumi.getter(name="inProductMarketingEmailsEnabled")
    def in_product_marketing_emails_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable in-product marketing emails.
        """
        return pulumi.get(self, "in_product_marketing_emails_enabled")

    @_builtins.property
    @pulumi.getter(name="inactiveProjectsDeleteAfterMonths")
    def inactive_projects_delete_after_months(self) -> pulumi.Output[_builtins.int]:
        """
        If delete*inactive*projects is true, the time (in months) to wait before deleting inactive projects.
        """
        return pulumi.get(self, "inactive_projects_delete_after_months")

    @_builtins.property
    @pulumi.getter(name="inactiveProjectsMinSizeMb")
    def inactive_projects_min_size_mb(self) -> pulumi.Output[_builtins.int]:
        """
        If delete*inactive*projects is true, the minimum repository size for projects to be checked for inactivity.
        """
        return pulumi.get(self, "inactive_projects_min_size_mb")

    @_builtins.property
    @pulumi.getter(name="inactiveProjectsSendWarningEmailAfterMonths")
    def inactive_projects_send_warning_email_after_months(self) -> pulumi.Output[_builtins.int]:
        """
        If delete*inactive*projects is true, sets the time (in months) to wait before emailing maintainers that the project is scheduled be deleted because it is inactive.
        """
        return pulumi.get(self, "inactive_projects_send_warning_email_after_months")

    @_builtins.property
    @pulumi.getter(name="includeOptionalMetricsInServicePing")
    def include_optional_metrics_in_service_ping(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether or not optional metrics are enabled in Service Ping.
        """
        return pulumi.get(self, "include_optional_metrics_in_service_ping")

    @_builtins.property
    @pulumi.getter(name="invisibleCaptchaEnabled")
    def invisible_captcha_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable Invisible CAPTCHA spam detection during sign-up.
        """
        return pulumi.get(self, "invisible_captcha_enabled")

    @_builtins.property
    @pulumi.getter(name="issuesCreateLimit")
    def issues_create_limit(self) -> pulumi.Output[_builtins.int]:
        """
        Max number of issue creation requests per minute per user.
        """
        return pulumi.get(self, "issues_create_limit")

    @_builtins.property
    @pulumi.getter(name="jiraConnectApplicationKey")
    def jira_connect_application_key(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the OAuth application used to authenticate with the GitLab for Jira Cloud app.
        """
        return pulumi.get(self, "jira_connect_application_key")

    @_builtins.property
    @pulumi.getter(name="jiraConnectProxyUrl")
    def jira_connect_proxy_url(self) -> pulumi.Output[_builtins.str]:
        """
        URL of the GitLab instance used as a proxy for the GitLab for Jira Cloud app.
        """
        return pulumi.get(self, "jira_connect_proxy_url")

    @_builtins.property
    @pulumi.getter(name="jiraConnectPublicKeyStorageEnabled")
    def jira_connect_public_key_storage_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable public key storage for the GitLab for Jira Cloud app.
        """
        return pulumi.get(self, "jira_connect_public_key_storage_enabled")

    @_builtins.property
    @pulumi.getter(name="keepLatestArtifact")
    def keep_latest_artifact(self) -> pulumi.Output[_builtins.bool]:
        """
        Prevent the deletion of the artifacts from the most recent successful jobs, regardless of the expiry time.
        """
        return pulumi.get(self, "keep_latest_artifact")

    @_builtins.property
    @pulumi.getter(name="localMarkdownVersion")
    def local_markdown_version(self) -> pulumi.Output[_builtins.int]:
        """
        Increase this value when any cached Markdown should be invalidated.
        """
        return pulumi.get(self, "local_markdown_version")

    @_builtins.property
    @pulumi.getter(name="lockDuoFeaturesEnabled")
    def lock_duo_features_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates whether the GitLab Duo features enabled setting is enforced for all subgroups. Self-managed, Premium and Ultimate only.
        """
        return pulumi.get(self, "lock_duo_features_enabled")

    @_builtins.property
    @pulumi.getter(name="lockMembershipsToLdap")
    def lock_memberships_to_ldap(self) -> pulumi.Output[_builtins.bool]:
        """
        Set to true to lock all memberships to LDAP. Premium and Ultimate only.
        """
        return pulumi.get(self, "lock_memberships_to_ldap")

    @_builtins.property
    @pulumi.getter(name="mailgunEventsEnabled")
    def mailgun_events_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable Mailgun event receiver.
        """
        return pulumi.get(self, "mailgun_events_enabled")

    @_builtins.property
    @pulumi.getter(name="mailgunSigningKey")
    def mailgun_signing_key(self) -> pulumi.Output[_builtins.str]:
        """
        The Mailgun HTTP webhook signing key for receiving events from webhook.
        """
        return pulumi.get(self, "mailgun_signing_key")

    @_builtins.property
    @pulumi.getter(name="maintenanceMode")
    def maintenance_mode(self) -> pulumi.Output[_builtins.bool]:
        """
        When instance is in maintenance mode, non-administrative users can sign in with read-only access and make read-only API requests.
        """
        return pulumi.get(self, "maintenance_mode")

    @_builtins.property
    @pulumi.getter(name="maintenanceModeMessage")
    def maintenance_mode_message(self) -> pulumi.Output[_builtins.str]:
        """
        Message displayed when instance is in maintenance mode.
        """
        return pulumi.get(self, "maintenance_mode_message")

    @_builtins.property
    @pulumi.getter(name="mavenPackageRequestsForwarding")
    def maven_package_requests_forwarding(self) -> pulumi.Output[_builtins.bool]:
        """
        Use repo.maven.apache.org as a default remote repository when the package is not found in the GitLab Package Registry for Maven. Premium and Ultimate only.
        """
        return pulumi.get(self, "maven_package_requests_forwarding")

    @_builtins.property
    @pulumi.getter(name="maxArtifactsSize")
    def max_artifacts_size(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum artifacts size in MB.
        """
        return pulumi.get(self, "max_artifacts_size")

    @_builtins.property
    @pulumi.getter(name="maxAttachmentSize")
    def max_attachment_size(self) -> pulumi.Output[_builtins.int]:
        """
        Limit attachment size in MB.
        """
        return pulumi.get(self, "max_attachment_size")

    @_builtins.property
    @pulumi.getter(name="maxDecompressedArchiveSize")
    def max_decompressed_archive_size(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum decompressed archive size in bytes.
        """
        return pulumi.get(self, "max_decompressed_archive_size")

    @_builtins.property
    @pulumi.getter(name="maxExportSize")
    def max_export_size(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum export size in MB. 0 for unlimited.
        """
        return pulumi.get(self, "max_export_size")

    @_builtins.property
    @pulumi.getter(name="maxImportRemoteFileSize")
    def max_import_remote_file_size(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum remote file size for imports from external object storages.
        """
        return pulumi.get(self, "max_import_remote_file_size")

    @_builtins.property
    @pulumi.getter(name="maxImportSize")
    def max_import_size(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum import size in MB. 0 for unlimited.
        """
        return pulumi.get(self, "max_import_size")

    @_builtins.property
    @pulumi.getter(name="maxLoginAttempts")
    def max_login_attempts(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum number of sign-in attempts before locking out the user.
        """
        return pulumi.get(self, "max_login_attempts")

    @_builtins.property
    @pulumi.getter(name="maxNumberOfRepositoryDownloads")
    def max_number_of_repository_downloads(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum number of unique repositories a user can download in the specified time period before they are banned. Maximum: 10,000 repositories.
        """
        return pulumi.get(self, "max_number_of_repository_downloads")

    @_builtins.property
    @pulumi.getter(name="maxNumberOfRepositoryDownloadsWithinTimePeriod")
    def max_number_of_repository_downloads_within_time_period(self) -> pulumi.Output[_builtins.int]:
        """
        Reporting time period (in seconds). Maximum: 864000 seconds (10 days).
        """
        return pulumi.get(self, "max_number_of_repository_downloads_within_time_period")

    @_builtins.property
    @pulumi.getter(name="maxPagesSize")
    def max_pages_size(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum size of pages repositories in MB.
        """
        return pulumi.get(self, "max_pages_size")

    @_builtins.property
    @pulumi.getter(name="maxPersonalAccessTokenLifetime")
    def max_personal_access_token_lifetime(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum allowable lifetime for access tokens in days.
        """
        return pulumi.get(self, "max_personal_access_token_lifetime")

    @_builtins.property
    @pulumi.getter(name="maxSshKeyLifetime")
    def max_ssh_key_lifetime(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum allowable lifetime for SSH keys in days.
        """
        return pulumi.get(self, "max_ssh_key_lifetime")

    @_builtins.property
    @pulumi.getter(name="maxTerraformStateSizeBytes")
    def max_terraform_state_size_bytes(self) -> pulumi.Output[_builtins.int]:
        return pulumi.get(self, "max_terraform_state_size_bytes")

    @_builtins.property
    @pulumi.getter(name="metricsMethodCallThreshold")
    def metrics_method_call_threshold(self) -> pulumi.Output[_builtins.int]:
        """
        A method call is only tracked when it takes longer than the given amount of milliseconds.
        """
        return pulumi.get(self, "metrics_method_call_threshold")

    @_builtins.property
    @pulumi.getter(name="minimumPasswordLength")
    def minimum_password_length(self) -> pulumi.Output[_builtins.int]:
        """
        Indicates whether passwords require a minimum length. Premium and Ultimate only.
        """
        return pulumi.get(self, "minimum_password_length")

    @_builtins.property
    @pulumi.getter(name="mirrorAvailable")
    def mirror_available(self) -> pulumi.Output[_builtins.bool]:
        """
        Allow repository mirroring to configured by project Maintainers. If disabled, only Administrators can configure repository mirroring.
        """
        return pulumi.get(self, "mirror_available")

    @_builtins.property
    @pulumi.getter(name="mirrorCapacityThreshold")
    def mirror_capacity_threshold(self) -> pulumi.Output[_builtins.int]:
        """
        Minimum capacity to be available before scheduling more mirrors preemptively.
        """
        return pulumi.get(self, "mirror_capacity_threshold")

    @_builtins.property
    @pulumi.getter(name="mirrorMaxCapacity")
    def mirror_max_capacity(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum number of mirrors that can be synchronizing at the same time.
        """
        return pulumi.get(self, "mirror_max_capacity")

    @_builtins.property
    @pulumi.getter(name="mirrorMaxDelay")
    def mirror_max_delay(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum time (in minutes) between updates that a mirror can have when scheduled to synchronize.
        """
        return pulumi.get(self, "mirror_max_delay")

    @_builtins.property
    @pulumi.getter(name="npmPackageRequestsForwarding")
    def npm_package_requests_forwarding(self) -> pulumi.Output[_builtins.bool]:
        """
        Use npmjs.org as a default remote repository when the package is not found in the GitLab Package Registry for npm.
        """
        return pulumi.get(self, "npm_package_requests_forwarding")

    @_builtins.property
    @pulumi.getter(name="nugetSkipMetadataUrlValidation")
    def nuget_skip_metadata_url_validation(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates whether to skip metadata URL validation for the NuGet package.
        """
        return pulumi.get(self, "nuget_skip_metadata_url_validation")

    @_builtins.property
    @pulumi.getter(name="outboundLocalRequestsWhitelists")
    def outbound_local_requests_whitelists(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Define a list of trusted domains or IP addresses to which local requests are allowed when local requests for hooks and services are disabled.
        """
        return pulumi.get(self, "outbound_local_requests_whitelists")

    @_builtins.property
    @pulumi.getter(name="packageMetadataPurlTypes")
    def package_metadata_purl_types(self) -> pulumi.Output[Sequence[_builtins.int]]:
        """
        List of package registry metadata to sync. See the list of the available values (https://gitlab.com/gitlab-org/gitlab/-/blob/ace16c20d5da7c4928dd03fb139692638b557fe3/app/models/concerns/enums/package_metadata.rb#L5). Self-managed, Ultimate only.
        """
        return pulumi.get(self, "package_metadata_purl_types")

    @_builtins.property
    @pulumi.getter(name="packageRegistryAllowAnyoneToPullOption")
    def package_registry_allow_anyone_to_pull_option(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable to allow anyone to pull from Package Registry visible and changeable.
        """
        return pulumi.get(self, "package_registry_allow_anyone_to_pull_option")

    @_builtins.property
    @pulumi.getter(name="packageRegistryCleanupPoliciesWorkerCapacity")
    def package_registry_cleanup_policies_worker_capacity(self) -> pulumi.Output[_builtins.int]:
        """
        Number of workers assigned to the packages cleanup policies.
        """
        return pulumi.get(self, "package_registry_cleanup_policies_worker_capacity")

    @_builtins.property
    @pulumi.getter(name="pagesDomainVerificationEnabled")
    def pages_domain_verification_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Require users to prove ownership of custom domains. Domain verification is an essential security measure for public GitLab sites. Users are required to demonstrate they control a domain before it is enabled.
        """
        return pulumi.get(self, "pages_domain_verification_enabled")

    @_builtins.property
    @pulumi.getter(name="passwordAuthenticationEnabledForGit")
    def password_authentication_enabled_for_git(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable authentication for Git over HTTP(S) via a GitLab account password.
        """
        return pulumi.get(self, "password_authentication_enabled_for_git")

    @_builtins.property
    @pulumi.getter(name="passwordAuthenticationEnabledForWeb")
    def password_authentication_enabled_for_web(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable authentication for the web interface via a GitLab account password.
        """
        return pulumi.get(self, "password_authentication_enabled_for_web")

    @_builtins.property
    @pulumi.getter(name="passwordLowercaseRequired")
    def password_lowercase_required(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates whether passwords require at least one lowercase letter.
        """
        return pulumi.get(self, "password_lowercase_required")

    @_builtins.property
    @pulumi.getter(name="passwordNumberRequired")
    def password_number_required(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates whether passwords require at least one number.
        """
        return pulumi.get(self, "password_number_required")

    @_builtins.property
    @pulumi.getter(name="passwordSymbolRequired")
    def password_symbol_required(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates whether passwords require at least one symbol character.
        """
        return pulumi.get(self, "password_symbol_required")

    @_builtins.property
    @pulumi.getter(name="passwordUppercaseRequired")
    def password_uppercase_required(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates whether passwords require at least one uppercase letter.
        """
        return pulumi.get(self, "password_uppercase_required")

    @_builtins.property
    @pulumi.getter(name="performanceBarAllowedGroupPath")
    def performance_bar_allowed_group_path(self) -> pulumi.Output[_builtins.str]:
        """
        Path of the group that is allowed to toggle the performance bar.
        """
        return pulumi.get(self, "performance_bar_allowed_group_path")

    @_builtins.property
    @pulumi.getter(name="personalAccessTokenPrefix")
    def personal_access_token_prefix(self) -> pulumi.Output[_builtins.str]:
        """
        Prefix for all generated personal access tokens.
        """
        return pulumi.get(self, "personal_access_token_prefix")

    @_builtins.property
    @pulumi.getter(name="pipelineLimitPerProjectUserSha")
    def pipeline_limit_per_project_user_sha(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum number of pipeline creation requests per minute per user and commit.
        """
        return pulumi.get(self, "pipeline_limit_per_project_user_sha")

    @_builtins.property
    @pulumi.getter(name="plantumlEnabled")
    def plantuml_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        (If enabled, requires: plantuml_url) Enable PlantUML integration.
        """
        return pulumi.get(self, "plantuml_enabled")

    @_builtins.property
    @pulumi.getter(name="plantumlUrl")
    def plantuml_url(self) -> pulumi.Output[_builtins.str]:
        """
        The PlantUML instance URL for integration.
        """
        return pulumi.get(self, "plantuml_url")

    @_builtins.property
    @pulumi.getter(name="pollingIntervalMultiplier")
    def polling_interval_multiplier(self) -> pulumi.Output[_builtins.float]:
        """
        Interval multiplier used by endpoints that perform polling. Set to 0 to disable polling.
        """
        return pulumi.get(self, "polling_interval_multiplier")

    @_builtins.property
    @pulumi.getter(name="projectExportEnabled")
    def project_export_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable project export.
        """
        return pulumi.get(self, "project_export_enabled")

    @_builtins.property
    @pulumi.getter(name="projectJobsApiRateLimit")
    def project_jobs_api_rate_limit(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum authenticated requests to /project/:id/jobs per minute.
        """
        return pulumi.get(self, "project_jobs_api_rate_limit")

    @_builtins.property
    @pulumi.getter(name="projectsApiRateLimitUnauthenticated")
    def projects_api_rate_limit_unauthenticated(self) -> pulumi.Output[_builtins.int]:
        """
        Max number of requests per 10 minutes per IP address for unauthenticated requests to the list all projects API. To disable throttling set to 0.
        """
        return pulumi.get(self, "projects_api_rate_limit_unauthenticated")

    @_builtins.property
    @pulumi.getter(name="prometheusMetricsEnabled")
    def prometheus_metrics_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable Prometheus metrics.
        """
        return pulumi.get(self, "prometheus_metrics_enabled")

    @_builtins.property
    @pulumi.getter(name="protectedCiVariables")
    def protected_ci_variables(self) -> pulumi.Output[_builtins.bool]:
        """
        CI/CD variables are protected by default.
        """
        return pulumi.get(self, "protected_ci_variables")

    @_builtins.property
    @pulumi.getter(name="pushEventActivitiesLimit")
    def push_event_activities_limit(self) -> pulumi.Output[_builtins.int]:
        """
        Number of changes (branches or tags) in a single push to determine whether individual push events or bulk push events are created. Bulk push events are created if it surpasses that value.
        """
        return pulumi.get(self, "push_event_activities_limit")

    @_builtins.property
    @pulumi.getter(name="pushEventHooksLimit")
    def push_event_hooks_limit(self) -> pulumi.Output[_builtins.int]:
        """
        Number of changes (branches or tags) in a single push to determine whether webhooks and services fire or not. Webhooks and services aren’t submitted if it surpasses that value.
        """
        return pulumi.get(self, "push_event_hooks_limit")

    @_builtins.property
    @pulumi.getter(name="pypiPackageRequestsForwarding")
    def pypi_package_requests_forwarding(self) -> pulumi.Output[_builtins.bool]:
        """
        Use pypi.org as a default remote repository when the package is not found in the GitLab Package Registry for PyPI.
        """
        return pulumi.get(self, "pypi_package_requests_forwarding")

    @_builtins.property
    @pulumi.getter(name="rateLimitingResponseText")
    def rate_limiting_response_text(self) -> pulumi.Output[_builtins.str]:
        """
        When rate limiting is enabled via the throttle_* settings, send this plain text response when a rate limit is exceeded. ‘Retry later’ is sent if this is blank.
        """
        return pulumi.get(self, "rate_limiting_response_text")

    @_builtins.property
    @pulumi.getter(name="rawBlobRequestLimit")
    def raw_blob_request_limit(self) -> pulumi.Output[_builtins.int]:
        """
        Max number of requests per minute for each raw path. To disable throttling set to 0.
        """
        return pulumi.get(self, "raw_blob_request_limit")

    @_builtins.property
    @pulumi.getter(name="recaptchaEnabled")
    def recaptcha_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        (If enabled, requires: recaptcha*private*key and recaptcha*site*key) Enable reCAPTCHA.
        """
        return pulumi.get(self, "recaptcha_enabled")

    @_builtins.property
    @pulumi.getter(name="recaptchaPrivateKey")
    def recaptcha_private_key(self) -> pulumi.Output[_builtins.str]:
        """
        Private key for reCAPTCHA.
        """
        return pulumi.get(self, "recaptcha_private_key")

    @_builtins.property
    @pulumi.getter(name="recaptchaSiteKey")
    def recaptcha_site_key(self) -> pulumi.Output[_builtins.str]:
        """
        Site key for reCAPTCHA.
        """
        return pulumi.get(self, "recaptcha_site_key")

    @_builtins.property
    @pulumi.getter(name="receiveMaxInputSize")
    def receive_max_input_size(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum push size (MB).
        """
        return pulumi.get(self, "receive_max_input_size")

    @_builtins.property
    @pulumi.getter(name="receptiveClusterAgentsEnabled")
    def receptive_cluster_agents_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable receptive mode for GitLab Agents for Kubernetes.
        """
        return pulumi.get(self, "receptive_cluster_agents_enabled")

    @_builtins.property
    @pulumi.getter(name="rememberMeEnabled")
    def remember_me_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable Remember me setting.
        """
        return pulumi.get(self, "remember_me_enabled")

    @_builtins.property
    @pulumi.getter(name="repositoryChecksEnabled")
    def repository_checks_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        GitLab periodically runs git fsck in all project and wiki repositories to look for silent disk corruption issues.
        """
        return pulumi.get(self, "repository_checks_enabled")

    @_builtins.property
    @pulumi.getter(name="repositorySizeLimit")
    def repository_size_limit(self) -> pulumi.Output[_builtins.int]:
        """
        Size limit per repository (MB).
        """
        return pulumi.get(self, "repository_size_limit")

    @_builtins.property
    @pulumi.getter(name="repositoryStoragesWeighted")
    def repository_storages_weighted(self) -> pulumi.Output[Mapping[str, _builtins.int]]:
        """
        Hash of names taken from gitlab.yml to weights. New projects are created in one of these stores, chosen by a weighted random selection.
        """
        return pulumi.get(self, "repository_storages_weighted")

    @_builtins.property
    @pulumi.getter(name="requireAdminApprovalAfterUserSignup")
    def require_admin_approval_after_user_signup(self) -> pulumi.Output[_builtins.bool]:
        """
        When enabled, any user that signs up for an account using the registration form is placed under a Pending approval state and has to be explicitly approved by an administrator.
        """
        return pulumi.get(self, "require_admin_approval_after_user_signup")

    @_builtins.property
    @pulumi.getter(name="requireAdminTwoFactorAuthentication")
    def require_admin_two_factor_authentication(self) -> pulumi.Output[_builtins.bool]:
        """
        Allow administrators to require 2FA for all administrators on the instance.
        """
        return pulumi.get(self, "require_admin_two_factor_authentication")

    @_builtins.property
    @pulumi.getter(name="requirePersonalAccessTokenExpiry")
    def require_personal_access_token_expiry(self) -> pulumi.Output[_builtins.bool]:
        """
        When enabled, users must set an expiration date when creating a group or project access token, or a personal access token owned by a non-service account.
        """
        return pulumi.get(self, "require_personal_access_token_expiry")

    @_builtins.property
    @pulumi.getter(name="requireTwoFactorAuthentication")
    def require_two_factor_authentication(self) -> pulumi.Output[_builtins.bool]:
        """
        (If enabled, requires: two*factor*grace_period) Require all users to set up Two-factor authentication.
        """
        return pulumi.get(self, "require_two_factor_authentication")

    @_builtins.property
    @pulumi.getter(name="restrictedVisibilityLevels")
    def restricted_visibility_levels(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Selected levels cannot be used by non-Administrator users for groups, projects or snippets. Can take private, internal and public as a parameter. Null means there is no restriction.
        """
        return pulumi.get(self, "restricted_visibility_levels")

    @_builtins.property
    @pulumi.getter(name="rsaKeyRestriction")
    def rsa_key_restriction(self) -> pulumi.Output[_builtins.int]:
        """
        The minimum allowed bit length of an uploaded RSA key. 0 means no restriction. -1 disables RSA keys.
        """
        return pulumi.get(self, "rsa_key_restriction")

    @_builtins.property
    @pulumi.getter(name="searchRateLimit")
    def search_rate_limit(self) -> pulumi.Output[_builtins.int]:
        """
        Max number of requests per minute for performing a search while authenticated. To disable throttling set to 0.
        """
        return pulumi.get(self, "search_rate_limit")

    @_builtins.property
    @pulumi.getter(name="searchRateLimitUnauthenticated")
    def search_rate_limit_unauthenticated(self) -> pulumi.Output[_builtins.int]:
        """
        Max number of requests per minute for performing a search while unauthenticated. To disable throttling set to 0.
        """
        return pulumi.get(self, "search_rate_limit_unauthenticated")

    @_builtins.property
    @pulumi.getter(name="securityApprovalPoliciesLimit")
    def security_approval_policies_limit(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum number of active merge request approval policies per security policy project. Maximum: 20
        """
        return pulumi.get(self, "security_approval_policies_limit")

    @_builtins.property
    @pulumi.getter(name="securityPolicyGlobalGroupApproversEnabled")
    def security_policy_global_group_approvers_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether to look up merge request approval policy approval groups globally or within project hierarchies.
        """
        return pulumi.get(self, "security_policy_global_group_approvers_enabled")

    @_builtins.property
    @pulumi.getter(name="securityTxtContent")
    def security_txt_content(self) -> pulumi.Output[_builtins.str]:
        """
        Public security contact information.
        """
        return pulumi.get(self, "security_txt_content")

    @_builtins.property
    @pulumi.getter(name="sendUserConfirmationEmail")
    def send_user_confirmation_email(self) -> pulumi.Output[_builtins.bool]:
        """
        Send confirmation email on sign-up.
        """
        return pulumi.get(self, "send_user_confirmation_email")

    @_builtins.property
    @pulumi.getter(name="serviceAccessTokensExpirationEnforced")
    def service_access_tokens_expiration_enforced(self) -> pulumi.Output[_builtins.bool]:
        """
        Flag to indicate if token expiry date can be optional for service account users
        """
        return pulumi.get(self, "service_access_tokens_expiration_enforced")

    @_builtins.property
    @pulumi.getter(name="sessionExpireDelay")
    def session_expire_delay(self) -> pulumi.Output[_builtins.int]:
        """
        Session duration in minutes. GitLab restart is required to apply changes.
        """
        return pulumi.get(self, "session_expire_delay")

    @_builtins.property
    @pulumi.getter(name="sharedRunnersEnabled")
    def shared_runners_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        (If enabled, requires: shared*runners*text and shared*runners*minutes) Enable shared runners for new projects.
        """
        return pulumi.get(self, "shared_runners_enabled")

    @_builtins.property
    @pulumi.getter(name="sharedRunnersMinutes")
    def shared_runners_minutes(self) -> pulumi.Output[_builtins.int]:
        """
        Set the maximum number of CI/CD minutes that a group can use on shared runners per month.
        """
        return pulumi.get(self, "shared_runners_minutes")

    @_builtins.property
    @pulumi.getter(name="sharedRunnersText")
    def shared_runners_text(self) -> pulumi.Output[_builtins.str]:
        """
        Shared runners text.
        """
        return pulumi.get(self, "shared_runners_text")

    @_builtins.property
    @pulumi.getter(name="sidekiqJobLimiterCompressionThresholdBytes")
    def sidekiq_job_limiter_compression_threshold_bytes(self) -> pulumi.Output[_builtins.int]:
        """
        The threshold in bytes at which Sidekiq jobs are compressed before being stored in Redis.
        """
        return pulumi.get(self, "sidekiq_job_limiter_compression_threshold_bytes")

    @_builtins.property
    @pulumi.getter(name="sidekiqJobLimiterLimitBytes")
    def sidekiq_job_limiter_limit_bytes(self) -> pulumi.Output[_builtins.int]:
        """
        The threshold in bytes at which Sidekiq jobs are rejected. 0 means do not reject any job.
        """
        return pulumi.get(self, "sidekiq_job_limiter_limit_bytes")

    @_builtins.property
    @pulumi.getter(name="sidekiqJobLimiterMode")
    def sidekiq_job_limiter_mode(self) -> pulumi.Output[_builtins.str]:
        """
        track or compress. Sets the behavior for Sidekiq job size limits.
        """
        return pulumi.get(self, "sidekiq_job_limiter_mode")

    @_builtins.property
    @pulumi.getter(name="signInText")
    def sign_in_text(self) -> pulumi.Output[_builtins.str]:
        """
        Text on the login page.
        """
        return pulumi.get(self, "sign_in_text")

    @_builtins.property
    @pulumi.getter(name="signupEnabled")
    def signup_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable registration.
        """
        return pulumi.get(self, "signup_enabled")

    @_builtins.property
    @pulumi.getter(name="silentAdminExportsEnabled")
    def silent_admin_exports_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable Silent admin exports.
        """
        return pulumi.get(self, "silent_admin_exports_enabled")

    @_builtins.property
    @pulumi.getter(name="silentModeEnabled")
    def silent_mode_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable Silent mode.
        """
        return pulumi.get(self, "silent_mode_enabled")

    @_builtins.property
    @pulumi.getter(name="slackAppEnabled")
    def slack_app_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        (If enabled, requires: slack*app*id, slack*app*secret and slack*app*secret) Enable Slack app.
        """
        return pulumi.get(self, "slack_app_enabled")

    @_builtins.property
    @pulumi.getter(name="slackAppId")
    def slack_app_id(self) -> pulumi.Output[_builtins.str]:
        """
        The app ID of the Slack-app.
        """
        return pulumi.get(self, "slack_app_id")

    @_builtins.property
    @pulumi.getter(name="slackAppSecret")
    def slack_app_secret(self) -> pulumi.Output[_builtins.str]:
        """
        The app secret of the Slack-app.
        """
        return pulumi.get(self, "slack_app_secret")

    @_builtins.property
    @pulumi.getter(name="slackAppSigningSecret")
    def slack_app_signing_secret(self) -> pulumi.Output[_builtins.str]:
        """
        The signing secret of the Slack-app.
        """
        return pulumi.get(self, "slack_app_signing_secret")

    @_builtins.property
    @pulumi.getter(name="slackAppVerificationToken")
    def slack_app_verification_token(self) -> pulumi.Output[_builtins.str]:
        """
        The verification token of the Slack-app.
        """
        return pulumi.get(self, "slack_app_verification_token")

    @_builtins.property
    @pulumi.getter(name="snippetSizeLimit")
    def snippet_size_limit(self) -> pulumi.Output[_builtins.int]:
        """
        Max snippet content size in bytes.
        """
        return pulumi.get(self, "snippet_size_limit")

    @_builtins.property
    @pulumi.getter(name="snowplowAppId")
    def snowplow_app_id(self) -> pulumi.Output[_builtins.str]:
        """
        The Snowplow site name / application ID. (for example, gitlab)
        """
        return pulumi.get(self, "snowplow_app_id")

    @_builtins.property
    @pulumi.getter(name="snowplowCollectorHostname")
    def snowplow_collector_hostname(self) -> pulumi.Output[_builtins.str]:
        """
        The Snowplow collector hostname. (for example, snowplow.trx.gitlab.net)
        """
        return pulumi.get(self, "snowplow_collector_hostname")

    @_builtins.property
    @pulumi.getter(name="snowplowCookieDomain")
    def snowplow_cookie_domain(self) -> pulumi.Output[_builtins.str]:
        """
        The Snowplow cookie domain. (for example, .gitlab.com)
        """
        return pulumi.get(self, "snowplow_cookie_domain")

    @_builtins.property
    @pulumi.getter(name="snowplowDatabaseCollectorHostname")
    def snowplow_database_collector_hostname(self) -> pulumi.Output[_builtins.str]:
        """
        The Snowplow collector for database events hostname. (for example, db-snowplow.trx.gitlab.net)
        """
        return pulumi.get(self, "snowplow_database_collector_hostname")

    @_builtins.property
    @pulumi.getter(name="snowplowEnabled")
    def snowplow_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable snowplow tracking.
        """
        return pulumi.get(self, "snowplow_enabled")

    @_builtins.property
    @pulumi.getter(name="sourcegraphEnabled")
    def sourcegraph_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enables Sourcegraph integration. If enabled, requires sourcegraph_url.
        """
        return pulumi.get(self, "sourcegraph_enabled")

    @_builtins.property
    @pulumi.getter(name="sourcegraphPublicOnly")
    def sourcegraph_public_only(self) -> pulumi.Output[_builtins.bool]:
        """
        Blocks Sourcegraph from being loaded on private and internal projects.
        """
        return pulumi.get(self, "sourcegraph_public_only")

    @_builtins.property
    @pulumi.getter(name="sourcegraphUrl")
    def sourcegraph_url(self) -> pulumi.Output[_builtins.str]:
        """
        The Sourcegraph instance URL for integration.
        """
        return pulumi.get(self, "sourcegraph_url")

    @_builtins.property
    @pulumi.getter(name="spamCheckApiKey")
    def spam_check_api_key(self) -> pulumi.Output[_builtins.str]:
        """
        API key used by GitLab for accessing the Spam Check service endpoint.
        """
        return pulumi.get(self, "spam_check_api_key")

    @_builtins.property
    @pulumi.getter(name="spamCheckEndpointEnabled")
    def spam_check_endpoint_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enables spam checking using external Spam Check API endpoint.
        """
        return pulumi.get(self, "spam_check_endpoint_enabled")

    @_builtins.property
    @pulumi.getter(name="spamCheckEndpointUrl")
    def spam_check_endpoint_url(self) -> pulumi.Output[_builtins.str]:
        """
        URL of the external Spamcheck service endpoint. Valid URI schemes are grpc or tls. Specifying tls forces communication to be encrypted.
        """
        return pulumi.get(self, "spam_check_endpoint_url")

    @_builtins.property
    @pulumi.getter(name="staticObjectsExternalStorageAuthToken")
    def static_objects_external_storage_auth_token(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Authentication token for the external storage linked in static*objects*external*storage*url.
        """
        return pulumi.get(self, "static_objects_external_storage_auth_token")

    @_builtins.property
    @pulumi.getter(name="staticObjectsExternalStorageUrl")
    def static_objects_external_storage_url(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        URL to an external storage for repository static objects.
        """
        return pulumi.get(self, "static_objects_external_storage_url")

    @_builtins.property
    @pulumi.getter(name="suggestPipelineEnabled")
    def suggest_pipeline_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable pipeline suggestion banner.
        """
        return pulumi.get(self, "suggest_pipeline_enabled")

    @_builtins.property
    @pulumi.getter(name="terminalMaxSessionTime")
    def terminal_max_session_time(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum time for web terminal websocket connection (in seconds). Set to 0 for unlimited time.
        """
        return pulumi.get(self, "terminal_max_session_time")

    @_builtins.property
    @pulumi.getter
    def terms(self) -> pulumi.Output[_builtins.str]:
        """
        (Required by: enforce_terms) Markdown content for the ToS.
        """
        return pulumi.get(self, "terms")

    @_builtins.property
    @pulumi.getter(name="throttleAuthenticatedApiEnabled")
    def throttle_authenticated_api_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        (If enabled, requires: throttle*authenticated*api*period*in*seconds and throttle*authenticated*api*requests*per*period) Enable authenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        """
        return pulumi.get(self, "throttle_authenticated_api_enabled")

    @_builtins.property
    @pulumi.getter(name="throttleAuthenticatedApiPeriodInSeconds")
    def throttle_authenticated_api_period_in_seconds(self) -> pulumi.Output[_builtins.int]:
        """
        Rate limit period (in seconds).
        """
        return pulumi.get(self, "throttle_authenticated_api_period_in_seconds")

    @_builtins.property
    @pulumi.getter(name="throttleAuthenticatedApiRequestsPerPeriod")
    def throttle_authenticated_api_requests_per_period(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum requests per period per user.
        """
        return pulumi.get(self, "throttle_authenticated_api_requests_per_period")

    @_builtins.property
    @pulumi.getter(name="throttleAuthenticatedPackagesApiEnabled")
    def throttle_authenticated_packages_api_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        (If enabled, requires: throttle*authenticated*packages*api*period*in*seconds and throttle*authenticated*packages*api*requests*per*period) Enable authenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots). View Package Registry rate limits for more details.
        """
        return pulumi.get(self, "throttle_authenticated_packages_api_enabled")

    @_builtins.property
    @pulumi.getter(name="throttleAuthenticatedPackagesApiPeriodInSeconds")
    def throttle_authenticated_packages_api_period_in_seconds(self) -> pulumi.Output[_builtins.int]:
        """
        Rate limit period (in seconds). View Package Registry rate limits for more details.
        """
        return pulumi.get(self, "throttle_authenticated_packages_api_period_in_seconds")

    @_builtins.property
    @pulumi.getter(name="throttleAuthenticatedPackagesApiRequestsPerPeriod")
    def throttle_authenticated_packages_api_requests_per_period(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum requests per period per user. View Package Registry rate limits for more details.
        """
        return pulumi.get(self, "throttle_authenticated_packages_api_requests_per_period")

    @_builtins.property
    @pulumi.getter(name="throttleAuthenticatedWebEnabled")
    def throttle_authenticated_web_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        (If enabled, requires: throttle*authenticated*web*period*in*seconds and throttle*authenticated*web*requests*per*period) Enable authenticated web request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        """
        return pulumi.get(self, "throttle_authenticated_web_enabled")

    @_builtins.property
    @pulumi.getter(name="throttleAuthenticatedWebPeriodInSeconds")
    def throttle_authenticated_web_period_in_seconds(self) -> pulumi.Output[_builtins.int]:
        """
        Rate limit period (in seconds).
        """
        return pulumi.get(self, "throttle_authenticated_web_period_in_seconds")

    @_builtins.property
    @pulumi.getter(name="throttleAuthenticatedWebRequestsPerPeriod")
    def throttle_authenticated_web_requests_per_period(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum requests per period per user.
        """
        return pulumi.get(self, "throttle_authenticated_web_requests_per_period")

    @_builtins.property
    @pulumi.getter(name="throttleUnauthenticatedApiEnabled")
    def throttle_unauthenticated_api_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        (If enabled, requires: throttle*unauthenticated*api*period*in*seconds and throttle*unauthenticated*api*requests*per*period) Enable unauthenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        """
        return pulumi.get(self, "throttle_unauthenticated_api_enabled")

    @_builtins.property
    @pulumi.getter(name="throttleUnauthenticatedApiPeriodInSeconds")
    def throttle_unauthenticated_api_period_in_seconds(self) -> pulumi.Output[_builtins.int]:
        """
        Rate limit period in seconds.
        """
        return pulumi.get(self, "throttle_unauthenticated_api_period_in_seconds")

    @_builtins.property
    @pulumi.getter(name="throttleUnauthenticatedApiRequestsPerPeriod")
    def throttle_unauthenticated_api_requests_per_period(self) -> pulumi.Output[_builtins.int]:
        """
        Max requests per period per IP.
        """
        return pulumi.get(self, "throttle_unauthenticated_api_requests_per_period")

    @_builtins.property
    @pulumi.getter(name="throttleUnauthenticatedPackagesApiEnabled")
    def throttle_unauthenticated_packages_api_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        (If enabled, requires: throttle*unauthenticated*packages*api*period*in*seconds and throttle*unauthenticated*packages*api*requests*per*period) Enable authenticated API request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots). View Package Registry rate limits for more details.
        """
        return pulumi.get(self, "throttle_unauthenticated_packages_api_enabled")

    @_builtins.property
    @pulumi.getter(name="throttleUnauthenticatedPackagesApiPeriodInSeconds")
    def throttle_unauthenticated_packages_api_period_in_seconds(self) -> pulumi.Output[_builtins.int]:
        """
        Rate limit period (in seconds). View Package Registry rate limits for more details.
        """
        return pulumi.get(self, "throttle_unauthenticated_packages_api_period_in_seconds")

    @_builtins.property
    @pulumi.getter(name="throttleUnauthenticatedPackagesApiRequestsPerPeriod")
    def throttle_unauthenticated_packages_api_requests_per_period(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum requests per period per user. View Package Registry rate limits for more details.
        """
        return pulumi.get(self, "throttle_unauthenticated_packages_api_requests_per_period")

    @_builtins.property
    @pulumi.getter(name="throttleUnauthenticatedWebEnabled")
    def throttle_unauthenticated_web_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        (If enabled, requires: throttle*unauthenticated*web*period*in*seconds and throttle*unauthenticated*web*requests*per*period) Enable unauthenticated web request rate limit. Helps reduce request volume (for example, from crawlers or abusive bots).
        """
        return pulumi.get(self, "throttle_unauthenticated_web_enabled")

    @_builtins.property
    @pulumi.getter(name="throttleUnauthenticatedWebPeriodInSeconds")
    def throttle_unauthenticated_web_period_in_seconds(self) -> pulumi.Output[_builtins.int]:
        """
        Rate limit period in seconds.
        """
        return pulumi.get(self, "throttle_unauthenticated_web_period_in_seconds")

    @_builtins.property
    @pulumi.getter(name="throttleUnauthenticatedWebRequestsPerPeriod")
    def throttle_unauthenticated_web_requests_per_period(self) -> pulumi.Output[_builtins.int]:
        """
        Max requests per period per IP.
        """
        return pulumi.get(self, "throttle_unauthenticated_web_requests_per_period")

    @_builtins.property
    @pulumi.getter(name="timeTrackingLimitToHours")
    def time_tracking_limit_to_hours(self) -> pulumi.Output[_builtins.bool]:
        """
        Limit display of time tracking units to hours.
        """
        return pulumi.get(self, "time_tracking_limit_to_hours")

    @_builtins.property
    @pulumi.getter(name="twoFactorGracePeriod")
    def two_factor_grace_period(self) -> pulumi.Output[_builtins.int]:
        """
        Amount of time (in hours) that users are allowed to skip forced configuration of two-factor authentication.
        """
        return pulumi.get(self, "two_factor_grace_period")

    @_builtins.property
    @pulumi.getter(name="unconfirmedUsersDeleteAfterDays")
    def unconfirmed_users_delete_after_days(self) -> pulumi.Output[_builtins.int]:
        """
        Specifies how many days after sign-up to delete users who have not confirmed their email. Only applicable if delete*unconfirmed*users is set to true. Must be 1 or greater. Self-managed, Premium and Ultimate only.
        """
        return pulumi.get(self, "unconfirmed_users_delete_after_days")

    @_builtins.property
    @pulumi.getter(name="uniqueIpsLimitEnabled")
    def unique_ips_limit_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        (If enabled, requires: unique*ips*limit*per*user and unique*ips*limit*time*window) Limit sign in from multiple IPs.
        """
        return pulumi.get(self, "unique_ips_limit_enabled")

    @_builtins.property
    @pulumi.getter(name="uniqueIpsLimitPerUser")
    def unique_ips_limit_per_user(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum number of IPs per user.
        """
        return pulumi.get(self, "unique_ips_limit_per_user")

    @_builtins.property
    @pulumi.getter(name="uniqueIpsLimitTimeWindow")
    def unique_ips_limit_time_window(self) -> pulumi.Output[_builtins.int]:
        """
        How many seconds an IP is counted towards the limit.
        """
        return pulumi.get(self, "unique_ips_limit_time_window")

    @_builtins.property
    @pulumi.getter(name="updateRunnerVersionsEnabled")
    def update_runner_versions_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Fetch GitLab Runner release version data from GitLab.com.
        """
        return pulumi.get(self, "update_runner_versions_enabled")

    @_builtins.property
    @pulumi.getter(name="usagePingEnabled")
    def usage_ping_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Every week GitLab reports license usage back to GitLab, Inc.
        """
        return pulumi.get(self, "usage_ping_enabled")

    @_builtins.property
    @pulumi.getter(name="useClickhouseForAnalytics")
    def use_clickhouse_for_analytics(self) -> pulumi.Output[_builtins.bool]:
        """
        Enables ClickHouse as a data source for analytics reports. ClickHouse must be configured for this setting to take effect. Available on Premium and Ultimate only.
        """
        return pulumi.get(self, "use_clickhouse_for_analytics")

    @_builtins.property
    @pulumi.getter(name="userDeactivationEmailsEnabled")
    def user_deactivation_emails_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Send an email to users upon account deactivation.
        """
        return pulumi.get(self, "user_deactivation_emails_enabled")

    @_builtins.property
    @pulumi.getter(name="userDefaultExternal")
    def user_default_external(self) -> pulumi.Output[_builtins.bool]:
        """
        Newly registered users are external by default.
        """
        return pulumi.get(self, "user_default_external")

    @_builtins.property
    @pulumi.getter(name="userDefaultInternalRegex")
    def user_default_internal_regex(self) -> pulumi.Output[_builtins.str]:
        """
        Specify an email address regex pattern to identify default internal users.
        """
        return pulumi.get(self, "user_default_internal_regex")

    @_builtins.property
    @pulumi.getter(name="userDefaultsToPrivateProfile")
    def user_defaults_to_private_profile(self) -> pulumi.Output[_builtins.bool]:
        """
        Newly created users have private profile by default.
        """
        return pulumi.get(self, "user_defaults_to_private_profile")

    @_builtins.property
    @pulumi.getter(name="userOauthApplications")
    def user_oauth_applications(self) -> pulumi.Output[_builtins.bool]:
        """
        Allow users to register any application to use GitLab as an OAuth provider.
        """
        return pulumi.get(self, "user_oauth_applications")

    @_builtins.property
    @pulumi.getter(name="userShowAddSshKeyMessage")
    def user_show_add_ssh_key_message(self) -> pulumi.Output[_builtins.bool]:
        """
        When set to false disable the You won't be able to pull or push project code via SSH warning shown to users with no uploaded SSH key.
        """
        return pulumi.get(self, "user_show_add_ssh_key_message")

    @_builtins.property
    @pulumi.getter(name="validRunnerRegistrars")
    def valid_runner_registrars(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        List of types which are allowed to register a GitLab Runner. Can be [], ['group'], ['project'] or ['group', 'project'].
        """
        return pulumi.get(self, "valid_runner_registrars")

    @_builtins.property
    @pulumi.getter(name="versionCheckEnabled")
    def version_check_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Let GitLab inform you when an update is available.
        """
        return pulumi.get(self, "version_check_enabled")

    @_builtins.property
    @pulumi.getter(name="webIdeClientsidePreviewEnabled")
    def web_ide_clientside_preview_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Live Preview (allow live previews of JavaScript projects in the Web IDE using CodeSandbox Live Preview).
        """
        return pulumi.get(self, "web_ide_clientside_preview_enabled")

    @_builtins.property
    @pulumi.getter(name="whatsNewVariant")
    def whats_new_variant(self) -> pulumi.Output[_builtins.str]:
        """
        What's new variant, possible values: all*tiers, current*tier, and disabled.
        """
        return pulumi.get(self, "whats_new_variant")

    @_builtins.property
    @pulumi.getter(name="wikiPageMaxContentBytes")
    def wiki_page_max_content_bytes(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum wiki page content size in bytes. The minimum value is 1024 bytes.
        """
        return pulumi.get(self, "wiki_page_max_content_bytes")

